(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    494245,      14208]*)
(*NotebookOutlinePosition[    568977,      16718]*)
(*  CellTagsIndexPosition[    568933,      16714]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["\<\
Triple quantum dot - LINEAR CHAIN
Exact diagonalisation study: eigenvalue spectrum as a function of the gate \
voltage
Rok Zitko, rok.zitko@ijs.si, June, July, August 2005\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(<< "\<../sneg.m\>"\)], "Input"],

Cell[BoxData[
    \("sneg $Id: sneg.m,v 1.66 2006/07/14 10:43:56 rok Exp rok $"\)], "Print"],

Cell[BoxData[
    \("Copyright (C) 2006 Rok Zitko, rok.zitko@ijs.si"\)], "Print"],

Cell[BoxData[
    \("sneg.m $Id: sneg.m,v 1.66 2006/07/14 10:43:56 rok Exp rok $ \
loaded"\)], "Output"]
}, Open  ]],

Cell[BoxData[{
    \(<< Graphics`Colors`\), "\[IndentingNewLine]", 
    \(<< Graphics`MultipleListPlot`\)}], "Input"],

Cell[BoxData[{
    \(\(Off[General::spell1];\)\), "\[IndentingNewLine]", 
    \(\(Off[General::spell];\)\), "\[IndentingNewLine]", 
    \(ClearAll[a, b, c, e, o, f]\)}], "Input"],

Cell[BoxData[
    \(<< Utilities`Notation`\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"(", 
        RowBox[{
          RowBox[{"Notation", "[", 
            RowBox[{
              TagBox[\(f\_\(\(i_\)\(\[UpArrow]\)\)\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"], " ", 
              "\[DoubleLongLeftRightArrow]", " ", 
              TagBox[\(f[1, i_, 1]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"]}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"Notation", "[", 
            RowBox[{
              TagBox[\(f\_\(\(i_\)\(\[DownArrow]\)\)\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"], " ", 
              "\[DoubleLongLeftRightArrow]", " ", 
              TagBox[\(f[1, i_, 0]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"]}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"Notation", "[", 
            RowBox[{
              TagBox[\(f\_\(\(i_\)\(\[UpArrow]\)\)\^\[Dagger]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"], " ", 
              "\[DoubleLongLeftRightArrow]", " ", 
              TagBox[\(f[0, i_, 1]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"]}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"Notation", "[", 
            RowBox[{
              TagBox[\(f\_\(\(i_\)\(\[DownArrow]\)\)\^\[Dagger]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"], " ", 
              "\[DoubleLongLeftRightArrow]", " ", 
              TagBox[\(f[0, i_, 0]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"]}], "]"}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"Notation", "[", 
            RowBox[{
              TagBox[\(b\_\[UpArrow]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"], " ", 
              "\[DoubleLongLeftRightArrow]", " ", 
              TagBox[\(b[1, 1]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"]}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"Notation", "[", 
            RowBox[{
              TagBox[\(b\_\[DownArrow]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"], " ", 
              "\[DoubleLongLeftRightArrow]", " ", 
              TagBox[\(b[1, 0]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"]}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"Notation", "[", 
            RowBox[{
              TagBox[\(b\_\[UpArrow]\^\[Dagger]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"], " ", 
              "\[DoubleLongLeftRightArrow]", " ", 
              TagBox[\(b[0, 1]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"]}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"Notation", "[", 
            RowBox[{
              TagBox[\(b\_\[DownArrow]\^\[Dagger]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"], " ", 
              "\[DoubleLongLeftRightArrow]", " ", 
              TagBox[\(b[0, 0]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"]}], "]"}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"Notation", "[", 
            RowBox[{
              TagBox[\(a\_\[UpArrow]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"], " ", 
              "\[DoubleLongLeftRightArrow]", " ", 
              TagBox[\(a[1, 1]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"]}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"Notation", "[", 
            RowBox[{
              TagBox[\(a\_\[DownArrow]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"], " ", 
              "\[DoubleLongLeftRightArrow]", " ", 
              TagBox[\(a[1, 0]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"]}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"Notation", "[", 
            RowBox[{
              TagBox[\(a\_\[UpArrow]\^\[Dagger]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"], " ", 
              "\[DoubleLongLeftRightArrow]", " ", 
              TagBox[\(a[0, 1]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"]}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"Notation", "[", 
            RowBox[{
              TagBox[\(a\_\[DownArrow]\^\[Dagger]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"], " ", 
              "\[DoubleLongLeftRightArrow]", " ", 
              TagBox[\(a[0, 0]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"]}], "]"}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"Notation", "[", 
            RowBox[{
              TagBox[\(c\_\[UpArrow]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"], " ", 
              "\[DoubleLongLeftRightArrow]", " ", 
              TagBox[\(c[1, 1]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"]}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"Notation", "[", 
            RowBox[{
              TagBox[\(c\_\[DownArrow]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"], " ", 
              "\[DoubleLongLeftRightArrow]", " ", 
              TagBox[\(c[1, 0]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"]}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"Notation", "[", 
            RowBox[{
              TagBox[\(c\_\[UpArrow]\^\[Dagger]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"], " ", 
              "\[DoubleLongLeftRightArrow]", " ", 
              TagBox[\(c[0, 1]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"]}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"Notation", "[", 
            RowBox[{
              TagBox[\(c\_\[DownArrow]\^\[Dagger]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"], " ", 
              "\[DoubleLongLeftRightArrow]", " ", 
              TagBox[\(c[0, 0]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"]}], "]"}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"Notation", "[", 
            RowBox[{
              TagBox[\(e\_\[UpArrow]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"], " ", 
              "\[DoubleLongLeftRightArrow]", " ", 
              TagBox[\(e[1, 1]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"]}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"Notation", "[", 
            RowBox[{
              TagBox[\(e\_\[DownArrow]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"], " ", 
              "\[DoubleLongLeftRightArrow]", " ", 
              TagBox[\(e[1, 0]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"]}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"Notation", "[", 
            RowBox[{
              TagBox[\(e\_\[UpArrow]\^\[Dagger]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"], " ", 
              "\[DoubleLongLeftRightArrow]", " ", 
              TagBox[\(e[0, 1]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"]}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"Notation", "[", 
            RowBox[{
              TagBox[\(e\_\[DownArrow]\^\[Dagger]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"], " ", 
              "\[DoubleLongLeftRightArrow]", " ", 
              TagBox[\(e[0, 0]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"]}], "]"}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"Notation", "[", 
            RowBox[{
              TagBox[\(o\_\[UpArrow]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"], " ", 
              "\[DoubleLongLeftRightArrow]", " ", 
              TagBox[\(o[1, 1]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"]}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"Notation", "[", 
            RowBox[{
              TagBox[\(o\_\[DownArrow]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"], " ", 
              "\[DoubleLongLeftRightArrow]", " ", 
              TagBox[\(o[1, 0]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"]}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"Notation", "[", 
            RowBox[{
              TagBox[\(o\_\[UpArrow]\^\[Dagger]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"], " ", 
              "\[DoubleLongLeftRightArrow]", " ", 
              TagBox[\(o[0, 1]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"]}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"Notation", "[", 
            RowBox[{
              TagBox[\(o\_\[DownArrow]\^\[Dagger]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"], " ", 
              "\[DoubleLongLeftRightArrow]", " ", 
              TagBox[\(o[0, 0]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"]}], "]"}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"InfixNotation", "[", 
            RowBox[{
              TagBox["\[CenterDot]",
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"], ",", "nc"}], "]"}], ";"}],
         ")"}], ";"}]], "Input"],

Cell[BoxData[{
    \(snegfermionoperators[a, b, c, f, e, o]\), "\[IndentingNewLine]", 
    \(snegrealconstants[t, tab, 
      U, \[Delta], \[Delta]a, \[Delta]b, \[Delta]c]\)}], "Input"],

Cell["Hamiltonian definition", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Ha = \[Delta]a \((\ number[a[]] - 1)\)\  + 
        U/2  pow[\ number[a[]] - 1, 2]\), "\[IndentingNewLine]", 
    \(Hb = \[Delta]b \((\ number[b[]] - 1)\)\  + 
        U/2  pow[\ number[b[]] - 1, 2]\), "\[IndentingNewLine]", 
    \(Hc = \[Delta]c \((\ number[c[]] - 1)\)\  + 
        U/2  pow[\ number[c[]] - 1, 2]\), "\[IndentingNewLine]", 
    \(H1 = \(-tx\)\ hop[a[], f[1]]\), "\[IndentingNewLine]", 
    \(H2 = \(-tx\)\ hop[c[], f[2]]\), "\[IndentingNewLine]", 
    \(Habc = t\ hop[a[], b[]] + t\ hop[b[], c[]]\), "\[IndentingNewLine]", 
    \(H = H1 + H2 + Ha + Hb + Hc + Habc // Expand\)}], "Input"],

Cell[BoxData[
    \(\[Delta]a\ \((\(-1\) + \(a\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(a\_\
\[DownArrow]\) + \(a\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(a\_\[UpArrow]\))\) \
+ 1\/2\ U\ \((1 - \(a\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(a\_\[DownArrow]\
\) - \(a\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(a\_\[UpArrow]\) - 
            2\ \(a\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(a\_\[UpArrow]\)\^\
\[Dagger]\[CenterDot]\(a\_\[DownArrow]\)\[CenterDot]\(a\_\[UpArrow]\))\)\)], \
"Output"],

Cell[BoxData[
    \(\[Delta]b\ \((\(-1\) + \(b\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(b\_\
\[DownArrow]\) + \(b\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(b\_\[UpArrow]\))\) \
+ 1\/2\ U\ \((1 - \(b\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(b\_\[DownArrow]\
\) - \(b\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(b\_\[UpArrow]\) - 
            2\ \(b\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(b\_\[UpArrow]\)\^\
\[Dagger]\[CenterDot]\(b\_\[DownArrow]\)\[CenterDot]\(b\_\[UpArrow]\))\)\)], \
"Output"],

Cell[BoxData[
    \(\[Delta]c\ \((\(-1\) + \(c\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(c\_\
\[DownArrow]\) + \(c\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(c\_\[UpArrow]\))\) \
+ 1\/2\ U\ \((1 - \(c\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(c\_\[DownArrow]\
\) - \(c\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(c\_\[UpArrow]\) - 
            2\ \(c\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(c\_\[UpArrow]\)\^\
\[Dagger]\[CenterDot]\(c\_\[DownArrow]\)\[CenterDot]\(c\_\[UpArrow]\))\)\)], \
"Output"],

Cell[BoxData[
    \(\(-tx\)\ \((\(a\_\[DownArrow]\)\^\[Dagger]\[CenterDot]
            f\_\(\(1\)\(\[DownArrow]\)\) + \(a\_\[UpArrow]\)\^\[Dagger]\
\[CenterDot]f\_\(\(1\)\(\[UpArrow]\)\) + 
          f\_\(\(1\)\(\[DownArrow]\)\)\^\[Dagger]\[CenterDot]\(a\_\[DownArrow]\
\) + f\_\(\(1\)\(\[UpArrow]\)\)\^\[Dagger]\[CenterDot]\(a\_\[UpArrow]\))\)\)],\
 "Output"],

Cell[BoxData[
    \(\(-tx\)\ \((\(c\_\[DownArrow]\)\^\[Dagger]\[CenterDot]
            f\_\(\(2\)\(\[DownArrow]\)\) + \(c\_\[UpArrow]\)\^\[Dagger]\
\[CenterDot]f\_\(\(2\)\(\[UpArrow]\)\) + 
          f\_\(\(2\)\(\[DownArrow]\)\)\^\[Dagger]\[CenterDot]\(c\_\[DownArrow]\
\) + f\_\(\(2\)\(\[UpArrow]\)\)\^\[Dagger]\[CenterDot]\(c\_\[UpArrow]\))\)\)],\
 "Output"],

Cell[BoxData[
    \(t\ \((\(a\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(b\_\[DownArrow]\) + \
\(a\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(b\_\[UpArrow]\) + \(b\_\[DownArrow]\
\)\^\[Dagger]\[CenterDot]\(a\_\[DownArrow]\) + \(b\_\[UpArrow]\)\^\[Dagger]\
\[CenterDot]\(a\_\[UpArrow]\))\) + 
      t\ \((\(b\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(c\_\[DownArrow]\) + \
\(b\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(c\_\[UpArrow]\) + \(c\_\[DownArrow]\
\)\^\[Dagger]\[CenterDot]\(b\_\[DownArrow]\) + \(c\_\[UpArrow]\)\^\[Dagger]\
\[CenterDot]\(b\_\[UpArrow]\))\)\)], "Output"],

Cell[BoxData[
    \(\(3\ U\)\/2 - \[Delta]a - \[Delta]b - \[Delta]c - 
      1\/2\ U\ \(a\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(a\_\[DownArrow]\) \
+ \[Delta]a\ \(a\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(a\_\[DownArrow]\) + 
      t\ \(a\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(b\_\[DownArrow]\) - 
      tx\ \(a\_\[DownArrow]\)\^\[Dagger]\[CenterDot]
          f\_\(\(1\)\(\[DownArrow]\)\) - 
      1\/2\ U\ \(a\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(a\_\[UpArrow]\) + \
\[Delta]a\ \(a\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(a\_\[UpArrow]\) + 
      t\ \(a\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(b\_\[UpArrow]\) - 
      tx\ \(a\_\[UpArrow]\)\^\[Dagger]\[CenterDot]
          f\_\(\(1\)\(\[UpArrow]\)\) + 
      t\ \(b\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(a\_\[DownArrow]\) - 
      1\/2\ U\ \(b\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(b\_\[DownArrow]\) \
+ \[Delta]b\ \(b\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(b\_\[DownArrow]\) + 
      t\ \(b\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(c\_\[DownArrow]\) + 
      t\ \(b\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(a\_\[UpArrow]\) - 
      1\/2\ U\ \(b\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(b\_\[UpArrow]\) + \
\[Delta]b\ \(b\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(b\_\[UpArrow]\) + 
      t\ \(b\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(c\_\[UpArrow]\) + 
      t\ \(c\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(b\_\[DownArrow]\) - 
      1\/2\ U\ \(c\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(c\_\[DownArrow]\) \
+ \[Delta]c\ \(c\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(c\_\[DownArrow]\) - 
      tx\ \(c\_\[DownArrow]\)\^\[Dagger]\[CenterDot]
          f\_\(\(2\)\(\[DownArrow]\)\) + 
      t\ \(c\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(b\_\[UpArrow]\) - 
      1\/2\ U\ \(c\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(c\_\[UpArrow]\) + \
\[Delta]c\ \(c\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(c\_\[UpArrow]\) - 
      tx\ \(c\_\[UpArrow]\)\^\[Dagger]\[CenterDot]
          f\_\(\(2\)\(\[UpArrow]\)\) - 
      tx\ f\_\(\(1\)\(\[DownArrow]\)\)\^\[Dagger]\[CenterDot]\(a\_\[DownArrow]\
\) - tx\ f\_\(\(1\)\(\[UpArrow]\)\)\^\[Dagger]\[CenterDot]\(a\_\[UpArrow]\) - 
      tx\ \
f\_\(\(2\)\(\[DownArrow]\)\)\^\[Dagger]\[CenterDot]\(c\_\[DownArrow]\) - 
      tx\ f\_\(\(2\)\(\[UpArrow]\)\)\^\[Dagger]\[CenterDot]\(c\_\[UpArrow]\) \
- U\ \(a\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(a\_\[UpArrow]\)\^\[Dagger]\
\[CenterDot]\(a\_\[DownArrow]\)\[CenterDot]\(a\_\[UpArrow]\) - 
      U\ \(b\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(b\_\[UpArrow]\)\^\
\[Dagger]\[CenterDot]\(b\_\[DownArrow]\)\[CenterDot]\(b\_\[UpArrow]\) - 
      U\ \(c\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(c\_\[UpArrow]\)\^\
\[Dagger]\[CenterDot]\(c\_\[DownArrow]\)\[CenterDot]\(c\_\[UpArrow]\)\)], \
"Output"]
}, Open  ]],

Cell["\<\
Transformation to even and odd combination of conduction band \
orbitals\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Heo = 
      H /. {f[i_, 1, 
                j_] \[Rule] \(1\/\@2\) \((e[i, j] + 
                    o[i, j])\), \[IndentingNewLine]f[i_, 2, 
                j_] \[Rule] \(1\/\@2\) \((e[i, j] - o[i, j])\)} // 
        Expand\)], "Input"],

Cell[BoxData[
    \(\(3\ U\)\/2 - \[Delta]a - \[Delta]b - \[Delta]c - 
      1\/2\ U\ \(a\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(a\_\[DownArrow]\) \
+ \[Delta]a\ \(a\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(a\_\[DownArrow]\) + 
      t\ \(a\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(b\_\[DownArrow]\) - \(tx\
\ \(a\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(e\_\[DownArrow]\)\)\/\@2 - \(tx\
\ \(a\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(o\_\[DownArrow]\)\)\/\@2 - 
      1\/2\ U\ \(a\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(a\_\[UpArrow]\) + \
\[Delta]a\ \(a\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(a\_\[UpArrow]\) + 
      t\ \(a\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(b\_\[UpArrow]\) - \(tx\ \
\(a\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(e\_\[UpArrow]\)\)\/\@2 - \(tx\ \
\(a\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(o\_\[UpArrow]\)\)\/\@2 + 
      t\ \(b\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(a\_\[DownArrow]\) - 
      1\/2\ U\ \(b\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(b\_\[DownArrow]\) \
+ \[Delta]b\ \(b\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(b\_\[DownArrow]\) + 
      t\ \(b\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(c\_\[DownArrow]\) + 
      t\ \(b\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(a\_\[UpArrow]\) - 
      1\/2\ U\ \(b\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(b\_\[UpArrow]\) + \
\[Delta]b\ \(b\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(b\_\[UpArrow]\) + 
      t\ \(b\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(c\_\[UpArrow]\) + 
      t\ \(c\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(b\_\[DownArrow]\) - 
      1\/2\ U\ \(c\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(c\_\[DownArrow]\) \
+ \[Delta]c\ \(c\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(c\_\[DownArrow]\) - \
\(tx\ \(c\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(e\_\[DownArrow]\)\)\/\@2 + \
\(tx\ \(c\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(o\_\[DownArrow]\)\)\/\@2 + 
      t\ \(c\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(b\_\[UpArrow]\) - 
      1\/2\ U\ \(c\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(c\_\[UpArrow]\) + \
\[Delta]c\ \(c\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(c\_\[UpArrow]\) - \(tx\ \
\(c\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(e\_\[UpArrow]\)\)\/\@2 + \(tx\ \
\(c\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(o\_\[UpArrow]\)\)\/\@2 - \(tx\ \
\(e\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(a\_\[DownArrow]\)\)\/\@2 - \(tx\ \
\(e\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(c\_\[DownArrow]\)\)\/\@2 - \(tx\ \
\(e\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(a\_\[UpArrow]\)\)\/\@2 - \(tx\ \
\(e\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(c\_\[UpArrow]\)\)\/\@2 - \(tx\ \
\(o\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(a\_\[DownArrow]\)\)\/\@2 + \(tx\ \
\(o\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(c\_\[DownArrow]\)\)\/\@2 - \(tx\ \
\(o\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(a\_\[UpArrow]\)\)\/\@2 + \(tx\ \
\(o\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(c\_\[UpArrow]\)\)\/\@2 - 
      U\ \(a\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(a\_\[UpArrow]\)\^\
\[Dagger]\[CenterDot]\(a\_\[DownArrow]\)\[CenterDot]\(a\_\[UpArrow]\) - 
      U\ \(b\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(b\_\[UpArrow]\)\^\
\[Dagger]\[CenterDot]\(b\_\[DownArrow]\)\[CenterDot]\(b\_\[UpArrow]\) - 
      U\ \(c\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(c\_\[UpArrow]\)\^\
\[Dagger]\[CenterDot]\(c\_\[DownArrow]\)\[CenterDot]\(c\_\[UpArrow]\)\)], \
"Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\( (*\ Isolated, \ 
      symmetric\ tqd\ *) \)\(\[IndentingNewLine]\)\(\(Huse = 
        Heo /. {\[Delta]a \[Rule] \[Delta], \[Delta]b \[Rule] \[Delta], \
\[Delta]c \[Rule] \[Delta], tab \[Rule] t};\)\[IndentingNewLine]
    H0 = Huse /. {tx \[Rule] 0, 
          tx \[Rule] 0}\[IndentingNewLine]\[IndentingNewLine] (*\ 
      Coupling\ term\ *) \[IndentingNewLine]
    H1 = Huse - H0\[IndentingNewLine]
    FullSimplify[H1]\)\)\)], "Input"],

Cell[BoxData[
    \(\(3\ U\)\/2 - 3\ \[Delta] - 
      1\/2\ U\ \(a\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(a\_\[DownArrow]\) \
+ \[Delta]\ \(a\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(a\_\[DownArrow]\) + 
      t\ \(a\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(b\_\[DownArrow]\) - 
      1\/2\ U\ \(a\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(a\_\[UpArrow]\) + \
\[Delta]\ \(a\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(a\_\[UpArrow]\) + 
      t\ \(a\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(b\_\[UpArrow]\) + 
      t\ \(b\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(a\_\[DownArrow]\) - 
      1\/2\ U\ \(b\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(b\_\[DownArrow]\) \
+ \[Delta]\ \(b\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(b\_\[DownArrow]\) + 
      t\ \(b\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(c\_\[DownArrow]\) + 
      t\ \(b\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(a\_\[UpArrow]\) - 
      1\/2\ U\ \(b\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(b\_\[UpArrow]\) + \
\[Delta]\ \(b\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(b\_\[UpArrow]\) + 
      t\ \(b\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(c\_\[UpArrow]\) + 
      t\ \(c\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(b\_\[DownArrow]\) - 
      1\/2\ U\ \(c\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(c\_\[DownArrow]\) \
+ \[Delta]\ \(c\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(c\_\[DownArrow]\) + 
      t\ \(c\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(b\_\[UpArrow]\) - 
      1\/2\ U\ \(c\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(c\_\[UpArrow]\) + \
\[Delta]\ \(c\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(c\_\[UpArrow]\) - 
      U\ \(a\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(a\_\[UpArrow]\)\^\
\[Dagger]\[CenterDot]\(a\_\[DownArrow]\)\[CenterDot]\(a\_\[UpArrow]\) - 
      U\ \(b\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(b\_\[UpArrow]\)\^\
\[Dagger]\[CenterDot]\(b\_\[DownArrow]\)\[CenterDot]\(b\_\[UpArrow]\) - 
      U\ \(c\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(c\_\[UpArrow]\)\^\
\[Dagger]\[CenterDot]\(c\_\[DownArrow]\)\[CenterDot]\(c\_\[UpArrow]\)\)], \
"Output"],

Cell[BoxData[
    \(\(-\(\(tx\ \
\(a\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(e\_\[DownArrow]\)\)\/\@2\)\) - \
\(tx\ \(a\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(o\_\[DownArrow]\)\)\/\@2 - \
\(tx\ \(a\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(e\_\[UpArrow]\)\)\/\@2 - \(tx\
\ \(a\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(o\_\[UpArrow]\)\)\/\@2 - \(tx\ \
\(c\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(e\_\[DownArrow]\)\)\/\@2 + \(tx\ \
\(c\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(o\_\[DownArrow]\)\)\/\@2 - \(tx\ \
\(c\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(e\_\[UpArrow]\)\)\/\@2 + \(tx\ \
\(c\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(o\_\[UpArrow]\)\)\/\@2 - \(tx\ \
\(e\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(a\_\[DownArrow]\)\)\/\@2 - \(tx\ \
\(e\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(c\_\[DownArrow]\)\)\/\@2 - \(tx\ \
\(e\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(a\_\[UpArrow]\)\)\/\@2 - \(tx\ \
\(e\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(c\_\[UpArrow]\)\)\/\@2 - \(tx\ \
\(o\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(a\_\[DownArrow]\)\)\/\@2 + \(tx\ \
\(o\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(c\_\[DownArrow]\)\)\/\@2 - \(tx\ \
\(o\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(a\_\[UpArrow]\)\)\/\@2 + \(tx\ \
\(o\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(c\_\[UpArrow]\)\)\/\@2\)], "Output"],

Cell[BoxData[
    \(\(-\(\(1\/\@2\)\((tx\ \
\((\(a\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(e\_\[DownArrow]\) + \(a\_\
\[DownArrow]\)\^\[Dagger]\[CenterDot]\(o\_\[DownArrow]\) + \
\(a\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(e\_\[UpArrow]\) + \(a\_\[UpArrow]\)\
\^\[Dagger]\[CenterDot]\(o\_\[UpArrow]\) + \(c\_\[DownArrow]\)\^\[Dagger]\
\[CenterDot]\(e\_\[DownArrow]\) - \
\(c\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(o\_\[DownArrow]\) + \(c\_\
\[UpArrow]\)\^\[Dagger]\[CenterDot]\(e\_\[UpArrow]\) - \(c\_\[UpArrow]\)\^\
\[Dagger]\[CenterDot]\(o\_\[UpArrow]\) + \(e\_\[DownArrow]\)\^\[Dagger]\
\[CenterDot]\(a\_\[DownArrow]\) + \
\(e\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(c\_\[DownArrow]\) + \(e\_\
\[UpArrow]\)\^\[Dagger]\[CenterDot]\(a\_\[UpArrow]\) + \(e\_\[UpArrow]\)\^\
\[Dagger]\[CenterDot]\(c\_\[UpArrow]\) + \(o\_\[DownArrow]\)\^\[Dagger]\
\[CenterDot]\(a\_\[DownArrow]\) - \
\(o\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(c\_\[DownArrow]\) + \(o\_\
\[UpArrow]\)\^\[Dagger]\[CenterDot]\(a\_\[UpArrow]\) - \(o\_\[UpArrow]\)\^\
\[Dagger]\[CenterDot]\(c\_\[UpArrow]\))\))\)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\( (*\ 
      Definition\ of\ \((Q, 
          S)\)\ basis\ states\ *) \)\(\[IndentingNewLine]\)\(\(basisops = \
{a[], b[], c[]};\)\[IndentingNewLine]
    makebasis[basisops]\[IndentingNewLine]
    \(vak\  = \ vacuum[];\)\[IndentingNewLine]
    bz = qsbasis[basisops]; bz // MatrixForm\[IndentingNewLine]
    Scan[\((baza[\ #[\([1]\)]\ ]\  = \ #[\([2]\)])\) &, 
      bz]\[IndentingNewLine]
    bvc = Map[{#[\([1]\)], ap[#[\([2]\)], vak]} &, bz]; 
    bvc // MatrixForm\[IndentingNewLine]
    Scan[\((bazavc[\ #[\([1]\)]\ ] = #[\([2]\)])\) &, bvc]\[IndentingNewLine]
    \(baza[q, s]\  := \ baza[{q, s}];\)\[IndentingNewLine]
    \(dim[{q_, s_}] := Length[baza[{q, s}]];\)\[IndentingNewLine]
    subspaces = bz[\([All, 1]\)]\[IndentingNewLine]
    nrsub = Length[subspaces]\)\)\)], "Input"],

Cell[BoxData[
    \({\(a\_\[UpArrow]\)\^\[Dagger], \(a\_\[DownArrow]\)\^\[Dagger], \(b\_\
\[UpArrow]\)\^\[Dagger], \(b\_\[DownArrow]\)\^\[Dagger], \(c\_\[UpArrow]\)\^\
\[Dagger], \(c\_\[DownArrow]\)\^\[Dagger]}\)], "Output"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\({\(-3\), 0}\), \({1}\)},
            {\({\(-2\), 
                1\/2}\), \({\(c\_\[UpArrow]\)\^\[Dagger], \(b\_\[UpArrow]\)\^\
\[Dagger], \(a\_\[UpArrow]\)\^\[Dagger]}\)},
            {\({\(-1\), 
                0}\), \({\(c\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(c\_\
\[UpArrow]\)\^\[Dagger], \(\(b\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(c\_\
\[UpArrow]\)\^\[Dagger]\)\/\@2 - \
\(\(b\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(c\_\[DownArrow]\)\^\[Dagger]\)\/\@\
2, \(\(a\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(c\_\[UpArrow]\)\^\[Dagger]\)\
\/\@2 - \(\(a\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(c\_\[DownArrow]\)\^\
\[Dagger]\)\/\@2, \(b\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(b\_\[UpArrow]\)\
\^\[Dagger], \(\(a\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(b\_\[UpArrow]\)\^\
\[Dagger]\)\/\@2 - \
\(\(a\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(b\_\[DownArrow]\)\^\[Dagger]\)\/\@\
2, \(a\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(a\_\[UpArrow]\)\^\[Dagger]}\)},\

            {\({\(-1\), 
                1}\), \({\(-\((\(b\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(c\_\
\[UpArrow]\)\^\[Dagger])\)\), \
\(-\((\(a\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(c\_\[UpArrow]\)\^\[Dagger])\)\
\), \(-\((\(a\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(b\_\[UpArrow]\)\^\[Dagger]\
)\)\)}\)},
            {\({0, 
                1\/2}\), \({\(b\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(c\_\
\[DownArrow]\)\^\[Dagger]\[CenterDot]\(c\_\[UpArrow]\)\^\[Dagger], \(a\_\
\[UpArrow]\)\^\[Dagger]\[CenterDot]\(c\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\
\(c\_\[UpArrow]\)\^\[Dagger], \(b\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(b\_\
\[UpArrow]\)\^\[Dagger]\[CenterDot]\(c\_\[UpArrow]\)\^\[Dagger], \(\(a\_\
\[DownArrow]\)\^\[Dagger]\[CenterDot]\(b\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\
\(c\_\[UpArrow]\)\^\[Dagger]\)\/\@2 - \(\(a\_\[UpArrow]\)\^\[Dagger]\
\[CenterDot]\(b\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(c\_\[UpArrow]\)\^\
\[Dagger]\)\/\@2, \(a\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(a\_\[UpArrow]\)\
\^\[Dagger]\[CenterDot]\(c\_\[UpArrow]\)\^\[Dagger], \(-\(\(\(-\((\(a\_\
\[DownArrow]\)\^\[Dagger]\[CenterDot]\(b\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\
\(c\_\[UpArrow]\)\^\[Dagger])\)\) - \
\(a\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(b\_\[DownArrow]\)\^\[Dagger]\
\[CenterDot]\(c\_\[UpArrow]\)\^\[Dagger]\)\/\@6\)\) - \@\(2\/3\)\ \(a\_\
\[UpArrow]\)\^\[Dagger]\[CenterDot]\(b\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(\
c\_\[DownArrow]\)\^\[Dagger], \(a\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(b\_\
\[DownArrow]\)\^\[Dagger]\[CenterDot]\(b\_\[UpArrow]\)\^\[Dagger], \(a\_\
\[DownArrow]\)\^\[Dagger]\[CenterDot]\(a\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\
\(b\_\[UpArrow]\)\^\[Dagger]}\)},
            {\({0, 
                3\/2}\), \({\(-\((\(a\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(b\
\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(c\_\[UpArrow]\)\^\[Dagger])\)\)}\)},
            {\({1, 
                0}\), \({\(b\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(b\_\
\[UpArrow]\)\^\[Dagger]\[CenterDot]\(c\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\
\(c\_\[UpArrow]\)\^\[Dagger], \(\(a\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(b\
\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(c\_\[DownArrow]\)\^\[Dagger]\
\[CenterDot]\(c\_\[UpArrow]\)\^\[Dagger]\)\/\@2 - \(\(a\_\[UpArrow]\)\^\
\[Dagger]\[CenterDot]\(b\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(c\_\
\[DownArrow]\)\^\[Dagger]\[CenterDot]\(c\_\[UpArrow]\)\^\[Dagger]\)\/\@2, \(a\
\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(a\_\[UpArrow]\)\^\[Dagger]\
\[CenterDot]\(c\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(c\_\[UpArrow]\)\^\
\[Dagger], \(\(a\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(b\_\[DownArrow]\)\^\
\[Dagger]\[CenterDot]\(b\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(c\_\[UpArrow]\)\
\^\[Dagger]\)\/\@2 - \(\(a\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(b\_\
\[DownArrow]\)\^\[Dagger]\[CenterDot]\(b\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\
\(c\_\[DownArrow]\)\^\[Dagger]\)\/\@2, \(\(a\_\[DownArrow]\)\^\[Dagger]\
\[CenterDot]\(a\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(b\_\[DownArrow]\)\^\
\[Dagger]\[CenterDot]\(c\_\[UpArrow]\)\^\[Dagger]\)\/\@2 - \
\(\(a\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(a\_\[UpArrow]\)\^\[Dagger]\
\[CenterDot]\(b\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(c\_\[DownArrow]\)\^\
\[Dagger]\)\/\@2, \(a\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(a\_\[UpArrow]\)\
\^\[Dagger]\[CenterDot]\(b\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(b\_\
\[UpArrow]\)\^\[Dagger]}\)},
            {\({1, 
                1}\), \({\(-\((\(a\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(b\_\
\[UpArrow]\)\^\[Dagger]\[CenterDot]\(c\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\
\(c\_\[UpArrow]\)\^\[Dagger])\)\), \(-\((\(a\_\[UpArrow]\)\^\[Dagger]\
\[CenterDot]\(b\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(b\_\[UpArrow]\)\^\
\[Dagger]\[CenterDot]\(c\_\[UpArrow]\)\^\[Dagger])\)\), \(-\((\(a\_\
\[DownArrow]\)\^\[Dagger]\[CenterDot]\(a\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\
\(b\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(c\_\[UpArrow]\)\^\[Dagger])\)\)}\)},\

            {\({2, 
                1\/2}\), \({\(a\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(b\_\
\[DownArrow]\)\^\[Dagger]\[CenterDot]\(b\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\
\(c\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(c\_\[UpArrow]\)\^\[Dagger], \(a\_\
\[DownArrow]\)\^\[Dagger]\[CenterDot]\(a\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\
\(b\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(c\_\[DownArrow]\)\^\[Dagger]\
\[CenterDot]\(c\_\[UpArrow]\)\^\[Dagger], \(a\_\[DownArrow]\)\^\[Dagger]\
\[CenterDot]\(a\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(b\_\[DownArrow]\)\^\
\[Dagger]\[CenterDot]\(b\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(c\_\[UpArrow]\)\
\^\[Dagger]}\)},
            {\({3, 
                0}\), \({\(a\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\(a\_\
\[UpArrow]\)\^\[Dagger]\[CenterDot]\(b\_\[DownArrow]\)\^\[Dagger]\[CenterDot]\
\(b\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(c\_\[DownArrow]\)\^\[Dagger]\
\[CenterDot]\(c\_\[UpArrow]\)\^\[Dagger]}\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\({\(-3\), 0}\), \({vc[0, 0, 0, 0, 0, 0]}\)},
            {\({\(-2\), 1\/2}\), \({vc[0, 0, 0, 0, 1, 0], 
                vc[0, 0, 1, 0, 0, 0], vc[1, 0, 0, 0, 0, 0]}\)},
            {\({\(-1\), 0}\), \({\(-vc[0, 0, 0, 0, 1, 1]\), 
                vc[0, 0, 0, 1, 1, 0]\/\@2 - vc[0, 0, 1, 0, 0, 1]\/\@2, 
                vc[0, 1, 0, 0, 1, 0]\/\@2 - 
                  vc[1, 0, 0, 0, 0, 1]\/\@2, \(-vc[0, 0, 1, 1, 0, 0]\), 
                vc[0, 1, 1, 0, 0, 0]\/\@2 - 
                  vc[1, 0, 0, 1, 0, 0]\/\@2, \(-vc[1, 1, 0, 0, 0, 0]\)}\)},
            {\({\(-1\), 
                1}\), \({\(-vc[0, 0, 1, 0, 1, 0]\), \(-vc[1, 0, 0, 0, 1, 
                    0]\), \(-vc[1, 0, 1, 0, 0, 0]\)}\)},
            {\({0, 
                1\/2}\), \({\(-vc[0, 0, 1, 0, 1, 1]\), \(-vc[1, 0, 0, 0, 1, 
                    1]\), \(-vc[0, 0, 1, 1, 1, 0]\), 
                vc[0, 1, 1, 0, 1, 0]\/\@2 - 
                  vc[1, 0, 0, 1, 1, 0]\/\@2, \(-vc[1, 1, 0, 0, 1, 
                    0]\), \(-\(\(\(-vc[0, 1, 1, 0, 1, 0]\) - 
                          vc[1, 0, 0, 1, 1, 0]\)\/\@6\)\) - \@\(2\/3\)\ vc[1, 
                      0, 1, 0, 0, 1], \(-vc[1, 0, 1, 1, 0, 0]\), \(-vc[1, 1, 
                    1, 0, 0, 0]\)}\)},
            {\({0, 3\/2}\), \({\(-vc[1, 0, 1, 0, 1, 0]\)}\)},
            {\({1, 
                0}\), \({vc[0, 0, 1, 1, 1, 
                  1], \(-\(vc[0, 1, 1, 0, 1, 1]\/\@2\)\) + 
                  vc[1, 0, 0, 1, 1, 1]\/\@2, 
                vc[1, 1, 0, 0, 1, 1], \(-\(vc[0, 1, 1, 1, 1, 0]\/\@2\)\) + 
                  vc[1, 0, 1, 1, 0, 1]\/\@2, \(-\(vc[1, 1, 0, 1, 1, 
                          0]\/\@2\)\) + vc[1, 1, 1, 0, 0, 1]\/\@2, 
                vc[1, 1, 1, 1, 0, 0]}\)},
            {\({1, 1}\), \({vc[1, 0, 1, 0, 1, 1], vc[1, 0, 1, 1, 1, 0], 
                vc[1, 1, 1, 0, 1, 0]}\)},
            {\({2, 1\/2}\), \({vc[1, 0, 1, 1, 1, 1], vc[1, 1, 1, 0, 1, 1], 
                vc[1, 1, 1, 1, 1, 0]}\)},
            {\({3, 0}\), \({\(-vc[1, 1, 1, 1, 1, 1]\)}\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"],

Cell[BoxData[
    \({{\(-3\), 0}, {\(-2\), 1\/2}, {\(-1\), 0}, {\(-1\), 1}, {0, 1\/2}, {0, 
        3\/2}, {1, 0}, {1, 1}, {2, 1\/2}, {3, 0}}\)], "Output"],

Cell[BoxData[
    \(10\)], "Output"]
}, Open  ]],

Cell[BoxData[{
    \(\(diagonalizerepl[i_, repl_, showvc_:  0] := 
        Module[{}, \[IndentingNewLine]subsp = 
            subspaces[\([i]\)]; \[IndentingNewLine]bb = 
            bazavc[subsp]; \[IndentingNewLine]h = 
            matrixrepresentationvc[H0, bb]; \[IndentingNewLine]h = 
            Simplify[h\  //. \ repl]; \[IndentingNewLine]Print[
            MatrixForm[h]]; \[IndentingNewLine]hh = 
            h //. {t \[Rule] T, \[Delta] \[Rule] delta, 
                U \[Rule] UU}; \[IndentingNewLine]es = 
            Eigensystem[hh]; \[IndentingNewLine]Print[
            es[\([1]\)]]; \[IndentingNewLine]stanja = 
            Table[es[\([2, j]\)] . bb, {j, dim[subsp]}] /. {TAB \[Rule] tab, 
                delta \[Rule] \[Delta], UU \[Rule] U, 
                deltaa \[Rule] \[Delta]a, 
                deltab \[Rule] \[Delta]b}; \[IndentingNewLine]xx = \
{es[\([1]\)], stanja // Simplify}; \[IndentingNewLine]If[showvc \[Equal] 1, 
            Print[xx]]; \[IndentingNewLine]xx\[IndentingNewLine]];\)\), "\
\[IndentingNewLine]", 
    \(\(diagonalize[i_] := diagonalizerepl[i, {}];\)\)}], "Input"],

Cell[BoxData[{
    \(\(myrule = {t \[Rule] \(-1\)/2, 
          U \[Rule] 1};\)\), "\[IndentingNewLine]", 
    \(\(mindelta = \(-1.5\);\)\), "\[IndentingNewLine]", 
    \(\(maxdelta = 1.5;\)\)}], "Input"],

Cell[BoxData[{
    \(\(legenda = {};\)\), "\[IndentingNewLine]", 
    \(ClearAll[genpl]\), "\[IndentingNewLine]", 
    \(\(genpl[i_, ps__] := 
        Module[{}, \[IndentingNewLine]st = 
            diagonalizerepl[i, myrule, 0]; \[IndentingNewLine]Print[
            st[\([1]\)] /. delta \[Rule] 0 // N]; \[IndentingNewLine]ps2 = 
            Table[{ps}, {Length[st[\([1]\)]]}]; \[IndentingNewLine]slika[i] = 
            Plot[Evaluate[st[\([1]\)]], {delta, mindelta, maxdelta}, 
              PlotStyle \[Rule] ps2]; \[IndentingNewLine]legenda = 
            Join[legenda, {Dashing[{}], Thickness[0.004], ps, 
                Line[{{0, i}, {1, i}}], 
                Text[subspaces[\([i]\)], {1.2, 
                    i}]}];\[IndentingNewLine]];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(genpl[1, {}]\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(3\/2 - 3\ \[Delta]\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Print"],

Cell[BoxData[
    \({\(-\(3\/2\)\)\ \((\(-1\) + 2\ delta)\)}\)], "Print"],

Cell[BoxData[
    \({1.5`}\)], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.31746 0.210916 0.0654004 [
[.02381 .19842 -12 -9 ]
[.02381 .19842 12 0 ]
[.18254 .19842 -6 -9 ]
[.18254 .19842 6 0 ]
[.34127 .19842 -12 -9 ]
[.34127 .19842 12 0 ]
[.65873 .19842 -9 -9 ]
[.65873 .19842 9 0 ]
[.81746 .19842 -3 -9 ]
[.81746 .19842 3 0 ]
[.97619 .19842 -9 -9 ]
[.97619 .19842 9 0 ]
[.4875 .08012 -12 -4.5 ]
[.4875 .08012 0 4.5 ]
[.4875 .34172 -6 -4.5 ]
[.4875 .34172 0 4.5 ]
[.4875 .47252 -6 -4.5 ]
[.4875 .47252 0 4.5 ]
[.4875 .60332 -6 -4.5 ]
[.4875 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .21092 m
.02381 .21717 L
s
[(-1.5)] .02381 .19842 0 1 Mshowa
.18254 .21092 m
.18254 .21717 L
s
[(-1)] .18254 .19842 0 1 Mshowa
.34127 .21092 m
.34127 .21717 L
s
[(-0.5)] .34127 .19842 0 1 Mshowa
.65873 .21092 m
.65873 .21717 L
s
[(0.5)] .65873 .19842 0 1 Mshowa
.81746 .21092 m
.81746 .21717 L
s
[(1)] .81746 .19842 0 1 Mshowa
.97619 .21092 m
.97619 .21717 L
s
[(1.5)] .97619 .19842 0 1 Mshowa
.125 Mabswid
.05556 .21092 m
.05556 .21467 L
s
.0873 .21092 m
.0873 .21467 L
s
.11905 .21092 m
.11905 .21467 L
s
.15079 .21092 m
.15079 .21467 L
s
.21429 .21092 m
.21429 .21467 L
s
.24603 .21092 m
.24603 .21467 L
s
.27778 .21092 m
.27778 .21467 L
s
.30952 .21092 m
.30952 .21467 L
s
.37302 .21092 m
.37302 .21467 L
s
.40476 .21092 m
.40476 .21467 L
s
.43651 .21092 m
.43651 .21467 L
s
.46825 .21092 m
.46825 .21467 L
s
.53175 .21092 m
.53175 .21467 L
s
.56349 .21092 m
.56349 .21467 L
s
.59524 .21092 m
.59524 .21467 L
s
.62698 .21092 m
.62698 .21467 L
s
.69048 .21092 m
.69048 .21467 L
s
.72222 .21092 m
.72222 .21467 L
s
.75397 .21092 m
.75397 .21467 L
s
.78571 .21092 m
.78571 .21467 L
s
.84921 .21092 m
.84921 .21467 L
s
.88095 .21092 m
.88095 .21467 L
s
.9127 .21092 m
.9127 .21467 L
s
.94444 .21092 m
.94444 .21467 L
s
.25 Mabswid
0 .21092 m
1 .21092 L
s
.5 .08012 m
.50625 .08012 L
s
[(-2)] .4875 .08012 1 0 Mshowa
.5 .34172 m
.50625 .34172 L
s
[(2)] .4875 .34172 1 0 Mshowa
.5 .47252 m
.50625 .47252 L
s
[(4)] .4875 .47252 1 0 Mshowa
.5 .60332 m
.50625 .60332 L
s
[(6)] .4875 .60332 1 0 Mshowa
.125 Mabswid
.5 .11282 m
.50375 .11282 L
s
.5 .14552 m
.50375 .14552 L
s
.5 .17822 m
.50375 .17822 L
s
.5 .24362 m
.50375 .24362 L
s
.5 .27632 m
.50375 .27632 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .37442 m
.50375 .37442 L
s
.5 .40712 m
.50375 .40712 L
s
.5 .43982 m
.50375 .43982 L
s
.5 .50522 m
.50375 .50522 L
s
.5 .53792 m
.50375 .53792 L
s
.5 .57062 m
.50375 .57062 L
s
.5 .04742 m
.50375 .04742 L
s
.5 .01472 m
.50375 .01472 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.06244 .57944 L
.10458 .5534 L
.14415 .52894 L
.18221 .50542 L
.22272 .48039 L
.26171 .45629 L
.30316 .43067 L
.34309 .406 L
.3815 .38225 L
.42237 .357 L
.46172 .33268 L
.49955 .30929 L
.53984 .2844 L
.57861 .26043 L
.61984 .23495 L
.65954 .21041 L
.69774 .18681 L
.73838 .16169 L
.77751 .13751 L
.81909 .11181 L
.85916 .08704 L
.89771 .06322 L
.93871 .03788 L
.97619 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo
0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<
0?ooo`00T@3oool2000008<0oooo00<000000?ooo`3oool01`3oool00940oooo00<000000?ooo`3o
ool0P03oool2000000X0oooo002A0?ooo`030000003oool0oooo07h0oooo0P00000<0?ooo`00T@3o
ool00`000000oooo0?ooo`1l0?ooo`8000003P3oool00940oooo00<000000?ooo`3oool0NP3oool2
00000100oooo002A0?ooo`030000003oool0oooo07P0oooo0P00000B0?ooo`00T@3oool00`000000
oooo0?ooo`1g0?ooo`030000003oool0oooo0180oooo002A0?ooo`030000003oool0oooo07D0oooo
0P00000E0?ooo`00T@3oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo01D0oooo002A
0?ooo`800000L`3oool2000001P0oooo002A0?ooo`030000003oool0oooo0700oooo0P00000J0?oo
o`00T@3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo01X0oooo002A0?ooo`030000
003oool0oooo06d0oooo0P00000M0?ooo`00T@3oool00`000000oooo0?ooo`1/0?ooo`030000003o
ool0oooo01d0oooo002A0?ooo`030000003oool0oooo06X0oooo0P00000P0?ooo`00T@3oool00`00
0000oooo0?ooo`1Y0?ooo`030000003oool0oooo0200oooo00280?ooo`@000001@3oool00`000000
oooo0?ooo`1W0?ooo`8000008`3oool008P0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`1U0?ooo`8000009@3oool008T0oooo00<000000?ooo`3oool01@3oool2000006D0oooo00<0
00000?ooo`3oool09@3oool00880oooo100000040?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0HP3oool2000002P0oooo002;0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0H@3oool00`000000oooo0?ooo`0X0?ooo`00R03oool010000000oooo0?ooo`0000050?oo
o`030000003oool0oooo05l0oooo0P00000[0?ooo`00R@3oool2000000H0oooo00<000000?ooo`3o
ool0GP3oool00`000000oooo0?ooo`0[0?ooo`00T@3oool00`000000oooo0?ooo`1L0?ooo`800000
;P3oool00940oooo00<000000?ooo`3oool0FP3oool200000300oooo002A0?ooo`030000003oool0
oooo05T0oooo00<000000?ooo`3oool0<03oool00940oooo00<000000?ooo`3oool0E`3oool20000
03<0oooo002A0?ooo`800000E`3oool00`000000oooo0?ooo`0c0?ooo`00T@3oool00`000000oooo
0?ooo`1D0?ooo`800000=P3oool00940oooo00<000000?ooo`3oool0DP3oool2000003P0oooo002A
0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0>03oool00940oooo00<000000?oo
o`3oool0C`3oool2000003/0oooo002A0?ooo`030000003oool0oooo04d0oooo0P00000m0?ooo`00
T@3oool00`000000oooo0?ooo`1;0?ooo`800000?`3oool00940oooo00<000000?ooo`3oool0BP3o
ool00`000000oooo0?ooo`0o0?ooo`00T@3oool00`000000oooo0?ooo`180?ooo`800000@P3oool0
0940oooo0P0000180?ooo`030000003oool0oooo0480oooo002A0?ooo`030000003oool0oooo04D0
oooo0P0000150?ooo`00T@3oool00`000000oooo0?ooo`130?ooo`800000A`3oool00940oooo00<0
00000?ooo`3oool0@P3oool00`000000oooo0?ooo`170?ooo`00T@3oool00`000000oooo0?ooo`10
0?ooo`800000BP3oool00940oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`1:0?oo
o`00T@3oool00`000000oooo0?ooo`0m0?ooo`800000C@3oool00940oooo00<000000?ooo`3oool0
?03oool00`000000oooo0?ooo`1=0?ooo`001`3oool4000000<0oooo00<000000?ooo`3oool00P3o
ool3000002<0oooo1000000S0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`<000008`3o
ool00`000000oooo0?ooo`0R0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`<000002P3o
ool2000001L0oooo1000000S0?ooo`@000000`3oool00`000000oooo0?ooo`020?ooo`<000000`3o
ool000T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0
oooo0240oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`0P0?ooo`8000008P3o
ool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo00D0oooo0P00000K0?ooo`030000
003oool0oooo02@0oooo00<000000?ooo`3oool02P3oool100000040oooo0@3oool000T0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0240oooo00@0
00000?ooo`3oool000002`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0240oooo
00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0:0?ooo`4000000@3oool10?ooo`00
00<0oooo0000000000000P0000040?ooo`030000003oool0oooo00L0oooo0`00000M0?ooo`@00000
103oool00`000000oooo0?ooo`0K0?ooo`@000000P3oool010000000oooo0?ooo`0000080?ooo`<0
00008`3oool00`000000oooo0?ooo`0Q0?ooo`040000003oool0oooo000000P0oooo0`0000050?oo
o`8000007P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00L0oooo0`0000030?oo
o`002@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool08@3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo02<0oooo00<000000?oo
o`3oool08@3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool00`3oool000L0oooo0`0000090?ooo`030000003oool0oooo02<0oooo0`00000S0?oo
o`040000003oool0oooo000000P0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0Q
0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool00P3oool2000001l0oooo0`00
000T0?ooo`<000002@3oool00`000000oooo0?ooo`030?ooo`002@3oool00`000000oooo0?ooo`07
0?ooo`@00000903oool00`000000oooo0?ooo`0R0?ooo`8000002@3oool400000280oooo00<00000
0?ooo`3oool08P3oool2000000T0oooo1@00000S0?ooo`030000003oool0oooo02@0oooo00<00000
0?ooo`3oool01`3oool400000080oooo002A0?ooo`030000003oool0oooo02h0oooo0P00001L0?oo
o`00T@3oool00`000000oooo0?ooo`0/0?ooo`800000GP3oool00940oooo00<000000?ooo`3oool0
:P3oool200000600oooo00050?ooool000006@0000030?ooo`00303oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00@0oooo0`0000080?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo000<0?oo
o`030000003oool0oooo02T0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0Z0?oo
o`030000003oool0oooo02H0oooo00@000000?ooo`3oool00000:`3oool00`000000oooo0?ooo`0Z
0?ooo`030000003oool0oooo00L0oooo002A0?ooo`030000003oool0oooo02@0oooo0P00001V0?oo
o`00T@3oool00`000000oooo0?ooo`0R0?ooo`800000J03oool00940oooo00<000000?ooo`3oool0
8@3oool00`000000oooo0?ooo`1X0?ooo`00T@3oool00`000000oooo0?ooo`0O0?ooo`800000J`3o
ool00940oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1[0?ooo`00T@3oool00`00
0000oooo0?ooo`0L0?ooo`800000KP3oool00940oooo00<000000?ooo`3oool06P3oool200000700
oooo002A0?ooo`8000006P3oool00`000000oooo0?ooo`1`0?ooo`00T@3oool00`000000oooo0?oo
o`0G0?ooo`800000L`3oool00940oooo00<000000?ooo`3oool05@3oool2000007D0oooo002A0?oo
o`030000003oool0oooo01<0oooo0P00001g0?ooo`00T@3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo07L0oooo002A0?ooo`030000003oool0oooo0100oooo0P00001j0?ooo`00T@3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo07X0oooo002A0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool0N`3oool00940oooo00<000000?ooo`3oool0303oool20000
07h0oooo002A0?ooo`800000303oool00`000000oooo0?ooo`1n0?ooo`00T@3oool00`000000oooo
0?ooo`090?ooo`800000P@3oool00940oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`210?ooo`00T@3oool00`000000oooo0?ooo`060?ooo`800000Q03oool00940oooo00<000000?oo
o`3oool0103oool2000008H0oooo002A0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0QP3oool00940oooo00@000000?ooo`3oool0oooo0P0000290?ooo`00T@3oool010000000oooo
00000000002;0?ooo`00T@3oool2000008d0oooo002@0?ooo`<00000S@3oool008h0oooo0P000000
0`3oool000000?ooo`2=0?ooo`00S03oool2000000<0oooo00<000000?ooo`3oool0S03oool008/0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2<0?ooo`00R@3oool2000000H0oooo
00<000000?ooo`3oool0S03oool008L0oooo0P0000080?ooo`030000003oool0oooo08`0oooo0026
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0S03oool008@0oooo0P0000020?oo
o`@000001@3oool00`000000oooo0?ooo`2<0?ooo`00P`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0S03oool00840oooo0P0000060?ooo`030000
003oool0oooo00D0oooo0P00002=0?ooo`00O`3oool2000000T0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`2<0?ooo`00OP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0S03oool007`0oooo0P00000:0?ooo`040000003oool0oooo
000000D0oooo00<000000?ooo`3oool0S03oool007/0oooo00<000000?ooo`3oool02`3oool20000
00H0oooo00<000000?ooo`3oool0S03oool007T0oooo0P00000F0?ooo`030000003oool0oooo08`0
oooo001g0?ooo`800000603oool00`000000oooo0?ooo`2<0?ooo`00MP3oool00`000000oooo0?oo
o`0H0?ooo`030000003oool0oooo08`0oooo001d0?ooo`8000006`3oool00`000000oooo0?ooo`2<
0?ooo`00LP3oool2000001d0oooo0P00002=0?ooo`00L03oool2000001l0oooo00<000000?ooo`3o
ool0S03oool006l0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`2<0?ooo`00K@3o
ool200000280oooo00<000000?ooo`3oool0S03oool006`0oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`2<0?ooo`00J`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
08`0oooo001Y0?ooo`8000009P3oool00`000000oooo0?ooo`2<0?ooo`00J03oool00`000000oooo
0?ooo`0V0?ooo`030000003oool0oooo08`0oooo001V0?ooo`800000:@3oool00`000000oooo0?oo
o`2<0?ooo`00I@3oool00`000000oooo0?ooo`0Y0?ooo`800000S@3oool006<0oooo0P00000/0?oo
o`030000003oool0oooo08`0oooo001R0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3o
ool0S03oool00600oooo0P00000_0?ooo`030000003oool0oooo08`0oooo001N0?ooo`800000<@3o
ool00`000000oooo0?ooo`2<0?ooo`00G@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0
oooo08`0oooo001K0?ooo`800000=03oool00`000000oooo0?ooo`2<0?ooo`00FP3oool00`000000
oooo0?ooo`0d0?ooo`030000003oool0oooo08`0oooo001H0?ooo`800000=`3oool00`000000oooo
0?ooo`2<0?ooo`00EP3oool2000003T0oooo0P00002=0?ooo`00E@3oool00`000000oooo0?ooo`0i
0?ooo`030000003oool0oooo08`0oooo001C0?ooo`800000?03oool00`000000oooo0?ooo`2<0?oo
o`00D@3oool2000003h0oooo00<000000?ooo`3oool0S03oool004l0oooo0P0000100?ooo`030000
003oool0oooo08`0oooo001>0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0S03o
ool004`0oooo0P0000130?ooo`030000003oool0oooo08`0oooo001;0?ooo`030000003oool0oooo
04<0oooo00<000000?ooo`3oool0S03oool004T0oooo0P00000o0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0S03oool004L0oooo0P0000110?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0S03oool004H0oooo00<000000?ooo`3oool0?P3oool5000000D0oooo0P00
002=0?ooo`00A03oool200000440oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?oo
o`2<0?ooo`00@`3oool00`000000oooo0?ooo`120?ooo`030000003oool0000000H0oooo00<00000
0?ooo`3oool0S03oool00440oooo0P0000160?ooo`8000001P3oool00`000000oooo0?ooo`2<0?oo
o`00@03oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0S03oool003h0oooo0P00001A0?ooo`030000003oool0oooo08`0oooo000l0?ooo`800000D`3o
ool00`000000oooo0?ooo`2<0?ooo`00>`3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0
oooo08`0oooo000i0?ooo`800000EP3oool00`000000oooo0?ooo`2<0?ooo`00>03oool00`000000
oooo0?ooo`1F0?ooo`800000S@3oool003H0oooo0P00001I0?ooo`030000003oool0oooo08`0oooo
000d0?ooo`800000F`3oool00`000000oooo0?ooo`2<0?ooo`00<P3oool2000005d0oooo00<00000
0?ooo`3oool0S03oool00300oooo0P00001O0?ooo`030000003oool0oooo08`0oooo000^0?ooo`80
0000H@3oool00`000000oooo0?ooo`2<0?ooo`00;@3oool00`000000oooo0?ooo`1Q0?ooo`030000
003oool0oooo08`0oooo000[0?ooo`800000I03oool00`000000oooo0?ooo`2<0?ooo`00:P3oool0
0`000000oooo0?ooo`1T0?ooo`030000003oool0oooo08`0oooo000X0?ooo`800000I`3oool20000
08d0oooo000V0?ooo`800000J@3oool00`000000oooo0?ooo`2<0?ooo`009@3oool00`000000oooo
0?ooo`1Y0?ooo`030000003oool0oooo08`0oooo000S0?ooo`800000K03oool00`000000oooo0?oo
o`2<0?ooo`008P3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo08`0oooo000P0?oo
o`800000K`3oool00`000000oooo0?ooo`2<0?ooo`007P3oool200000740oooo00<000000?ooo`3o
ool0S03oool001d0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`2<0?ooo`006`3o
ool2000007@0oooo00<000000?ooo`3oool0S03oool001T0oooo0P00001f0?ooo`800000S@3oool0
01L0oooo0P00001h0?ooo`030000003oool0oooo08`0oooo000F0?ooo`030000003oool0oooo07P0
oooo00<000000?ooo`3oool0S03oool001@0oooo0P00001k0?ooo`030000003oool0oooo08`0oooo
000C0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0S03oool00180oooo00<00000
0?ooo`3oool0O03oool00`000000oooo0?ooo`2<0?ooo`00403oool2000007l0oooo00<000000?oo
o`3oool0S03oool000l0oooo00<000000?ooo`3oool0M`3oool2000000H0oooo00<000000?ooo`3o
ool0S03oool000d0oooo0P00001i0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3o
ool0S03oool000`0oooo00<000000?ooo`3oool0N@3oool010000000oooo0?ooo`0000050?ooo`80
0000S@3oool008P0oooo0`0000060?ooo`030000003oool0oooo08`0oooo00280?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0S03oool008P0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`2<0?ooo`00R@3oool3000000D0oooo00<000000?ooo`3oool0S03oool00?l0
oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.63535, -3.33262, \
0.0112783, 0.054746}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(genpl[2, Blue]\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(1 - 2\ \[Delta]\), \(-\(1\/2\)\), "0"},
            {\(-\(1\/2\)\), \(1 - 2\ \[Delta]\), \(-\(1\/2\)\)},
            {"0", \(-\(1\/2\)\), \(1 - 2\ \[Delta]\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Print"],

Cell[BoxData[
    \({1\/2\ \((2 - \@2 - 4\ delta)\), 1\/2\ \((2 + \@2 - 4\ delta)\), 
      1 - 2\ delta}\)], "Print"],

Cell[BoxData[
    \({0.2928932188134524`, 1.7071067811865475`, 1.`}\)], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.31746 0.229628 0.0793886 [
[.02381 .21713 -12 -9 ]
[.02381 .21713 12 0 ]
[.18254 .21713 -6 -9 ]
[.18254 .21713 6 0 ]
[.34127 .21713 -12 -9 ]
[.34127 .21713 12 0 ]
[.65873 .21713 -9 -9 ]
[.65873 .21713 9 0 ]
[.81746 .21713 -3 -9 ]
[.81746 .21713 3 0 ]
[.97619 .21713 -9 -9 ]
[.97619 .21713 9 0 ]
[.4875 .07085 -12 -4.5 ]
[.4875 .07085 0 4.5 ]
[.4875 .15024 -12 -4.5 ]
[.4875 .15024 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38841 -6 -4.5 ]
[.4875 .38841 0 4.5 ]
[.4875 .46779 -6 -4.5 ]
[.4875 .46779 0 4.5 ]
[.4875 .54718 -6 -4.5 ]
[.4875 .54718 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .22963 m
.02381 .23588 L
s
[(-1.5)] .02381 .21713 0 1 Mshowa
.18254 .22963 m
.18254 .23588 L
s
[(-1)] .18254 .21713 0 1 Mshowa
.34127 .22963 m
.34127 .23588 L
s
[(-0.5)] .34127 .21713 0 1 Mshowa
.65873 .22963 m
.65873 .23588 L
s
[(0.5)] .65873 .21713 0 1 Mshowa
.81746 .22963 m
.81746 .23588 L
s
[(1)] .81746 .21713 0 1 Mshowa
.97619 .22963 m
.97619 .23588 L
s
[(1.5)] .97619 .21713 0 1 Mshowa
.125 Mabswid
.05556 .22963 m
.05556 .23338 L
s
.0873 .22963 m
.0873 .23338 L
s
.11905 .22963 m
.11905 .23338 L
s
.15079 .22963 m
.15079 .23338 L
s
.21429 .22963 m
.21429 .23338 L
s
.24603 .22963 m
.24603 .23338 L
s
.27778 .22963 m
.27778 .23338 L
s
.30952 .22963 m
.30952 .23338 L
s
.37302 .22963 m
.37302 .23338 L
s
.40476 .22963 m
.40476 .23338 L
s
.43651 .22963 m
.43651 .23338 L
s
.46825 .22963 m
.46825 .23338 L
s
.53175 .22963 m
.53175 .23338 L
s
.56349 .22963 m
.56349 .23338 L
s
.59524 .22963 m
.59524 .23338 L
s
.62698 .22963 m
.62698 .23338 L
s
.69048 .22963 m
.69048 .23338 L
s
.72222 .22963 m
.72222 .23338 L
s
.75397 .22963 m
.75397 .23338 L
s
.78571 .22963 m
.78571 .23338 L
s
.84921 .22963 m
.84921 .23338 L
s
.88095 .22963 m
.88095 .23338 L
s
.9127 .22963 m
.9127 .23338 L
s
.94444 .22963 m
.94444 .23338 L
s
.25 Mabswid
0 .22963 m
1 .22963 L
s
.5 .07085 m
.50625 .07085 L
s
[(-2)] .4875 .07085 1 0 Mshowa
.5 .15024 m
.50625 .15024 L
s
[(-1)] .4875 .15024 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(1)] .4875 .30902 1 0 Mshowa
.5 .38841 m
.50625 .38841 L
s
[(2)] .4875 .38841 1 0 Mshowa
.5 .46779 m
.50625 .46779 L
s
[(3)] .4875 .46779 1 0 Mshowa
.5 .54718 m
.50625 .54718 L
s
[(4)] .4875 .54718 1 0 Mshowa
.125 Mabswid
.5 .08673 m
.50375 .08673 L
s
.5 .10261 m
.50375 .10261 L
s
.5 .11848 m
.50375 .11848 L
s
.5 .13436 m
.50375 .13436 L
s
.5 .16612 m
.50375 .16612 L
s
.5 .182 m
.50375 .182 L
s
.5 .19787 m
.50375 .19787 L
s
.5 .21375 m
.50375 .21375 L
s
.5 .24551 m
.50375 .24551 L
s
.5 .26138 m
.50375 .26138 L
s
.5 .27726 m
.50375 .27726 L
s
.5 .29314 m
.50375 .29314 L
s
.5 .32489 m
.50375 .32489 L
s
.5 .34077 m
.50375 .34077 L
s
.5 .35665 m
.50375 .35665 L
s
.5 .37253 m
.50375 .37253 L
s
.5 .40428 m
.50375 .40428 L
s
.5 .42016 m
.50375 .42016 L
s
.5 .43604 m
.50375 .43604 L
s
.5 .45192 m
.50375 .45192 L
s
.5 .48367 m
.50375 .48367 L
s
.5 .49955 m
.50375 .49955 L
s
.5 .51543 m
.50375 .51543 L
s
.5 .53131 m
.50375 .53131 L
s
.5 .05497 m
.50375 .05497 L
s
.5 .0391 m
.50375 .0391 L
s
.5 .02322 m
.50375 .02322 L
s
.5 .00734 m
.50375 .00734 L
s
.5 .56306 m
.50375 .56306 L
s
.5 .57894 m
.50375 .57894 L
s
.5 .59482 m
.50375 .59482 L
s
.5 .61069 m
.50375 .61069 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .49105 m
.06244 .47172 L
.10458 .45065 L
.14415 .43086 L
.18221 .41182 L
.22272 .39156 L
.26171 .37206 L
.30316 .35133 L
.34309 .33136 L
.3815 .31215 L
.42237 .29171 L
.46172 .27203 L
.49955 .25311 L
.53984 .23296 L
.57861 .21356 L
.61984 .19295 L
.65954 .17309 L
.69774 .15398 L
.73838 .13365 L
.77751 .11408 L
.81909 .09329 L
.85916 .07325 L
.89771 .05397 L
.93871 .03346 L
.97619 .01472 L
s
.02381 .60332 m
.06244 .584 L
.10458 .56292 L
.14415 .54313 L
.18221 .5241 L
.22272 .50384 L
.26171 .48433 L
.30316 .4636 L
.34309 .44363 L
.3815 .42442 L
.42237 .40398 L
.46172 .3843 L
.49955 .36538 L
.53984 .34523 L
.57861 .32584 L
.61984 .30522 L
.65954 .28536 L
.69774 .26626 L
.73838 .24593 L
.77751 .22636 L
.81909 .20556 L
.85916 .18552 L
.89771 .16624 L
.93871 .14573 L
.97619 .12699 L
s
.02381 .54718 m
.06244 .52786 L
.10458 .50679 L
.14415 .48699 L
.18221 .46796 L
.22272 .4477 L
.26171 .4282 L
.30316 .40747 L
.34309 .3875 L
.3815 .36828 L
.42237 .34785 L
.46172 .32816 L
.49955 .30924 L
.53984 .28909 L
.57861 .2697 L
.61984 .24908 L
.65954 .22922 L
.69774 .21012 L
.73838 .18979 L
.77751 .17022 L
.81909 .14942 L
.85916 .12938 L
.89771 .1101 L
.93871 .08959 L
.97619 .07085 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo
0?ooo`2<0?ooo`00T@3oool2000008d0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?oo
o`030000003oool0oooo0840oooo0P000?l90?ooo`00T@3oool00`000000oooo0?ooo`1o0?ooo`80
003o2`3oool00940oooo0P00001n0?ooo`80003o3@3oool00940oooo00<000000?ooo`3oool0N`3o
ool20000o`l0oooo002A0?ooo`030000003oool0oooo07T0oooo0P000?lA0?ooo`00T@3oool00`00
0000oooo0?ooo`1g0?ooo`80003o4`3oool00940oooo00<000000?ooo`3oool0M@3oool20000oaD0
oooo002A0?ooo`800000M03oool20000oaL0oooo002A0?ooo`030000003oool0oooo0740oooo0P00
0?lI0?ooo`00T@3oool00`000000oooo0?ooo`1_0?ooo`80003o6`3oool00940oooo00<000000?oo
o`3oool0K@3oool20000oad0oooo002A0?ooo`800000K03oool20000oal0oooo002A0?ooo`030000
003oool0oooo06T0oooo0P000?lQ0?ooo`00T@3oool00`000000oooo0?ooo`1W0?ooo`80003o8`3o
ool008P0oooo100000050?ooo`030000003oool0oooo06D0oooo0P000?lU0?ooo`00R03oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo06<0oooo0P000?lW0?ooo`00R@3oool00`000000
oooo0?ooo`050?ooo`800000HP3oool20000oah0oooo0P000?l90?ooo`00PP3oool4000000@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1O0?ooo`80003o7P3oool20000o`/0oooo
002;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0G@3oool20000oah0oooo0P00
0?l=0?ooo`00R03oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo05/0oooo0P00
0?lN0?ooo`80003o3`3oool008T0oooo0P0000060?ooo`800000FP3oool20000oah0oooo0P000?lA
0?ooo`00T@3oool00`000000oooo0?ooo`1G0?ooo`80003o7@3oool30000oa<0oooo002A0?ooo`03
0000003oool0oooo05H0oooo00<0003o0?ooo`3oool06`3oool20000oaH0oooo002A0?ooo`030000
003oool0oooo05@0oooo0P000?lL0?ooo`80003o603oool00940oooo0P00001C0?ooo`80003o703o
ool20000oaX0oooo002A0?ooo`030000003oool0oooo0500oooo0P000?lL0?ooo`80003o703oool0
0940oooo00<000000?ooo`3oool0CP3oool20000oa`0oooo0P000?lN0?ooo`00T@3oool00`000000
oooo0?ooo`1<0?ooo`80003o703oool20000ob00oooo002A0?ooo`030000003oool0oooo04T0oooo
0`000?lL0?ooo`80003o8P3oool00940oooo0P0000180?ooo`80003o7@3oool20000ob@0oooo002A
0?ooo`030000003oool0oooo04D0oooo0P000?lM0?ooo`80003o9P3oool00940oooo00<000000?oo
o`3oool0@`3oool20000oad0oooo0P000?lM0?ooo`80003o2@3oool00940oooo00<000000?ooo`3o
ool0@@3oool20000oad0oooo0P000?lM0?ooo`80003o2`3oool00940oooo0P0000100?ooo`80003o
7@3oool20000oad0oooo0P000?l=0?ooo`00T@3oool00`000000oooo0?ooo`0m0?ooo`80003o7@3o
ool20000oad0oooo0P000?l?0?ooo`00T@3oool00`000000oooo0?ooo`0k0?ooo`80003o7@3oool2
0000oad0oooo0P000?lA0?ooo`00R03oool4000000D0oooo00<000000?ooo`3oool0>@3oool20000
oad0oooo0P000?lM0?ooo`80003o4`3oool008X0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0g0?ooo`80003o7@3oool20000oad0oooo0P000?lE0?ooo`00RP3oool00`000000oooo
0?ooo`040?ooo`800000=P3oool20000oad0oooo0P000?lM0?ooo`80003o5`3oool00880oooo1000
00040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0<`3oool20000oad0oooo0P00
0?lM0?ooo`80003o6@3oool008X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0a
0?ooo`80003o7@3oool20000oad0oooo0P000?lK0?ooo`00R03oool3000000H0oooo00<000000?oo
o`3oool0;`3oool20000oad0oooo0P000?lM0?ooo`80003o7@3oool008X0oooo00<000000?ooo`3o
ool0103oool2000002h0oooo0P000?lM0?ooo`80003o7P3oool00`000?l0oooo0?ooo`0M0?ooo`00
T@3oool00`000000oooo0?ooo`0[0?ooo`80003o7@3oool20000oah0oooo0P000?lP0?ooo`00T@3o
ool00`000000oooo0?ooo`0Y0?ooo`80003o7@3oool20000oah0oooo0P000?lR0?ooo`00T@3oool0
0`000000oooo0?ooo`0W0?ooo`80003o7@3oool20000oah0oooo0P000?lT0?ooo`00T@3oool00`00
0000oooo0?ooo`0U0?ooo`80003o7@3oool20000oah0oooo0P000?lV0?ooo`00T@3oool2000002@0
oooo0P000?lM0?ooo`80003o7P3oool20000obP0oooo002A0?ooo`030000003oool0oooo0240oooo
0P000?lM0?ooo`80003o7P3oool20000obX0oooo00070?ooo`@000000`3oool00`000000oooo0?oo
o`020?ooo`<000008`3oool4000002<0oooo0P0000040?ooo`030000003oool0oooo0080oooo0`00
000S0?ooo`030000003oool0oooo01l0oooo0P000?l00`3oool00000000000040?ooo`030000003o
ool0oooo0080oooo0`00000>0?ooo`80003o4`3oool4000000L0oooo0P000?lJ0?ooo`@000000`3o
ool00`000000oooo0?ooo`020?ooo`<000000`3oool000T0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0240oooo00@000000?ooo`3oool000002`3o
ool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01d0oooo0P000?l20?ooo`040000003o
ool0oooo000000/0oooo00<000000?ooo`3oool02@3oool20000oaL0oooo00<000000?ooo`3oool0
103oool20000oah0oooo00<000000?ooo`3oool02P3oool100000040oooo0@3oool000T0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0240oooo00@0
00000?ooo`3oool000002`3oool00`000000oooo0?ooo`0P0?ooo`800000703oool20000o`@0oooo
00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`070?ooo`80003o6@3oool00`000000
oooo0?ooo`020?ooo`80003o803oool00`000000oooo0?ooo`0:0?ooo`4000000@3oool10?ooo`00
00<0oooo0000000000000P0000040?ooo`030000003oool0oooo00L0oooo0`00000M0?ooo`@00000
103oool00`000000oooo0?ooo`0K0?ooo`@000000P3oool010000000oooo0?ooo`0000080?ooo`<0
00008`3oool00`000000oooo0?ooo`0I0?ooo`80003o1P3oool010000000oooo0?ooo`0000080?oo
o`<00000203oool20000oa/0oooo00<000000?ooo`3oool00P000?lR0?ooo`030000003oool0oooo
00L0oooo0`0000030?ooo`002@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool08@3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool05P3oool30000o`P0oooo00@000000?ooo`3oool00000203oool0
0`000000oooo0?ooo`060?ooo`80003o7@3oool00`000000003o0000o`0T0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool00`3oool000L0oooo0`0000090?ooo`030000003oool0oooo
02<0oooo0`00000S0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`0D0?ooo`80003o2`3oool010000000oooo0?ooo`0000080?ooo`030000003o
ool0oooo00@0oooo0P000?lM0?ooo`03000000000?l0003o02@0oooo0`0000090?ooo`030000003o
ool0oooo00<0oooo00090?ooo`030000003oool0oooo00L0oooo1000000T0?ooo`030000003oool0
oooo0280oooo0P0000090?ooo`@000008P3oool2000001<0oooo0P000?l>0?ooo`8000002@3oool4
000000030?ooo`000?l0003o01h0oooo0P000?l00`3oool000000?ooo`0U0?ooo`030000003oool0
oooo00L0oooo100000020?ooo`00T@3oool00`000000oooo0?ooo`0@0?ooo`80003o7P3oool20000
oah0oooo0P000?lj0?ooo`00T@3oool00`000000oooo0?ooo`0>0?ooo`80003o7P3oool20000oah0
oooo0P000?ll0?ooo`00T@3oool00`000000oooo0?ooo`0=0?ooo`030000o`3oool0oooo01`0oooo
0P000?lN0?ooo`80003o?P3oool00940oooo00<000000?ooo`3oool02`3oool20000oad0oooo0P00
0?lM0?ooo`<0003o@03oool000D0ooooV00000020000oad000000P000?lM00000080003o@0000003
0?ooo`00303oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`050?ooo`040000003oool0003o0000o`D0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo0P000?l0
0`3oool000000?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool0
10000000oooo0000o`000?l50?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo000<0?ooo`030000003oool0
oooo02T0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0
oooo00D0oooo0P000?lM0?ooo`80003o0`3oool00`000000oooo0?ooo`0G0?ooo`80003o403oool0
0`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00L0oooo002A0?ooo`030000003oool0oooo
00<0oooo0P000?lM0?ooo`80003o7@3oool20000odT0oooo002A0?ooo`80000000@0oooo0000o`00
0?l0003o7@3oool20000oad0oooo0P000?m;0?ooo`00T@3oool00`000000003o0000o`0N0?ooo`80
003o7@3oool20000odd0oooo002@0?ooo`80003o7P3oool20000oad0oooo0P000?m?0?ooo`00SP3o
ool20000o`030?ooo`000000oooo01/0oooo0P000?lM0?ooo`80003oD@3oool008`0oooo0P000?l3
0?ooo`030000003oool0oooo01P0oooo0P000?lM0?ooo`80003oD`3oool008/0oooo00<0003o0?oo
o`3oool00`3oool2000001L0oooo0P000?lM0?ooo`80003oE@3oool008T0oooo0P000?l60?ooo`03
0000003oool0oooo01@0oooo0P000?lM0?ooo`80003oE`3oool008L0oooo0P000?l80?ooo`030000
003oool0oooo0180oooo0P000?lM0?ooo`80003oF@3oool008D0oooo0P000?l:0?ooo`030000003o
ool0oooo0100oooo0P000?lM0?ooo`80003oF`3oool008<0oooo0P000?l<0?ooo`8000003`3oool2
0000oad0oooo0P000?mM0?ooo`00P@3oool20000o`h0oooo00<000000?ooo`3oool0303oool20000
oad0oooo0P000?mO0?ooo`00O`3oool20000oa00oooo00<000000?ooo`3oool02P3oool20000oad0
oooo0P000?mQ0?ooo`00O@3oool20000oa80oooo00<000000?ooo`3oool0203oool20000oad0oooo
0P000?mS0?ooo`00N`3oool20000oa@0oooo00<000000?ooo`3oool01P3oool20000oad0oooo0P00
0?mU0?ooo`00N@3oool20000oaH0oooo0P0000050?ooo`80003o7@3oool20000ofL0oooo001g0?oo
o`80003o603oool00`000000oooo0?ooo`020?ooo`80003o7@3oool20000ofT0oooo001e0?ooo`80
003o4@3oool4000000D0oooo00<000000?ooo`3oool00P000?lM0?ooo`80003oJ`3oool007<0oooo
0P000?lE0?ooo`030000003oool0oooo00@0oooo00<000000000o`000?l07P3oool00`000?l0oooo
0?ooo`1[0?ooo`00L@3oool20000oaL0oooo00<000000?ooo`3oool00`3oool20000o`030000003o
ool0oooo01/0oooo0P000?m^0?ooo`00K`3oool20000oaT0oooo00@000000?ooo`3oool0oooo0P00
0?l00`3oool000000?ooo`0K0?ooo`80003oL03oool006d0oooo0P000?lK0?ooo`040000003oool0
003o0000o`<0oooo00<000000?ooo`3oool0603oool20000og80oooo001[0?ooo`80003o6`3oool2
00000080003o1@3oool00`000000oooo0?ooo`0F0?ooo`80003oM03oool006T0oooo0P000?lM0?oo
o`80003o00<000000?ooo`3oool0103oool2000001D0oooo0P000?mf0?ooo`00I`3oool20000oad0
oooo0P000?l90?ooo`030000003oool0oooo0180oooo0P000?mh0?ooo`00I@3oool20000oad0oooo
0P000?l;0?ooo`030000003oool0oooo0100oooo0P000?mj0?ooo`00H`3oool20000oad0oooo0P00
0?l=0?ooo`030000003oool0oooo00h0oooo0P000?ml0?ooo`00H@3oool20000oad0oooo0P000?l?
0?ooo`030000003oool0oooo00`0oooo0P000?mn0?ooo`00G`3oool20000oad0oooo0P000?lA0?oo
o`8000002`3oool20000oh00oooo001M0?ooo`80003o7@3oool20000oa<0oooo00<000000?ooo`3o
ool0203oool20000oh80oooo001K0?ooo`80003o7P3oool00`000?l0oooo0?ooo`0C0?ooo`030000
003oool0oooo00H0oooo0P000?n40?ooo`00FP3oool00`000?l0oooo0?ooo`0L0?ooo`80003o5P3o
ool00`000000oooo0?ooo`040?ooo`80003oQP3oool005P0oooo0P000?lM0?ooo`80003o603oool2
000000<0oooo0P000?n80?ooo`00EP3oool20000oad0oooo0P000?lJ0?ooo`030000003oool0oooo
0080003oRP3oool005@0oooo0P000?lM0?ooo`80003o703oool00`000000003o0000o`2<0?ooo`00
DP3oool20000oad0oooo0P000?lM0?ooo`80003oSP3oool00500oooo0P000?lM0?ooo`80003o7@3o
ool20000o`030?ooo`000000oooo08d0oooo001=0?ooo`<0003o7@3oool20000oad0oooo0P000?l3
0?ooo`800000S@3oool004/0oooo0P000?lN0?ooo`80003o7@3oool20000o`D0oooo00<000000?oo
o`3oool0S03oool004T0oooo0P000?lN0?ooo`80003o7@3oool20000o`8000001@3oool00`000000
oooo0?ooo`2<0?ooo`00A`3oool20000oah0oooo0P000?lM0?ooo`80003o00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`2<0?ooo`00A@3oool20000oah0oooo0P000?lM0?ooo`80003o0`3o
ool00`000000oooo0?ooo`050?ooo`800000S@3oool004<0oooo0P000?lN0?ooo`80003o7@3oool2
0000o`H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2<0?ooo`00@@3oool20000
oah0oooo0P000?lM0?ooo`80003o2@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
08`0oooo000o0?ooo`80003o7P3oool20000oad0oooo0P000?l80?ooo`040000003oool0oooo0000
00D0oooo00<000000?ooo`3oool0S03oool003d0oooo0P000?lN0?ooo`80003o7@3oool20000o`/0
oooo0P0000060?ooo`030000003oool0oooo08`0oooo000k0?ooo`80003o7P3oool20000oad0oooo
0P000?lE0?ooo`800000S@3oool003T0oooo0P000?lN0?ooo`80003o7@3oool20000oaL0oooo00<0
00000?ooo`3oool0S03oool003L0oooo0P000?lN0?ooo`80003o7@3oool20000oaT0oooo00<00000
0?ooo`3oool0S03oool003D0oooo0P000?lN0?ooo`80003o703oool30000oa/0oooo00<000000?oo
o`3oool0S03oool003<0oooo0P000?lM0?ooo`<0003o703oool20000oah0oooo0P00002=0?ooo`00
<@3oool20000oad0oooo0P000?lM0?ooo`80003o803oool00`000000oooo0?ooo`2<0?ooo`00;`3o
ool20000oad0oooo0P000?lM0?ooo`80003o8P3oool00`000000oooo0?ooo`2<0?ooo`00;@3oool2
0000oad0oooo0P000?lM0?ooo`80003o903oool00`000000oooo0?ooo`2<0?ooo`00:`3oool20000
oad0oooo0P000?lN0?ooo`030000o`3oool0oooo02@0oooo00<000000?ooo`3oool0S03oool002T0
oooo0P000?lM0?ooo`80003o7P3oool20000obL0oooo0P00002=0?ooo`009`3oool20000oad0oooo
0P000?lN0?ooo`80003o:@3oool00`000000oooo0?ooo`2<0?ooo`009@3oool20000oad0oooo0P00
0?lN0?ooo`80003o:`3oool00`000000oooo0?ooo`2<0?ooo`008`3oool20000oad0oooo0P000?lN
0?ooo`80003o;@3oool00`000000oooo0?ooo`2<0?ooo`008@3oool20000oad0oooo0P000?lN0?oo
o`80003o;`3oool2000008d0oooo000O0?ooo`80003o7@3oool20000oah0oooo0P000?la0?ooo`03
0000003oool0oooo08`0oooo000M0?ooo`80003o7@3oool20000oah0oooo0P000?l[0?ooo`800000
1P3oool00`000000oooo0?ooo`2<0?ooo`006P3oool30000oad0oooo0P000?lN0?ooo`80003o;03o
ool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo08`0oooo000H0?ooo`80003o7P3o
ool20000oah0oooo0P000?la0?ooo`030000003oool0oooo00<0oooo0P00002=0?ooo`005P3oool2
0000oah0oooo0P000?lN0?ooo`80003o<@3oool2000000H0oooo00<000000?ooo`3oool0S03oool0
01@0oooo0P000?lN0?ooo`80003o7P3oool20000ocD0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`2<0?ooo`004P3oool20000oah0oooo0P000?lN0?ooo`80003o=03oool010000000
oooo0?ooo`0000050?ooo`030000003oool0oooo08`0oooo000A0?ooo`030000o`3oool0oooo01`0
oooo0P000?lN0?ooo`80003o=`3oool2000000H0oooo00<000000?ooo`3oool0S03oool000l0oooo
0P000?lM0?ooo`80003o7@3oool30000od40oooo0P00002=0?ooo`003@3oool20000oad0oooo0P00
0?lM0?ooo`80003oA03oool00`000000oooo0?ooo`2<0?ooo`00303oool00`000?l0oooo0?ooo`0K
0?ooo`80003o7@3oool20000odH0oooo00<000000?ooo`3oool0S03oool002P0oooo0P000?lM0?oo
o`80003oB03oool00`000000oooo0?ooo`2<0?ooo`009P3oool20000oad0oooo0P000?m:0?ooo`80
0000S@3oool002@0oooo0P000?lM0?ooo`80003oC03oool00`000000oooo0?ooo`2<0?ooo`008P3o
ool20000oad0oooo0P000?m>0?ooo`030000003oool0oooo08`0oooo000P0?ooo`80003o7@3oool2
0000oe00oooo00<000000?ooo`3oool0S03oool001h0oooo0P000?lM0?ooo`80003oDP3oool00`00
0000oooo0?ooo`2<0?ooo`00703oool20000oad0oooo0P000?mD0?ooo`800000S@3oool001X0oooo
0P000?lM0?ooo`80003oEP3oool00`000000oooo0?ooo`2<0?ooo`00603oool20000oad0oooo0P00
0?mH0?ooo`030000003oool0oooo08`0oooo000F0?ooo`80003o7@3oool20000oeX0oooo00<00000
0?ooo`3oool0S03oool001@0oooo0P000?lM0?ooo`80003oG03oool2000008d0oooo000B0?ooo`80
003o7@3oool20000oeh0oooo00<000000?ooo`3oool0S03oool00140oooo00<0003o0?ooo`3oool0
6`3oool20000of00oooo00<000000?ooo`3oool0S03oool000l0oooo0P000?lL0?ooo`80003oF`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08`0oooo000=0?ooo`80003o703oool2
0000oed0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2<0?ooo`00303oool00`00
0?l0oooo0?ooo`0J0?ooo`80003oG03oool5000000D0oooo0P00002=0?ooo`009`3oool20000oeh0
oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`2<0?ooo`009@3oool20000of40
oooo00<000000?ooo`0000001P3oool00`000000oooo0?ooo`2<0?ooo`008`3oool20000of@0oooo
0P0000060?ooo`030000003oool0oooo08`0oooo000R0?ooo`030000o`3oool0oooo06D0oooo00<0
00000?ooo`3oool0103oool2000008d0oooo000P0?ooo`80003oK`3oool00`000000oooo0?ooo`2<
0?ooo`007P3oool20000og40oooo00<000000?ooo`3oool0S03oool001`0oooo0P000?mc0?ooo`03
0000003oool0oooo08`0oooo000J0?ooo`80003oM@3oool2000008d0oooo000H0?ooo`80003oM`3o
ool00`000000oooo0?ooo`2<0?ooo`005P3oool20000ogT0oooo00<000000?ooo`3oool0S03oool0
01@0oooo0P000?mk0?ooo`030000003oool0oooo08`0oooo000B0?ooo`80003oO@3oool00`000000
oooo0?ooo`2<0?ooo`00403oool20000ogl0oooo0P00002=0?ooo`003P3oool20000oh40oooo00<0
00000?ooo`3oool0S03oool000`0oooo0P000?n30?ooo`030000003oool0oooo08`0oooo002A0?oo
o`030000003oool0oooo08`0oooo002A0?ooo`800000S@3oool00940oooo00<000000?ooo`3oool0
S03oool00940oooo00<000000?ooo`3oool0S03oool00?l0oooo8@3oool00?l0oooo8@3oool00001
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.63535, -2.98994, \
0.0112783, 0.0450998}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(genpl[3, Red]\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(3\/2 - \[Delta]\), \(-\(1\/\@2\)\), "0", "0", "0", "0"},
            {\(-\(1\/\@2\)\), \(1\/2 - \[Delta]\), \(-\(1\/2\)\), \(-\(1\/\@2\
\)\), "0", "0"},
            {"0", \(-\(1\/2\)\), \(1\/2 - \[Delta]\), "0", \(-\(1\/2\)\), 
              "0"},
            {"0", \(-\(1\/\@2\)\), "0", \(3\/2 - \[Delta]\), \(-\(1\/\@2\)\), 
              "0"},
            {"0", 
              "0", \(-\(1\/2\)\), \(-\(1\/\@2\)\), \(1\/2 - \[Delta]\), \
\(-\(1\/\@2\)\)},
            {"0", "0", "0", "0", \(-\(1\/\@2\)\), \(3\/2 - \[Delta]\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Print"],

Cell[BoxData[
    \({1\/2\ \((3 - 2\ delta)\), 1\/2\ \((2 - \@3 - 2\ delta)\), 
      1\/2\ \((2 + \@3 - 2\ delta)\), 
      Root[9 - 2\ delta - 20\ delta\^2 + 8\ delta\^3 - 2\ #1 - 
            40\ delta\ #1 + 24\ delta\^2\ #1 - 20\ #1\^2 + 24\ delta\ #1\^2 + 
            8\ #1\^3 &, 1], 
      Root[9 - 2\ delta - 20\ delta\^2 + 8\ delta\^3 - 2\ #1 - 
            40\ delta\ #1 + 24\ delta\^2\ #1 - 20\ #1\^2 + 24\ delta\ #1\^2 + 
            8\ #1\^3 &, 2], 
      Root[9 - 2\ delta - 20\ delta\^2 + 8\ delta\^3 - 2\ #1 - 
            40\ delta\ #1 + 24\ delta\^2\ #1 - 20\ #1\^2 + 24\ delta\ #1\^2 + 
            8\ #1\^3 &, 3]}\)], "Print"],

Cell[BoxData[
    \({1.5`, 0.1339745962155614`, 
      1.8660254037844386`, \(-0.6397261578843032`\), 0.7296814706969094`, 
      2.410044687187394`}\)], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.31746 0.222897 0.0972936 [
[.02381 .2104 -12 -9 ]
[.02381 .2104 12 0 ]
[.18254 .2104 -6 -9 ]
[.18254 .2104 6 0 ]
[.34127 .2104 -12 -9 ]
[.34127 .2104 12 0 ]
[.65873 .2104 -9 -9 ]
[.65873 .2104 9 0 ]
[.81746 .2104 -3 -9 ]
[.81746 .2104 3 0 ]
[.97619 .2104 -9 -9 ]
[.97619 .2104 9 0 ]
[.4875 .02831 -12 -4.5 ]
[.4875 .02831 0 4.5 ]
[.4875 .1256 -12 -4.5 ]
[.4875 .1256 0 4.5 ]
[.4875 .32019 -6 -4.5 ]
[.4875 .32019 0 4.5 ]
[.4875 .41748 -6 -4.5 ]
[.4875 .41748 0 4.5 ]
[.4875 .51478 -6 -4.5 ]
[.4875 .51478 0 4.5 ]
[.4875 .61207 -6 -4.5 ]
[.4875 .61207 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .2229 m
.02381 .22915 L
s
[(-1.5)] .02381 .2104 0 1 Mshowa
.18254 .2229 m
.18254 .22915 L
s
[(-1)] .18254 .2104 0 1 Mshowa
.34127 .2229 m
.34127 .22915 L
s
[(-0.5)] .34127 .2104 0 1 Mshowa
.65873 .2229 m
.65873 .22915 L
s
[(0.5)] .65873 .2104 0 1 Mshowa
.81746 .2229 m
.81746 .22915 L
s
[(1)] .81746 .2104 0 1 Mshowa
.97619 .2229 m
.97619 .22915 L
s
[(1.5)] .97619 .2104 0 1 Mshowa
.125 Mabswid
.05556 .2229 m
.05556 .22665 L
s
.0873 .2229 m
.0873 .22665 L
s
.11905 .2229 m
.11905 .22665 L
s
.15079 .2229 m
.15079 .22665 L
s
.21429 .2229 m
.21429 .22665 L
s
.24603 .2229 m
.24603 .22665 L
s
.27778 .2229 m
.27778 .22665 L
s
.30952 .2229 m
.30952 .22665 L
s
.37302 .2229 m
.37302 .22665 L
s
.40476 .2229 m
.40476 .22665 L
s
.43651 .2229 m
.43651 .22665 L
s
.46825 .2229 m
.46825 .22665 L
s
.53175 .2229 m
.53175 .22665 L
s
.56349 .2229 m
.56349 .22665 L
s
.59524 .2229 m
.59524 .22665 L
s
.62698 .2229 m
.62698 .22665 L
s
.69048 .2229 m
.69048 .22665 L
s
.72222 .2229 m
.72222 .22665 L
s
.75397 .2229 m
.75397 .22665 L
s
.78571 .2229 m
.78571 .22665 L
s
.84921 .2229 m
.84921 .22665 L
s
.88095 .2229 m
.88095 .22665 L
s
.9127 .2229 m
.9127 .22665 L
s
.94444 .2229 m
.94444 .22665 L
s
.25 Mabswid
0 .2229 m
1 .2229 L
s
.5 .02831 m
.50625 .02831 L
s
[(-2)] .4875 .02831 1 0 Mshowa
.5 .1256 m
.50625 .1256 L
s
[(-1)] .4875 .1256 1 0 Mshowa
.5 .32019 m
.50625 .32019 L
s
[(1)] .4875 .32019 1 0 Mshowa
.5 .41748 m
.50625 .41748 L
s
[(2)] .4875 .41748 1 0 Mshowa
.5 .51478 m
.50625 .51478 L
s
[(3)] .4875 .51478 1 0 Mshowa
.5 .61207 m
.50625 .61207 L
s
[(4)] .4875 .61207 1 0 Mshowa
.125 Mabswid
.5 .04777 m
.50375 .04777 L
s
.5 .06723 m
.50375 .06723 L
s
.5 .08669 m
.50375 .08669 L
s
.5 .10614 m
.50375 .10614 L
s
.5 .14506 m
.50375 .14506 L
s
.5 .16452 m
.50375 .16452 L
s
.5 .18398 m
.50375 .18398 L
s
.5 .20344 m
.50375 .20344 L
s
.5 .24236 m
.50375 .24236 L
s
.5 .26181 m
.50375 .26181 L
s
.5 .28127 m
.50375 .28127 L
s
.5 .30073 m
.50375 .30073 L
s
.5 .33965 m
.50375 .33965 L
s
.5 .35911 m
.50375 .35911 L
s
.5 .37857 m
.50375 .37857 L
s
.5 .39803 m
.50375 .39803 L
s
.5 .43694 m
.50375 .43694 L
s
.5 .4564 m
.50375 .4564 L
s
.5 .47586 m
.50375 .47586 L
s
.5 .49532 m
.50375 .49532 L
s
.5 .53424 m
.50375 .53424 L
s
.5 .55369 m
.50375 .55369 L
s
.5 .57315 m
.50375 .57315 L
s
.5 .59261 m
.50375 .59261 L
s
.5 .00885 m
.50375 .00885 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .51478 m
.06244 .50294 L
.10458 .49002 L
.14415 .4779 L
.18221 .46623 L
.22272 .45382 L
.26171 .44187 L
.30316 .42916 L
.34309 .41693 L
.3815 .40515 L
.42237 .39263 L
.46172 .38057 L
.49955 .36897 L
.53984 .35663 L
.57861 .34474 L
.61984 .33211 L
.65954 .31994 L
.69774 .30824 L
.73838 .29578 L
.77751 .28379 L
.81909 .27104 L
.85916 .25876 L
.89771 .24695 L
.93871 .23438 L
.97619 .2229 L
s
.02381 .38187 m
.06244 .37003 L
.10458 .35712 L
.14415 .34499 L
.18221 .33333 L
.22272 .32091 L
.26171 .30896 L
.30316 .29626 L
.34309 .28402 L
.3815 .27225 L
.42237 .25972 L
.46172 .24766 L
.49955 .23607 L
.53984 .22372 L
.57861 .21184 L
.61984 .19921 L
.65954 .18704 L
.69774 .17533 L
.73838 .16287 L
.77751 .15088 L
.81909 .13814 L
.85916 .12586 L
.89771 .11404 L
.93871 .10148 L
.97619 .08999 L
s
.02381 .55039 m
.06244 .53855 L
.10458 .52564 L
.14415 .51351 L
.18221 .50184 L
.22272 .48943 L
.26171 .47748 L
.30316 .46478 L
.34309 .45254 L
.3815 .44077 L
.42237 .42824 L
.46172 .41618 L
.49955 .40459 L
.53984 .39224 L
.57861 .38036 L
.61984 .36772 L
.65954 .35555 L
.69774 .34385 L
.73838 .33139 L
.77751 .3194 L
.81909 .30665 L
.85916 .29438 L
.89771 .28256 L
.93871 .26999 L
.97619 .25851 L
s
.02381 .3066 m
.06244 .29476 L
.10458 .28184 L
.14415 .26971 L
.18221 .25805 L
.22272 .24564 L
.26171 .23369 L
.30316 .22098 L
.34309 .20875 L
.3815 .19697 L
.42237 .18445 L
.46172 .17239 L
.49955 .16079 L
.53984 .14845 L
.57861 .13656 L
.61984 .12393 L
.65954 .11176 L
.69774 .10005 L
.73838 .0876 L
.77751 .0756 L
.81909 .06286 L
.85916 .05058 L
.89771 .03877 L
.93871 .0262 L
.97619 .01472 L
s
.02381 .43983 m
.06244 .42799 L
.10458 .41508 L
.14415 .40295 L
.18221 .39129 L
.22272 .37887 L
.26171 .36692 L
.30316 .35422 L
.34309 .34198 L
.3815 .33021 L
.42237 .31768 L
.46172 .30562 L
.49955 .29403 L
.53984 .28168 L
.57861 .2698 L
.61984 .25716 L
.65954 .24499 L
.69774 .23329 L
.73838 .22083 L
.77751 .20884 L
.81909 .1961 L
.85916 .18382 L
.89771 .172 L
.93871 .15944 L
.97619 .14795 L
s
.02381 .60332 m
.06244 .59148 L
.10458 .57856 L
.14415 .56644 L
.18221 .55477 L
.22272 .54236 L
.26171 .53041 L
.30316 .51771 L
.34309 .50547 L
.3815 .4937 L
.42237 .48117 L
.46172 .46911 L
.49955 .45752 L
.53984 .44517 L
.57861 .43329 L
.61984 .42065 L
.65954 .40848 L
.69774 .39678 L
.73838 .38432 L
.77751 .37233 L
.81909 .35958 L
.85916 .3473 L
.89771 .33549 L
.93871 .32292 L
.97619 .31144 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oT@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool2000008d0oooo002A0?ooo`030000003oool0oooo0840oooo0P3o
00090?ooo`00T@3oool00`000000oooo0?ooo`1n0?ooo`<0o`002`3oool008P0oooo100000050?oo
o`030000003oool0oooo07`0oooo0P3o000>0?ooo`00R03oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo07T0oooo0`3o000@0?ooo`00R@3oool00`000000oooo0?ooo`050?ooo`800000
M`3oool30?l001<0oooo00220?ooo`@00000103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0780oooo103o000F0?ooo`00R`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo06h0oooo103o000J0?ooo`00R03oool010000000oooo0?ooo`0000050?ooo`030000003oool0
oooo06/0oooo0`3o000N0?ooo`00R@3oool2000000H0oooo00<000000?ooo`3oool0I`3oool40?l0
0240oooo002A0?ooo`030000003oool0oooo06<0oooo103o000U0?ooo`00T@3oool200000640oooo
0`3o000Y0?ooo`00T@3oool00`000000oooo0?ooo`1M0?ooo`<0o`00;03oool00940oooo00<00000
0?ooo`3oool0F`3oool20?l002l0oooo002A0?ooo`030000003oool0oooo05P0oooo0`3o000a0?oo
o`00T@3oool00`000000oooo0?ooo`1E0?ooo`<0o`00=03oool00940oooo0P00001B0?ooo`@0o`00
=`3oool00940oooo00<000000?ooo`3oool0C@3oool40?l003/0oooo002A0?ooo`030000003oool0
oooo04T0oooo103o000o0?ooo`00T@3oool00`000000oooo0?ooo`160?ooo`<0o`00@`3oool00940
oooo00<000000?ooo`3oool0A03oool20?l004H0oooo002A0?ooo`030000003oool0oooo0440oooo
0`3o00180?ooo`00T@3oool2000003l0oooo0`3o00100?ooo`80o`002@3oool00940oooo00<00000
0?ooo`3oool0>P3oool40?l00400oooo0`3o000;0?ooo`00T@3oool00`000000oooo0?ooo`0f0?oo
o`@0o`00@P3oool20?l000h0oooo002A0?ooo`030000003oool0oooo03<0oooo0`3o00130?ooo`<0
o`00403oool00940oooo00<000000?ooo`3oool0<03oool30?l004<0oooo0`3o000C0?ooo`00T@3o
ool2000002l0oooo0P3o00120?ooo`@0o`005P3oool00940oooo00<000000?ooo`3oool0:`3oool3
0?l00400oooo103o000J0?ooo`00T@3oool00`000000oooo0?ooo`0X0?ooo`<0o`00@03oool30?l0
01h0oooo00280?ooo`@000001@3oool00`000000oooo0?ooo`0T0?ooo`@0o`00?`3oool40?l00240
oooo002:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0803oool40?l003l0oooo
103o000U0?ooo`00RP3oool00`000000oooo0?ooo`040?ooo`8000007P3oool30?l00400oooo0`3o
000Y0?ooo`00PP3oool4000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0I
0?ooo`@0o`00@03oool30?l002`0oooo002:0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool05@3oool40?l00480oooo0P3o000_0?ooo`00R03oool3000000H0oooo00<000000?ooo`3o
ool04@3oool40?l004<0oooo0`3o000a0?ooo`00RP3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00l0oooo0P3o00140?ooo`<0o`00=03oool00940oooo00<000000?ooo`3oool0303o
ool30?l00480oooo103o000g0?ooo`00T@3oool2000000/0oooo0P3o00110?ooo`@0o`00>`3oool0
0940oooo00<000000?ooo`3oool01`3oool30?l003l0oooo103o000d0?ooo`80o`002@3oool00940
oooo00<000000?ooo`3oool00`3oool40?l003l0oooo0`3o000d0?ooo`@0o`002`3oool00940oooo
00<000000?ooo`3o00000`3o00110?ooo`80o`00<`3oool40?l000l0oooo002?0?ooo`@0o`00@P3o
ool30?l00380oooo0`3o000C0?ooo`00S03oool30?l00080oooo0P00000o0?ooo`<0o`00<@3oool4
0?l001H0oooo00280?ooo`@0o`001@3oool00`000000oooo0?ooo`0j0?ooo`@0o`00<03oool40?l0
01X0oooo00250?ooo`<0o`002@3oool00`000000oooo0?ooo`0f0?ooo`@0o`00<@3oool30?l001h0
oooo00220?ooo`<0o`00303oool00`000000oooo0?ooo`0c0?ooo`<0o`00<P3oool30?l00240oooo
00200?ooo`80o`003`3oool00`000000oooo0?ooo`0`0?ooo`<0o`00<`3oool20?l002@0oooo001m
0?ooo`<0o`004@3oool00`000000oooo0?ooo`0^0?ooo`80o`00<`3oool30?l002H0oooo00070?oo
o`@000000`3oool00`000000oooo0?ooo`020?ooo`<000008`3oool4000002<0oooo0P0000040?oo
o`030000003oool0oooo0080oooo0`00000<0?ooo`<0o`00503oool2000002<0oooo0P0000040?oo
o`030000003oool0oooo00<0o`000P00000S0?ooo`@000002@3oool30?l001L0oooo100000030?oo
o`030000003oool0oooo0080oooo0`0000030?ooo`002@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool08@3oool010000000oooo0?ooo`00000;0?oo
o`030000003oool0oooo00D0oooo103o000G0?ooo`030000003oool0oooo0240oooo00@000000?oo
o`3oool000000`3oool30?l000D0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`04
0?ooo`@0o`00703oool00`000000oooo0?ooo`0:0?ooo`4000000@3oool10?ooo`002@3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool08@3oool01000
0000oooo0?ooo`00000;0?ooo`040000003oool0oooo0?ooo`@0o`006`3oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo00@0o`00203oool00`000000oooo0?ooo`0R0?ooo`030000003o
ool0oooo00@0o`00803oool00`000000oooo0?ooo`0:0?ooo`4000000@3oool10?ooo`0000<0oooo
0000000000000P0000040?ooo`030000003oool0oooo00L0oooo0`00000M0?ooo`@00000103oool0
0`000000oooo0?ooo`0K0?ooo`@000000P3oool010000000oooo0?ooo`0000080?ooo`<00000103o
000O0?ooo`030000003oool0oooo0200oooo103o00000`000000oooo0?ooo`060?ooo`<000009@3o
ool30?l002@0oooo00<000000?ooo`3oool01`3oool3000000<0oooo00090?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0Q0?ooo`040000003oool0
oooo000000P0oooo00<000000?l0003o00008`3oool00`000000oooo0?ooo`0M0?ooo`<0o`0000D0
oooo0000003oool0oooo000000080?ooo`030000003oool0oooo0280oooo0`3o00000`000000oooo
0?ooo`0T0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool000L0oooo0`00
00090?ooo`030000003oool0oooo02<0oooo0`00000S0?ooo`040000003oool0oooo000000H0oooo
0`3o000U0?ooo`8000006P3oool40?l000@0oooo00@000000?ooo`3oool00000203oool00`000000
oooo0?ooo`0O0?ooo`<0o`0000@0oooo0000000000000000903oool3000000T0oooo00<000000?oo
o`3oool00`3oool000T0oooo00<000000?ooo`3oool01`3oool4000002@0oooo00<000000?ooo`3o
ool08P3oool2000000D0oooo0P3o00020?ooo`@000008P3oool00`000000oooo0?ooo`0E0?ooo`@0
o`002@3oool2000000T0oooo1000000K0?ooo`<0o`001P3oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo00L0oooo100000020?ooo`00I03oool30?l002X0oooo00<000000?ooo`3oool0
4@3oool40?l003@0oooo0`3o00100?ooo`00H03oool40?l002d0oooo00<000000?ooo`3oool03`3o
ool20?l003@0oooo103o00130?ooo`00G03oool40?l00340oooo00<000000?ooo`3oool0303oool3
0?l00380oooo103o00170?ooo`00F@3oool30?l003D0oooo00<000000?ooo`3oool02P3oool20?l0
0380oooo0`3o001;0?ooo`001@3ooomA000000<0o`00@P0000030?l003000000103o001300000080
o`001P0000030?ooo`00303oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo
00@000000?l0003o0000o`001@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`@0o`001`3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`060?ooo`040000003oool0oooo0?ooo`@0o`0000<0oooo0000003oool01P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool01000
0000oooo0?ooo`3oool40?l000030?ooo`000000oooo00P0oooo001@0?ooo`<0o`00?P3oool00`00
0000oooo0?l000030?l00300oooo0`3o00130?ooo`@0o`003`3oool004d0oooo0`3o000o0?ooo`@0
o`00<@3oool30?l004<0oooo0`3o000C0?ooo`00B@3oool40?l003l0oooo0`3o00020?ooo`030000
003oool0oooo02h0oooo0P3o00120?ooo`@0o`005P3oool004D0oooo103o000o0?ooo`@0o`001@3o
ool2000002`0oooo0`3o00100?ooo`@0o`006P3oool00480oooo0`3o00100?ooo`<0o`002@3oool0
0`000000oooo0?ooo`0X0?ooo`<0o`00@03oool30?l001h0oooo000n0?ooo`@0o`00@03oool30?l0
00`0oooo00<000000?ooo`3oool0903oool40?l00400oooo0`3o000Q0?ooo`00>P3oool40?l00480
oooo0P3o000?0?ooo`030000003oool0oooo0200oooo103o00120?ooo`80o`00903oool003L0oooo
0`3o00130?ooo`<0o`004@3oool00`000000oooo0?ooo`0M0?ooo`<0o`00@`3oool30?l002H0oooo
000d0?ooo`<0o`00@`3oool30?l001@0oooo0P00000K0?ooo`<0o`00@`3oool30?l001h0oooo0P3o
00090?ooo`00<P3oool20?l00480oooo103o000G0?ooo`030000003oool0oooo01L0oooo0`3o0012
0?ooo`@0o`007@3oool40?l000/0oooo000_0?ooo`<0o`00@03oool40?l001/0oooo00<000000?oo
o`3oool0503oool30?l00440oooo103o000M0?ooo`@0o`003`3oool002`0oooo0`3o000o0?ooo`@0
o`007`3oool00`000000oooo0?ooo`0A0?ooo`<0o`00@@3oool30?l001h0oooo0`3o000C0?ooo`00
:03oool40?l00400oooo0P3o000S0?ooo`030000003oool0oooo00h0oooo0`3o00110?ooo`<0o`00
7@3oool40?l001H0oooo000T0?ooo`@0o`00@@3oool30?l002D0oooo00<000000?ooo`3oool02P3o
ool40?l00440oooo0`3o000L0?ooo`@0o`006P3oool00240oooo0`3o00130?ooo`80o`00:03oool2
000000P0oooo0`3o00120?ooo`<0o`00703oool30?l001h0oooo000N0?ooo`<0o`00@`3oool30?l0
02X0oooo00<000000?ooo`3oool00`3oool40?l00480oooo0`3o000L0?ooo`<0o`008@3oool001/0
oooo0`3o00120?ooo`@0o`00;@3oool00`000000oooo0?l000030?l00480oooo103o000M0?ooo`80
o`00903oool001P0oooo0`3o00110?ooo`@0o`00;`3oool40?l00480oooo103o000N0?ooo`<0o`00
9P3oool001D0oooo0`3o00110?ooo`<0o`00<@3oool20?l00080oooo00<000000?ooo`3oool0?P3o
ool30?l001l0oooo0`3o000Y0?ooo`004P3oool30?l00440oooo0`3o000a0?ooo`<0o`00103oool2
000003/0oooo103o000N0?ooo`@0o`00;03oool000h0oooo103o00110?ooo`<0o`00<P3oool20?l0
00L0oooo00<000000?ooo`3oool0=P3oool40?l001h0oooo103o000`0?ooo`00303oool20?l00480
oooo0`3o000b0?ooo`<0o`002@3oool00`000000oooo0?ooo`0c0?ooo`<0o`007`3oool30?l003@0
oooo001=0?ooo`<0o`00<@3oool40?l000`0oooo00<000000?ooo`3oool0<03oool30?l001l0oooo
0`3o000/0?ooo`80o`002@3oool004T0oooo103o000`0?ooo`@0o`001`3oool4000000D0oooo00<0
00000?ooo`3oool0;P3oool20?l001l0oooo0`3o000[0?ooo`@0o`002`3oool004D0oooo103o000a
0?ooo`<0o`003@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02/0oooo0`3o000N
0?ooo`<0o`00:P3oool40?l000l0oooo00120?ooo`<0o`00<P3oool30?l00100oooo00<000000?oo
o`3oool0103oool2000002T0oooo0`3o000N0?ooo`<0o`00:P3oool30?l001<0oooo000n0?ooo`@0
o`00<P3oool30?l001<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0T0?ooo`@0
o`007@3oool40?l002X0oooo0`3o000F0?ooo`00>P3oool40?l003<0oooo0`3o000F0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0803oool40?l001d0oooo103o000/0?ooo`80o`00
6@3oool003L0oooo0`3o000d0?ooo`<0o`005`3oool3000000H0oooo00<000000?ooo`3oool07@3o
ool30?l001h0oooo0`3o000]0?ooo`<0o`006`3oool003@0oooo0`3o000d0?ooo`<0o`00703oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo01X0oooo0`3o000M0?ooo`@0o`00;@3oool3
0?l001h0oooo000b0?ooo`80o`00<`3oool40?l002H0oooo0P00000H0?ooo`<0o`00703oool40?l0
02d0oooo103o000Q0?ooo`00;`3oool30?l00380oooo0`3o000Z0?ooo`030000003oool0oooo01@0
oooo0`3o000L0?ooo`<0o`00;@3oool40?l002D0oooo000/0?ooo`<0o`00<@3oool40?l002d0oooo
00<000000?ooo`3oool04@3oool30?l001`0oooo0`3o000]0?ooo`<0o`00:@3oool002P0oooo103o
000`0?ooo`@0o`00<@3oool00`000000oooo0?ooo`0>0?ooo`<0o`007@3oool20?l002d0oooo0`3o
000/0?ooo`00903oool40?l00340oooo0`3o000e0?ooo`030000003oool0oooo00X0oooo103o000M
0?ooo`<0o`00;@3oool20?l002l0oooo000Q0?ooo`<0o`00<P3oool30?l003P0oooo00<000000?oo
o`3oool01`3oool30?l001h0oooo0`3o000]0?ooo`<0o`00<@3oool001h0oooo0`3o000b0?ooo`<0
o`00>`3oool2000000@0oooo103o000M0?ooo`@0o`00;@3oool30?l003@0oooo000K0?ooo`<0o`00
<P3oool30?l003h0oooo00<000000?ooo`3o00000`3o000M0?ooo`@0o`00;@3oool40?l003L0oooo
000H0?ooo`<0o`00<P3oool30?l003l0oooo103o000N0?ooo`<0o`00;@3oool40?l003/0oooo000E
0?ooo`<0o`00<@3oool40?l00400oooo0P3o00020?ooo`030000003oool0oooo01X0oooo0`3o000/
0?ooo`@0o`00?`3oool00180oooo0`3o000`0?ooo`@0o`00@@3oool30?l000@0oooo00<000000?oo
o`3oool05`3oool30?l002`0oooo0`3o00130?ooo`003P3oool40?l00300oooo0`3o00130?ooo`80
o`001`3oool2000001D0oooo0`3o000]0?ooo`80o`00AP3oool000`0oooo0P3o000a0?ooo`<0o`00
@`3oool30?l000T0oooo00<000000?ooo`3oool04@3oool30?l002d0oooo0`3o00180?ooo`00?@3o
ool20?l00480oooo103o000<0?ooo`030000003oool0oooo00h0oooo0`3o000]0?ooo`<0o`00B`3o
ool003X0oooo0`3o00100?ooo`@0o`00403oool00`000000oooo0?ooo`0:0?ooo`@0o`00;03oool4
0?l004h0oooo000g0?ooo`<0o`00@03oool30?l001@0oooo00<000000?ooo`3oool01`3oool30?l0
02`0oooo103o001B0?ooo`00<`3oool40?l003l0oooo103o000G0?ooo`800000103oool40?l002`0
oooo0`3o001F0?ooo`00;`3oool40?l003l0oooo103o000K0?ooo`030000003oool0o`0000<0o`00
;03oool40?l005T0oooo000/0?ooo`<0o`00?`3oool40?l001d0oooo103o000/0?ooo`@0o`00G@3o
ool002P0oooo103o00100?ooo`80o`007`3oool20?l00080oooo00<000000?ooo`3oool0:03oool3
0?l00640oooo000T0?ooo`@0o`00@@3oool30?l001`0oooo0P0000030?l000@0oooo00<000000?oo
o`3oool09@3oool30?l006@0oooo000Q0?ooo`<0o`00@`3oool20?l001l0oooo0P3o00070?ooo`03
0000003oool0oooo02<0oooo0P3o001W0?ooo`007P3oool30?l004<0oooo0`3o000N0?ooo`<0o`00
00<0oooo0000003oool01P3oool200000240oooo0`3o001Y0?ooo`006`3oool30?l00480oooo103o
000M0?ooo`@0o`001@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01d0oooo0`3o
001/0?ooo`00603oool30?l00440oooo103o000M0?ooo`@0o`002P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo01T0oooo103o001_0?ooo`005@3oool30?l00440oooo0`3o000N0?oo
o`<0o`002`3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo01D0oooo103o001c
0?ooo`004P3oool30?l00440oooo0`3o000M0?ooo`@0o`003`3oool2000000H0oooo00<000000?oo
o`3oool04@3oool40?l007L0oooo000>0?ooo`@0o`00@@3oool30?l001`0oooo103o000K0?ooo`80
0000403oool20?l007/0oooo000<0?ooo`80o`00@P3oool30?l001/0oooo103o000O0?ooo`030000
003oool0oooo00`0oooo0`3o001m0?ooo`00C@3oool30?l001`0oooo0P3o000S0?ooo`030000003o
ool0oooo00X0oooo0P3o00200?ooo`00B@3oool40?l001`0oooo0`3o000U0?ooo`030000003oool0
oooo00L0oooo0`3o00220?ooo`00A@3oool40?l001h0oooo0P3o000X0?ooo`030000003oool0oooo
00<0oooo103o00250?ooo`00@P3oool30?l001l0oooo0`3o000Z0?ooo`030000003oool0o`0000<0
o`00R@3oool003l0oooo0`3o000N0?ooo`@0o`00:`3oool40?l008d0oooo000m0?ooo`80o`007@3o
ool40?l002`0oooo0`3o00020?ooo`030000003oool0oooo08`0oooo000j0?ooo`<0o`00703oool3
0?l002`0oooo103o00050?ooo`030000003oool0oooo08`0oooo000g0?ooo`<0o`00703oool30?l0
02`0oooo0`3o00090?ooo`030000003oool0oooo08`0oooo000c0?ooo`@0o`00703oool30?l002`0
oooo0`3o000<0?ooo`030000003oool0oooo08`0oooo000_0?ooo`@0o`007@3oool30?l002d0oooo
0P3o000?0?ooo`800000S@3oool002`0oooo0`3o000N0?ooo`<0o`00;@3oool30?l00140oooo00<0
00000?ooo`3oool0S03oool002P0oooo103o000M0?ooo`@0o`00;@3oool30?l001@0oooo00<00000
0?ooo`3oool0S03oool002@0oooo103o000M0?ooo`@0o`00;@3oool40?l001L0oooo00<000000?oo
o`3oool0S03oool00240oooo0`3o000N0?ooo`<0o`00;@3oool40?l001/0oooo00<000000?ooo`3o
ool0S03oool001h0oooo0`3o000M0?ooo`@0o`00;03oool40?l001l0oooo00<000000?ooo`3oool0
S03oool001/0oooo0`3o000L0?ooo`@0o`00;@3oool30?l002<0oooo0P00002=0?ooo`00603oool3
0?l001`0oooo0`3o000]0?ooo`@0o`009P3oool00`000000oooo0?ooo`2<0?ooo`005@3oool30?l0
01`0oooo0`3o000]0?ooo`<0o`00:P3oool00`000000oooo0?ooo`2<0?ooo`004P3oool30?l001d0
oooo0P3o000]0?ooo`<0o`009@3oool2000000H0oooo00<000000?ooo`3oool0S03oool000h0oooo
103o000M0?ooo`<0o`00;@3oool20?l002L0oooo00@000000?ooo`3oool000001@3oool00`000000
oooo0?ooo`2<0?ooo`00303oool20?l001h0oooo0`3o000]0?ooo`<0o`00;03oool00`000000oooo
0?ooo`030?ooo`800000S@3oool002P0oooo103o000]0?ooo`<0o`00;@3oool2000000H0oooo00<0
00000?ooo`3oool0S03oool002@0oooo103o000]0?ooo`@0o`00<P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo08`0oooo000Q0?ooo`<0o`00;@3oool40?l003<0oooo00@000000?oo
o`3oool000001@3oool00`000000oooo0?ooo`2<0?ooo`007P3oool30?l002`0oooo103o000h0?oo
o`8000001P3oool00`000000oooo0?ooo`2<0?ooo`006`3oool30?l002`0oooo0`3o00140?ooo`03
0000003oool0oooo08`0oooo000H0?ooo`<0o`00;@3oool20?l004L0oooo0P00002=0?ooo`005@3o
ool30?l002d0oooo0`3o00190?ooo`030000003oool0oooo08`0oooo000B0?ooo`<0o`00;@3oool3
0?l004`0oooo00<000000?ooo`3oool0S03oool000h0oooo103o000/0?ooo`@0o`00C`3oool00`00
0000oooo0?ooo`2<0?ooo`00303oool20?l002`0oooo103o001C0?ooo`030000003oool0oooo08`0
oooo000g0?ooo`<0o`00E`3oool2000008d0oooo000d0?ooo`<0o`00FP3oool00`000000oooo0?oo
o`2<0?ooo`00<P3oool20?l005d0oooo00<000000?ooo`3oool0S03oool002l0oooo0`3o001O0?oo
o`030000003oool0oooo08`0oooo000/0?ooo`<0o`00HP3oool00`000000oooo0?ooo`2<0?ooo`00
:03oool40?l006D0oooo0P00002=0?ooo`00903oool40?l006T0oooo00<000000?ooo`3oool0S03o
ool00240oooo0`3o001]0?ooo`030000003oool0oooo08`0oooo000N0?ooo`<0o`00L03oool00`00
0000oooo0?ooo`2<0?ooo`006`3oool30?l007<0oooo00<000000?ooo`3oool0S03oool001P0oooo
0`3o001f0?ooo`030000003oool0oooo08`0oooo000E0?ooo`<0o`00N@3oool2000008d0oooo000B
0?ooo`<0o`00O03oool00`000000oooo0?ooo`2<0?ooo`003P3oool40?l007l0oooo00<000000?oo
o`3oool0S03oool000`0oooo0P3o001l0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0S03oool008X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2<0?ooo`00Q`3o
ool5000000D0oooo0P00002=0?ooo`00Q`3oool010000000oooo0?ooo`0000060?ooo`030000003o
ool0oooo08`0oooo00280?ooo`030000003oool0000000H0oooo00<000000?ooo`3oool0S03oool0
08T0oooo0P00002E0?ooo`00RP3oool00`000000oooo0?ooo`2C0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.63535, -2.31835, \
0.0112783, 0.0368001}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(genpl[4, Thickness[0.008], Red]\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(1\/2 - \[Delta]\), \(-\(1\/2\)\), "0"},
            {\(-\(1\/2\)\), \(1\/2 - \[Delta]\), \(-\(1\/2\)\)},
            {"0", \(-\(1\/2\)\), \(1\/2 - \[Delta]\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Print"],

Cell[BoxData[
    \({1\/2\ \((1 - 2\ delta)\), 1\/2\ \((1 - \@2 - 2\ delta)\), 
      1\/2\ \((1 + \@2 - 2\ delta)\)}\)], "Print"],

Cell[BoxData[
    \({0.5`, \(-0.20710678118654757`\), 1.2071067811865475`}\)], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.31746 0.242346 0.133343 [
[.02381 .22985 -12 -9 ]
[.02381 .22985 12 0 ]
[.18254 .22985 -6 -9 ]
[.18254 .22985 6 0 ]
[.34127 .22985 -12 -9 ]
[.34127 .22985 12 0 ]
[.65873 .22985 -9 -9 ]
[.65873 .22985 9 0 ]
[.81746 .22985 -3 -9 ]
[.81746 .22985 3 0 ]
[.97619 .22985 -9 -9 ]
[.97619 .22985 9 0 ]
[.4875 .109 -12 -4.5 ]
[.4875 .109 0 4.5 ]
[.4875 .37569 -6 -4.5 ]
[.4875 .37569 0 4.5 ]
[.4875 .50903 -6 -4.5 ]
[.4875 .50903 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24235 m
.02381 .2486 L
s
[(-1.5)] .02381 .22985 0 1 Mshowa
.18254 .24235 m
.18254 .2486 L
s
[(-1)] .18254 .22985 0 1 Mshowa
.34127 .24235 m
.34127 .2486 L
s
[(-0.5)] .34127 .22985 0 1 Mshowa
.65873 .24235 m
.65873 .2486 L
s
[(0.5)] .65873 .22985 0 1 Mshowa
.81746 .24235 m
.81746 .2486 L
s
[(1)] .81746 .22985 0 1 Mshowa
.97619 .24235 m
.97619 .2486 L
s
[(1.5)] .97619 .22985 0 1 Mshowa
.125 Mabswid
.05556 .24235 m
.05556 .2461 L
s
.0873 .24235 m
.0873 .2461 L
s
.11905 .24235 m
.11905 .2461 L
s
.15079 .24235 m
.15079 .2461 L
s
.21429 .24235 m
.21429 .2461 L
s
.24603 .24235 m
.24603 .2461 L
s
.27778 .24235 m
.27778 .2461 L
s
.30952 .24235 m
.30952 .2461 L
s
.37302 .24235 m
.37302 .2461 L
s
.40476 .24235 m
.40476 .2461 L
s
.43651 .24235 m
.43651 .2461 L
s
.46825 .24235 m
.46825 .2461 L
s
.53175 .24235 m
.53175 .2461 L
s
.56349 .24235 m
.56349 .2461 L
s
.59524 .24235 m
.59524 .2461 L
s
.62698 .24235 m
.62698 .2461 L
s
.69048 .24235 m
.69048 .2461 L
s
.72222 .24235 m
.72222 .2461 L
s
.75397 .24235 m
.75397 .2461 L
s
.78571 .24235 m
.78571 .2461 L
s
.84921 .24235 m
.84921 .2461 L
s
.88095 .24235 m
.88095 .2461 L
s
.9127 .24235 m
.9127 .2461 L
s
.94444 .24235 m
.94444 .2461 L
s
.25 Mabswid
0 .24235 m
1 .24235 L
s
.5 .109 m
.50625 .109 L
s
[(-1)] .4875 .109 1 0 Mshowa
.5 .37569 m
.50625 .37569 L
s
[(1)] .4875 .37569 1 0 Mshowa
.5 .50903 m
.50625 .50903 L
s
[(2)] .4875 .50903 1 0 Mshowa
.125 Mabswid
.5 .13567 m
.50375 .13567 L
s
.5 .16234 m
.50375 .16234 L
s
.5 .18901 m
.50375 .18901 L
s
.5 .21568 m
.50375 .21568 L
s
.5 .26901 m
.50375 .26901 L
s
.5 .29568 m
.50375 .29568 L
s
.5 .32235 m
.50375 .32235 L
s
.5 .34902 m
.50375 .34902 L
s
.5 .40236 m
.50375 .40236 L
s
.5 .42903 m
.50375 .42903 L
s
.5 .45569 m
.50375 .45569 L
s
.5 .48236 m
.50375 .48236 L
s
.5 .08233 m
.50375 .08233 L
s
.5 .05567 m
.50375 .05567 L
s
.5 .029 m
.50375 .029 L
s
.5 .00233 m
.50375 .00233 L
s
.5 .5357 m
.50375 .5357 L
s
.5 .56237 m
.50375 .56237 L
s
.5 .58904 m
.50375 .58904 L
s
.5 .61571 m
.50375 .61571 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.008 w
.02381 .50903 m
.06244 .4928 L
.10458 .47511 L
.14415 .45848 L
.18221 .4425 L
.22272 .42548 L
.26171 .40911 L
.30316 .3917 L
.34309 .37493 L
.3815 .35879 L
.42237 .34163 L
.46172 .3251 L
.49955 .30921 L
.53984 .29228 L
.57861 .276 L
.61984 .25868 L
.65954 .242 L
.69774 .22596 L
.73838 .20889 L
.77751 .19245 L
.81909 .17499 L
.85916 .15816 L
.89771 .14197 L
.93871 .12474 L
.97619 .109 L
s
.02381 .41474 m
.06244 .39852 L
.10458 .38082 L
.14415 .3642 L
.18221 .34821 L
.22272 .3312 L
.26171 .31482 L
.30316 .29741 L
.34309 .28064 L
.3815 .2645 L
.42237 .24734 L
.46172 .23081 L
.49955 .21492 L
.53984 .198 L
.57861 .18171 L
.61984 .16439 L
.65954 .14772 L
.69774 .13167 L
.73838 .1146 L
.77751 .09817 L
.81909 .0807 L
.85916 .06387 L
.89771 .04768 L
.93871 .03046 L
.97619 .01472 L
s
.02381 .60332 m
.06244 .58709 L
.10458 .56939 L
.14415 .55277 L
.18221 .53679 L
.22272 .51977 L
.26171 .50339 L
.30316 .48599 L
.34309 .46921 L
.3815 .45308 L
.42237 .43591 L
.46172 .41938 L
.49955 .40349 L
.53984 .38657 L
.57861 .37029 L
.61984 .35297 L
.65954 .33629 L
.69774 .32025 L
.73838 .30318 L
.77751 .28674 L
.81909 .26928 L
.85916 .25245 L
.89771 .23625 L
.93871 .21903 L
.97619 .20329 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00T@3oool2000008d0oooo002A0?ooo`030000003oool0oooo08`0oooo
002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo0880oooo00<0o`00
0?ooo`3oool01`3oool00940oooo00<000000?ooo`3oool0P03oool40?l000P0oooo002A0?ooo`03
0000003oool0oooo07d0oooo1P3o00090?ooo`00T@3oool00`000000oooo0?ooo`1j0?ooo`H0o`00
303oool00940oooo00<000000?ooo`3oool0M`3oool60?l000l0oooo002A0?ooo`800000MP3oool5
0?l00180oooo002A0?ooo`030000003oool0oooo07<0oooo1@3o000D0?ooo`00T@3oool00`000000
oooo0?ooo`1a0?ooo`D0o`005P3oool00940oooo00<000000?ooo`3oool0KP3oool50?l001T0oooo
002A0?ooo`030000003oool0oooo06`0oooo1@3o000K0?ooo`00T@3oool00`000000oooo0?ooo`1Z
0?ooo`D0o`007@3oool00940oooo00<000000?ooo`3oool0J03oool50?l001l0oooo002A0?ooo`80
0000I`3oool50?l00240oooo002A0?ooo`030000003oool0oooo06<0oooo1@3o000T0?ooo`00T@3o
ool00`000000oooo0?ooo`1Q0?ooo`D0o`009P3oool00940oooo00<000000?ooo`3oool0G`3oool5
0?l002P0oooo002A0?ooo`030000003oool0oooo05`0oooo1P3o000Z0?ooo`00T@3oool00`000000
oooo0?ooo`1I0?ooo`H0o`00;@3oool00940oooo00<000000?ooo`3oool0EP3oool60?l00300oooo
002A0?ooo`030000003oool0oooo05@0oooo1@3o000c0?ooo`00T@3oool200000580oooo1P3o000e
0?ooo`00T@3oool00`000000oooo0?ooo`1?0?ooo`D0o`00>03oool00940oooo00<000000?ooo`3o
ool0C@3oool50?l003X0oooo002A0?ooo`030000003oool0oooo04X0oooo1@3o000m0?ooo`00T@3o
ool00`000000oooo0?ooo`180?ooo`D0o`00?`3oool008P0oooo100000050?ooo`030000003oool0
oooo04H0oooo1@3o00110?ooo`00RP3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
04@0oooo1@3o000i0?ooo`030?l0003oool0oooo00L0oooo002:0?ooo`030000003oool0oooo00@0
oooo0P0000120?ooo`D0o`00>P3oool40?l000P0oooo00220?ooo`@00000103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo03l0oooo1@3o000j0?ooo`D0o`002@3oool008X0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0m0?ooo`D0o`00>P3oool50?l000/0oooo0028
0?ooo`<000001P3oool00`000000oooo0?ooo`0j0?ooo`H0o`00>@3oool50?l000h0oooo002:0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0=`3oool60?l003X0oooo1@3o000@0?oo
o`00T@3oool00`000000oooo0?ooo`0d0?ooo`H0o`00>`3oool50?l00180oooo002A0?ooo`030000
003oool0oooo0380oooo1@3o000k0?ooo`H0o`00503oool00940oooo00<000000?ooo`3oool0<03o
ool50?l003X0oooo1P3o000G0?ooo`00T@3oool2000002l0oooo1@3o000i0?ooo`H0o`006P3oool0
0940oooo00<000000?ooo`3oool0:`3oool50?l003X0oooo1@3o000M0?ooo`00T@3oool00`000000
oooo0?ooo`0Y0?ooo`D0o`00>P3oool50?l001l0oooo002A0?ooo`030000003oool0oooo02L0oooo
1@3o000j0?ooo`D0o`008@3oool00940oooo00<000000?ooo`3oool09@3oool50?l003T0oooo1@3o
000T0?ooo`00T@3oool00`000000oooo0?ooo`0S0?ooo`D0o`00>@3oool50?l002H0oooo002A0?oo
o`030000003oool0oooo0200oooo1@3o000j0?ooo`D0o`00:03oool00940oooo0P00000O0?ooo`D0
o`00>P3oool50?l002X0oooo002A0?ooo`030000003oool0oooo01/0oooo1P3o000j0?ooo`D0o`00
;03oool00940oooo00<000000?ooo`3oool0603oool70?l003T0oooo1@3o000_0?ooo`00T@3oool0
0`000000oooo0?ooo`0E0?ooo`L0o`00>P3oool50?l00340oooo002A0?ooo`030000003oool0oooo
0180oooo1`3o000j0?ooo`H0o`00<`3oool00940oooo00<000000?ooo`3oool0403oool60?l003X0
oooo1`3o000e0?ooo`00T@3oool00`000000oooo0?ooo`0>0?ooo`D0o`00>P3oool70?l003P0oooo
002A0?ooo`030000003oool0oooo00`0oooo1@3o000i0?ooo`L0o`00>`3oool00940oooo0P00000;
0?ooo`D0o`00>@3oool60?l003h0oooo002A0?ooo`030000003oool0oooo00P0oooo1@3o000i0?oo
o`D0o`00@@3oool00940oooo00<000000?ooo`3oool01P3oool50?l003T0oooo1@3o00130?ooo`00
T@3oool00`000000oooo0?ooo`030?ooo`H0o`00>03oool50?l003`0oooo00<0o`000?ooo`3oool0
1`3oool000L0oooo100000030?ooo`030000003oool0oooo0080oooo0`00000S0?ooo`@000008`3o
ool2000000@0oooo00<000000?ooo`3oool00P3oool3000002<0oooo00@000000?ooo`3oool0oooo
1@3o000L0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`<000003`3oool50?l000l0oooo
1000000S0?ooo`@000000P3oool40?l00080oooo0`0000030?ooo`002@3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool08@3oool010000000oooo0?oo
o`00000;0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3o0000103o000M0?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool02P3oool50?l001<0oooo00<000000?ooo`3o
ool0903oool00`000000o`000?l000040?l000H0oooo0@0000010?ooo`40oooo00090?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0Q0?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool07`3oool50?l00200oooo00@000000?ooo`3o
ool000002`3oool00`000000oooo0?ooo`080?ooo`D0o`005@3oool00`000000oooo0?ooo`0R0?oo
o`H0o`002@3oool100000040oooo0@3oool000030?ooo`000000000000800000103oool00`000000
oooo0?ooo`070?ooo`<000007@3oool4000000@0oooo00<000000?ooo`3oool06`3oool400000080
oooo00@000000?ooo`3oool00000203oool300000200oooo1@3o000R0?ooo`040000003oool0oooo
000000P0oooo0`0000090?ooo`D0o`005`3oool00`000000oooo0?ooo`0O0?ooo`H0o`002@3oool3
000000<0oooo00090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool09@3oool00`00
0000oooo0?ooo`0Q0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool07@3oool6
0?l000030000003oool0oooo0240oooo00@000000?ooo`3oool00000203oool00`000000oooo0?oo
o`060?ooo`D0o`006P3oool00`000000oooo0?ooo`0M0?ooo`D0o`000P3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00<0oooo00070?ooo`<000002@3oool00`000000oooo0?ooo`0S
0?ooo`<000008`3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo01/0oooo1@3o
00030?ooo`030000003oool0oooo0240oooo00@000000?ooo`3oool00000203oool00`000000oooo
0?ooo`040?ooo`D0o`006P3oool3000001d0oooo1@3o00020?ooo`<000002@3oool00`000000oooo
0?ooo`030?ooo`002@3oool00`000000oooo0?ooo`070?ooo`@00000903oool00`000000oooo0?oo
o`0R0?ooo`8000002@3oool4000001L0oooo1P3o00050?ooo`030000003oool0oooo0280oooo0P00
00090?ooo`@0000000<0oooo0?l0003o00000`3o000N0?ooo`030000003oool0oooo01T0oooo1@3o
00060?ooo`030000003oool0oooo00L0oooo100000020?ooo`00Q03oool50?l000P0oooo00<00000
0?ooo`3oool0;`3oool60?l003T0oooo1@3o000I0?ooo`00PP3oool50?l000X0oooo00<000000?oo
o`3oool0;03oool60?l003X0oooo1@3o000K0?ooo`00P03oool50?l000`0oooo00<000000?ooo`3o
ool0:@3oool60?l003/0oooo1@3o000M0?ooo`001@3ooomh000000D0o`00>@0000050?l003/00000
1P3o000L000000<0oooo000<0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo1@3o00080?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`D0o`00203o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3o
ool60?l000H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00L0oooo000<0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`0B0?ooo`D0o`004`3oool00`000000oooo0?ooo`0S0?ooo`D0o`0000<0oooo
0000003oool0:P3oool00`000000oooo0?ooo`090?ooo`H0o`006`3oool00`000000oooo0?ooo`07
0?ooo`00MP3oool60?l001D0oooo00<000000?ooo`3oool0803oool50?l003X0oooo1@3o000X0?oo
o`00M03oool50?l001P0oooo00<000000?ooo`3oool07P3oool50?l003X0oooo1@3o000Z0?ooo`00
LP3oool50?l001X0oooo00<000000?ooo`3oool0703oool50?l003X0oooo1@3o000/0?ooo`00K`3o
ool50?l001d0oooo00<000000?ooo`3oool06@3oool60?l003T0oooo1@3o000_0?ooo`00K@3oool5
0?l001l0oooo00<000000?ooo`3oool05`3oool50?l003X0oooo1@3o000a0?ooo`00JP3oool60?l0
0240oooo0P00000F0?ooo`D0o`00>P3oool50?l003<0oooo001X0?ooo`D0o`00903oool00`000000
oooo0?ooo`0B0?ooo`D0o`00>P3oool60?l003D0oooo001U0?ooo`H0o`009P3oool00`000000oooo
0?ooo`0@0?ooo`D0o`00>P3oool50?l003P0oooo001S0?ooo`D0o`00:@3oool00`000000oooo0?oo
o`0=0?ooo`H0o`00>P3oool50?l003X0oooo001Q0?ooo`D0o`00:`3oool00`000000oooo0?ooo`0;
0?ooo`D0o`00>P3oool50?l003d0oooo001O0?ooo`D0o`00;@3oool00`000000oooo0?ooo`080?oo
o`H0o`00>P3oool50?l003l0oooo001L0?ooo`D0o`00<03oool00`000000oooo0?ooo`060?ooo`D0
o`00>P3oool60?l00440oooo001J0?ooo`D0o`00<P3oool2000000@0oooo1P3o000i0?ooo`H0o`00
A03oool005P0oooo1@3o000d0?ooo`040000003oool0oooo0?ooo`D0o`00>@3oool60?l004L0oooo
001E0?ooo`H0o`00=P3oool00`000000oooo0?l000040?l003T0oooo1@3o001:0?ooo`00D`3oool5
0?l003P0oooo1@3o000j0?ooo`D0o`00C03oool00540oooo1@3o000h0?ooo`D0o`00>P3oool50?l0
04h0oooo001>0?ooo`D0o`00>@3oool50?l000030000003oool0oooo03H0oooo1@3o001A0?ooo`00
C03oool50?l003T0oooo1@3o00020?ooo`030000003oool0oooo03@0oooo1@3o001C0?ooo`00B@3o
ool60?l003T0oooo1@3o00040?ooo`030000003oool0oooo0380oooo1@3o001E0?ooo`00AP3oool6
0?l003X0oooo1@3o00060?ooo`800000<@3oool50?l005L0oooo00130?ooo`H0o`00>`3oool50?l0
00P0oooo00<000000?ooo`3oool0;P3oool50?l005T0oooo00110?ooo`D0o`00>`3oool60?l000X0
oooo00<000000?ooo`3oool0:`3oool50?l005`0oooo000o0?ooo`D0o`00>P3oool60?l000d0oooo
00<000000?ooo`3oool0:@3oool50?l005h0oooo000m0?ooo`D0o`00>@3oool60?l00100oooo00<0
00000?ooo`3oool09`3oool50?l00600oooo000j0?ooo`D0o`00>P3oool50?l001<0oooo00<00000
0?ooo`3oool0903oool60?l00680oooo000h0?ooo`D0o`00>@3oool60?l001D0oooo00<000000?oo
o`3oool08@3oool60?l006D0oooo000f0?ooo`D0o`00>@3oool50?l001P0oooo0P00000O0?ooo`H0
o`00J03oool003<0oooo1P3o000i0?ooo`D0o`006P3oool00`000000oooo0?ooo`0L0?ooo`D0o`00
J`3oool00300oooo1P3o000i0?ooo`D0o`007@3oool00`000000oooo0?ooo`0I0?ooo`H0o`00K@3o
ool002d0oooo1P3o000j0?ooo`D0o`007`3oool00`000000oooo0?ooo`0G0?ooo`D0o`00L03oool0
02/0oooo1@3o000j0?ooo`H0o`008@3oool00`000000oooo0?ooo`0E0?ooo`D0o`00LP3oool002T0
oooo1@3o000j0?ooo`D0o`00903oool00`000000oooo0?ooo`0B0?ooo`D0o`00M@3oool002L0oooo
1@3o000i0?ooo`H0o`007@3oool4000000D0oooo00<000000?ooo`3oool0403oool50?l007L0oooo
000T0?ooo`D0o`00>P3oool50?l00280oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0>0?ooo`D0o`00N@3oool00280oooo1@3o000j0?ooo`D0o`00903oool00`000000oooo0?ooo`04
0?ooo`8000003@3oool50?l007/0oooo000P0?ooo`D0o`00>P3oool50?l002H0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0:0?ooo`D0o`00O@3oool001d0oooo1P3o000i0?ooo`D0
o`00:@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo1@3o001o0?ooo`00
6`3oool50?l003X0oooo1@3o000Y0?ooo`<000001P3oool00`000000oooo0?ooo`050?ooo`H0o`00
P@3oool001T0oooo1@3o000j0?ooo`D0o`00;@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0080oooo1`3o00230?ooo`005P3oool50?l003X0oooo1P3o000f0?ooo`030000003oool0
o`0000H0o`00QP3oool001@0oooo1@3o000j0?ooo`D0o`00>03oool70?l008T0oooo000B0?ooo`D0
o`00>P3oool50?l003P0oooo1P3o002<0?ooo`00403oool50?l003T0oooo1@3o000i0?ooo`D0o`00
00<000000?ooo`3oool0S03oool000h0oooo1@3o000i0?ooo`D0o`00>@3oool50?l00080oooo00<0
00000?ooo`3oool0S03oool000`0oooo1@3o000i0?ooo`D0o`00>@3oool50?l000@0oooo00<00000
0?ooo`3oool0S03oool000/0oooo103o000i0?ooo`D0o`00>@3oool50?l000H0oooo00<000000?oo
o`3oool0S03oool000`0oooo00<0o`000?ooo`3oool0=P3oool50?l003X0oooo1@3o00080?ooo`03
0000003oool0oooo08`0oooo00130?ooo`D0o`00>@3oool60?l000X0oooo00<000000?ooo`3oool0
S03oool00440oooo1@3o000h0?ooo`H0o`003@3oool00`000000oooo0?ooo`2<0?ooo`00?P3oool6
0?l003L0oooo1P3o000@0?ooo`800000S@3oool003/0oooo1P3o000h0?ooo`D0o`004`3oool00`00
0000oooo0?ooo`2<0?ooo`00>03oool60?l003P0oooo1P3o000E0?ooo`030000003oool0oooo08`0
oooo000f0?ooo`D0o`00>@3oool50?l001P0oooo00<000000?ooo`3oool0S03oool003@0oooo1@3o
000i0?ooo`D0o`006P3oool00`000000oooo0?ooo`2<0?ooo`00<P3oool50?l003P0oooo1@3o000M
0?ooo`030000003oool0oooo08`0oooo000_0?ooo`D0o`00>@3oool50?l001l0oooo00<000000?oo
o`3oool0S03oool002d0oooo1@3o000i0?ooo`D0o`008@3oool2000008d0oooo000[0?ooo`D0o`00
>@3oool50?l002<0oooo00<000000?ooo`3oool0S03oool002P0oooo1P3o000i0?ooo`D0o`009@3o
ool00`000000oooo0?ooo`2<0?ooo`009@3oool60?l003X0oooo1@3o000W0?ooo`030000003oool0
oooo08`0oooo000R0?ooo`H0o`00>`3oool50?l002T0oooo00<000000?ooo`3oool0S03oool00200
oooo1@3o000k0?ooo`H0o`00:`3oool00`000000oooo0?ooo`2<0?ooo`007@3oool60?l003X0oooo
1P3o000^0?ooo`030000003oool0oooo08`0oooo000K0?ooo`D0o`00>P3oool60?l00340oooo0P00
002=0?ooo`006@3oool50?l003X0oooo1@3o000d0?ooo`030000003oool0oooo08`0oooo000F0?oo
o`D0o`00>P3oool60?l003H0oooo00<000000?ooo`3oool0S03oool001@0oooo1@3o000j0?ooo`D0
o`00>@3oool00`000000oooo0?ooo`2<0?ooo`004P3oool50?l003X0oooo1@3o000k0?ooo`030000
003oool0oooo08`0oooo000@0?ooo`D0o`00>@3oool50?l003h0oooo00<000000?ooo`3oool0S03o
ool000h0oooo1@3o000i0?ooo`D0o`00=`3oool4000000D0oooo00<000000?ooo`3oool0S03oool0
00`0oooo1@3o000i0?ooo`D0o`00>@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
08`0oooo000;0?ooo`@0o`00>@3oool50?l003`0oooo00<000000?ooo`3oool01@3oool2000008d0
oooo000<0?ooo`030?l0003oool0oooo03H0oooo1@3o00100?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0S03oool004<0oooo1@3o00130?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0S03oool00440oooo1@3o00120?ooo`040000003oool0oooo000000D0oooo00<0
00000?ooo`3oool0S03oool003l0oooo1@3o00150?ooo`8000001P3oool00`000000oooo0?ooo`2<
0?ooo`00?@3oool50?l004l0oooo00<000000?ooo`3oool0S03oool003X0oooo1@3o001B0?ooo`03
0000003oool0oooo08`0oooo000h0?ooo`D0o`00E03oool2000008d0oooo000f0?ooo`D0o`00EP3o
ool00`000000oooo0?ooo`2<0?ooo`00<`3oool60?l005P0oooo00<000000?ooo`3oool0S03oool0
0300oooo1P3o001K0?ooo`030000003oool0oooo08`0oooo000]0?ooo`H0o`00GP3oool00`000000
oooo0?ooo`2<0?ooo`00:`3oool50?l00640oooo00<000000?ooo`3oool0S03oool002T0oooo1@3o
001S0?ooo`030000003oool0oooo08`0oooo000W0?ooo`D0o`00I@3oool00`000000oooo0?ooo`2<
0?ooo`00903oool50?l006P0oooo0P00002=0?ooo`008P3oool50?l006X0oooo00<000000?ooo`3o
ool0S03oool00200oooo1@3o001/0?ooo`030000003oool0oooo08`0oooo000M0?ooo`H0o`00KP3o
ool00`000000oooo0?ooo`2<0?ooo`006`3oool50?l00740oooo00<000000?ooo`3oool0S03oool0
01T0oooo1@3o001c0?ooo`030000003oool0oooo08`0oooo000F0?ooo`D0o`00MP3oool00`000000
oooo0?ooo`2<0?ooo`00503oool50?l007P0oooo0P00002=0?ooo`004@3oool60?l007X0oooo00<0
00000?ooo`3oool0S03oool000l0oooo1@3o001m0?ooo`030000003oool0oooo08`0oooo000<0?oo
o`H0o`00O`3oool00`000000oooo0?ooo`2<0?ooo`002`3oool40?l00880oooo00<000000?ooo`3o
ool0S03oool000`0oooo00<0o`000?ooo`3oool0PP3oool00`000000oooo0?ooo`2<0?ooo`00T@3o
ool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool20000
08d0oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.63535, -1.87551, \
0.0112783, 0.0268511}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(genpl[5, DarkGreen]\)\(\[IndentingNewLine]\)
    \)\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", \(-\(1\/2\)\), \(1\/2\), "0", "0", "0", "0", "0"},
            {\(-\(1\/2\)\), "1", "0", \(1\/\(2\ \@2\)\), 
              "0", \(-\(\@\(3\/2\)\/2\)\), "0", "0"},
            {\(1\/2\), "0", "1", \(-\(1\/\@2\)\), "0", "0", "0", "0"},
            {"0", \(1\/\(2\ \@2\)\), \(-\(1\/\@2\)\), "0", \(-\(1\/\@2\)\), 
              "0", \(1\/\(2\ \@2\)\), "0"},
            {"0", "0", "0", \(-\(1\/\@2\)\), "1", "0", "0", \(-\(1\/2\)\)},
            {"0", \(-\(\@\(3\/2\)\/2\)\), "0", "0", "0", 
              "0", \(-\(\@\(3\/2\)\/2\)\), "0"},
            {"0", "0", "0", \(1\/\(2\ \@2\)\), "0", \(-\(\@\(3\/2\)\/2\)\), 
              "1", \(1\/2\)},
            {"0", "0", "0", "0", \(-\(1\/2\)\), "0", \(1\/2\), "1"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Print"],

Cell[BoxData[
    \({Root[3 - 2\ #1 - 4\ #1\^2 + 2\ #1\^3 &, 3], 1\/2\ \((2 + \@2)\), 
      1\/2\ \((1 + \@3)\), 1, Root[3 - 2\ #1 - 4\ #1\^2 + 2\ #1\^3 &, 1], 
      Root[3 - 2\ #1 - 4\ #1\^2 + 2\ #1\^3 &, 2], 1\/2\ \((1 - \@3)\), 
      1\/2\ \((2 - \@2)\)}\)], "Print"],

Cell[BoxData[
    \({2.139726157884303`, 1.7071067811865475`, 1.3660254037844386`, 
      1.`, \(-0.9100446871873938`\), 
      0.7703185293030906`, \(-0.3660254037844386`\), 
      0.2928932188134524`}\)], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.31746 0.190353 0.192999 [
[.02381 .17785 -12 -9 ]
[.02381 .17785 12 0 ]
[.18254 .17785 -6 -9 ]
[.18254 .17785 6 0 ]
[.34127 .17785 -12 -9 ]
[.34127 .17785 12 0 ]
[.65873 .17785 -9 -9 ]
[.65873 .17785 9 0 ]
[.81746 .17785 -3 -9 ]
[.81746 .17785 3 0 ]
[.97619 .17785 -9 -9 ]
[.97619 .17785 9 0 ]
[.4875 .09385 -24 -4.5 ]
[.4875 .09385 0 4.5 ]
[.4875 .28685 -18 -4.5 ]
[.4875 .28685 0 4.5 ]
[.4875 .38335 -6 -4.5 ]
[.4875 .38335 0 4.5 ]
[.4875 .47985 -18 -4.5 ]
[.4875 .47985 0 4.5 ]
[.4875 .57635 -6 -4.5 ]
[.4875 .57635 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .19035 m
.02381 .1966 L
s
[(-1.5)] .02381 .17785 0 1 Mshowa
.18254 .19035 m
.18254 .1966 L
s
[(-1)] .18254 .17785 0 1 Mshowa
.34127 .19035 m
.34127 .1966 L
s
[(-0.5)] .34127 .17785 0 1 Mshowa
.65873 .19035 m
.65873 .1966 L
s
[(0.5)] .65873 .17785 0 1 Mshowa
.81746 .19035 m
.81746 .1966 L
s
[(1)] .81746 .17785 0 1 Mshowa
.97619 .19035 m
.97619 .1966 L
s
[(1.5)] .97619 .17785 0 1 Mshowa
.125 Mabswid
.05556 .19035 m
.05556 .1941 L
s
.0873 .19035 m
.0873 .1941 L
s
.11905 .19035 m
.11905 .1941 L
s
.15079 .19035 m
.15079 .1941 L
s
.21429 .19035 m
.21429 .1941 L
s
.24603 .19035 m
.24603 .1941 L
s
.27778 .19035 m
.27778 .1941 L
s
.30952 .19035 m
.30952 .1941 L
s
.37302 .19035 m
.37302 .1941 L
s
.40476 .19035 m
.40476 .1941 L
s
.43651 .19035 m
.43651 .1941 L
s
.46825 .19035 m
.46825 .1941 L
s
.53175 .19035 m
.53175 .1941 L
s
.56349 .19035 m
.56349 .1941 L
s
.59524 .19035 m
.59524 .1941 L
s
.62698 .19035 m
.62698 .1941 L
s
.69048 .19035 m
.69048 .1941 L
s
.72222 .19035 m
.72222 .1941 L
s
.75397 .19035 m
.75397 .1941 L
s
.78571 .19035 m
.78571 .1941 L
s
.84921 .19035 m
.84921 .1941 L
s
.88095 .19035 m
.88095 .1941 L
s
.9127 .19035 m
.9127 .1941 L
s
.94444 .19035 m
.94444 .1941 L
s
.25 Mabswid
0 .19035 m
1 .19035 L
s
.5 .09385 m
.50625 .09385 L
s
[(-0.5)] .4875 .09385 1 0 Mshowa
.5 .28685 m
.50625 .28685 L
s
[(0.5)] .4875 .28685 1 0 Mshowa
.5 .38335 m
.50625 .38335 L
s
[(1)] .4875 .38335 1 0 Mshowa
.5 .47985 m
.50625 .47985 L
s
[(1.5)] .4875 .47985 1 0 Mshowa
.5 .57635 m
.50625 .57635 L
s
[(2)] .4875 .57635 1 0 Mshowa
.125 Mabswid
.5 .01665 m
.50375 .01665 L
s
.5 .03595 m
.50375 .03595 L
s
.5 .05525 m
.50375 .05525 L
s
.5 .07455 m
.50375 .07455 L
s
.5 .11315 m
.50375 .11315 L
s
.5 .13245 m
.50375 .13245 L
s
.5 .15175 m
.50375 .15175 L
s
.5 .17105 m
.50375 .17105 L
s
.5 .20965 m
.50375 .20965 L
s
.5 .22895 m
.50375 .22895 L
s
.5 .24825 m
.50375 .24825 L
s
.5 .26755 m
.50375 .26755 L
s
.5 .30615 m
.50375 .30615 L
s
.5 .32545 m
.50375 .32545 L
s
.5 .34475 m
.50375 .34475 L
s
.5 .36405 m
.50375 .36405 L
s
.5 .40265 m
.50375 .40265 L
s
.5 .42195 m
.50375 .42195 L
s
.5 .44125 m
.50375 .44125 L
s
.5 .46055 m
.50375 .46055 L
s
.5 .49915 m
.50375 .49915 L
s
.5 .51845 m
.50375 .51845 L
s
.5 .53775 m
.50375 .53775 L
s
.5 .55705 m
.50375 .55705 L
s
.5 .59565 m
.50375 .59565 L
s
.5 .61495 m
.50375 .61495 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 .392 0 r
.5 Mabswid
.02381 .60332 m
.06244 .60332 L
.10458 .60332 L
.14415 .60332 L
.18221 .60332 L
.22272 .60332 L
.26171 .60332 L
.30316 .60332 L
.34309 .60332 L
.3815 .60332 L
.42237 .60332 L
.46172 .60332 L
.49955 .60332 L
.53984 .60332 L
.57861 .60332 L
.61984 .60332 L
.65954 .60332 L
.69774 .60332 L
.73838 .60332 L
.77751 .60332 L
.81909 .60332 L
.85916 .60332 L
.89771 .60332 L
.93871 .60332 L
.97619 .60332 L
s
.02381 .51982 m
.06244 .51982 L
.10458 .51982 L
.14415 .51982 L
.18221 .51982 L
.22272 .51982 L
.26171 .51982 L
.30316 .51982 L
.34309 .51982 L
.3815 .51982 L
.42237 .51982 L
.46172 .51982 L
.49955 .51982 L
.53984 .51982 L
.57861 .51982 L
.61984 .51982 L
.65954 .51982 L
.69774 .51982 L
.73838 .51982 L
.77751 .51982 L
.81909 .51982 L
.85916 .51982 L
.89771 .51982 L
.93871 .51982 L
.97619 .51982 L
s
.02381 .454 m
.06244 .454 L
.10458 .454 L
.14415 .454 L
.18221 .454 L
.22272 .454 L
.26171 .454 L
.30316 .454 L
.34309 .454 L
.3815 .454 L
.42237 .454 L
.46172 .454 L
.49955 .454 L
.53984 .454 L
.57861 .454 L
.61984 .454 L
.65954 .454 L
.69774 .454 L
.73838 .454 L
.77751 .454 L
.81909 .454 L
.85916 .454 L
.89771 .454 L
.93871 .454 L
.97619 .454 L
s
.02381 .38335 m
.06244 .38335 L
.10458 .38335 L
.14415 .38335 L
.18221 .38335 L
.22272 .38335 L
.26171 .38335 L
.30316 .38335 L
.34309 .38335 L
.3815 .38335 L
.42237 .38335 L
.46172 .38335 L
.49955 .38335 L
.53984 .38335 L
.57861 .38335 L
.61984 .38335 L
.65954 .38335 L
.69774 .38335 L
.73838 .38335 L
.77751 .38335 L
.81909 .38335 L
.85916 .38335 L
.89771 .38335 L
.93871 .38335 L
.97619 .38335 L
s
.02381 .01472 m
.06244 .01472 L
.10458 .01472 L
.14415 .01472 L
.18221 .01472 L
.22272 .01472 L
.26171 .01472 L
.30316 .01472 L
.34309 .01472 L
.3815 .01472 L
.42237 .01472 L
.46172 .01472 L
.49955 .01472 L
.53984 .01472 L
.57861 .01472 L
.61984 .01472 L
.65954 .01472 L
.69774 .01472 L
.73838 .01472 L
.77751 .01472 L
.81909 .01472 L
.85916 .01472 L
.89771 .01472 L
.93871 .01472 L
.97619 .01472 L
s
.02381 .33902 m
.06244 .33902 L
.10458 .33902 L
.14415 .33902 L
.18221 .33902 L
.22272 .33902 L
.26171 .33902 L
.30316 .33902 L
.34309 .33902 L
.3815 .33902 L
.42237 .33902 L
.46172 .33902 L
.49955 .33902 L
.53984 .33902 L
.57861 .33902 L
.61984 .33902 L
.65954 .33902 L
.69774 .33902 L
.73838 .33902 L
.77751 .33902 L
.81909 .33902 L
.85916 .33902 L
.89771 .33902 L
.93871 .33902 L
.97619 .33902 L
s
.02381 .11971 m
.06244 .11971 L
.10458 .11971 L
.14415 .11971 L
.18221 .11971 L
.22272 .11971 L
.26171 .11971 L
.30316 .11971 L
.34309 .11971 L
.3815 .11971 L
.42237 .11971 L
.46172 .11971 L
.49955 .11971 L
.53984 .11971 L
.57861 .11971 L
.61984 .11971 L
.65954 .11971 L
.69774 .11971 L
.73838 .11971 L
.77751 .11971 L
.81909 .11971 L
.85916 .11971 L
.89771 .11971 L
.93871 .11971 L
.97619 .11971 L
s
.02381 .24688 m
.06244 .24688 L
.10458 .24688 L
.14415 .24688 L
.18221 .24688 L
.22272 .24688 L
.26171 .24688 L
.30316 .24688 L
.34309 .24688 L
.3815 .24688 L
.42237 .24688 L
.46172 .24688 L
.49955 .24688 L
.53984 .24688 L
.57861 .24688 L
.61984 .24688 L
.65954 .24688 L
.69774 .24688 L
.73838 .24688 L
.77751 .24688 L
.81909 .24688 L
.85916 .24688 L
.89771 .24688 L
.93871 .24688 L
.97619 .24688 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo
0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<
0?ooo`00303ooooo001T00`006@02@3oool00940oooo00<000000?ooo`3oool0S03oool00940oooo
00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<00000
0?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool2000008d0
oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A
0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`03
0000003oool0oooo08`0oooo002A0?ooo`800000S@3oool00940oooo00<000000?ooo`3oool0S03o
ool00940oooo00<000000?ooo`3oool0S03oool007d0oooo0P0000040?ooo`030000003oool0oooo
0080oooo0`0000060?ooo`030000003oool0oooo08`0oooo001l0?ooo`040000003oool0oooo0000
00/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2<0?ooo`00O03oool010000000
oooo0?ooo`00000;0?ooo`030000003oool0oooo00<0oooo0P00002=0?ooo`00MP3oool400000080
oooo00@000000?ooo`3oool00000203oool3000000H0oooo00<000000?ooo`3oool0S03oool007`0
oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
08`0oooo001l0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`2<0?ooo`00O@3oool2000000T0oooo100000050?ooo`030000003oool0oooo08`0
oooo002A0?ooo`800000S@3oool00940oooo00<000000?ooo`3oool0S03oool000`0ooooo`00I00<
001T00T0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0
oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`800000S@3oool00940oooo00<00000
0?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3o
ool0S03oool00940oooo00<000000?ooo`3oool0S03oool000L0oooo100000030?ooo`030000003o
ool0oooo0080oooo0`00000S0?ooo`@000008`3oool2000000@0oooo00<000000?ooo`3oool00P3o
ool3000002<0oooo0P00000S0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`<000008`3o
ool4000002<0oooo100000030?ooo`030000003oool0oooo0080oooo0`0000030?ooo`002@3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool08@3oool0
10000000oooo0?ooo`00000;0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool08@3o
ool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0
903oool00`000000oooo0?ooo`0:0?ooo`4000000@3oool10?ooo`002@3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool08@3oool010000000oooo0?oo
o`00000;0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool08@3oool010000000oooo
0?ooo`00000;0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0903oool00`000000
oooo0?ooo`0:0?ooo`4000000@3oool10?ooo`0000<0oooo0000000000000P0000040?ooo`030000
003oool0oooo00L0oooo0`00000M0?ooo`@00000103oool00`000000oooo0?ooo`0K0?ooo`@00000
0P3oool010000000oooo0?ooo`0000080?ooo`<000008`3oool00`000000oooo0?ooo`0Q0?ooo`04
0000003oool0oooo000000P0oooo0`00000U0?ooo`030000003oool0oooo02@0oooo00<000000?oo
o`3oool01`3oool3000000<0oooo00090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool09@3oool00`000000oooo0?ooo`0Q0?ooo`040000003oool0oooo000000P0oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`0Q0?ooo`040000003oool0oooo000000P0oooo00<00000
0?ooo`3oool09@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool00`3oool000L0oooo0`0000090?ooo`030000003oool0oooo02<0oooo0`00000S0?oo
o`040000003oool0oooo000000P0oooo00<000000?ooo`3oool08`3oool200000280oooo00@00000
0?ooo`3oool00000203oool00`000000oooo0?ooo`0S0?ooo`<00000903oool3000000T0oooo00<0
00000?ooo`3oool00`3oool000T0oooo00<000000?ooo`3oool01`3oool4000002@0oooo00<00000
0?ooo`3oool08P3oool2000000T0oooo1000000R0?ooo`030000003oool0oooo0280oooo0P000009
0?ooo`@00000903oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00L0oooo10000002
0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`001@3ooooo
000001T000000`3oool000`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool000`0oooo00<000000?ooo`3o
ool0:@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3o
ool0:@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3o
ool01`3oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03o
ool00940oooo0P00002=0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool2000008d0oooo002A0?ooo`03
0000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003o
ool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo000<0?ooool006@03000I0090?oo
o`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3o
ool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool20000
08d0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo
002A0?ooo`030000003oool0oooo08`0oooo001m0?ooo`800000103oool00`000000oooo0?ooo`02
0?ooo`<000001P3oool00`000000oooo0?ooo`2<0?ooo`00O03oool010000000oooo0?ooo`00000;
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0S03oool007`0oooo00@000000?oo
o`3oool000002`3oool00`000000oooo0?ooo`030?ooo`800000S@3oool007`0oooo00@000000?oo
o`3oool00000203oool3000000H0oooo00<000000?ooo`3oool0S03oool007`0oooo00@000000?oo
o`3oool00000203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08`0oooo001l0?oo
o`040000003oool0oooo000000P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2<
0?ooo`00O@3oool2000000T0oooo100000050?ooo`030000003oool0oooo08`0oooo002A0?ooo`80
0000S@3oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03o
ool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940
oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00303ooooo001T00`006@02@3oool00940
oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool2000008d0oooo002A0?ooo`030000003o
ool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo
08`0oooo00280?ooo`@000001@3oool00`000000oooo0?ooo`2<0?ooo`00RP3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo08`0oooo000<0?ooool006@03000I0090?ooo`00RP3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo08`0oooo002:0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0S03oool008P0oooo0`0000060?ooo`030000003oool0oooo08`0
oooo002:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0S03oool00940oooo0P00
002=0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3o
ool00`000000oooo0?ooo`2<0?ooo`00T@3oool2000008d0oooo002A0?ooo`030000003oool0oooo
08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo
002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`800000S@3oool00940oooo00<000000?oo
o`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0
S03oool000`0ooooo`00I00<001T00T0oooo002A0?ooo`800000S@3oool00940oooo00<000000?oo
o`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0
S03oool007`0oooo100000030?ooo`030000003oool0oooo0080oooo0`0000060?ooo`030000003o
ool0oooo08`0oooo001n0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`2<0?ooo`00OP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00<0oooo0P00002=0?ooo`00OP3oool00`000000oooo0?ooo`070?ooo`<000001P3oool00`000000
oooo0?ooo`2<0?ooo`00OP3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0S03oool007`0oooo0`0000090?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0S03oool007h0oooo00<000000?ooo`3oool01`3oool4000000D0oooo00<00000
0?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00303ooooo001T00`0
06@02@3oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03o
ool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940
oooo0P00002=0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00T@3oool2000008d0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003o
ool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo00280?ooo`@000001@3oool00`00
0000oooo0?ooo`2<0?ooo`00R03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08`0
oooo00290?ooo`030000003oool0oooo00D0oooo0P00002=0?ooo`00RP3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo08`0oooo002;0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0S03oool008P0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`2<
0?ooo`00R@3oool2000000H0oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00303ooooo001T00`006@02@3oool00940oooo00<00000
0?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.63535, -1.02639, \
0.0112783, 0.0185515}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(genpl[6, DarkGreen, Thickness[0.006]]\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Print"],

Cell[BoxData[
    \({0}\)], "Print"],

Cell[BoxData[
    \({0.`}\)], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.31746 0.309017 0.294302 [
[.02381 .29652 -12 -9 ]
[.02381 .29652 12 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -12 -9 ]
[.34127 .29652 12 0 ]
[.65873 .29652 -9 -9 ]
[.65873 .29652 9 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.4875 .01472 -12 -4.5 ]
[.4875 .01472 0 4.5 ]
[.4875 .16187 -24 -4.5 ]
[.4875 .16187 0 4.5 ]
[.4875 .45617 -18 -4.5 ]
[.4875 .45617 0 4.5 ]
[.4875 .60332 -6 -4.5 ]
[.4875 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-1.5)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-1)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-0.5)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(0.5)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(1)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 .01472 m
.50625 .01472 L
s
[(-1)] .4875 .01472 1 0 Mshowa
.5 .16187 m
.50625 .16187 L
s
[(-0.5)] .4875 .16187 1 0 Mshowa
.5 .45617 m
.50625 .45617 L
s
[(0.5)] .4875 .45617 1 0 Mshowa
.5 .60332 m
.50625 .60332 L
s
[(1)] .4875 .60332 1 0 Mshowa
.125 Mabswid
.5 .04415 m
.50375 .04415 L
s
.5 .07358 m
.50375 .07358 L
s
.5 .10301 m
.50375 .10301 L
s
.5 .13244 m
.50375 .13244 L
s
.5 .1913 m
.50375 .1913 L
s
.5 .22073 m
.50375 .22073 L
s
.5 .25016 m
.50375 .25016 L
s
.5 .27959 m
.50375 .27959 L
s
.5 .33845 m
.50375 .33845 L
s
.5 .36788 m
.50375 .36788 L
s
.5 .39731 m
.50375 .39731 L
s
.5 .42674 m
.50375 .42674 L
s
.5 .4856 m
.50375 .4856 L
s
.5 .51503 m
.50375 .51503 L
s
.5 .54446 m
.50375 .54446 L
s
.5 .57389 m
.50375 .57389 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 .392 0 r
.006 w
.02381 .30902 m
.02499 .30902 L
.02605 .30902 L
.02729 .30902 L
.02846 .30902 L
.02954 .30902 L
.03053 .30902 L
.03163 .30902 L
.03279 .30902 L
.03395 .30902 L
.0352 .30902 L
.03638 .30902 L
.03746 .30902 L
.03873 .30902 L
.03944 .30902 L
.04011 .30902 L
.04132 .30902 L
.04262 .30902 L
.04327 .30902 L
.04396 .30902 L
.04519 .30902 L
.04588 .30902 L
.04652 .30902 L
.04722 .30902 L
.04797 .30902 L
.04862 .30902 L
.04933 .30902 L
.05061 .30902 L
.05186 .30902 L
.05302 .30902 L
.05414 .30902 L
.05519 .30902 L
.05634 .30902 L
.05759 .30902 L
.05882 .30902 L
.06012 .30902 L
.06123 .30902 L
.06244 .30902 L
.06315 .30902 L
.06381 .30902 L
.06453 .30902 L
.06529 .30902 L
.06657 .30902 L
.06729 .30902 L
.06797 .30902 L
.06924 .30902 L
.0704 .30902 L
.07103 .30902 L
.07173 .30902 L
.073 .30902 L
Mistroke
.07376 .30902 L
.07448 .30902 L
.07513 .30902 L
.07583 .30902 L
.0766 .30902 L
.0774 .30902 L
.07809 .30902 L
.07885 .30902 L
.07956 .30902 L
.0802 .30902 L
.08095 .30902 L
.08166 .30902 L
.08291 .30902 L
.08362 .30902 L
.08427 .30902 L
.08544 .30902 L
.08669 .30902 L
.08787 .30902 L
.08896 .30902 L
.09016 .30902 L
.09148 .30902 L
.09214 .30902 L
.09285 .30902 L
.09413 .30902 L
.09483 .30902 L
.09548 .30902 L
.09619 .30902 L
.09695 .30902 L
.09821 .30902 L
.09893 .30902 L
.09961 .30902 L
.10086 .30902 L
.10201 .30902 L
.10333 .30902 L
.10458 .30902 L
.10572 .30902 L
.10694 .30902 L
.1081 .30902 L
.10916 .30902 L
.11033 .30902 L
.11162 .30902 L
.11227 .30902 L
.11297 .30902 L
.11422 .30902 L
.11491 .30902 L
.11554 .30902 L
.11624 .30902 L
.11698 .30902 L
.11822 .30902 L
.11892 .30902 L
Mistroke
.11958 .30902 L
.12081 .30902 L
.12194 .30902 L
.12323 .30902 L
.12446 .30902 L
.12562 .30902 L
.12668 .30902 L
.12789 .30902 L
.12903 .30902 L
.13009 .30902 L
.13107 .30902 L
.13214 .30902 L
.13327 .30902 L
.13441 .30902 L
.13564 .30902 L
.1368 .30902 L
.13785 .30902 L
.13909 .30902 L
.13979 .30902 L
.14043 .30902 L
.14162 .30902 L
.14288 .30902 L
.14402 .30902 L
.14526 .30902 L
.14656 .30902 L
.14777 .30902 L
.14891 .30902 L
.14994 .30902 L
.15113 .30902 L
.15226 .30902 L
.15348 .30902 L
.15478 .30902 L
.15589 .30902 L
.15711 .30902 L
.15842 .30902 L
.15915 .30902 L
.15982 .30902 L
.16113 .30902 L
.16236 .30902 L
.16352 .30902 L
.16456 .30902 L
.16577 .30902 L
.1669 .30902 L
.16796 .30902 L
.16893 .30902 L
.16999 .30902 L
.17111 .30902 L
.17225 .30902 L
.17347 .30902 L
.17462 .30902 L
Mistroke
.17566 .30902 L
.17689 .30902 L
.17758 .30902 L
.17823 .30902 L
.1794 .30902 L
.18065 .30902 L
.18185 .30902 L
.18316 .30902 L
.18441 .30902 L
.18556 .30902 L
.1867 .30902 L
.18773 .30902 L
.18893 .30902 L
.19005 .30902 L
.19128 .30902 L
.19258 .30902 L
.19369 .30902 L
.19491 .30902 L
.19623 .30902 L
.19696 .30902 L
.19763 .30902 L
.19894 .30902 L
.20017 .30902 L
.20122 .30902 L
.20238 .30902 L
.20359 .30902 L
.20472 .30902 L
.20578 .30902 L
.20675 .30902 L
.20781 .30902 L
.20894 .30902 L
.21008 .30902 L
.21129 .30902 L
.21244 .30902 L
.21349 .30902 L
.21472 .30902 L
.21541 .30902 L
.21605 .30902 L
.21723 .30902 L
.21847 .30902 L
.21968 .30902 L
.221 .30902 L
.22224 .30902 L
.2234 .30902 L
.22454 .30902 L
.22558 .30902 L
.22677 .30902 L
.2279 .30902 L
.22914 .30902 L
.23044 .30902 L
Mistroke
.23155 .30902 L
.23277 .30902 L
.23409 .30902 L
.23482 .30902 L
.2355 .30902 L
.2368 .30902 L
.23804 .30902 L
.23909 .30902 L
.24025 .30902 L
.24146 .30902 L
.2426 .30902 L
.24365 .30902 L
.24462 .30902 L
.24569 .30902 L
.24681 .30902 L
.24795 .30902 L
.24917 .30902 L
.25032 .30902 L
.25137 .30902 L
.2526 .30902 L
.25329 .30902 L
.25393 .30902 L
.2551 .30902 L
.25635 .30902 L
.25756 .30902 L
.25888 .30902 L
.26013 .30902 L
.26129 .30902 L
.26233 .30902 L
.26348 .30902 L
.26467 .30902 L
.2658 .30902 L
.26704 .30902 L
.26835 .30902 L
.26946 .30902 L
.27068 .30902 L
.272 .30902 L
.27274 .30902 L
.27341 .30902 L
.27472 .30902 L
.27595 .30902 L
.27701 .30902 L
.27817 .30902 L
.27938 .30902 L
.28052 .30902 L
.28158 .30902 L
.28255 .30902 L
.28367 .30902 L
.28474 .30902 L
.28588 .30902 L
Mistroke
.2871 .30902 L
.28825 .30902 L
.2893 .30902 L
.29053 .30902 L
.29122 .30902 L
.29186 .30902 L
.29303 .30902 L
.29427 .30902 L
.29549 .30902 L
.29618 .30902 L
.29682 .30902 L
.29799 .30902 L
.29923 .30902 L
.30034 .30902 L
.30138 .30902 L
.30252 .30902 L
.30375 .30902 L
.30499 .30902 L
.30569 .30902 L
.30634 .30902 L
.30765 .30902 L
.30839 .30902 L
.30906 .30902 L
.31026 .30902 L
.31156 .30902 L
.31278 .30902 L
.31392 .30902 L
.31497 .30902 L
.31611 .30902 L
.31718 .30902 L
.31816 .30902 L
.3193 .30902 L
.32055 .30902 L
.32173 .30902 L
.32282 .30902 L
.32406 .30902 L
.32522 .30902 L
.32626 .30902 L
.32739 .30902 L
.32862 .30902 L
.32992 .30902 L
.33103 .30902 L
.33225 .30902 L
.33356 .30902 L
.33477 .30902 L
.33541 .30902 L
.3361 .30902 L
.33683 .30902 L
.33751 .30902 L
.33876 .30902 L
Mistroke
.33991 .30902 L
.34123 .30902 L
.34249 .30902 L
.3436 .30902 L
.3448 .30902 L
.34592 .30902 L
.34694 .30902 L
.34814 .30902 L
.34945 .30902 L
.35067 .30902 L
.35181 .30902 L
.35302 .30902 L
.35431 .30902 L
.35554 .30902 L
.35665 .30902 L
.35796 .30902 L
.3587 .30902 L
.35939 .30902 L
.36064 .30902 L
.36128 .30902 L
.36198 .30902 L
.36266 .30902 L
.36337 .30902 L
.36465 .30902 L
.36536 .30902 L
.36602 .30902 L
.36675 .30902 L
.36753 .30902 L
.3682 .30902 L
.36893 .30902 L
.36962 .30902 L
.37026 .30902 L
.37146 .30902 L
.37274 .30902 L
.37394 .30902 L
.37526 .30902 L
.37651 .30902 L
.37766 .30902 L
.3788 .30902 L
.37984 .30902 L
.38103 .30902 L
.38216 .30902 L
.38339 .30902 L
.3847 .30902 L
.38581 .30902 L
.38703 .30902 L
.38834 .30902 L
.38908 .30902 L
.38975 .30902 L
.39106 .30902 L
Mistroke
.39229 .30902 L
.39334 .30902 L
.3945 .30902 L
.39571 .30902 L
.39685 .30902 L
.39791 .30902 L
.39888 .30902 L
.39994 .30902 L
.40106 .30902 L
.40221 .30902 L
.40342 .30902 L
.40457 .30902 L
.40562 .30902 L
.40685 .30902 L
.40754 .30902 L
.40818 .30902 L
.40936 .30902 L
.4106 .30902 L
.41181 .30902 L
.41313 .30902 L
.41438 .30902 L
.41554 .30902 L
.41669 .30902 L
.41772 .30902 L
.41892 .30902 L
.42005 .30902 L
.42129 .30902 L
.42259 .30902 L
.42371 .30902 L
.42493 .30902 L
.42624 .30902 L
.42698 .30902 L
.42765 .30902 L
.42896 .30902 L
.43019 .30902 L
.43125 .30902 L
.43241 .30902 L
.43362 .30902 L
.43476 .30902 L
.43582 .30902 L
.43679 .30902 L
.43791 .30902 L
.43898 .30902 L
.44012 .30902 L
.44134 .30902 L
.44249 .30902 L
.44354 .30902 L
.44477 .30902 L
.44546 .30902 L
.4461 .30902 L
Mistroke
.44727 .30902 L
.44851 .30902 L
.44973 .30902 L
.45042 .30902 L
.45106 .30902 L
.45223 .30902 L
.45347 .30902 L
.45458 .30902 L
.45562 .30902 L
.45676 .30902 L
.45799 .30902 L
.45922 .30902 L
.45992 .30902 L
.46057 .30902 L
.46188 .30902 L
.46262 .30902 L
.46329 .30902 L
.46449 .30902 L
.46579 .30902 L
.46702 .30902 L
.46815 .30902 L
.4692 .30902 L
.47034 .30902 L
.47141 .30902 L
.47239 .30902 L
.47353 .30902 L
.47478 .30902 L
.47596 .30902 L
.47705 .30902 L
.47829 .30902 L
.47945 .30902 L
.48049 .30902 L
.48162 .30902 L
.48285 .30902 L
.48415 .30902 L
.48526 .30902 L
.48648 .30902 L
.48779 .30902 L
.489 .30902 L
.48963 .30902 L
.49033 .30902 L
.49105 .30902 L
.49174 .30902 L
.49299 .30902 L
.49413 .30902 L
.49539 .30902 L
.49671 .30902 L
.49783 .30902 L
.49902 .30902 L
.50014 .30902 L
Mistroke
.50116 .30902 L
.50236 .30902 L
.50366 .30902 L
.50489 .30902 L
.50603 .30902 L
.50723 .30902 L
.50853 .30902 L
.50975 .30902 L
.51087 .30902 L
.51218 .30902 L
.51292 .30902 L
.51361 .30902 L
.51486 .30902 L
.5155 .30902 L
.5162 .30902 L
.51687 .30902 L
.51759 .30902 L
.51886 .30902 L
.51958 .30902 L
.52024 .30902 L
.52096 .30902 L
.52174 .30902 L
.52241 .30902 L
.52314 .30902 L
.52383 .30902 L
.52447 .30902 L
.52568 .30902 L
.52695 .30902 L
.52816 .30902 L
.52947 .30902 L
.53072 .30902 L
.53187 .30902 L
.53301 .30902 L
.53405 .30902 L
.53525 .30902 L
.53637 .30902 L
.5376 .30902 L
.53891 .30902 L
.54002 .30902 L
.54124 .30902 L
.54255 .30902 L
.54329 .30902 L
.54396 .30902 L
.54526 .30902 L
.5465 .30902 L
.54755 .30902 L
.54871 .30902 L
.54992 .30902 L
.55105 .30902 L
.55211 .30902 L
Mistroke
.55308 .30902 L
.55415 .30902 L
.55527 .30902 L
.55641 .30902 L
.55763 .30902 L
.55878 .30902 L
.55982 .30902 L
.56105 .30902 L
.56175 .30902 L
.56238 .30902 L
.56356 .30902 L
.5648 .30902 L
.56601 .30902 L
.56734 .30902 L
.56858 .30902 L
.56974 .30902 L
.57088 .30902 L
.57192 .30902 L
.57312 .30902 L
.57425 .30902 L
.57548 .30902 L
.57679 .30902 L
.5779 .30902 L
.57912 .30902 L
.58044 .30902 L
.58118 .30902 L
.58185 .30902 L
.58315 .30902 L
.58439 .30902 L
.58544 .30902 L
.5866 .30902 L
.58782 .30902 L
.58895 .30902 L
.59001 .30902 L
.59098 .30902 L
.5921 .30902 L
.59317 .30902 L
.59431 .30902 L
.59553 .30902 L
.59668 .30902 L
.59773 .30902 L
.59896 .30902 L
.59965 .30902 L
.60029 .30902 L
.60146 .30902 L
.60271 .30902 L
.60392 .30902 L
.60461 .30902 L
.60525 .30902 L
.60642 .30902 L
Mistroke
.60766 .30902 L
.60876 .30902 L
.6098 .30902 L
.61094 .30902 L
.61217 .30902 L
.61341 .30902 L
.6141 .30902 L
.61475 .30902 L
.61607 .30902 L
.6168 .30902 L
.61747 .30902 L
.61867 .30902 L
.61997 .30902 L
.6212 .30902 L
.62233 .30902 L
.62339 .30902 L
.62452 .30902 L
.62559 .30902 L
.62657 .30902 L
.62771 .30902 L
.62896 .30902 L
.63014 .30902 L
.63123 .30902 L
.63247 .30902 L
.63363 .30902 L
.63467 .30902 L
.6358 .30902 L
.63703 .30902 L
.63833 .30902 L
.63944 .30902 L
.64066 .30902 L
.64197 .30902 L
.64318 .30902 L
.64381 .30902 L
.6445 .30902 L
.64523 .30902 L
.64591 .30902 L
.64716 .30902 L
.64831 .30902 L
.64956 .30902 L
.65088 .30902 L
.652 .30902 L
.65319 .30902 L
.65431 .30902 L
.65533 .30902 L
.65653 .30902 L
.65784 .30902 L
.65906 .30902 L
.6602 .30902 L
.6614 .30902 L
Mistroke
.6627 .30902 L
.66392 .30902 L
.66504 .30902 L
.66635 .30902 L
.66709 .30902 L
.66777 .30902 L
.66903 .30902 L
.66966 .30902 L
.67036 .30902 L
.67104 .30902 L
.67175 .30902 L
.67303 .30902 L
.67374 .30902 L
.6744 .30902 L
.67513 .30902 L
.67591 .30902 L
.67658 .30902 L
.67731 .30902 L
.678 .30902 L
.67864 .30902 L
.67984 .30902 L
.68112 .30902 L
.68232 .30902 L
.68364 .30902 L
.68488 .30902 L
.68603 .30902 L
.68718 .30902 L
.68821 .30902 L
.68941 .30902 L
.69053 .30902 L
.69176 .30902 L
.69307 .30902 L
.69418 .30902 L
.6954 .30902 L
.69671 .30902 L
.69745 .30902 L
.69812 .30902 L
.69942 .30902 L
.70066 .30902 L
.70171 .30902 L
.70286 .30902 L
.70407 .30902 L
.70521 .30902 L
.70627 .30902 L
.70724 .30902 L
.7083 .30902 L
.70942 .30902 L
.71056 .30902 L
.71178 .30902 L
.71293 .30902 L
Mistroke
.71398 .30902 L
.71521 .30902 L
.7159 .30902 L
.71654 .30902 L
.71771 .30902 L
.71896 .30902 L
.72017 .30902 L
.72149 .30902 L
.72273 .30902 L
.72389 .30902 L
.72503 .30902 L
.72607 .30902 L
.72727 .30902 L
.7284 .30902 L
.72963 .30902 L
.73094 .30902 L
.73205 .30902 L
.73327 .30902 L
.73458 .30902 L
.73532 .30902 L
.73599 .30902 L
.7373 .30902 L
.73853 .30902 L
.73959 .30902 L
.74075 .30902 L
.74196 .30902 L
.7431 .30902 L
.74416 .30902 L
.74513 .30902 L
.74619 .30902 L
.74731 .30902 L
.74846 .30902 L
.74967 .30902 L
.75083 .30902 L
.75187 .30902 L
.7531 .30902 L
.75379 .30902 L
.75443 .30902 L
.75561 .30902 L
.75685 .30902 L
.75806 .30902 L
.75875 .30902 L
.75939 .30902 L
.76056 .30902 L
.7618 .30902 L
.7629 .30902 L
.76394 .30902 L
.76508 .30902 L
.76631 .30902 L
.76754 .30902 L
Mistroke
.76824 .30902 L
.76889 .30902 L
.7702 .30902 L
.77094 .30902 L
.77161 .30902 L
.7728 .30902 L
.7741 .30902 L
.77533 .30902 L
.77646 .30902 L
.77752 .30902 L
.77865 .30902 L
.77972 .30902 L
.7807 .30902 L
.78184 .30902 L
.78309 .30902 L
.78427 .30902 L
.78536 .30902 L
.7866 .30902 L
.78776 .30902 L
.7888 .30902 L
.78993 .30902 L
.79116 .30902 L
.79246 .30902 L
.79357 .30902 L
.79479 .30902 L
.7961 .30902 L
.7973 .30902 L
.79793 .30902 L
.79863 .30902 L
.79936 .30902 L
.80004 .30902 L
.80129 .30902 L
.80243 .30902 L
.80369 .30902 L
.80501 .30902 L
.80612 .30902 L
.80731 .30902 L
.80843 .30902 L
.80945 .30902 L
.81066 .30902 L
.81196 .30902 L
.81318 .30902 L
.81432 .30902 L
.81552 .30902 L
.81682 .30902 L
.81804 .30902 L
.81916 .30902 L
.82047 .30902 L
.8212 .30902 L
.82189 .30902 L
Mistroke
.82315 .30902 L
.82385 .30902 L
.82448 .30902 L
.82516 .30902 L
.82587 .30902 L
.82715 .30902 L
.82786 .30902 L
.82852 .30902 L
.82925 .30902 L
.83002 .30902 L
.8307 .30902 L
.83143 .30902 L
.83212 .30902 L
.83275 .30902 L
.83396 .30902 L
.83524 .30902 L
.83644 .30902 L
.83775 .30902 L
.839 .30902 L
.84015 .30902 L
.84129 .30902 L
.84232 .30902 L
.84352 .30902 L
.84464 .30902 L
.84587 .30902 L
.84718 .30902 L
.84829 .30902 L
.8495 .30902 L
.85082 .30902 L
.85155 .30902 L
.85222 .30902 L
.85353 .30902 L
.85476 .30902 L
.85581 .30902 L
.85697 .30902 L
.85818 .30902 L
.85932 .30902 L
.86037 .30902 L
.86134 .30902 L
.86241 .30902 L
.86353 .30902 L
.86467 .30902 L
.86589 .30902 L
.86704 .30902 L
.86808 .30902 L
.86931 .30902 L
.87 .30902 L
.87064 .30902 L
.87182 .30902 L
.87306 .30902 L
Mistroke
.87427 .30902 L
.87559 .30902 L
.87684 .30902 L
.87799 .30902 L
.87914 .30902 L
.88017 .30902 L
.88137 .30902 L
.88249 .30902 L
.88373 .30902 L
.88503 .30902 L
.88615 .30902 L
.88737 .30902 L
.88868 .30902 L
.88942 .30902 L
.89009 .30902 L
.89139 .30902 L
.89263 .30902 L
.89368 .30902 L
.89484 .30902 L
.89605 .30902 L
.89719 .30902 L
.89825 .30902 L
.89922 .30902 L
.90029 .30902 L
.90141 .30902 L
.90255 .30902 L
.90377 .30902 L
.90492 .30902 L
.90596 .30902 L
.90719 .30902 L
.90789 .30902 L
.90852 .30902 L
.9097 .30902 L
.91094 .30902 L
.91216 .30902 L
.91284 .30902 L
.91348 .30902 L
.91464 .30902 L
.91589 .30902 L
.91699 .30902 L
.91803 .30902 L
.91917 .30902 L
.9204 .30902 L
.92163 .30902 L
.92233 .30902 L
.92297 .30902 L
.92429 .30902 L
.92502 .30902 L
.92569 .30902 L
.92689 .30902 L
Mistroke
.92819 .30902 L
.92941 .30902 L
.93055 .30902 L
.9316 .30902 L
.93273 .30902 L
.9338 .30902 L
.93478 .30902 L
.93592 .30902 L
.93717 .30902 L
.93835 .30902 L
.93944 .30902 L
.94068 .30902 L
.94184 .30902 L
.94288 .30902 L
.94401 .30902 L
.94524 .30902 L
.94654 .30902 L
.94765 .30902 L
.94887 .30902 L
.94975 .30902 L
.95057 .30902 L
.95146 .30902 L
.95241 .30902 L
.95324 .30902 L
.95401 .30902 L
.95486 .30902 L
.95577 .30902 L
.95653 .30902 L
.95737 .30902 L
.95824 .30902 L
.95905 .30902 L
.95981 .30902 L
.9605 .30902 L
.9613 .30902 L
.96206 .30902 L
.96287 .30902 L
.96377 .30902 L
.96471 .30902 L
.96559 .30902 L
.96641 .30902 L
.96716 .30902 L
.96802 .30902 L
.96884 .30902 L
.96972 .30902 L
.97067 .30902 L
.97155 .30902 L
.97236 .30902 L
.97331 .30902 L
.97433 .30902 L
.9753 .30902 L
Mistroke
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo
0?ooo`2<0?ooo`00R03oool4000000D0oooo00<000000?ooo`3oool0S03oool008X0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`2<0?ooo`00RP3oool00`000000oooo0?ooo`040?oo
o`800000S@3oool00880oooo100000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0S03oool008X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2<0?ooo`00R03o
ool3000000H0oooo00<000000?ooo`3oool0S03oool008X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool2000008d0oooo002A
0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`03
0000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003o
ool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo
08`0oooo002A0?ooo`800000S@3oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<0
00000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?oo
o`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0
S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00T@3oool00`00
0000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo
0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<
0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool2000008d0oooo002A0?ooo`030000003oool0
oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0
oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo001m
0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`<000001P3oool00`000000oooo0?ooo`2<
0?ooo`00O03oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0S03oool007`0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`03
0?ooo`800000S@3oool007H0oooo100000020?ooo`040000003oool0oooo000000P0oooo0`000006
0?ooo`030000003oool0oooo08`0oooo001l0?ooo`040000003oool0oooo000000P0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`2<0?ooo`00O03oool010000000oooo0?ooo`000008
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0S03oool007d0oooo0P0000090?oo
o`@000001@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool2
000008d0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0
oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A
0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`03
0000003oool0oooo08`0oooo002A0?ooo`800000S@3oool00940oooo00<000000?ooo`3oool0S03o
ool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940
oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<0
00000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?oo
o`3oool0S03oool00940oooo0P00002=0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3o
ool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`00
0000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`001`3oool4000000<0oooo
00<000000?ooo`3oool00P3oool3000002<0oooo1000000S0?ooo`800000103oool00`000000oooo
0?ooo`020?ooo`<000008`3oool00`000000oooo0?ooo`0R0?ooo`800000103oool00`000000oooo
0?ooo`020?ooo`<000008`3oool4000002<0oooo100000030?ooo`030000003oool0oooo0080oooo
0`0000030?ooo`002@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`3oool08@3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo0200oooo
00<000000?ooo`3oool08@3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0:0?ooo`4000000@3oool10?ooo`00
2@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0
8@3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo0200oooo0P00000R0?ooo`04
0000003oool0oooo000000/0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0T0?oo
o`030000003oool0oooo00X0oooo0@0000010?ooo`40oooo00000`3oool0000000000002000000@0
oooo00<000000?ooo`3oool01`3oool3000001d0oooo100000040?ooo`030000003oool0oooo01/0
oooo100000020?ooo`040000003oool0oooo000000P0oooo0`00000S0?ooo`030000003oool0oooo
0240oooo00@000000?ooo`3oool00000203oool3000002D0oooo00<000000?ooo`3oool0903oool0
0`000000oooo0?ooo`070?ooo`<000000`3oool000T0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo0240oooo00@000000?ooo`3oool00000203oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0240oooo00@000000?ooo`3oool00000203o
ool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`030?ooo`001`3oool3000000T0oooo00<000000?ooo`3oool08`3oool3
000002<0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo0240oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0S0?ooo`<00000
903oool3000000T0oooo00<000000?ooo`3oool00`3oool000T0oooo00<000000?ooo`3oool01`3o
ool4000002@0oooo00<000000?ooo`3oool08P3oool2000000T0oooo1000000R0?ooo`030000003o
ool0oooo0280oooo0P0000090?ooo`@00000903oool00`000000oooo0?ooo`0T0?ooo`030000003o
ool0oooo00L0oooo100000020?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`00
0000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`001@3oool700000?l006@0
3000I006000000<0oooo000<0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo000<0?ooo`030000003oool0
oooo02T0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0
oooo02T0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0
oooo00L0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0
oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A
0?ooo`030000003oool0oooo08`0oooo002A0?ooo`800000S@3oool00940oooo00<000000?ooo`3o
ool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03o
ool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940
oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo0P00
002=0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3o
ool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`00
0000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool2000008d0oooo
002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?oo
o`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000
003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0
oooo08`0oooo002A0?ooo`800000S@3oool00940oooo00<000000?ooo`3oool0S03oool00940oooo
00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<00000
0?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool007d0oooo0P0000040?ooo`03
0000003oool0oooo0080oooo0`0000060?ooo`030000003oool0oooo08`0oooo001l0?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2<0?ooo`00
O03oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo00<0oooo0P00002=0?ooo`00
O03oool010000000oooo0?ooo`0000080?ooo`<000001P3oool00`000000oooo0?ooo`2<0?ooo`00
O03oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0S03oool007`0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo08`0oooo001m0?ooo`8000002@3oool4000000D0oooo00<000000?ooo`3oool0
S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool0
0940oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00T@3oool00`000000oooo
0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<
0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00
T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool2000008d0oooo002A0?ooo`030000003oool0oooo08`0
oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A
0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`03
0000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`800000S@3o
ool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940
oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<0
00000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?oo
o`3oool0S03oool00940oooo0P00002=0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3o
ool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`00
0000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00R03oool4000000D0oooo
00<000000?ooo`3oool0S03oool008X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`2<0?ooo`00RP3oool00`000000oooo0?ooo`040?ooo`800000S@3oool008X0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`2<0?ooo`00RP3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo08`0oooo00280?ooo`<000001P3oool00`000000oooo0?ooo`2<0?ooo`00RP3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08`0oooo003o0?ooob40oooo003o0?oo
ob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.63535, -1.07628, \
0.0112783, 0.0121658}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(genpl[7, Red, Dashing[{0.01, 0.01}]]\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(3\/2 + \[Delta]\), \(-\(1\/\@2\)\), "0", "0", "0", "0"},
            {\(-\(1\/\@2\)\), \(1\/2 + \[Delta]\), \(-\(1\/\@2\)\), \(1\/2\), 
              "0", "0"},
            {"0", \(-\(1\/\@2\)\), \(3\/2 + \[Delta]\), "0", \(-\(1\/\@2\)\), 
              "0"},
            {"0", \(1\/2\), "0", \(1\/2 + \[Delta]\), \(1\/2\), "0"},
            {"0", 
              "0", \(-\(1\/\@2\)\), \(1\/2\), \(1\/2 + \[Delta]\), \
\(-\(1\/\@2\)\)},
            {"0", "0", "0", "0", \(-\(1\/\@2\)\), \(3\/2 + \[Delta]\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Print"],

Cell[BoxData[
    \({1\/2\ \((3 + 2\ delta)\), 1\/2\ \((2 - \@3 + 2\ delta)\), 
      1\/2\ \((2 + \@3 + 2\ delta)\), 
      Root[9 + 2\ delta - 20\ delta\^2 - 8\ delta\^3 - 2\ #1 + 
            40\ delta\ #1 + 24\ delta\^2\ #1 - 20\ #1\^2 - 24\ delta\ #1\^2 + 
            8\ #1\^3 &, 1], 
      Root[9 + 2\ delta - 20\ delta\^2 - 8\ delta\^3 - 2\ #1 + 
            40\ delta\ #1 + 24\ delta\^2\ #1 - 20\ #1\^2 - 24\ delta\ #1\^2 + 
            8\ #1\^3 &, 2], 
      Root[9 + 2\ delta - 20\ delta\^2 - 8\ delta\^3 - 2\ #1 + 
            40\ delta\ #1 + 24\ delta\^2\ #1 - 20\ #1\^2 - 24\ delta\ #1\^2 + 
            8\ #1\^3 &, 3]}\)], "Print"],

Cell[BoxData[
    \({1.5`, 0.1339745962155614`, 
      1.8660254037844386`, \(-0.6397261578843032`\), 0.7296814706969094`, 
      2.410044687187394`}\)], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.31746 0.222897 0.0972936 [
[.02381 .2104 -12 -9 ]
[.02381 .2104 12 0 ]
[.18254 .2104 -6 -9 ]
[.18254 .2104 6 0 ]
[.34127 .2104 -12 -9 ]
[.34127 .2104 12 0 ]
[.65873 .2104 -9 -9 ]
[.65873 .2104 9 0 ]
[.81746 .2104 -3 -9 ]
[.81746 .2104 3 0 ]
[.97619 .2104 -9 -9 ]
[.97619 .2104 9 0 ]
[.4875 .02831 -12 -4.5 ]
[.4875 .02831 0 4.5 ]
[.4875 .1256 -12 -4.5 ]
[.4875 .1256 0 4.5 ]
[.4875 .32019 -6 -4.5 ]
[.4875 .32019 0 4.5 ]
[.4875 .41748 -6 -4.5 ]
[.4875 .41748 0 4.5 ]
[.4875 .51478 -6 -4.5 ]
[.4875 .51478 0 4.5 ]
[.4875 .61207 -6 -4.5 ]
[.4875 .61207 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .2229 m
.02381 .22915 L
s
[(-1.5)] .02381 .2104 0 1 Mshowa
.18254 .2229 m
.18254 .22915 L
s
[(-1)] .18254 .2104 0 1 Mshowa
.34127 .2229 m
.34127 .22915 L
s
[(-0.5)] .34127 .2104 0 1 Mshowa
.65873 .2229 m
.65873 .22915 L
s
[(0.5)] .65873 .2104 0 1 Mshowa
.81746 .2229 m
.81746 .22915 L
s
[(1)] .81746 .2104 0 1 Mshowa
.97619 .2229 m
.97619 .22915 L
s
[(1.5)] .97619 .2104 0 1 Mshowa
.125 Mabswid
.05556 .2229 m
.05556 .22665 L
s
.0873 .2229 m
.0873 .22665 L
s
.11905 .2229 m
.11905 .22665 L
s
.15079 .2229 m
.15079 .22665 L
s
.21429 .2229 m
.21429 .22665 L
s
.24603 .2229 m
.24603 .22665 L
s
.27778 .2229 m
.27778 .22665 L
s
.30952 .2229 m
.30952 .22665 L
s
.37302 .2229 m
.37302 .22665 L
s
.40476 .2229 m
.40476 .22665 L
s
.43651 .2229 m
.43651 .22665 L
s
.46825 .2229 m
.46825 .22665 L
s
.53175 .2229 m
.53175 .22665 L
s
.56349 .2229 m
.56349 .22665 L
s
.59524 .2229 m
.59524 .22665 L
s
.62698 .2229 m
.62698 .22665 L
s
.69048 .2229 m
.69048 .22665 L
s
.72222 .2229 m
.72222 .22665 L
s
.75397 .2229 m
.75397 .22665 L
s
.78571 .2229 m
.78571 .22665 L
s
.84921 .2229 m
.84921 .22665 L
s
.88095 .2229 m
.88095 .22665 L
s
.9127 .2229 m
.9127 .22665 L
s
.94444 .2229 m
.94444 .22665 L
s
.25 Mabswid
0 .2229 m
1 .2229 L
s
.5 .02831 m
.50625 .02831 L
s
[(-2)] .4875 .02831 1 0 Mshowa
.5 .1256 m
.50625 .1256 L
s
[(-1)] .4875 .1256 1 0 Mshowa
.5 .32019 m
.50625 .32019 L
s
[(1)] .4875 .32019 1 0 Mshowa
.5 .41748 m
.50625 .41748 L
s
[(2)] .4875 .41748 1 0 Mshowa
.5 .51478 m
.50625 .51478 L
s
[(3)] .4875 .51478 1 0 Mshowa
.5 .61207 m
.50625 .61207 L
s
[(4)] .4875 .61207 1 0 Mshowa
.125 Mabswid
.5 .04777 m
.50375 .04777 L
s
.5 .06723 m
.50375 .06723 L
s
.5 .08669 m
.50375 .08669 L
s
.5 .10614 m
.50375 .10614 L
s
.5 .14506 m
.50375 .14506 L
s
.5 .16452 m
.50375 .16452 L
s
.5 .18398 m
.50375 .18398 L
s
.5 .20344 m
.50375 .20344 L
s
.5 .24236 m
.50375 .24236 L
s
.5 .26181 m
.50375 .26181 L
s
.5 .28127 m
.50375 .28127 L
s
.5 .30073 m
.50375 .30073 L
s
.5 .33965 m
.50375 .33965 L
s
.5 .35911 m
.50375 .35911 L
s
.5 .37857 m
.50375 .37857 L
s
.5 .39803 m
.50375 .39803 L
s
.5 .43694 m
.50375 .43694 L
s
.5 .4564 m
.50375 .4564 L
s
.5 .47586 m
.50375 .47586 L
s
.5 .49532 m
.50375 .49532 L
s
.5 .53424 m
.50375 .53424 L
s
.5 .55369 m
.50375 .55369 L
s
.5 .57315 m
.50375 .57315 L
s
.5 .59261 m
.50375 .59261 L
s
.5 .00885 m
.50375 .00885 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ .01 .01 ] 0 setdash
.02381 .2229 m
.06244 .23474 L
.10458 .24765 L
.14415 .25978 L
.18221 .27144 L
.22272 .28386 L
.26171 .29581 L
.30316 .30851 L
.34309 .32075 L
.3815 .33252 L
.42237 .34504 L
.46172 .3571 L
.49955 .3687 L
.53984 .38105 L
.57861 .39293 L
.61984 .40556 L
.65954 .41773 L
.69774 .42944 L
.73838 .4419 L
.77751 .45389 L
.81909 .46663 L
.85916 .47891 L
.89771 .49073 L
.93871 .50329 L
.97619 .51478 L
s
.02381 .08999 m
.06244 .10183 L
.10458 .11475 L
.14415 .12687 L
.18221 .13854 L
.22272 .15095 L
.26171 .1629 L
.30316 .1756 L
.34309 .18784 L
.3815 .19961 L
.42237 .21214 L
.46172 .2242 L
.49955 .23579 L
.53984 .24814 L
.57861 .26002 L
.61984 .27266 L
.65954 .28483 L
.69774 .29653 L
.73838 .30899 L
.77751 .32098 L
.81909 .33373 L
.85916 .34601 L
.89771 .35782 L
.93871 .37039 L
.97619 .38187 L
s
.02381 .25851 m
.06244 .27035 L
.10458 .28326 L
.14415 .29539 L
.18221 .30705 L
.22272 .31947 L
.26171 .33142 L
.30316 .34412 L
.34309 .35636 L
.3815 .36813 L
.42237 .38066 L
.46172 .39272 L
.49955 .40431 L
.53984 .41666 L
.57861 .42854 L
.61984 .44118 L
.65954 .45335 L
.69774 .46505 L
.73838 .47751 L
.77751 .4895 L
.81909 .50224 L
.85916 .51452 L
.89771 .52634 L
.93871 .5389 L
.97619 .55039 L
s
.02381 .01472 m
.06244 .02656 L
.10458 .03947 L
.14415 .0516 L
.18221 .06326 L
.22272 .07568 L
.26171 .08763 L
.30316 .10033 L
.34309 .11256 L
.3815 .12434 L
.42237 .13686 L
.46172 .14892 L
.49955 .16052 L
.53984 .17287 L
.57861 .18475 L
.61984 .19738 L
.65954 .20955 L
.69774 .22126 L
.73838 .23371 L
.77751 .24571 L
.81909 .25845 L
.85916 .27073 L
.89771 .28254 L
.93871 .29511 L
.97619 .3066 L
s
.02381 .14795 m
.06244 .15979 L
.10458 .1727 L
.14415 .18483 L
.18221 .19649 L
.22272 .20891 L
.26171 .22086 L
.30316 .23356 L
.34309 .2458 L
.3815 .25757 L
.42237 .2701 L
.46172 .28216 L
.49955 .29375 L
.53984 .3061 L
.57861 .31798 L
.61984 .33062 L
.65954 .34279 L
.69774 .35449 L
.73838 .36695 L
.77751 .37894 L
.81909 .39168 L
.85916 .40396 L
.89771 .41578 L
.93871 .42834 L
.97619 .43983 L
s
.02381 .31144 m
.06244 .32328 L
.10458 .33619 L
.14415 .34832 L
.18221 .35998 L
.22272 .3724 L
.26171 .38435 L
.30316 .39705 L
.34309 .40929 L
.3815 .42106 L
.42237 .43359 L
.46172 .44565 L
.49955 .45724 L
.53984 .46959 L
.57861 .48147 L
.61984 .49411 L
.65954 .50627 L
.69774 .51798 L
.73838 .53044 L
.77751 .54243 L
.81909 .55517 L
.85916 .56745 L
.89771 .57927 L
.93871 .59183 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oT@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool2000008d0oooo000<0?ooo`80o`00P`3oool00`000000oooo0?oo
o`2<0?ooo`003P3oool00`3o0000oooo0?ooo`200?ooo`030000003oool0oooo08`0oooo000A0?oo
o`80o`00M@3oool4000000D0oooo00<000000?ooo`3oool0S03oool001<0oooo0P3o001c0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0S03oool001H0oooo0P3o001a0?ooo`030000
003oool0oooo00D0oooo0P00002=0?ooo`00603oool20?l00080oooo0P3o001T0?ooo`@00000103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08`0oooo000N0?ooo`030?l0003oool0
oooo06X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2<0?ooo`008@3oool30?l0
06@0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`2<0?ooo`00903oool00`3o
0000oooo0?ooo`1R0?ooo`8000001P3oool00`000000oooo0?ooo`2<0?ooo`009P3oool40?l006L0
oooo00<000000?ooo`3oool0S03oool002`0oooo00<0o`000?ooo`3oool0HP3oool2000008d0oooo
000]0?ooo`80o`00HP3oool00`000000oooo0?ooo`2<0?ooo`00<@3oool20?l005h0oooo00<00000
0?ooo`3oool0S03oool003<0oooo0P3o001L0?ooo`030000003oool0oooo08`0oooo000f0?ooo`@0
o`00E`3oool00`000000oooo0?ooo`2<0?ooo`00?03oool20?l005<0oooo0P00002=0?ooo`00?P3o
ool00`3o0000oooo0?ooo`1@0?ooo`030000003oool0oooo08`0oooo00110?ooo`<0o`00C@3oool0
0`000000oooo0?ooo`2<0?ooo`00A03oool0103o0000oooo0?l0003o00190?ooo`030000003oool0
oooo08`0oooo00180?ooo`80o`00A`3oool00`000000oooo0?ooo`2<0?ooo`00C03oool20?l004<0
oooo00<000000?ooo`3oool0S03oool000`0oooo0P3o00100?ooo`030?l0003oool0oooo0400oooo
0P00002=0?ooo`003P3oool00`3o0000oooo0?ooo`100?ooo`80o`00?P3oool00`000000oooo0?oo
o`2<0?ooo`004@3oool20?l00400oooo0P3o00000`3oool0o`000?l0000i0?ooo`030000003oool0
oooo08`0oooo000C0?ooo`80o`00@`3oool20?l003L0oooo00<000000?ooo`3oool0S03oool001H0
oooo0P3o00140?ooo`80o`00<`3oool00`000000oooo0?ooo`2<0?ooo`00603oool20?l00080oooo
0P3o00100?ooo`030?l0003oool0oooo0300oooo0P00002=0?ooo`007P3oool00`3o0000oooo0?oo
o`100?ooo`@0o`00;03oool00`000000oooo0?ooo`2<0?ooo`008@3oool30?l00480oooo0P3o000Y
0?ooo`030000003oool0oooo08`0oooo000T0?ooo`030?l0003oool0oooo0440oooo0P3o000N0?oo
o`@000001@3oool00`000000oooo0?ooo`2<0?ooo`009P3oool40?l00480oooo0P3o000L0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0S03oool002`0oooo00<0o`000?ooo`3oool0
?`3oool00`3o0000oooo0?ooo`0I0?ooo`030000003oool0oooo00@0oooo0P00002=0?ooo`00;@3o
ool20?l00480oooo103o000=0?ooo`@00000103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo08`0oooo000a0?ooo`80o`00@`3oool20?l00180oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`2<0?ooo`00<`3oool20?l004<0oooo0P3o000>0?ooo`<000001P3oool00`00
0000oooo0?ooo`2<0?ooo`00=P3oool40?l00480oooo0P3o000<0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0S03oool003`0oooo0P3o00100?ooo`030?l0003oool0oooo0080o`00
3P3oool00`000000oooo0?ooo`2<0?ooo`00?P3oool00`3o0000oooo0?ooo`120?ooo`80o`00303o
ool2000008d0oooo000<0?ooo`<0o`00<P3oool30?l00480oooo0P3o00090?ooo`030000003oool0
oooo08`0oooo000A0?ooo`80o`00<@3oool0103o0000oooo0?l0003o00100?ooo`80o`001`3oool0
0`000000oooo0?ooo`2<0?ooo`004`3oool20?l003<0oooo0P3o00120?ooo`80o`000`3oool00`00
0000oooo0?ooo`2<0?ooo`005P3oool20?l003@0oooo0P3o00100?ooo`030?l0003oool0oooo0080
o`00S@3oool001P0oooo0P3o000d0?ooo`030?l0003oool0oooo0400oooo0P0000020?l008/0oooo
000L0?ooo`<0o`00<P3oool20?l003h0oooo00<000000?ooo`3oool00P3oool20?l008P0oooo000Q
0?ooo`030?l0003oool0oooo02l0oooo0P3o00000`3oool0o`000?l0000i0?ooo`030000003oool0
oooo00@0oooo0P3o00260?ooo`008P3oool30?l003<0oooo0P3o000g0?ooo`030000003oool0oooo
00P0oooo0`3o00210?ooo`009P3oool20?l003@0oooo0P3o000c0?ooo`030000003oool0oooo00d0
oooo0P3o001m0?ooo`00:03oool20?l00080oooo00<0o`000?ooo`3oool0;`3oool00`3o0000oooo
0?ooo`0`0?ooo`030000003oool0oooo00l0oooo0P3o001k0?ooo`001`3oool4000000<0oooo00<0
00000?ooo`3oool00P3oool3000001L0oooo0P3o000:0?ooo`@000008`3oool00`000000o`000?l0
00030?ooo`030000003oool0oooo0080oooo0`00000S0?ooo`8000004`3oool20?l000h0oooo0P00
00040?ooo`030000003oool0oooo0080oooo0`00000S0?ooo`@000008`3oool4000000<0oooo00<0
00000?ooo`3oool00P3oool3000000<0oooo00090?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0603oool20?l000P0oooo00<000000?ooo`3oool08@3oool010000000oooo0?ooo`00
00020?l000030?ooo`3o0000o`0000H0oooo00<000000?ooo`3oool0803oool00`000000oooo0?oo
o`0D0?ooo`80o`002`3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo0280oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0:0?ooo`4000000@3oool10?ooo`002@3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01X0oooo0P3o00060?ooo`030000003o
ool0oooo0240oooo00@000000?ooo`3oool000001@3oool20?l000@0oooo00<000000?ooo`3oool0
803oool00`000000oooo0?ooo`0H0?ooo`<0o`001P3oool010000000oooo0?ooo`00000;0?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0:0?ooo`40
00000@3oool10?ooo`0000<0oooo0000000000000P0000040?ooo`030000003oool0oooo00L0oooo
0`00000M0?ooo`<000000`3o00020?ooo`030000003oool0oooo01/0oooo100000020?ooo`040000
003oool0oooo000000P0oooo00<000000?l0003o00008`3oool00`000000oooo0?ooo`0M0?ooo`<0
o`0000D0oooo0000003oool0oooo000000080?ooo`<000009@3oool00`000000oooo0?ooo`0T0?oo
o`030000003oool0oooo00L0oooo0`0000030?ooo`002@3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo02<0oooo00<0o`000?ooo`0000000P3o000Q0?ooo`040000003oool0oooo0000
00P0oooo00@000000?ooo`3oool0o`008P3oool00`000000oooo0?ooo`0P0?ooo`050?l000000000
oooo0?ooo`000000203oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02@0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`001`3oool3000000T0oooo00<00000
0?ooo`3oool08`3oool300000080oooo00<0o`000?ooo`3oool07P3oool010000000oooo0?ooo`00
00080?ooo`030000003oool0oooo00<0oooo103o000L0?ooo`8000008P3oool010000000o`000?l0
000000080?ooo`030000003oool0oooo02<0oooo0`00000T0?ooo`<000002@3oool00`000000oooo
0?ooo`030?ooo`002@3oool00`000000oooo0?ooo`070?ooo`@00000903oool00`000000oooo0?oo
o`030?ooo`80o`007@3oool2000000T0oooo100000070?ooo`80o`006@3oool00`000000oooo0?oo
o`0R0?ooo`8000000P3o00020?ooo`030?l0003oool0oooo0080oooo1000000T0?ooo`030000003o
ool0oooo02@0oooo00<000000?ooo`3oool01`3oool400000080oooo00130?ooo`80o`00<`3oool2
0?l001L0oooo00<000000?ooo`3oool0:@3oool20?l00640oooo00160?ooo`@0o`00<P3oool20?l0
01<0oooo00<000000?ooo`3oool0;@3oool20?l005d0oooo001<0?ooo`80o`00<03oool00`3o0000
oooo0?ooo`020?l000h0oooo00<000000?ooo`3oool0;`3oool20?l005/0oooo001>0?ooo`030?l0
003oool0oooo0380oooo0P3o000<0?ooo`030000003oool0oooo0380oooo0`3o001G0?ooo`001@3o
ool7000000<0o`00@P0000020?l003<000000P3o0011000000030?l00000000000000080o`00C`00
00030?ooo`00303oool00`000000oooo0?ooo`020?ooo`80o`0000<0oooo0000003oool01`3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool0
0`000000o`000?l000060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool2
0?l000L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01@3oool00`3o000000000?ooo`060?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01`3oool001<0oooo0P3o00110?ooo`@0o`00<P3oool20?l0
00<0oooo00<000000?ooo`3oool0?@3oool20?l004d0oooo000F0?ooo`80o`00A03oool20?l00300
oooo00<0o`000?ooo`3oool00P3o00100?ooo`80o`00B`3oool001P0oooo0P3o00020?ooo`80o`00
@03oool00`3o0000oooo0?ooo`0`0?ooo`040000003oool0o`000?l00440oooo103o00160?ooo`00
7P3oool00`3o0000oooo0?ooo`100?ooo`80o`00;P3oool2000000<0oooo0P3o00140?ooo`80o`00
@P3oool00240oooo0`3o000o0?ooo`80o`00;03oool00`000000oooo0?ooo`040?ooo`80o`00A03o
ool00`3o0000oooo0?ooo`0o0?ooo`00903oool00`3o0000oooo0?ooo`0o0?ooo`@0o`009`3oool0
0`000000oooo0?ooo`080?ooo`<0o`00@P3oool20?l003d0oooo000V0?ooo`80o`00A03oool20?l0
02<0oooo00<000000?ooo`3oool03@3oool20?l00400oooo0P3o000k0?ooo`00:03oool20?l00080
oooo00<0o`000?ooo`3oool0?`3oool00`3o0000oooo0?ooo`0P0?ooo`030000003oool0oooo00l0
oooo0P3o00110?ooo`@0o`00=P3oool000`0oooo0`3o000N0?ooo`80o`00@P3oool20?l001h0oooo
0P00000C0?ooo`80o`00A03oool20?l00380oooo000A0?ooo`80o`007P3oool20?l00400oooo0P3o
00000`3oool0o`000?l0000I0?ooo`030000003oool0oooo01@0oooo0P3o00140?ooo`030?l0003o
ool0oooo02l0oooo000C0?ooo`80o`007P3oool20?l004<0oooo0P3o000G0?ooo`030000003oool0
oooo01P0oooo0`3o00120?ooo`80o`00;@3oool001H0oooo0P3o000N0?ooo`@0o`00@P3oool20?l0
01<0oooo00<000000?ooo`3oool07@3oool30?l003l0oooo0P3o00000`3oool0o`000?l0000X0?oo
o`00603oool20?l00080oooo0P3o000N0?ooo`80o`00@03oool00`3o0000oooo0?ooo`0@0?ooo`03
0000003oool0oooo0200oooo00<0o`000?ooo`3oool0@@3oool20?l002H0oooo000N0?ooo`030?l0
003oool0oooo01d0oooo00<0o`000?ooo`3oool0@03oool40?l000`0oooo00<000000?ooo`3oool0
8P3oool20?l004@0oooo0P3o000R0?ooo`008@3oool30?l001d0oooo0P3o00130?ooo`80o`002@3o
ool2000002D0oooo0P3o00020?ooo`030?l0003oool0oooo03l0oooo0P3o000P0?ooo`00903oool0
0`3o0000oooo0?ooo`0L0?ooo`80o`00@`3oool20?l000L0oooo00<000000?ooo`3oool0:@3oool2
0?l00480oooo0P3o000M0?ooo`009P3oool20?l001h0oooo103o00120?ooo`80o`000`3oool00`00
0000oooo0?ooo`0]0?ooo`80o`00@03oool20?l00080oooo0P3o000G0?ooo`00:03oool20?l00080
oooo00<0o`000?ooo`3oool07@3oool20?l00400oooo00@0o`000?ooo`3oool00000<@3oool20?l0
04@0oooo00<0o`000?ooo`3oool0503oool002d0oooo0P3o000O0?ooo`030?l0003oool0oooo0400
oooo103o000a0?ooo`<0o`00@`3oool20?l00180oooo000a0?ooo`80o`007P3oool20?l003h0oooo
0P0000030?ooo`80o`00<@3oool00`3o0000oooo0?ooo`020?l00400oooo0P3o000@0?ooo`00<`3o
ool20?l001h0oooo0P3o000l0?ooo`030000003oool0oooo00@0oooo0P3o000d0?ooo`030?l0003o
ool0oooo0400oooo103o000;0?ooo`00=P3oool40?l001`0oooo103o000g0?ooo`030000003oool0
oooo00P0oooo0P3o000c0?ooo`80o`00C@3oool000`0oooo0P3o000^0?ooo`80o`007P3oool20?l0
03<0oooo00<000000?ooo`3oool02P3oool00`3o0000oooo0?ooo`020?l00300oooo0P3o001;0?oo
o`003P3oool00`3o0000oooo0?ooo`0]0?ooo`030?l0003oool0oooo01d0oooo00<0o`000?ooo`3o
ool09`3oool4000000D0oooo00<000000?ooo`3oool03`3oool20?l00340oooo103o00160?ooo`00
4@3oool20?l002h0oooo0P3o000N0?ooo`80o`009`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0180oooo0P3o000d0?ooo`80o`00@P3oool001<0oooo0P3o000^0?ooo`80o`007P3o
ool20?l000030?ooo`3o0000o`000280oooo00<000000?ooo`3oool0103oool2000001D0oooo0P3o
000d0?ooo`030?l0003oool0oooo03l0oooo000F0?ooo`@0o`00;03oool40?l001h0oooo0P3o000P
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0603oool20?l003<0oooo0P3o000m
0?ooo`00703oool20?l002h0oooo0P3o000N0?ooo`80o`00703oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo01X0oooo00@0o`000?ooo`3oool0o`00<@3oool20?l003/0oooo000N0?oo
o`030?l0003oool0oooo02d0oooo00<0o`000?ooo`3oool07@3oool00`3o0000oooo0?ooo`0G0?oo
o`<000001P3oool00`000000oooo0?ooo`0N0?ooo`<0o`00<@3oool40?l003H0oooo000Q0?ooo`<0
o`00;@3oool20?l001h0oooo103o000E0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool08P3oool20?l003@0oooo0P3o000b0?ooo`00903oool00`3o0000oooo0?ooo`0/0?ooo`80o`00
00<0oooo0?l0003o00007P3oool20?l001T0oooo0P00000U0?ooo`80o`00=03oool00`3o0000oooo
0?ooo`0_0?ooo`009P3oool40?l002h0oooo0P3o000N0?ooo`80o`005`3oool00`000000oooo0?oo
o`0X0?ooo`80o`00<`3oool20?l002d0oooo000/0?ooo`030?l0003oool0oooo02d0oooo0P3o000N
0?ooo`80o`004`3oool00`000000oooo0?ooo`0Z0?ooo`030?l0003oool0oooo0080o`00<03oool2
0?l002/0oooo000]0?ooo`80o`00;`3oool00`3o0000oooo0?ooo`0M0?ooo`030?l0003oool0oooo
0100oooo00<000000?ooo`3oool0;`3oool20?l00340oooo103o000V0?ooo`00<@3oool20?l002h0
oooo0P3o000N0?ooo`@0o`00303oool00`000000oooo0?ooo`0b0?ooo`<0o`00<`3oool20?l00280
oooo000c0?ooo`80o`0000<0oooo0?l0003o0000:`3oool20?l000030?ooo`3o0000o`0001h0oooo
0P3o00090?ooo`030000003oool0oooo03D0oooo00<0o`000?ooo`3oool0<P3oool20?l00200oooo
000h0?ooo`80o`00;P3oool20?l001h0oooo0P3o00070?ooo`800000>@3oool30?l00380oooo0P3o
000M0?ooo`00?03oool20?l002h0oooo0P3o000N0?ooo`80o`000`3oool00`000000oooo0?ooo`0m
0?ooo`80o`00<03oool20?l00080oooo0P3o000G0?ooo`00?P3oool00`3o0000oooo0?ooo`0]0?oo
o`030?l0003oool0oooo01d0oooo00@0o`000?ooo`3oool00000@@3oool20?l003@0oooo00<0o`00
0?ooo`3oool0503oool00440oooo0`3o000]0?ooo`@0o`00703oool40?l00440oooo0P3o000d0?oo
o`80o`004P3oool004@0oooo00@0o`000?ooo`3o0000o`00;P3oool20?l001T0oooo00<000000?oo
o`3oool00P3oool20?l00400oooo0P3o000d0?ooo`80o`00403oool004P0oooo0P3o000^0?ooo`80
o`005`3oool2000000D0oooo0P3o00120?ooo`<0o`00<P3oool20?l000d0oooo001<0?ooo`80o`00
;P3oool20?l001<0oooo00<000000?ooo`3oool0203oool20?l004<0oooo0P3o000`0?ooo`80o`00
2`3oool004h0oooo00<0o`000?ooo`3oool0;@3oool00`3o0000oooo0?ooo`0@0?ooo`030000003o
ool0oooo00X0oooo00<0o`000?ooo`3oool00P3o00100?ooo`80o`00>`3oool00540oooo103o000/
0?ooo`@0o`00303oool00`000000oooo0?ooo`0?0?ooo`80o`00@@3oool20?l003P0oooo001F0?oo
o`80o`00;P3oool20?l000T0oooo00<000000?ooo`3oool04P3oool20?l00400oooo0P3o00020?oo
o`80o`00<P3oool005P0oooo0P3o000^0?ooo`80o`001`3oool2000001D0oooo0P3o00140?ooo`03
0?l0003oool0oooo02l0oooo001L0?ooo`80o`00;P3oool20?l000<0oooo00<000000?ooo`3oool0
603oool20?l004<0oooo0P3o000]0?ooo`00GP3oool00`3o0000oooo0?ooo`0]0?ooo`030?l0003o
ool0oooo0080o`006`3oool0103o0000oooo0?ooo`3o00110?ooo`80o`00:`3oool00640oooo103o
000/0?ooo`040000003oool0o`000?l001d0oooo0`3o00110?ooo`80o`00:03oool006H0oooo0P3o
000P0?ooo`@000001@3oool00`000000oooo0?ooo`020?ooo`80o`007P3oool20?l00400oooo0P3o
00020?ooo`80o`008P3oool006P0oooo0P3o000N0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0103oool20?l001h0oooo0P3o00140?ooo`80o`00803oool006`0oooo0P3o000K0?oo
o`030000003oool0oooo00D0oooo0P0000090?ooo`80o`007P3oool30?l00480oooo0P3o000M0?oo
o`00KP3oool00`3o0000oooo0?ooo`020?l001L0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0:0?ooo`030?l0003oool0oooo0080o`007P3oool20?l00400oooo0P3o000K0?ooo`00
L`3oool20?l001H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0?0?ooo`80o`00
7P3oool20?l00480oooo0`3o000F0?ooo`00MP3oool20?l00100oooo00@000000?ooo`3oool00000
1@3oool00`000000oooo0?ooo`0B0?ooo`80o`007P3oool30?l004<0oooo0P3o000B0?ooo`00N03o
ool20?l000l0oooo0P0000060?ooo`030000003oool0oooo01@0oooo0P3o000O0?ooo`030?l0003o
ool0oooo0480oooo0P3o000@0?ooo`00O03oool20?l001<0oooo0P00000I0?ooo`<0o`007@3oool3
0?l00480oooo0P3o000=0?ooo`00OP3oool00`3o0000oooo0?ooo`020?l000h0oooo00<000000?oo
o`3oool07@3oool00`3o0000oooo0?ooo`0M0?ooo`80o`00@03oool20?l000/0oooo00230?ooo`80
o`00303oool00`000000oooo0?ooo`0N0?ooo`<0o`007P3oool20?l004/0oooo00260?ooo`80o`00
2@3oool00`000000oooo0?ooo`0R0?ooo`80o`007P3oool20?l004P0oooo00280?ooo`80o`001`3o
ool00`000000oooo0?ooo`0T0?ooo`80o`007P3oool20?l00080oooo0P3o00120?ooo`00S03oool3
0?l00080oooo00<000000?ooo`3oool0:03oool30?l001l0oooo00<0o`000?ooo`3oool0?`3oool0
0940oooo0P3o000^0?ooo`80o`007P3oool20?l003d0oooo002A0?ooo`040000003oool0o`000?l0
02h0oooo0P3o000N0?ooo`80o`00>`3oool00940oooo00<000000?ooo`3oool00P3oool20?l002h0
oooo0`3o000M0?ooo`80o`00>03oool00940oooo00<000000?ooo`3oool0103oool20?l002l0oooo
00<0o`000?ooo`3oool00P3o000J0?ooo`80o`000P3oool20?l00380oooo002A0?ooo`030000003o
ool0oooo00P0oooo0`3o000_0?ooo`030?l0003oool0oooo01d0oooo00<0o`000?ooo`3oool0;`3o
ool00940oooo0P00000>0?ooo`80o`00;P3oool20?l001h0oooo0P3o000]0?ooo`00T@3oool00`00
0000oooo0?ooo`0?0?ooo`80o`00;P3oool20?l001h0oooo0P3o000[0?ooo`00T@3oool00`000000
oooo0?ooo`0B0?ooo`80o`00;P3oool20?l001h0oooo103o000V0?ooo`00T@3oool00`000000oooo
0?ooo`0D0?ooo`80o`000P3oool20?l002X0oooo0P3o00020?ooo`80o`007P3oool20?l00280oooo
002A0?ooo`030000003oool0oooo01X0oooo00<0o`000?ooo`3oool0;@3oool00`3o0000oooo0?oo
o`0M0?ooo`80o`00803oool00940oooo00<000000?ooo`3oool07@3oool30?l002d0oooo0P3o000N
0?ooo`80o`007@3oool00940oooo0P00000Q0?ooo`030?l0003oool0oooo02`0oooo0P3o000N0?oo
o`80o`000P3oool20?l001L0oooo002A0?ooo`030000003oool0oooo0280oooo0P3o000^0?ooo`@0
o`007`3oool00`3o0000oooo0?ooo`0D0?ooo`00T@3oool00`000000oooo0?ooo`0T0?ooo`80o`00
0P3oool00`3o0000oooo0?ooo`0]0?ooo`80o`007P3oool20?l00180oooo00290?ooo`8000001P3o
ool00`000000oooo0?ooo`0Y0?ooo`80o`00;`3oool00`3o0000oooo0?ooo`0M0?ooo`80o`00403o
ool008P0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`0]0?ooo`80o`00;P3o
ool20?l001h0oooo0P3o000=0?ooo`00R`3oool00`000000oooo0?ooo`030?ooo`800000<03oool2
0?l002h0oooo0P3o000N0?ooo`80o`002`3oool008T0oooo0P0000060?ooo`030000003oool0oooo
0380oooo103o000/0?ooo`@0o`009P3oool008/0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0h0?ooo`80o`00;P3oool20?l00280oooo00280?ooo`040000003oool0oooo000000D0
oooo00<000000?ooo`3oool0>P3oool00`3o0000oooo0?ooo`0]0?ooo`80o`00803oool008T0oooo
0P0000060?ooo`030000003oool0oooo03d0oooo0`3o000]0?ooo`80o`007@3oool00940oooo00<0
00000?ooo`3oool0@03oool00`3o0000oooo0?ooo`0/0?ooo`80o`000P3oool20?l001L0oooo002A
0?ooo`800000@`3oool40?l002l0oooo00<0o`000?ooo`3oool0503oool00940oooo00<000000?oo
o`3oool0B03oool20?l002h0oooo0P3o000B0?ooo`00T@3oool00`000000oooo0?ooo`1:0?ooo`03
0?l0003oool0oooo02d0oooo0P3o000@0?ooo`00T@3oool00`000000oooo0?ooo`1=0?ooo`80o`00
;P3oool20?l000d0oooo002A0?ooo`030000003oool0oooo04l0oooo0P3o00000`3oool0o`000?l0
000[0?ooo`80o`002`3oool00940oooo0P00001E0?ooo`80o`00=P3oool00940oooo00<000000?oo
o`3oool0F03oool20?l00380oooo002A0?ooo`030000003oool0oooo05X0oooo00<0o`000?ooo`3o
ool0;`3oool00940oooo00<000000?ooo`3oool0G@3oool20?l002d0oooo002A0?ooo`030000003o
ool0oooo05l0oooo0P3o00000`3oool0o`000?l0000X0?ooo`00T@3oool2000006D0oooo0P3o000V
0?ooo`00T@3oool00`000000oooo0?ooo`1X0?ooo`80o`008P3oool00940oooo00<000000?ooo`3o
ool0JP3oool20?l00200oooo002A0?ooo`030000003oool0oooo06d0oooo103o000K0?ooo`00T@3o
ool00`000000oooo0?ooo`1c0?ooo`80o`005`3oool00940oooo00<000000?ooo`3oool0M@3oool0
0`3o0000oooo0?ooo`0D0?ooo`00T@3oool2000007T0oooo0P3o000B0?ooo`00T@3oool00`000000
oooo0?ooo`1j0?ooo`80o`00403oool00940oooo00<000000?ooo`3oool0O@3oool40?l000/0oooo
002:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0S03oool008X0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`2<0?ooo`00Q`3oool5000000D0oooo0P00002=0?oo
o`00Q`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo08`0oooo00280?ooo`03
0000003oool0000000H0oooo00<000000?ooo`3oool0S03oool008T0oooo0P00002E0?ooo`00RP3o
ool00`000000oooo0?ooo`2C0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.63535, -2.31835, \
0.0112783, 0.0368001}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(genpl[8, Thickness[0.008], Red, Dashing[{0.01, 0.01}]]\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(1\/2 + \[Delta]\), \(1\/2\), "0"},
            {\(1\/2\), \(1\/2 + \[Delta]\), \(1\/2\)},
            {"0", \(1\/2\), \(1\/2 + \[Delta]\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Print"],

Cell[BoxData[
    \({1\/2\ \((1 + 2\ delta)\), 1\/2\ \((1 - \@2 + 2\ delta)\), 
      1\/2\ \((1 + \@2 + 2\ delta)\)}\)], "Print"],

Cell[BoxData[
    \({0.5`, \(-0.20710678118654757`\), 1.2071067811865475`}\)], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.31746 0.242346 0.133343 [
[.02381 .22985 -12 -9 ]
[.02381 .22985 12 0 ]
[.18254 .22985 -6 -9 ]
[.18254 .22985 6 0 ]
[.34127 .22985 -12 -9 ]
[.34127 .22985 12 0 ]
[.65873 .22985 -9 -9 ]
[.65873 .22985 9 0 ]
[.81746 .22985 -3 -9 ]
[.81746 .22985 3 0 ]
[.97619 .22985 -9 -9 ]
[.97619 .22985 9 0 ]
[.4875 .109 -12 -4.5 ]
[.4875 .109 0 4.5 ]
[.4875 .37569 -6 -4.5 ]
[.4875 .37569 0 4.5 ]
[.4875 .50903 -6 -4.5 ]
[.4875 .50903 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24235 m
.02381 .2486 L
s
[(-1.5)] .02381 .22985 0 1 Mshowa
.18254 .24235 m
.18254 .2486 L
s
[(-1)] .18254 .22985 0 1 Mshowa
.34127 .24235 m
.34127 .2486 L
s
[(-0.5)] .34127 .22985 0 1 Mshowa
.65873 .24235 m
.65873 .2486 L
s
[(0.5)] .65873 .22985 0 1 Mshowa
.81746 .24235 m
.81746 .2486 L
s
[(1)] .81746 .22985 0 1 Mshowa
.97619 .24235 m
.97619 .2486 L
s
[(1.5)] .97619 .22985 0 1 Mshowa
.125 Mabswid
.05556 .24235 m
.05556 .2461 L
s
.0873 .24235 m
.0873 .2461 L
s
.11905 .24235 m
.11905 .2461 L
s
.15079 .24235 m
.15079 .2461 L
s
.21429 .24235 m
.21429 .2461 L
s
.24603 .24235 m
.24603 .2461 L
s
.27778 .24235 m
.27778 .2461 L
s
.30952 .24235 m
.30952 .2461 L
s
.37302 .24235 m
.37302 .2461 L
s
.40476 .24235 m
.40476 .2461 L
s
.43651 .24235 m
.43651 .2461 L
s
.46825 .24235 m
.46825 .2461 L
s
.53175 .24235 m
.53175 .2461 L
s
.56349 .24235 m
.56349 .2461 L
s
.59524 .24235 m
.59524 .2461 L
s
.62698 .24235 m
.62698 .2461 L
s
.69048 .24235 m
.69048 .2461 L
s
.72222 .24235 m
.72222 .2461 L
s
.75397 .24235 m
.75397 .2461 L
s
.78571 .24235 m
.78571 .2461 L
s
.84921 .24235 m
.84921 .2461 L
s
.88095 .24235 m
.88095 .2461 L
s
.9127 .24235 m
.9127 .2461 L
s
.94444 .24235 m
.94444 .2461 L
s
.25 Mabswid
0 .24235 m
1 .24235 L
s
.5 .109 m
.50625 .109 L
s
[(-1)] .4875 .109 1 0 Mshowa
.5 .37569 m
.50625 .37569 L
s
[(1)] .4875 .37569 1 0 Mshowa
.5 .50903 m
.50625 .50903 L
s
[(2)] .4875 .50903 1 0 Mshowa
.125 Mabswid
.5 .13567 m
.50375 .13567 L
s
.5 .16234 m
.50375 .16234 L
s
.5 .18901 m
.50375 .18901 L
s
.5 .21568 m
.50375 .21568 L
s
.5 .26901 m
.50375 .26901 L
s
.5 .29568 m
.50375 .29568 L
s
.5 .32235 m
.50375 .32235 L
s
.5 .34902 m
.50375 .34902 L
s
.5 .40236 m
.50375 .40236 L
s
.5 .42903 m
.50375 .42903 L
s
.5 .45569 m
.50375 .45569 L
s
.5 .48236 m
.50375 .48236 L
s
.5 .08233 m
.50375 .08233 L
s
.5 .05567 m
.50375 .05567 L
s
.5 .029 m
.50375 .029 L
s
.5 .00233 m
.50375 .00233 L
s
.5 .5357 m
.50375 .5357 L
s
.5 .56237 m
.50375 .56237 L
s
.5 .58904 m
.50375 .58904 L
s
.5 .61571 m
.50375 .61571 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.008 w
[ .01 .01 ] 0 setdash
.02381 .109 m
.06244 .12523 L
.10458 .14293 L
.14415 .15955 L
.18221 .17553 L
.22272 .19255 L
.26171 .20893 L
.30316 .22634 L
.34309 .24311 L
.3815 .25924 L
.42237 .27641 L
.46172 .29294 L
.49955 .30883 L
.53984 .32575 L
.57861 .34204 L
.61984 .35935 L
.65954 .37603 L
.69774 .39207 L
.73838 .40914 L
.77751 .42558 L
.81909 .44305 L
.85916 .45988 L
.89771 .47607 L
.93871 .49329 L
.97619 .50903 L
s
.02381 .01472 m
.06244 .03094 L
.10458 .04864 L
.14415 .06526 L
.18221 .08125 L
.22272 .09826 L
.26171 .11464 L
.30316 .13205 L
.34309 .14882 L
.3815 .16496 L
.42237 .18212 L
.46172 .19865 L
.49955 .21454 L
.53984 .23146 L
.57861 .24775 L
.61984 .26506 L
.65954 .28174 L
.69774 .29778 L
.73838 .31486 L
.77751 .33129 L
.81909 .34876 L
.85916 .36559 L
.89771 .38178 L
.93871 .399 L
.97619 .41474 L
s
.02381 .20329 m
.06244 .21952 L
.10458 .23722 L
.14415 .25384 L
.18221 .26982 L
.22272 .28684 L
.26171 .30322 L
.30316 .32062 L
.34309 .3374 L
.3815 .35353 L
.42237 .3707 L
.46172 .38722 L
.49955 .40312 L
.53984 .42004 L
.57861 .43632 L
.61984 .45364 L
.65954 .47032 L
.69774 .48636 L
.73838 .50343 L
.77751 .51987 L
.81909 .53733 L
.85916 .55416 L
.89771 .57036 L
.93871 .58758 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00T@3oool2000008d0oooo002A0?ooo`030000003oool0oooo08`0oooo
002A0?ooo`030000003oool0oooo08`0oooo000<0?ooo`030?l0003oool0oooo0880oooo00<00000
0?ooo`3oool0S03oool000/0oooo103o00220?ooo`030000003oool0oooo08`0oooo000<0?ooo`@0
o`0000<0oooo0?l0003oool0OP3oool00`000000oooo0?ooo`2<0?ooo`003P3oool00`3o0000oooo
0?l000030?l007d0oooo00<000000?ooo`3oool0S03oool00140oooo103o00000`3oool0o`000?oo
o`1i0?ooo`030000003oool0oooo08`0oooo000C0?ooo`030?l0003oool0o`0000<0o`00N03oool2
000008d0oooo000E0?ooo`D0o`0000<0oooo0?l0003oool0M03oool00`000000oooo0?ooo`2<0?oo
o`00603oool00`3o0000oooo0?l000040?l00780oooo00<000000?ooo`3oool0S03oool001/0oooo
1@3o001a0?ooo`030000003oool0oooo08`0oooo000N0?ooo`050?l0003oool0oooo0?ooo`3o0000
KP3oool00`000000oooo0?ooo`2<0?ooo`007`3oool50?l006d0oooo00<000000?ooo`3oool0S03o
ool001l0oooo1`3o001[0?ooo`030000003oool0oooo08`0oooo000S0?ooo`H0o`00J03oool20000
08d0oooo000U0?ooo`H0o`00IP3oool00`000000oooo0?ooo`2<0?ooo`00:03oool60?l006<0oooo
00<000000?ooo`3oool0S03oool002X0oooo1@3o00000`3oool0o`000?ooo`1O0?ooo`030000003o
ool0oooo08`0oooo000]0?ooo`030?l0003oool0o`0000<0o`00GP3oool00`000000oooo0?ooo`2<
0?ooo`00<03oool40?l000030?ooo`3o0000oooo05X0oooo00<000000?ooo`3oool0S03oool00380
oooo00<0o`000?ooo`3o00000`3o001I0?ooo`030000003oool0oooo08`0oooo000e0?ooo`@0o`00
00<0oooo0?l0003oool0E@3oool00`000000oooo0?ooo`2<0?ooo`00=`3oool00`3o0000oooo0?l0
00030?l005@0oooo0P00002=0?ooo`00>P3oool40?l005<0oooo00<000000?ooo`3oool0S03oool0
03`0oooo00@0o`000?ooo`3oool0o`00D@3oool00`000000oooo0?ooo`2<0?ooo`00?P3oool50?l0
04h0oooo00<000000?ooo`3oool0S03oool003l0oooo1P3o001<0?ooo`030000003oool0oooo08`0
oooo00120?ooo`H0o`00@03oool4000000D0oooo00<000000?ooo`3oool0S03oool000`0oooo00<0
o`000?ooo`3oool0=@3oool60?l00400oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`2<0?ooo`002`3oool40?l003P0oooo1P3o000m0?ooo`030000003oool0oooo00@0oooo0P00002=
0?ooo`00303oool40?l000030?ooo`3o0000oooo03H0oooo1P3o000c0?ooo`@00000103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo08`0oooo000>0?ooo`030?l0003oool0o`0000<0
o`00>03oool60?l003P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2<0?ooo`00
4@3oool40?l003T0oooo1@3o00000`3oool0o`000?ooo`0b0?ooo`<000001P3oool00`000000oooo
0?ooo`2<0?ooo`004`3oool0103o0000oooo0?ooo`3o000j0?ooo`030?l0003oool0o`0000<0o`00
<`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08`0oooo000E0?ooo`@0o`00>`3o
ool40?l000030?ooo`3o0000oooo03H0oooo00<000000?ooo`3oool0S03oool001D0oooo1@3o0000
0`3oool0o`000?ooo`0i0?ooo`030?l0003oool0o`000080o`00=P3oool00`000000oooo0?ooo`2<
0?ooo`00603oool00`3o0000oooo0?l000040?l003X0oooo0`3o00020?ooo`030?l0003oool0oooo
0300oooo00<000000?ooo`3oool0S03oool001/0oooo1P3o000h0?ooo`<0o`0000@0oooo0?l0003o
0000o`00<@3oool2000008d0oooo000N0?ooo`D0o`00>`3oool30?l00300oooo00<000000?ooo`3o
ool0S03oool00200oooo103o00000`3oool0o`000?ooo`0h0?ooo`<0o`000`3oool00`3o0000oooo
0?ooo`0Y0?ooo`030000003oool0oooo08`0oooo000Q0?ooo`P0o`00=`3oool00`3o0000oooo0?l0
00040?l002X0oooo00<000000?ooo`3oool0S03oool002D0oooo1P3o000g0?ooo`L0o`00:03oool0
0`000000oooo0?ooo`2<0?ooo`00:03oool60?l003P0oooo1P3o000U0?ooo`030000003oool0oooo
08`0oooo000Z0?ooo`D0o`0000<0oooo0?l0003oool0=P3oool60?l002<0oooo00<000000?ooo`3o
ool0S03oool002d0oooo00<0o`000?ooo`3o00000`3o000h0?ooo`D0o`008@3oool2000008d0oooo
000`0?ooo`@0o`0000<0oooo0?l0003oool0=P3oool40?l00080oooo00<0o`000?ooo`3oool06`3o
ool00`000000oooo0?ooo`2<0?ooo`00<P3oool00`3o0000oooo0?l000020?l003L0oooo0`3o0000
0`3oool0o`000?l000020?l001/0oooo00<000000?ooo`3oool0S03oool003D0oooo0`3o000k0?oo
o`@0o`0000<0oooo0?l0003oool05`3oool00`000000oooo0?ooo`2<0?ooo`00=P3oool30?l00003
0?ooo`3o0000oooo03T0oooo00<0o`000?ooo`3o00000`3o000F0?ooo`030000003oool0oooo08`0
oooo000g0?ooo`030?l0003oool0o`0000<0o`00>`3oool40?l000030?ooo`3o0000oooo0180oooo
00<000000?ooo`3oool0S03oool003X0oooo103o00000`3oool0o`000?ooo`0i0?ooo`030?l0003o
ool0o`000080o`004P3oool00`000000oooo0?ooo`2<0?ooo`00?03oool00`3o0000oooo0?l00004
0?l003X0oooo0`3o000A0?ooo`030000003oool0oooo08`0oooo000o0?ooo`H0o`00>@3oool30?l0
00030?ooo`3o0000oooo00d0oooo0P00002=0?ooo`00@P3oool60?l003L0oooo00<0o`000?ooo`3o
0000103o000;0?ooo`030000003oool0oooo08`0oooo00140?ooo`H0o`00>03oool60?l000T0oooo
00<000000?ooo`3oool0S03oool000`0oooo00<0o`000?ooo`3oool0>03oool60?l003P0oooo1P3o
00060?ooo`030000003oool0oooo08`0oooo00070?ooo`@00000103o00040?ooo`<000008`3oool4
000000`0oooo1P3o000A0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`<000006@3oool6
0?l000@0oooo00<000000?ooo`3oool08P3oool2000000@0oooo00<000000?ooo`3oool00P3oool3
000002<0oooo1000000S0?ooo`@000000`3oool00`000000oooo0?ooo`020?ooo`<000000`3oool0
00T0oooo00<000000?ooo`3oool0103o00000`3oool0o`000?ooo`030?ooo`030000003oool0oooo
0280oooo00<000000?ooo`3oool03P3oool60?l000d0oooo00@000000?ooo`3oool000002`3oool0
0`000000oooo0?ooo`0I0?ooo`H0o`0000<0oooo0000003oool08P3oool010000000oooo0?ooo`00
000;0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0903oool00`000000oooo0?oo
o`0:0?ooo`4000000@3oool10?ooo`002@3oool00`000000oooo0?ooo`020?ooo`030?l0003oool0
o`0000<0o`000P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0100oooo1@3o000<
0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool06`3oool60?l002<0oooo00@0
00000?ooo`3oool000002`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02@0oooo
00<000000?ooo`3oool02P3oool100000040oooo0@3oool000030?ooo`000000000000800000103o
ool00`000000oooo0?ooo`050?ooo`@0o`0000<000000?l0003oool06`3oool4000000@0oooo00<0
00000?ooo`3oool04`3oool0103o0000oooo0?ooo`3o00040?ooo`@000000P3oool010000000oooo
0?ooo`0000080?ooo`<000008@3oool60?l00200oooo00@000000?ooo`3oool00000203oool30000
02D0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`070?ooo`<000000`3oool000T0
oooo00<000000?ooo`3oool01`3oool00`3o0000oooo0?l000030?l00280oooo00<000000?ooo`3o
ool05@3oool40?l000P0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0S0?oo
o`D0o`0000<0oooo0?l0003oool0703oool010000000oooo0?ooo`0000080?ooo`030000003oool0
oooo02D0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00<0oooo00070?ooo`<000002@3oool00`000000oooo0?l000040?l000030?ooo`3o0000oooo
01`0oooo0`00000H0?ooo`@0o`000P3oool00`3o0000oooo0?ooo`020?ooo`040000003oool0oooo
000000P0oooo00<000000?ooo`3oool08`3oool01@000000oooo0?ooo`3o0000oooo00@0o`006`3o
ool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo02<0oooo0`00000T0?ooo`<00000
2@3oool00`000000oooo0?ooo`030?ooo`002@3oool00`000000oooo0?ooo`070?ooo`@0000000<0
oooo0?l0003oool01@3o000L0?ooo`030000003oool0oooo01P0oooo00<0o`000?ooo`3o00000`3o
00040?ooo`8000002@3oool400000280oooo00<000000?ooo`3oool00`3oool40?l000030?ooo`3o
0000oooo01P0oooo0P0000090?ooo`@00000903oool00`000000oooo0?ooo`0T0?ooo`030000003o
ool0oooo00L0oooo100000020?ooo`006`3oool60?l003L0oooo1@3o00000`3oool0o`000?ooo`0a
0?ooo`030000003oool0oooo00D0oooo00<0o`000?ooo`3o00000`3o00210?ooo`007P3oool50?l0
03P0oooo00<0o`000?ooo`3o00000`3o000`0?ooo`030000003oool0oooo00P0oooo103o00200?oo
o`00803oool40?l000030?ooo`3o0000oooo03L0oooo103o00000`3oool0o`000?ooo`0/0?ooo`03
0000003oool0oooo00X0oooo00@0o`000?ooo`3oool0o`00OP3oool000D0oooo700000080?l003L0
000000<0o`000000003o00000`3o000j000000@0o`00N@0000030?ooo`00303oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool50?l000D0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo
103o00000`3oool0o`000?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`050?ooo`@0o`0000<0oooo0?l0003oool00`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`070?ooo`00303oool00`000000oooo0?ooo`0I0?ooo`030?l0003oool0o`0000d0oooo00<0
00000?ooo`3oool0:@3oool80?l002D0oooo00<000000?ooo`3oool03`3oool00`3o0000oooo0?l0
00040?l001<0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0Z0?ooo`030000003o
ool0oooo00L0oooo000Y0?ooo`D0o`00>P3oool60?l002<0oooo00<000000?ooo`3oool04@3oool7
0?l007@0oooo000Z0?ooo`D0o`0000<0oooo0?l0003oool0>@3oool50?l00240oooo00<000000?oo
o`3oool05@3oool60?l00740oooo000]0?ooo`030?l0003oool0o`0000<0o`00>P3oool40?l00003
0?ooo`3o0000oooo01d0oooo00<000000?ooo`3oool05`3oool60?l006l0oooo000`0?ooo`@0o`00
00<0oooo0?l0003oool0=`3oool60?l001d0oooo00<000000?ooo`3oool06P3oool50?l006d0oooo
000b0?ooo`030?l0003oool0o`0000<0o`00>P3oool40?l001/0oooo00<000000?ooo`3oool0703o
ool40?l000030?ooo`3o0000oooo06T0oooo000e0?ooo`@0o`0000<0oooo0?l0003oool0>03oool3
0?l000030?ooo`3o0000oooo01L0oooo0P00000N0?ooo`P0o`00I`3oool003L0oooo00<0o`000?oo
o`3o00000`3o000h0?ooo`030?l0003oool0o`0000<0o`005P3oool00`000000oooo0?ooo`0Q0?oo
o`D0o`0000<0oooo0?l0003oool0H`3oool003X0oooo103o00000`3oool0o`000?ooo`0g0?ooo`@0
o`0000<0oooo0?l0003oool04P3oool00`000000oooo0?ooo`0T0?ooo`030?l0003oool0o`0000<0
o`00HP3oool003`0oooo00<0o`000?ooo`3o0000103o000g0?ooo`030?l0003oool0o`0000<0o`00
4@3oool00`000000oooo0?ooo`0W0?ooo`@0o`00H@3oool003l0oooo1P3o000h0?ooo`@0o`0000<0
oooo0?l0003oool03@3oool00`000000oooo0?ooo`0X0?ooo`80o`000P3oool00`3o0000oooo0?oo
o`1M0?ooo`00@P3oool60?l003L0oooo00<0o`000?ooo`3o0000103o000;0?ooo`030000003oool0
oooo02P0oooo0P3o00000`3oool0o`000?l000020?l005d0oooo00140?ooo`D0o`00>@3oool60?l0
00T0oooo00<000000?ooo`3oool0;03oool40?l000030?ooo`3o0000oooo05T0oooo00170?ooo`03
0?l0003oool0o`0003/0oooo1P3o00060?ooo`800000;`3oool00`3o0000oooo0?l000030?l005P0
oooo00180?ooo`D0o`00>P3oool60?l000@0oooo00<000000?ooo`3oool0<@3oool40?l000030?oo
o`3o0000oooo05@0oooo00190?ooo`H0o`00>`3oool60?l000030?ooo`000000oooo03@0oooo00<0
o`000?ooo`3o0000103o001B0?ooo`00C03oool60?l003X0oooo1P3o000h0?ooo`H0o`00D03oool0
04h0oooo1@3o00000`3oool0o`000?ooo`0i0?ooo`@0o`00>P3oool60?l004d0oooo001A0?ooo`03
0?l0003oool0o`0000<0o`00>P3oool40?l003X0oooo1P3o001;0?ooo`00E03oool40?l00080oooo
00<0o`000?ooo`3oool0=03oool00`000000oooo0?l000020?l000030?ooo`3o0000oooo03T0oooo
1P3o00180?ooo`00EP3oool00`3o0000oooo0?l000030?l003D0oooo00D000000?ooo`3oool0o`00
0?ooo`040?l003X0oooo1@3o00000`3oool0o`000?ooo`140?ooo`00F03oool50?l000030?ooo`3o
0000oooo0340oooo0P0000040?ooo`@0o`0000<0oooo0?l0003oool0>@3oool00`3o0000oooo0?l0
00030?l004<0oooo001K0?ooo`030?l0003oool0o`0000<0o`00<03oool00`000000oooo0?ooo`05
0?ooo`030?l0003oool0o`0000<0o`00>`3oool40?l00480oooo001N0?ooo`@0o`0000<0oooo0?l0
003oool0;03oool00`000000oooo0?ooo`080?ooo`@0o`0000<0oooo0?l0003oool0>@3oool0103o
0000oooo0?ooo`3o00100?ooo`00H03oool00`3o0000oooo0?l000030?l002/0oooo00<000000?oo
o`3oool02P3oool00`3o0000oooo0?l000030?l003X0oooo103o000n0?ooo`00H`3oool40?l00003
0?ooo`3o0000oooo02L0oooo00<000000?ooo`3oool03@3oool40?l000030?ooo`3o0000oooo03L0
oooo103o00000`3oool0o`000?ooo`0j0?ooo`00I03oool60?l002L0oooo00<000000?ooo`3oool0
3`3oool00`3o0000oooo0?l000040?l003L0oooo00<0o`000?ooo`3o00000`3o000i0?ooo`00J03o
ool40?l002D0oooo00<000000?ooo`3oool04@3oool70?l003P0oooo103o00020?ooo`030?l0003o
ool0oooo03<0oooo001Z0?ooo`<0o`000P3oool00`3o0000oooo0?ooo`0O0?ooo`8000005P3oool6
0?l003L0oooo00<0o`000?ooo`3o0000103o000c0?ooo`00J`3oool60?l00200oooo00<000000?oo
o`3oool05`3oool60?l003L0oooo1`3o000a0?ooo`00K03oool60?l000030?ooo`3o0000oooo01`0
oooo00<000000?ooo`3oool06P3oool50?l003T0oooo1P3o000^0?ooo`00L03oool00`3o0000oooo
0?l000030?l001/0oooo00<000000?ooo`3oool0703oool40?l003X0oooo1P3o000/0?ooo`00L`3o
ool40?l000030?ooo`3o0000oooo01L0oooo00<000000?ooo`3oool07P3oool40?l003/0oooo1@3o
000Z0?ooo`00M@3oool00`3o0000oooo0?l000030?l001H0oooo00<000000?ooo`3oool07`3oool6
0?l003X0oooo103o00000`3oool0o`000?ooo`0V0?ooo`00N03oool40?l000030?ooo`3o0000oooo
00T0oooo100000050?ooo`030000003oool0oooo0240oooo1@3o00000`3oool0o`000?ooo`0g0?oo
o`P0o`00903oool007X0oooo00<0o`000?ooo`3o00000`3o000:0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0903oool00`3o0000oooo0?l000030?l003X0oooo1@3o000S0?ooo`00
O@3oool40?l000030?ooo`3o0000oooo00H0oooo00<000000?ooo`3oool0103oool2000002P0oooo
103o00000`3oool0o`000?ooo`0i0?ooo`030?l0003oool0oooo0280oooo001o0?ooo`030?l0003o
ool0o`0000@0o`00103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02P0oooo0P3o
00000`3oool0o`000?l000020?l003X0oooo103o000O0?ooo`00PP3oool60?l00080oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0/0?ooo`@0o`0000<0oooo0?l0003oool0=P3oool4
0?l00080oooo00<0o`000?ooo`3oool06P3oool008D0oooo103o0002000000H0oooo00<000000?oo
o`3oool0;P3oool00`3o0000oooo0?l000030?l003L0oooo0P3o00000`3oool0o`000?l000020?l0
01X0oooo00270?ooo`@0o`001P3oool00`000000oooo0?ooo`0a0?ooo`@0o`0000<0oooo0?l0003o
ool0=`3oool40?l000030?ooo`3o0000oooo01H0oooo00290?ooo`@0o`00103oool00`000000oooo
0?ooo`0c0?ooo`030?l0003oool0o`0000@0o`00=`3oool00`3o0000oooo0?l000030?l001D0oooo
002:0?ooo`H0o`0000<0oooo0000003oool0=`3oool60?l003P0oooo103o00000`3oool0o`000?oo
o`0A0?ooo`00S03oool60?l000030000003oool0oooo03P0oooo1P3o000g0?ooo`030?l0003oool0
o`0000@0o`003`3oool008l0oooo1P3o000j0?ooo`D0o`00>@3oool60?l000d0oooo002A0?ooo`D0
o`0000<0oooo0?l0003oool0>@3oool00`3o0000oooo0?l0000k0?ooo`H0o`002P3oool00940oooo
00D000000?ooo`3oool0o`000?ooo`040?l003T0oooo1@3o000j0?ooo`D0o`002@3oool00940oooo
00<000000?ooo`3oool00`3oool40?l000030?ooo`3o0000oooo03H0oooo1@3o00000`3oool0o`00
0?ooo`0i0?ooo`030?l0003oool0oooo00P0oooo002A0?ooo`030000003oool0oooo00D0oooo00<0
o`000?ooo`3o00000`3o000h0?ooo`030?l0003oool0o`0000<0o`00@`3oool00940oooo00<00000
0?ooo`3oool0203oool40?l000030?ooo`3o0000oooo03L0oooo103o00000`3oool0o`000?ooo`0o
0?ooo`00T@3oool00`000000oooo0?ooo`0:0?ooo`030?l0003oool0o`0000<0o`00>03oool00`3o
0000oooo0?l000030?l003h0oooo002A0?ooo`8000003P3oool40?l003X0oooo103o00000`3oool0
o`000?ooo`0j0?ooo`00T@3oool00`000000oooo0?ooo`0?0?ooo`040?l0003oool0o`000?l003X0
oooo00<0o`000?ooo`3o00000`3o000i0?ooo`00T@3oool00`000000oooo0?ooo`0A0?ooo`D0o`00
>P3oool40?l00080oooo00<0o`000?ooo`3oool0<`3oool00940oooo00<000000?ooo`3oool04@3o
ool70?l003X0oooo00<0o`000?ooo`3o0000103o000c0?ooo`00T@3oool00`000000oooo0?ooo`0E
0?ooo`H0o`00>@3oool70?l00340oooo002A0?ooo`030000003oool0oooo01L0oooo1@3o00020?oo
o`030?l0003oool0oooo03L0oooo1P3o000^0?ooo`00T@3oool00`000000oooo0?ooo`0J0?ooo`H0
o`00>P3oool50?l002d0oooo002A0?ooo`800000703oool70?l003/0oooo00D0o`000?ooo`3oool0
oooo0?l0000Z0?ooo`00T@3oool00`000000oooo0?ooo`0O0?ooo`H0o`00>@3oool50?l002T0oooo
002A0?ooo`030000003oool0oooo0240oooo1@3o00000`3oool0o`000?ooo`0e0?ooo`L0o`009`3o
ool00940oooo00<000000?ooo`3oool0903oool00`3o0000oooo0?l000030?l003P0oooo1P3o000T
0?ooo`00T@3oool00`000000oooo0?ooo`0W0?ooo`@0o`0000<0oooo0?l0003oool0=P3oool50?l0
00030?ooo`3o0000oooo0200oooo002A0?ooo`030000003oool0oooo02P0oooo0P3o00000`3oool0
o`000?l000020?l003P0oooo00<0o`000?ooo`3o00000`3o000O0?ooo`00T@3oool00`000000oooo
0?ooo`0/0?ooo`@0o`0000<0oooo0?l0003oool0=`3oool40?l000030?ooo`3o0000oooo01/0oooo
002A0?ooo`800000;`3oool00`3o0000oooo0?l000030?l003L0oooo0P3o00000`3oool0o`000?l0
00020?l001X0oooo002A0?ooo`030000003oool0oooo0340oooo103o000j0?ooo`@0o`0000<0oooo
0?l0003oool05P3oool00940oooo00<000000?ooo`3oool0<`3oool0103o0000oooo0?ooo`3o000j
0?ooo`030?l0003oool0o`0000<0o`005@3oool00940oooo00<000000?ooo`3oool0=@3oool50?l0
03X0oooo103o00000`3oool0o`000?ooo`0A0?ooo`00T@3oool00`000000oooo0?ooo`0f0?ooo`H0
o`00>P3oool00`3o0000oooo0?l000040?l000l0oooo002A0?ooo`030000003oool0oooo03T0oooo
1P3o000j0?ooo`D0o`003P3oool008P0oooo100000050?ooo`030000003oool0oooo03/0oooo1P3o
000k0?ooo`030?l0003oool0o`0000d0oooo00280?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0?P3oool60?l003T0oooo1@3o000:0?ooo`00R@3oool00`000000oooo0?ooo`050?oo
o`800000@@3oool50?l000030?ooo`3o0000oooo03H0oooo1@3o00090?ooo`00RP3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo04<0oooo00<0o`000?ooo`3o00000`3o000h0?ooo`03
0?l0003oool0oooo00P0oooo002;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
AP3oool40?l000030?ooo`3o0000oooo03l0oooo00280?ooo`040000003oool0oooo000000D0oooo
00<000000?ooo`3oool0B03oool00`3o0000oooo0?l000030?l003h0oooo00290?ooo`8000001P3o
ool00`000000oooo0?ooo`1;0?ooo`@0o`0000<0oooo0?l0003oool0>P3oool00940oooo00<00000
0?ooo`3oool0C@3oool00`3o0000oooo0?l000030?l003T0oooo002A0?ooo`030000003oool0oooo
0500oooo103o000h0?ooo`00T@3oool2000005<0oooo00D0o`000?ooo`3oool0oooo0?l0000e0?oo
o`00T@3oool00`000000oooo0?ooo`1D0?ooo`D0o`00<`3oool00940oooo00<000000?ooo`3oool0
E03oool70?l00340oooo002A0?ooo`030000003oool0oooo05P0oooo1P3o000^0?ooo`00T@3oool0
0`000000oooo0?ooo`1J0?ooo`D0o`000P3oool00`3o0000oooo0?ooo`0X0?ooo`00T@3oool00`00
0000oooo0?ooo`1M0?ooo`H0o`00:@3oool00940oooo00<000000?ooo`3oool0GP3oool70?l002L0
oooo002A0?ooo`030000003oool0oooo0680oooo1P3o000T0?ooo`00T@3oool2000006D0oooo1@3o
00000`3oool0o`000?ooo`0P0?ooo`00T@3oool00`000000oooo0?ooo`1W0?ooo`030?l0003oool0
o`0000<0o`007`3oool00940oooo00<000000?ooo`3oool0JP3oool40?l000030?ooo`3o0000oooo
01/0oooo002A0?ooo`030000003oool0oooo06/0oooo0P3o00000`3oool0o`000?l000020?l001X0
oooo002A0?ooo`030000003oool0oooo06l0oooo103o000I0?ooo`00T@3oool00`000000oooo0?oo
o`1a0?ooo`040?l0003oool0oooo0?l001L0oooo002A0?ooo`030000003oool0oooo07<0oooo103o
000E0?ooo`00T@3oool2000007D0oooo103o00000`3oool0o`000?ooo`0A0?ooo`00T@3oool00`00
0000oooo0?ooo`1f0?ooo`030?l0003oool0o`0000@0o`003`3oool00940oooo00<000000?ooo`3o
ool0N@3oool60?l000d0oooo002A0?ooo`030000003oool0oooo07`0oooo1P3o000:0?ooo`00T@3o
ool00`000000oooo0?ooo`1n0?ooo`D0o`002@3oool00940oooo00<000000?ooo`3oool0P@3oool0
0`3o0000oooo0?ooo`080?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool2000008d0oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.63535, -1.87551, \
0.0112783, 0.0268511}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(genpl[9, Blue, Dashing[{0.01, 0.01}]]\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(1 + 2\ \[Delta]\), \(1\/2\), "0"},
            {\(1\/2\), \(1 + 2\ \[Delta]\), \(1\/2\)},
            {"0", \(1\/2\), \(1 + 2\ \[Delta]\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Print"],

Cell[BoxData[
    \({1 + 2\ delta, 1\/2\ \((2 - \@2 + 4\ delta)\), 
      1\/2\ \((2 + \@2 + 4\ delta)\)}\)], "Print"],

Cell[BoxData[
    \({1.`, 0.2928932188134524`, 1.7071067811865475`}\)], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.31746 0.229628 0.0793886 [
[.02381 .21713 -12 -9 ]
[.02381 .21713 12 0 ]
[.18254 .21713 -6 -9 ]
[.18254 .21713 6 0 ]
[.34127 .21713 -12 -9 ]
[.34127 .21713 12 0 ]
[.65873 .21713 -9 -9 ]
[.65873 .21713 9 0 ]
[.81746 .21713 -3 -9 ]
[.81746 .21713 3 0 ]
[.97619 .21713 -9 -9 ]
[.97619 .21713 9 0 ]
[.4875 .07085 -12 -4.5 ]
[.4875 .07085 0 4.5 ]
[.4875 .15024 -12 -4.5 ]
[.4875 .15024 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38841 -6 -4.5 ]
[.4875 .38841 0 4.5 ]
[.4875 .46779 -6 -4.5 ]
[.4875 .46779 0 4.5 ]
[.4875 .54718 -6 -4.5 ]
[.4875 .54718 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .22963 m
.02381 .23588 L
s
[(-1.5)] .02381 .21713 0 1 Mshowa
.18254 .22963 m
.18254 .23588 L
s
[(-1)] .18254 .21713 0 1 Mshowa
.34127 .22963 m
.34127 .23588 L
s
[(-0.5)] .34127 .21713 0 1 Mshowa
.65873 .22963 m
.65873 .23588 L
s
[(0.5)] .65873 .21713 0 1 Mshowa
.81746 .22963 m
.81746 .23588 L
s
[(1)] .81746 .21713 0 1 Mshowa
.97619 .22963 m
.97619 .23588 L
s
[(1.5)] .97619 .21713 0 1 Mshowa
.125 Mabswid
.05556 .22963 m
.05556 .23338 L
s
.0873 .22963 m
.0873 .23338 L
s
.11905 .22963 m
.11905 .23338 L
s
.15079 .22963 m
.15079 .23338 L
s
.21429 .22963 m
.21429 .23338 L
s
.24603 .22963 m
.24603 .23338 L
s
.27778 .22963 m
.27778 .23338 L
s
.30952 .22963 m
.30952 .23338 L
s
.37302 .22963 m
.37302 .23338 L
s
.40476 .22963 m
.40476 .23338 L
s
.43651 .22963 m
.43651 .23338 L
s
.46825 .22963 m
.46825 .23338 L
s
.53175 .22963 m
.53175 .23338 L
s
.56349 .22963 m
.56349 .23338 L
s
.59524 .22963 m
.59524 .23338 L
s
.62698 .22963 m
.62698 .23338 L
s
.69048 .22963 m
.69048 .23338 L
s
.72222 .22963 m
.72222 .23338 L
s
.75397 .22963 m
.75397 .23338 L
s
.78571 .22963 m
.78571 .23338 L
s
.84921 .22963 m
.84921 .23338 L
s
.88095 .22963 m
.88095 .23338 L
s
.9127 .22963 m
.9127 .23338 L
s
.94444 .22963 m
.94444 .23338 L
s
.25 Mabswid
0 .22963 m
1 .22963 L
s
.5 .07085 m
.50625 .07085 L
s
[(-2)] .4875 .07085 1 0 Mshowa
.5 .15024 m
.50625 .15024 L
s
[(-1)] .4875 .15024 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(1)] .4875 .30902 1 0 Mshowa
.5 .38841 m
.50625 .38841 L
s
[(2)] .4875 .38841 1 0 Mshowa
.5 .46779 m
.50625 .46779 L
s
[(3)] .4875 .46779 1 0 Mshowa
.5 .54718 m
.50625 .54718 L
s
[(4)] .4875 .54718 1 0 Mshowa
.125 Mabswid
.5 .08673 m
.50375 .08673 L
s
.5 .10261 m
.50375 .10261 L
s
.5 .11848 m
.50375 .11848 L
s
.5 .13436 m
.50375 .13436 L
s
.5 .16612 m
.50375 .16612 L
s
.5 .182 m
.50375 .182 L
s
.5 .19787 m
.50375 .19787 L
s
.5 .21375 m
.50375 .21375 L
s
.5 .24551 m
.50375 .24551 L
s
.5 .26138 m
.50375 .26138 L
s
.5 .27726 m
.50375 .27726 L
s
.5 .29314 m
.50375 .29314 L
s
.5 .32489 m
.50375 .32489 L
s
.5 .34077 m
.50375 .34077 L
s
.5 .35665 m
.50375 .35665 L
s
.5 .37253 m
.50375 .37253 L
s
.5 .40428 m
.50375 .40428 L
s
.5 .42016 m
.50375 .42016 L
s
.5 .43604 m
.50375 .43604 L
s
.5 .45192 m
.50375 .45192 L
s
.5 .48367 m
.50375 .48367 L
s
.5 .49955 m
.50375 .49955 L
s
.5 .51543 m
.50375 .51543 L
s
.5 .53131 m
.50375 .53131 L
s
.5 .05497 m
.50375 .05497 L
s
.5 .0391 m
.50375 .0391 L
s
.5 .02322 m
.50375 .02322 L
s
.5 .00734 m
.50375 .00734 L
s
.5 .56306 m
.50375 .56306 L
s
.5 .57894 m
.50375 .57894 L
s
.5 .59482 m
.50375 .59482 L
s
.5 .61069 m
.50375 .61069 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ .01 .01 ] 0 setdash
.02381 .07085 m
.06244 .09017 L
.10458 .11125 L
.14415 .13104 L
.18221 .15007 L
.22272 .17033 L
.26171 .18984 L
.30316 .21057 L
.34309 .23054 L
.3815 .24975 L
.42237 .27019 L
.46172 .28987 L
.49955 .30879 L
.53984 .32894 L
.57861 .34833 L
.61984 .36895 L
.65954 .38881 L
.69774 .40791 L
.73838 .42824 L
.77751 .44781 L
.81909 .46861 L
.85916 .48865 L
.89771 .50793 L
.93871 .52844 L
.97619 .54718 L
s
.02381 .01472 m
.06244 .03404 L
.10458 .05511 L
.14415 .0749 L
.18221 .09394 L
.22272 .1142 L
.26171 .1337 L
.30316 .15443 L
.34309 .1744 L
.3815 .19361 L
.42237 .21405 L
.46172 .23373 L
.49955 .25266 L
.53984 .27281 L
.57861 .2922 L
.61984 .31282 L
.65954 .33268 L
.69774 .35178 L
.73838 .37211 L
.77751 .39168 L
.81909 .41248 L
.85916 .43251 L
.89771 .4518 L
.93871 .4723 L
.97619 .49105 L
s
.02381 .12699 m
.06244 .14631 L
.10458 .16738 L
.14415 .18718 L
.18221 .20621 L
.22272 .22647 L
.26171 .24597 L
.30316 .2667 L
.34309 .28667 L
.3815 .30589 L
.42237 .32632 L
.46172 .34601 L
.49955 .36493 L
.53984 .38508 L
.57861 .40447 L
.61984 .42509 L
.65954 .44495 L
.69774 .46405 L
.73838 .48438 L
.77751 .50395 L
.81909 .52475 L
.85916 .54479 L
.89771 .56407 L
.93871 .58458 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo
0?ooo`2<0?ooo`00T@3oool2000008d0oooo002A0?ooo`030000003oool0oooo08`0oooo000<0?oo
o`80003oP`3oool00`000000oooo0?ooo`2<0?ooo`003P3oool00`000?l0oooo0?ooo`200?ooo`03
0000003oool0oooo08`0oooo000@0?ooo`030000o`3oool0oooo07h0oooo0P00002=0?ooo`004@3o
ool20000ogh0oooo00<000000?ooo`3oool0S03oool001<0oooo00<0003o0?ooo`3oool0N`3oool0
0`000000oooo0?ooo`2<0?ooo`005@3oool30000ogT0oooo00<000000?ooo`3oool0S03oool001P0
oooo00<0003o0?ooo`3oool0MP3oool00`000000oooo0?ooo`2<0?ooo`006P3oool00`000?l0oooo
0?ooo`1d0?ooo`800000S@3oool001/0oooo0P000?md0?ooo`030000003oool0oooo08`0oooo000M
0?ooo`030000o`3oool0oooo0740oooo00<000000?ooo`3oool0S03oool001l0oooo0P000?m`0?oo
o`030000003oool0oooo08`0oooo000Q0?ooo`80003oKP3oool2000008d0oooo000T0?ooo`030000
o`3oool0oooo06X0oooo00<000000?ooo`3oool0S03oool002D0oooo0P000?mZ0?ooo`030000003o
ool0oooo08`0oooo000W0?ooo`030000o`3oool0oooo05h0oooo100000050?ooo`030000003oool0
oooo08`0oooo000Y0?ooo`80003oG@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
08`0oooo000<0?ooo`80003o7@3oool20000oe`0oooo00<000000?ooo`3oool01@3oool2000008d0
oooo000>0?ooo`030000o`3oool0oooo01d0oooo00<0003o0?ooo`3oool0D@3oool4000000@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2<0?ooo`00403oool20000oad0oooo0P00
0?mJ0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0S03oool00180oooo0P000?lM
0?ooo`030000o`3oool0oooo05@0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?oo
o`2<0?ooo`00<`3oool20000oe@0oooo0P0000060?ooo`800000S@3oool001D0oooo0`000?lM0?oo
o`80003oFP3oool00`000000oooo0?ooo`2<0?ooo`00603oool00`000?l0oooo0?ooo`0M0?ooo`03
0000o`3oool0oooo05H0oooo00<000000?ooo`3oool0S03oool001X0oooo0P000?lM0?ooo`80003o
EP3oool00`000000oooo0?ooo`2<0?ooo`00703oool20000oad0oooo00<0003o0?ooo`3oool0D`3o
ool2000008d0oooo000m0?ooo`80003oDP3oool00`000000oooo0?ooo`2<0?ooo`007`3oool20000
oah0oooo0P000?m@0?ooo`030000003oool0oooo08`0oooo000Q0?ooo`80003o7`3oool00`000?l0
oooo0?ooo`1<0?ooo`030000003oool0oooo08`0oooo000T0?ooo`80003o7@3oool20000od`0oooo
00<000000?ooo`3oool0S03oool002H0oooo0P000?lM0?ooo`030000o`3oool0oooo04T0oooo0P00
002=0?ooo`00A`3oool20000odP0oooo00<000000?ooo`3oool0S03oool000`0oooo0P000?lK0?oo
o`80003o7P3oool20000odH0oooo00<000000?ooo`3oool0S03oool000h0oooo00<0003o0?ooo`3o
ool06P3oool20000oal0oooo0P000?m30?ooo`030000003oool0oooo08`0oooo000^0?ooo`80003o
7P3oool00`000?l0oooo0?ooo`100?ooo`800000S@3oool00100oooo0P000?lN0?ooo`80003o7@3o
ool00`000?l0oooo0?ooo`0o0?ooo`030000003oool0oooo08`0oooo000B0?ooo`80003o?@3oool2
0000och0oooo00<000000?ooo`3oool0S03oool001D0oooo00<0003o0?ooo`3oool06`3oool20000
oah0oooo0P000?lc0?ooo`@000001@3oool00`000000oooo0?ooo`2<0?ooo`005P3oool30000oa`0
oooo0P000?lO0?ooo`030000o`3oool0oooo0340oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`2<0?ooo`00>03oool20000oad0oooo0P000?la0?ooo`030000003oool0oooo00@0oooo
0P00002=0?ooo`006P3oool20000oah0oooo0P000?lM0?ooo`030000o`3oool0oooo02H0oooo1000
00040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0S03oool001`0oooo0P000?lm
0?ooo`80003o;@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08`0oooo000O0?oo
o`80003o703oool20000oah0oooo0P000?lY0?ooo`<000001P3oool00`000000oooo0?ooo`2<0?oo
o`008@3oool20000oa`0oooo0P000?lO0?ooo`030000o`3oool0oooo02L0oooo00<000000?ooo`3o
ool0103oool2000008d0oooo00120?ooo`<0003o703oool20000obh0oooo00<000000?ooo`3oool0
S03oool002@0oooo0P000?lO0?ooo`030000o`3oool0oooo01/0oooo00<0003o0?ooo`3oool0:`3o
ool00`000000oooo0?ooo`2<0?ooo`009P3oool20000ocd0oooo0P000?lZ0?ooo`030000003oool0
oooo08`0oooo000Y0?ooo`030000o`3oool0oooo01/0oooo0P000?lN0?ooo`80003o:03oool00`00
0000oooo0?ooo`2<0?ooo`00:P3oool20000oad0oooo0P000?lO0?ooo`030000o`3oool0oooo02@0
oooo0P00002=0?ooo`00;03oool00`000?l0oooo0?ooo`0M0?ooo`80003o7@3oool20000ob@0oooo
00<000000?ooo`3oool0S03oool000L0oooo100000030?ooo`030000003oool0oooo0080oooo0`00
000H0?ooo`80003o2@3oool400000140oooo0P000?l@0?ooo`800000103oool00`000000oooo0?oo
o`020?ooo`80000000<0003o0?ooo`3oool08@3oool00`000000oooo0?ooo`0R0?ooo`800000103o
ool00`000000oooo0?ooo`020?ooo`<000008`3oool4000002<0oooo100000030?ooo`030000003o
ool0oooo0080oooo0`0000030?ooo`002@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo01L0oooo0P000?l90?ooo`030000003oool0oooo0240oooo00@000000?ooo`3oool000002`3o
ool00`000000003o0000o`0P0?ooo`030000003oool0oooo0240oooo00@000000?ooo`3oool00000
2`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0
2P3oool100000040oooo0@3oool000T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0J0?ooo`030000o`3oool0oooo00D0oooo00<000000?ooo`3oool04`3oool20000o``0oooo00@0
00000?ooo`3oool000002`3oool00`000000oooo0?ooo`020000oah0oooo0P00000R0?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo00X0oooo0@0000010?ooo`40oooo00000`3oool0000000000002000000@0oooo
00<000000?ooo`3oool01`3oool3000001d0oooo00@000000000o`000?l00000103oool00`000000
oooo0?ooo`0E0?ooo`80003o103oool400000080oooo00@000000?ooo`3oool00000203oool30000
00H0oooo00<0003o0?ooo`3oool06P3oool00`000000oooo0?ooo`0Q0?ooo`040000003oool0oooo
000000P0oooo0`00000U0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool01`3oool3
000000<0oooo00090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0803oool00`00
0?l0oooo0?ooo`020?ooo`030000003oool0oooo01P0oooo0P000?l70?ooo`040000003oool0oooo
000000P0oooo00<000000?ooo`3oool01`3oool20000oaX0oooo00<000000?ooo`3oool08@3oool0
10000000oooo0?ooo`0000080?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0903o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00070?ooo`<000002@3oool0
0`000000oooo0?ooo`0R0?ooo`80003o0P00000L0?ooo`80003o1@3oool010000000oooo0?ooo`00
00080?ooo`030000003oool0oooo00T0oooo00<0003o0?ooo`3oool05`3oool00`000000oooo0?oo
o`0Q0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool08`3oool3000002@0oooo
0`0000090?ooo`030000003oool0oooo00<0oooo00090?ooo`030000003oool0oooo00L0oooo1000
000S0?ooo`80003o903oool2000000T0oooo1000000:0?ooo`80003o5P3oool2000002<0oooo0P00
00090?ooo`@00000903oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00L0oooo1000
00020?ooo`00?@3oool20000oa`0oooo0P000?lN0?ooo`80003o503oool00`000000oooo0?ooo`2<
0?ooo`00?`3oool20000oa`0oooo0P000?lO0?ooo`030000o`3oool0oooo0100oooo00<000000?oo
o`3oool0S03oool00600oooo0P000?lM0?ooo`80003o403oool00`000000oooo0?ooo`2<0?ooo`00
@P3oool30000oad0oooo0P000?lM0?ooo`030000o`3oool0oooo00d0oooo00<000000?ooo`3oool0
S03oool000D0oooo@00000000`000?l000000000000k00000080003oV00000030?ooo`00303oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`030?ooo`80003o00<0oooo0000003oool01P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00H0oooo00<000000000o`000?l01P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool20000o`030?ooo`000000
oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01`3oool000`0oooo00<000000?ooo`3oool0:@3oool00`00
0000oooo0?ooo`0>0?ooo`80003o6@3oool00`000000oooo0?ooo`020000oal0oooo00<0003o0?oo
o`3oool01P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02T0oooo00<000000?oo
o`3oool0:P3oool00`000000oooo0?ooo`070?ooo`00JP3oool20000oad0oooo0P000?l60?ooo`03
0000003oool0oooo08`0oooo001<0?ooo`<0003o7@3oool20000oad0oooo00<0003o0?ooo`3oool0
0`3oool2000008d0oooo001?0?ooo`030000o`3oool0oooo03/0oooo0P000?l20?ooo`030000003o
ool0oooo08`0oooo001A0?ooo`80003o703oool20000oah0oooo0P000?l00`000000oooo0?ooo`2<
0?ooo`00D`3oool20000oa`0oooo0P000?lN0?ooo`03000000000?l0oooo08`0oooo001d0?ooo`80
003o6`3oool010000000oooo0000o`000?n;0?ooo`00EP3oool20000oah0oooo0P000?lI0?ooo`80
00000P3oool00`000?l0oooo0?ooo`280?ooo`00F03oool20000oal0oooo0P000?lF0?ooo`030000
003oool0oooo00<0oooo0P000?n70?ooo`00F`3oool20000oah0oooo00<0003o0?ooo`3oool04`3o
ool00`000000oooo0?ooo`050?ooo`80003oQ@3oool005d0oooo0P000?lM0?ooo`030000o`3oool0
oooo0180oooo00<000000?ooo`3oool0203oool00`000?l0oooo0?ooo`210?ooo`00OP3oool20000
oa40oooo0P00000:0?ooo`80003oP@3oool00600oooo0P000?lN0?ooo`80003o3`3oool00`000000
oooo0?ooo`0;0?ooo`030000o`3oool0oooo07h0oooo001R0?ooo`80003o;@3oool00`000000oooo
0?ooo`0=0?ooo`80003oO@3oool006D0oooo0P000?lL0?ooo`80003o303oool00`000000oooo0?oo
o`0?0?ooo`80003oN`3oool006L0oooo0P000?lL0?ooo`80003o2P3oool00`000000oooo0?ooo`0B
0?ooo`030000o`3oool0oooo07L0oooo00280?ooo`80003o1`3oool2000001@0oooo0P000?mg0?oo
o`00JP3oool20000oah0oooo0P000?l50?ooo`030000003oool0oooo01D0oooo00<0003o0?ooo`3o
ool0M03oool006`0oooo0P000?lJ0?ooo`@000001@3oool00`000000oooo0?ooo`0G0?ooo`80003o
L`3oool006l0oooo0P000?lI0?ooo`030000003oool0oooo0080003o0P3oool00`000000oooo0?oo
o`0I0?ooo`80003oL@3oool00740oooo0P000?lG0?ooo`030000003oool0oooo0080oooo0P000?l2
000001d0oooo0P000?m^0?ooo`00RP3oool00`000000oooo0?ooo`040?ooo`03000000000?l0003o
01h0oooo00<0003o0?ooo`3oool0J`3oool007@0oooo0P000?lD0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool00P000?lM0?ooo`030000o`3oool0oooo06X0oooo001f0?ooo`80003o
403oool3000000H0oooo00<000000?ooo`3oool08@3oool20000ofT0oooo001i0?ooo`80003o3`3o
ool00`000000oooo0?ooo`040?ooo`800000103oool20000oah0oooo0P000?mW0?ooo`00N`3oool2
0000oa@0oooo00<000000?ooo`3oool01@3oool20000oal0oooo00<0003o0?ooo`3oool0H`3oool0
0940oooo00<000000?ooo`3oool0203oool20000oad0oooo0P000?mS0?ooo`00OP3oool20000oa40
oooo00<000000?ooo`3oool02P3oool20000oad0oooo00<0003o0?ooo`3oool0H03oool00800oooo
0P000?l?0?ooo`030000003oool0oooo02/0oooo0P000?mO0?ooo`00P`3oool20000o``0oooo0P00
000>0?ooo`80003o7P3oool20000oed0oooo00250?ooo`80003o2P3oool00`000000oooo0?ooo`0?
0?ooo`80003o7`3oool00`000?l0oooo0?ooo`1I0?ooo`00T@3oool00`000000oooo0?ooo`0B0?oo
o`80003o7@3oool20000oeT0oooo00280?ooo`80003o1`3oool00`000000oooo0?ooo`0D0?ooo`80
003o7@3oool00`000?l0oooo0?ooo`1F0?ooo`00RP3oool20000o`D0oooo0P00000f0?ooo`80003o
E@3oool008d0oooo0P000?l20?ooo`030000003oool0oooo01L0oooo0P000?lN0?ooo`80003oD`3o
ool008l0oooo0P000?l00`000000oooo0?ooo`0I0?ooo`80003o7`3oool00`000?l0oooo0?ooo`1?
0?ooo`00T@3oool00`000000oooo0?ooo`0L0?ooo`80003o7@3oool20000odl0oooo002A0?ooo`03
000000000?l0003o01h0oooo0P000?lM0?ooo`030000o`3oool0oooo04`0oooo002A0?ooo`800000
00<0oooo0000o`000?l0?@3oool20000od/0oooo002A0?ooo`030000003oool0oooo00<0oooo0P00
0?lL0?ooo`80003o7P3oool20000odT0oooo00280?ooo`@000001@3oool00`000000oooo0?ooo`05
0?ooo`80003o703oool20000oal0oooo00<0003o0?ooo`3oool0A@3oool008P0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0V0?ooo`80003o7@3oool20000odD0oooo00290?ooo`03
0000003oool0oooo00D0oooo0P0000090?ooo`80003o7P3oool20000oad0oooo00<0003o0?ooo`3o
ool0@P3oool008X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`80003o
?@3oool30000od00oooo002;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03@3o
ool20000oa`0oooo0P000?lO0?ooo`030000o`3oool0oooo03d0oooo00280?ooo`040000003oool0
oooo000000D0oooo00<000000?ooo`3oool03`3oool20000oa`0oooo0P000?lO0?ooo`030000o`3o
ool0oooo03/0oooo00290?ooo`8000001P3oool00`000000oooo0?ooo`0`0?ooo`80003o7@3oool2
0000oc/0oooo002A0?ooo`8000004`3oool20000oah0oooo0P000?lM0?ooo`030000o`3oool0oooo
03P0oooo002A0?ooo`030000003oool0oooo01@0oooo0P000?lm0?ooo`80003o=`3oool00940oooo
00<000000?ooo`3oool05`3oool20000oa`0oooo0P000?lN0?ooo`80003o=@3oool00940oooo00<0
00000?ooo`3oool06@3oool20000oa`0oooo0P000?lO0?ooo`030000o`3oool0oooo0340oooo002A
0?ooo`800000>`3oool20000oad0oooo0P000?la0?ooo`00T@3oool00`000000oooo0?ooo`0L0?oo
o`<0003o7@3oool20000oad0oooo00<0003o0?ooo`3oool0;P3oool00940oooo00<000000?ooo`3o
ool07`3oool00`000?l0oooo0?ooo`0k0?ooo`80003o;@3oool00940oooo00<000000?ooo`3oool0
8@3oool20000oa`0oooo0P000?lN0?ooo`80003o:`3oool00940oooo00<000000?ooo`3oool08`3o
ool20000oa`0oooo0P000?lO0?ooo`030000o`3oool0oooo02L0oooo002A0?ooo`800000A@3oool2
0000oad0oooo0P000?lW0?ooo`00T@3oool00`000000oooo0?ooo`0V0?ooo`80003o7P3oool20000
oad0oooo00<0003o0?ooo`3oool0903oool00940oooo00<000000?ooo`3oool0:03oool20000oal0
oooo00<0003o0?ooo`3oool06`3oool20000ob<0oooo002A0?ooo`030000003oool0oooo02/0oooo
0P000?lM0?ooo`80003o7@3oool20000ob40oooo002A0?ooo`800000;P3oool20000oad0oooo00<0
003o0?ooo`3oool07@3oool00`000?l0oooo0?ooo`0M0?ooo`00T@3oool00`000000oooo0?ooo`1>
0?ooo`80003o7@3oool20000oad0oooo00290?ooo`8000001P3oool00`000000oooo0?ooo`0`0?oo
o`80003o7P3oool20000oad0oooo00<0003o0?ooo`3oool06P3oool008P0oooo00@000000?ooo`3o
ool000001@3oool00`000000oooo0?ooo`0b0?ooo`80003o7`3oool00`000?l0oooo0?ooo`0K0?oo
o`80003o6@3oool008/0oooo00<000000?ooo`3oool00`3oool2000003H0oooo0P000?lM0?ooo`80
003o7@3oool20000oaL0oooo00290?ooo`8000001P3oool00`000000oooo0?ooo`0g0?ooo`80003o
7@3oool00`000?l0oooo0?ooo`0M0?ooo`030000o`3oool0oooo01<0oooo002;0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0F03oool20000oad0oooo0P000?lC0?ooo`00R03oool0
10000000oooo0?ooo`0000050?ooo`030000003oool0oooo03X0oooo0P000?lN0?ooo`80003o7@3o
ool00`000?l0oooo0?ooo`0@0?ooo`00R@3oool2000000H0oooo00<000000?ooo`3oool0?03oool2
0000oal0oooo00<0003o0?ooo`3oool06`3oool20000o`l0oooo002A0?ooo`800000@03oool20000
oad0oooo0P000?lM0?ooo`80003o3@3oool00940oooo00<000000?ooo`3oool0@@3oool20000oad0
oooo00<0003o0?ooo`3oool07@3oool20000o`X0oooo002A0?ooo`030000003oool0oooo0680oooo
0P000?lN0?ooo`030000o`3oool0oooo00L0oooo002A0?ooo`030000003oool0oooo04@0oooo0P00
0?lN0?ooo`80003o9P3oool00940oooo0P0000170?ooo`80003o7`3oool00`000?l0oooo0?ooo`0R
0?ooo`00T@3oool00`000000oooo0?ooo`190?ooo`<0003o703oool20000ob80oooo002A0?ooo`03
0000003oool0oooo04`0oooo00<0003o0?ooo`3oool06`3oool00`000?l0oooo0?ooo`0O0?ooo`00
T@3oool00`000000oooo0?ooo`1/0?ooo`80003o7P3oool00940oooo00<000000?ooo`3oool0CP3o
ool20000oah0oooo0P000?lL0?ooo`00T@3oool200000540oooo0P000?lj0?ooo`00T@3oool00`00
0000oooo0?ooo`1C0?ooo`80003o703oool20000oaT0oooo002A0?ooo`030000003oool0oooo05D0
oooo0P000?lL0?ooo`80003o5`3oool00940oooo00<000000?ooo`3oool0MP3oool30000oa<0oooo
002A0?ooo`800000F@3oool20000oal0oooo00<0003o0?ooo`3oool0403oool00940oooo00<00000
0?ooo`3oool0FP3oool20000oal0oooo00<0003o0?ooo`3oool03P3oool00940oooo00<000000?oo
o`3oool0G@3oool20000oad0oooo0P000?l>0?ooo`00RP3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo05l0oooo0P000?lM0?ooo`030000o`3oool0oooo00/0oooo002:0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0P03oool20000o`X0oooo00270?ooo`D000001@3o
ool2000006<0oooo0P000?lN0?ooo`030000o`3oool0oooo00L0oooo00270?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0I03oool20000obH0oooo00280?ooo`030000003oool0
000000H0oooo00<000000?ooo`3oool0I`3oool20000ob<0oooo00290?ooo`8000001P3oool00`00
0000oooo0?ooo`1Y0?ooo`80003o8@3oool008X0oooo00<000000?ooo`3oool0103oool2000008d0
oooo002A0?ooo`030000003oool0oooo06`0oooo0P000?lN0?ooo`00T@3oool00`000000oooo0?oo
o`1^0?ooo`80003o703oool00940oooo00<000000?ooo`3oool0L@3oool20000oaT0oooo002A0?oo
o`800000M03oool20000oaL0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000
003oool0oooo07H0oooo0`000?lC0?ooo`00T@3oool00`000000oooo0?ooo`1i0?ooo`030000o`3o
ool0oooo0100oooo002A0?ooo`030000003oool0oooo07/0oooo0P000?l?0?ooo`00T@3oool20000
07h0oooo0P000?l=0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo
0?ooo`200?ooo`<0003o2@3oool00940oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=
0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.63535, -2.98994, \
0.0112783, 0.0450998}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(genpl[10, Black, Dashing[{0.01, 0.01}]]\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(3\/2 + 3\ \[Delta]\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Print"],

Cell[BoxData[
    \({3\/2\ \((1 + 2\ delta)\)}\)], "Print"],

Cell[BoxData[
    \({1.5`}\)], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.31746 0.210916 0.0654004 [
[.02381 .19842 -12 -9 ]
[.02381 .19842 12 0 ]
[.18254 .19842 -6 -9 ]
[.18254 .19842 6 0 ]
[.34127 .19842 -12 -9 ]
[.34127 .19842 12 0 ]
[.65873 .19842 -9 -9 ]
[.65873 .19842 9 0 ]
[.81746 .19842 -3 -9 ]
[.81746 .19842 3 0 ]
[.97619 .19842 -9 -9 ]
[.97619 .19842 9 0 ]
[.4875 .08012 -12 -4.5 ]
[.4875 .08012 0 4.5 ]
[.4875 .34172 -6 -4.5 ]
[.4875 .34172 0 4.5 ]
[.4875 .47252 -6 -4.5 ]
[.4875 .47252 0 4.5 ]
[.4875 .60332 -6 -4.5 ]
[.4875 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .21092 m
.02381 .21717 L
s
[(-1.5)] .02381 .19842 0 1 Mshowa
.18254 .21092 m
.18254 .21717 L
s
[(-1)] .18254 .19842 0 1 Mshowa
.34127 .21092 m
.34127 .21717 L
s
[(-0.5)] .34127 .19842 0 1 Mshowa
.65873 .21092 m
.65873 .21717 L
s
[(0.5)] .65873 .19842 0 1 Mshowa
.81746 .21092 m
.81746 .21717 L
s
[(1)] .81746 .19842 0 1 Mshowa
.97619 .21092 m
.97619 .21717 L
s
[(1.5)] .97619 .19842 0 1 Mshowa
.125 Mabswid
.05556 .21092 m
.05556 .21467 L
s
.0873 .21092 m
.0873 .21467 L
s
.11905 .21092 m
.11905 .21467 L
s
.15079 .21092 m
.15079 .21467 L
s
.21429 .21092 m
.21429 .21467 L
s
.24603 .21092 m
.24603 .21467 L
s
.27778 .21092 m
.27778 .21467 L
s
.30952 .21092 m
.30952 .21467 L
s
.37302 .21092 m
.37302 .21467 L
s
.40476 .21092 m
.40476 .21467 L
s
.43651 .21092 m
.43651 .21467 L
s
.46825 .21092 m
.46825 .21467 L
s
.53175 .21092 m
.53175 .21467 L
s
.56349 .21092 m
.56349 .21467 L
s
.59524 .21092 m
.59524 .21467 L
s
.62698 .21092 m
.62698 .21467 L
s
.69048 .21092 m
.69048 .21467 L
s
.72222 .21092 m
.72222 .21467 L
s
.75397 .21092 m
.75397 .21467 L
s
.78571 .21092 m
.78571 .21467 L
s
.84921 .21092 m
.84921 .21467 L
s
.88095 .21092 m
.88095 .21467 L
s
.9127 .21092 m
.9127 .21467 L
s
.94444 .21092 m
.94444 .21467 L
s
.25 Mabswid
0 .21092 m
1 .21092 L
s
.5 .08012 m
.50625 .08012 L
s
[(-2)] .4875 .08012 1 0 Mshowa
.5 .34172 m
.50625 .34172 L
s
[(2)] .4875 .34172 1 0 Mshowa
.5 .47252 m
.50625 .47252 L
s
[(4)] .4875 .47252 1 0 Mshowa
.5 .60332 m
.50625 .60332 L
s
[(6)] .4875 .60332 1 0 Mshowa
.125 Mabswid
.5 .11282 m
.50375 .11282 L
s
.5 .14552 m
.50375 .14552 L
s
.5 .17822 m
.50375 .17822 L
s
.5 .24362 m
.50375 .24362 L
s
.5 .27632 m
.50375 .27632 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .37442 m
.50375 .37442 L
s
.5 .40712 m
.50375 .40712 L
s
.5 .43982 m
.50375 .43982 L
s
.5 .50522 m
.50375 .50522 L
s
.5 .53792 m
.50375 .53792 L
s
.5 .57062 m
.50375 .57062 L
s
.5 .04742 m
.50375 .04742 L
s
.5 .01472 m
.50375 .01472 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
[ .01 .01 ] 0 setdash
.02381 .01472 m
.06244 .03859 L
.10458 .06463 L
.14415 .08909 L
.18221 .11261 L
.22272 .13765 L
.26171 .16175 L
.30316 .18736 L
.34309 .21204 L
.3815 .23578 L
.42237 .26104 L
.46172 .28536 L
.49955 .30874 L
.53984 .33364 L
.57861 .3576 L
.61984 .38308 L
.65954 .40762 L
.69774 .43123 L
.73838 .45635 L
.77751 .48053 L
.81909 .50623 L
.85916 .53099 L
.89771 .55482 L
.93871 .58016 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo
0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<
0?ooo`00303oool2000008<0oooo0P00002=0?ooo`003P3oool00`000000oooo0?ooo`200?ooo`03
0000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo000@0?ooo`800000O`3o
ool00`000000oooo0?ooo`2<0?ooo`004P3oool2000007d0oooo00<000000?ooo`3oool0S03oool0
0940oooo00<000000?ooo`3oool0S03oool001D0oooo0P00001j0?ooo`030000003oool0oooo08`0
oooo000G0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0S03oool001X0oooo00<0
00000?ooo`3oool0M03oool00`000000oooo0?ooo`2<0?ooo`006`3oool00`000000oooo0?ooo`1c
0?ooo`800000S@3oool001`0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`2<0?oo
o`007`3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo08`0oooo000P0?ooo`030000
003oool0oooo06h0oooo00<000000?ooo`3oool0S03oool00240oooo00<000000?ooo`3oool0K@3o
ool00`000000oooo0?ooo`2<0?ooo`008`3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0
oooo08`0oooo000T0?ooo`800000J`3oool00`000000oooo0?ooo`2<0?ooo`009P3oool00`000000
oooo0?ooo`1O0?ooo`@000001@3oool00`000000oooo0?ooo`2<0?ooo`00:03oool00`000000oooo
0?ooo`1M0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0S03oool002T0oooo00<0
00000?ooo`3oool0G@3oool00`000000oooo0?ooo`050?ooo`800000S@3oool002X0oooo00<00000
0?ooo`3oool0E@3oool4000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2<
0?ooo`00;@3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0S03oool002h0oooo00<000000?ooo`3oool0E`3oool010000000oooo0?ooo`0000050?oo
o`030000003oool0oooo08`0oooo000_0?ooo`030000003oool0oooo05L0oooo0P0000060?ooo`03
0000003oool0oooo08`0oooo000b0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0
S03oool003<0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`2<0?ooo`00=03oool0
0`000000oooo0?ooo`1J0?ooo`030000003oool0oooo08`0oooo000f0?ooo`800000F@3oool00`00
0000oooo0?ooo`2<0?ooo`00>03oool00`000000oooo0?ooo`1F0?ooo`800000S@3oool003T0oooo
00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`2<0?ooo`00>`3oool00`000000oooo0?oo
o`1C0?ooo`030000003oool0oooo08`0oooo000l0?ooo`030000003oool0oooo0580oooo00<00000
0?ooo`3oool0S03oool003d0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`2<0?oo
o`00@03oool2000004l0oooo00<000000?ooo`3oool0S03oool00480oooo00<000000?ooo`3oool0
C03oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00A@3oool2
000004X0oooo00<000000?ooo`3oool0S03oool004L0oooo00<000000?ooo`3oool0A`3oool20000
08d0oooo002A0?ooo`030000003oool0oooo08`0oooo00190?ooo`800000AP3oool00`000000oooo
0?ooo`2<0?ooo`00B`3oool2000004@0oooo00<000000?ooo`3oool0S03oool00940oooo00<00000
0?ooo`3oool0S03oool004h0oooo0P0000110?ooo`030000003oool0oooo08`0oooo001@0?ooo`03
0000003oool0oooo03h0oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0
S03oool000L0oooo100000030?ooo`030000003oool0oooo0080oooo0`00000S0?ooo`@000005P3o
ool2000000/0oooo0P0000040?ooo`030000003oool0oooo0080oooo0`00000S0?ooo`030000003o
ool0oooo0280oooo0P0000040?ooo`030000003oool0oooo0080oooo0`00000S0?ooo`@000008`3o
ool4000000<0oooo00<000000?ooo`3oool00P3oool3000000<0oooo00090?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo00L0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`0P0?ooo`8000008P3o
ool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0
903oool00`000000oooo0?ooo`0:0?ooo`4000000@3oool10?ooo`002@3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool08@3oool010000000oooo0?oo
o`00000;0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool08@3oool010000000oooo
0?ooo`00000;0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0903oool00`000000
oooo0?ooo`0:0?ooo`4000000@3oool10?ooo`0000<0oooo0000000000000P0000040?ooo`030000
003oool0oooo00L0oooo0`00000M0?ooo`@00000103oool00`000000oooo0?ooo`0J0?ooo`D00000
0P3oool010000000oooo0?ooo`0000080?ooo`<000008`3oool00`000000oooo0?ooo`0Q0?ooo`04
0000003oool0oooo000000P0oooo0`00000U0?ooo`030000003oool0oooo02@0oooo00<000000?oo
o`3oool01`3oool3000000<0oooo00090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool09@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool00000203oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0240oooo00@000000?oo
o`3oool00000203oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02@0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`001`3oool3000000T0oooo00<000000?oo
o`3oool08`3oool3000002<0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo0240oooo00@000000?ooo`3oool00000203oool00`000000oooo0?oo
o`0S0?ooo`<00000903oool3000000T0oooo00<000000?ooo`3oool00`3oool000T0oooo00<00000
0?ooo`3oool01`3oool4000002@0oooo00<000000?ooo`3oool07P3oool200000080oooo0P000009
0?ooo`@000008P3oool00`000000oooo0?ooo`0R0?ooo`8000002@3oool4000002@0oooo00<00000
0?ooo`3oool0903oool00`000000oooo0?ooo`070?ooo`@000000P3oool005h0oooo0P00000a0?oo
o`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo001Q0?ooo`800000
;P3oool00`000000oooo0?ooo`2<0?ooo`001@3ooooo000001T000000`3oool000`0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo000000060?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01`3oool000`0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0Y0?oo
o`040000003oool0oooo000002T0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool01`3oool006P0oooo00<000000?oo
o`3oool09P3oool00`000000oooo0?ooo`2<0?ooo`00J`3oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo08`0oooo001/0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0
S03oool006d0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`2<0?ooo`00K`3oool0
0`000000oooo0?ooo`0O0?ooo`030000003oool0oooo08`0oooo001`0?ooo`8000007`3oool00`00
0000oooo0?ooo`2<0?ooo`00LP3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo08`0
oooo001d0?ooo`030000003oool0oooo01X0oooo0P00002=0?ooo`00M@3oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo08`0oooo001f0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool0S03oool007T0oooo0P00000F0?ooo`030000003oool0oooo08`0oooo001k0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0S03oool007/0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`2<0?ooo`00OP3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo08`0oooo001o0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0S03oool0
0800oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`2<0?ooo`00PP3oool00`000000
oooo0?ooo`0<0?ooo`800000S@3oool008<0oooo0P00000<0?ooo`030000003oool0oooo08`0oooo
00250?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0S03oool008L0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`2<0?ooo`00R03oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo08`0oooo00290?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0S03oool008`0oooo0P0000030?ooo`030000003oool0oooo08`0oooo002>0?ooo`040000003o
ool0oooo000008h0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`800000S@3oool0
0940oooo00<000000?ooo`000000S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo
00@000000?ooo`3oool0oooo0P0000290?ooo`00T@3oool00`000000oooo0?ooo`030?ooo`800000
Q`3oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool01P3oool2
000008@0oooo00280?ooo`@000001@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
0840oooo00280?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0S03oool008T0oooo
00<000000?ooo`3oool01@3oool2000000`0oooo0P00001o0?ooo`00RP3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0O03oool008/0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`2<0?ooo`00R03oool010000000oooo0?ooo`000005
0?ooo`030000003oool0oooo0100oooo0P00001j0?ooo`00R@3oool2000000H0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`1g0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00
T@3oool00`000000oooo0?ooo`0D0?ooo`800000MP3oool00940oooo00<000000?ooo`3oool05P3o
ool2000007@0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`8000006P3oool20000
0740oooo002A0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0KP3oool00940oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1[0?ooo`00T@3oool00`000000oooo0?oo
o`0N0?ooo`800000K03oool00940oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1Y
0?ooo`00T@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo06H0oooo002A0?ooo`03
0000003oool0oooo02@0oooo00<000000?ooo`3oool0I@3oool00940oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`1T0?ooo`00T@3oool00`000000oooo0?ooo`0W0?ooo`800000H`3o
ool00940oooo0P00000Z0?ooo`030000003oool0oooo0600oooo002A0?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool0G`3oool00940oooo00<000000?ooo`3oool0;03oool00`000000
oooo0?ooo`1M0?ooo`00T@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo05`0oooo
002A0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0F`3oool00940oooo00<00000
0?ooo`3oool0<@3oool00`000000oooo0?ooo`1H0?ooo`00T@3oool00`000000oooo0?ooo`0b0?oo
o`030000003oool0oooo05L0oooo002A0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3o
ool0EP3oool00940oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`1C0?ooo`00T@3o
ool2000003P0oooo00<000000?ooo`3oool0DP3oool00940oooo00<000000?ooo`3oool0>03oool0
0`000000oooo0?ooo`1A0?ooo`00T@3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo
04l0oooo002A0?ooo`030000003oool0oooo03/0oooo0P00001?0?ooo`00T@3oool00`000000oooo
0?ooo`0m0?ooo`030000003oool0oooo04`0oooo002A0?ooo`030000003oool0oooo03l0oooo0P00
001;0?ooo`00T@3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo04P0oooo002A0?oo
o`030000003oool0oooo08`0oooo002:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0A03oool2000004H0oooo002:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
AP3oool00`000000oooo0?ooo`130?ooo`00Q`3oool5000000D0oooo0P00002=0?ooo`00Q`3oool0
10000000oooo0?ooo`0000060?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0@03o
ool008P0oooo00<000000?ooo`0000001P3oool00`000000oooo0?ooo`1:0?ooo`800000@03oool0
08T0oooo0P0000060?ooo`030000003oool0oooo08`0oooo002:0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0C@3oool2000003d0oooo002A0?ooo`030000003oool0oooo04l0oooo
0P00000k0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`1B
0?ooo`800000>03oool00940oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0e0?oo
o`00T@3oool2000008d0oooo002A0?ooo`030000003oool0oooo05L0oooo0P00000c0?ooo`00T@3o
ool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo0300oooo002A0?ooo`030000003oool0
oooo08`0oooo002A0?ooo`030000003oool0oooo05`0oooo0P00000^0?ooo`00T@3oool00`000000
oooo0?ooo`1N0?ooo`030000003oool0oooo02/0oooo002A0?ooo`030000003oool0oooo08`0oooo
002A0?ooo`030000003oool0oooo0600oooo0`00000Y0?ooo`00T@3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo02H0oooo002A0?ooo`800000S@3oool00940oooo00<000000?ooo`3o
ool0I@3oool2000002D0oooo002A0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool0
8P3oool00940oooo00<000000?ooo`3oool0JP3oool200000200oooo002A0?ooo`030000003oool0
oooo06`0oooo00<000000?ooo`3oool07@3oool00940oooo00<000000?ooo`3oool0K03oool00`00
0000oooo0?ooo`0M0?ooo`00T@3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo01X0
oooo002A0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool06@3oool00940oooo00<0
00000?ooo`3oool0L@3oool00`000000oooo0?ooo`0H0?ooo`00T@3oool2000007@0oooo00<00000
0?ooo`3oool05P3oool00940oooo00<000000?ooo`3oool0M03oool2000001H0oooo002A0?ooo`03
0000003oool0oooo07H0oooo00<000000?ooo`3oool04`3oool00940oooo00<000000?ooo`3oool0
N03oool00`000000oooo0?ooo`0A0?ooo`00T@3oool00`000000oooo0?ooo`1i0?ooo`030000003o
ool0oooo0100oooo002A0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool03`3oool0
0940oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`0<0?ooo`00R@3oool2000000H0
oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`0;0?ooo`00R03oool010000000oooo
0?ooo`0000050?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool02P3oool008P0oooo
00@000000?ooo`3oool000001@3oool2000008d0oooo00280?ooo`<000001P3oool00`000000oooo
0?ooo`2<0?ooo`00R03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08`0oooo0028
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0S03oool008T0oooo0`0000050?oo
o`030000003oool0oooo08`0oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.63535, -3.33262, \
0.0112783, 0.054746}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(pic2 = 
      Show[Graphics[legenda], 
        PlotRange \[Rule] {{0.5, 1.5}, {\(-0.5\), 10.5}}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.5 1 0.0280925 0.0561849 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.004 w
[ ] 0 setdash
0 .08428 m
.5 .08428 L
s
gsave
.7 .08428 -83.0938 -9.03125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.0625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 11.250 moveto
(8) show
69.000 11.250 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
75.625 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
81.625 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
91.188 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
97.188 11.250 moveto
(<) show
1.000 setlinewidth
grestore
0 0 1 r
0 .14046 m
.5 .14046 L
s
gsave
.7 .14046 -86.1875 -14.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
63.000 17.250 moveto
(9) show
69.000 17.250 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(-) show
75.625 17.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(2) show
81.625 17.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(,) show
94.250 11.188 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(1) show
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
93.000 17.250 moveto
(\\200) show
95.062 17.250 moveto
(\\200) show
97.125 17.250 moveto
(\\200) show
99.188 17.250 moveto
(\\200) show
99.625 17.250 moveto
(\\200) show
94.250 23.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(2) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
103.375 17.250 moveto
(=) show
1.000 setlinewidth
grestore
1 0 0 r
0 .19665 m
.5 .19665 L
s
gsave
.7 .19665 -83.0938 -9.03125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.0625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
63.000 11.250 moveto
(8) show
69.000 11.250 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(-) show
75.625 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(1) show
81.625 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(,) show
91.188 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(0) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
97.188 11.250 moveto
(<) show
1.000 setlinewidth
grestore
.008 w
0 .25283 m
.5 .25283 L
s
gsave
.7 .25283 -83.0938 -9.03125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.0625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
63.000 11.250 moveto
(8) show
69.000 11.250 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(-) show
75.625 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(1) show
81.625 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(,) show
91.188 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
97.188 11.250 moveto
(<) show
1.000 setlinewidth
grestore
0 .392 0 r
.004 w
0 .30902 m
.5 .30902 L
s
gsave
.7 .30902 -82.875 -14.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.392 0.000 setrgbcolor
63.000 17.250 moveto
(9) show
69.000 17.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.392 0.000 setrgbcolor
(0) show
75.000 17.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.392 0.000 setrgbcolor
(,) show
87.625 11.188 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.392 0.000 setrgbcolor
(1) show
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.392 0.000 setrgbcolor
86.375 17.250 moveto
(\\200) show
88.438 17.250 moveto
(\\200) show
90.500 17.250 moveto
(\\200) show
92.562 17.250 moveto
(\\200) show
93.000 17.250 moveto
(\\200) show
87.625 23.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.392 0.000 setrgbcolor
(2) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.392 0.000 setrgbcolor
96.750 17.250 moveto
(=) show
1.000 setlinewidth
grestore
.006 w
0 .3652 m
.5 .3652 L
s
gsave
.7 .3652 -82.875 -14.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.392 0.000 setrgbcolor
63.000 17.250 moveto
(9) show
69.000 17.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.392 0.000 setrgbcolor
(0) show
75.000 17.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.392 0.000 setrgbcolor
(,) show
87.625 11.188 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.392 0.000 setrgbcolor
(3) show
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.392 0.000 setrgbcolor
86.375 17.250 moveto
(\\200) show
88.438 17.250 moveto
(\\200) show
90.500 17.250 moveto
(\\200) show
92.562 17.250 moveto
(\\200) show
93.000 17.250 moveto
(\\200) show
87.625 23.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.392 0.000 setrgbcolor
(2) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.392 0.000 setrgbcolor
96.750 17.250 moveto
(=) show
1.000 setlinewidth
grestore
1 0 0 r
.004 w
[ .01 .01 ] 0 setdash
0 .42139 m
.5 .42139 L
s
gsave
.7 .42139 -79.7812 -9.03125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.0625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
63.000 11.250 moveto
(8) show
69.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(1) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(,) show
84.562 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(0) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
90.562 11.250 moveto
(<) show
1.000 setlinewidth
grestore
.008 w
0 .47757 m
.5 .47757 L
s
gsave
.7 .47757 -79.7812 -9.03125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.0625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
63.000 11.250 moveto
(8) show
69.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(1) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(,) show
84.562 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
90.562 11.250 moveto
(<) show
1.000 setlinewidth
grestore
0 0 1 r
.004 w
0 .53376 m
.5 .53376 L
s
gsave
.7 .53376 -82.875 -14.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
63.000 17.250 moveto
(9) show
69.000 17.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(2) show
75.000 17.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(,) show
87.625 11.188 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(1) show
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
86.375 17.250 moveto
(\\200) show
88.438 17.250 moveto
(\\200) show
90.500 17.250 moveto
(\\200) show
92.562 17.250 moveto
(\\200) show
93.000 17.250 moveto
(\\200) show
87.625 23.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(2) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
96.750 17.250 moveto
(=) show
1.000 setlinewidth
grestore
0 g
0 .58994 m
.5 .58994 L
s
gsave
.7 .58994 -79.7812 -9.03125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.0625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 11.250 moveto
(8) show
69.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
84.562 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
90.562 11.250 moveto
(<) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{401.062, 247.875},
  ImageMargins->{{42, 0}, {0, 1}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006A0000mb000`400?l00000o`00003oo`3ooonB
0?ooo`00o`3ooonB0?ooo`00o`3ooonB0?ooo`00o`3ooonB0?ooo`00o`3ooonB0?ooo`00o`3ooonB
0?ooo`00o`3ooonB0?ooo`00o`3ooonB0?ooo`00o`3ooonB0?ooo`00o`3ooonB0?ooo`00o`3ooonB
0?ooo`00o`3ooonB0?ooo`00o`3ooonB0?ooo`00o`3ooonB0?ooo`00o`3ooonB0?ooo`00o`3ooonB
0?ooo`00o`3ooonB0?ooo`00o`3ooonB0?ooo`00o`3ooonB0?ooo`00o`3ooonB0?ooo`00o`3ooonB
0?ooo`00o`3ooonB0?ooo`00o`3ooonB0?ooo`00o`3ooonB0?ooo`00o`3ooonB0?ooo`00o`3ooonB
0?ooo`00o`3ooonB0?ooo`00o`3ooonB0?ooo`00o`3ooonB0?ooo`00o`3ooonB0?ooo`00o`3oool8
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1W
0?ooo`00o`3oool70?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`1V0?ooo`00o`3oool70?ooo`030000003oool0oooo00T0oooo0P0000040?ooo`03
0000003oool0oooo00L0oooo0P0000040?ooo`030000003oool0oooo06H0oooo0039000003d0oooo
00<000000?ooo`3oool0203oool010000000oooo0?ooo`00000<0?ooo`040000003oool0oooo0000
00<0oooo00<000000?ooo`3oool0IP3oool00?l0oooo1P3oool00`000000oooo0?ooo`020?ooo`@0
00001P3oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool0I@3oool00?l0oooo1`3oool00`000000oooo0?ooo`090?ooo`8000003@3oool010000000
oooo0?ooo`0000030?ooo`030000003oool0oooo06H0oooo003o0?ooo`L0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo000000<0oooo00<000000?oo
o`3oool0IP3oool00?l0oooo203oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo0000
00`0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`1W0?ooo`00o`3ooolC0?oo
o`8000003P3oool2000006d0oooo003o0?oooi80oooo003o0?oooi80oooo003o0?oooi80oooo003o
0?oooi80oooo003o0?oooi80oooo003o0?oooi80oooo003o0?oooi80oooo003o0?oooi80oooo003o
0?oooi80oooo003o0?ooob40oooo10000?m]0?ooo`00o`3ooolQ0?ooo`030000o`3oool0oooo06h0
oooo003o0?ooo`D0oooo00<0003o0?ooo`3oool06P3oool00`000?l0oooo0?ooo`060?ooo`030000
o`3oool0oooo06@0oooo003o0?ooo`@0oooo00<0003o0?ooo`3oool0703oool00`000?l0oooo0?oo
o`060?ooo`030000o`3oool0oooo06<0oooo003o0?ooo`@0oooo00<0003o0?ooo`3oool03P3oool0
0`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0H`3oool0
0?l0oooo103oool00`000?l0oooo0?ooo`0?0?ooo`030000o`3oool0oooo00P0oooo00@0003o0?oo
o`3oool0003o1`3oool00`000?l0oooo0?ooo`1S0?ooo`00o`3oool40?ooo`030000o`3oool0oooo
00P0oooo10000?l30?ooo`030000o`3oool0oooo00T0oooo0P000?l80?ooo`030000o`3oool0oooo
06<0oooo003o0?ooo`@0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0J0?ooo`03
0000o`3oool0oooo06<0oooo00390000ocT0oooo00<0003o0?ooo`3oool00P3oool40000o`@0oooo
00<0003o0?ooo`3oool0303oool90000o`D0oooo00<0003o0?ooo`3oool0HP3oool00?l0oooo103o
ool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo01P0oooo00<0003o0?ooo`3oool0H`3o
ool00?l0oooo103oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo01L0oooo00<0003o
0?ooo`3oool0H`3oool00?l0oooo103oool00`000?l0oooo0?ooo`080?ooo`040000o`3oool0oooo
0000oaT0oooo00<0003o0?ooo`3oool0H`3oool00?l0oooo103oool00`000?l0oooo0?ooo`090?oo
o`80003o3`3oool40000o`L0oooo00<0003o0?ooo`3oool0H`3oool00?l0oooo103oool00`000?l0
oooo0?ooo`0L0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0H`3oool00?l0oooo
1@3oool00`000?l0oooo0?ooo`0K0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0
I03oool00?l0oooo8`3oool00`000?l0oooo0?ooo`1/0?ooo`00o`3ooolS0?ooo`030000o`3oool0
oooo06`0oooo003o0?ooob40oooo0`000?m^0?ooo`00o`3ooolS0?ooo`030000o`3oool0oooo06`0
oooo003o0?oooi80oooo003o0?oooi80oooo003o0?oooi80oooo003o0?oooi80oooo003o0?oooi80
oooo003o0?oooi80oooo003o0?oooi80oooo003o0?oooi80oooo003o0?ooo`P0oooo00<0o`000?oo
o`3oool03@3oool00`3o0000oooo0?ooo`0=0?ooo`030?l0003oool0oooo06L0oooo003o0?ooo`L0
oooo00<0o`000?ooo`3oool03`3oool00`3o0000oooo0?ooo`0=0?ooo`030?l0003oool0oooo06H0
oooo003o0?ooo`L0oooo00<0o`000?ooo`3oool0203oool40?l000<0oooo00<0o`000?ooo`3oool0
1`3oool20?l000@0oooo00<0o`000?ooo`3oool0IP3oool00<T0o`00?@3oool00`3o0000oooo0?oo
o`0:0?ooo`030?l0003oool0oooo00/0oooo00@0o`000?ooo`3oool0o`000`3oool00`3o0000oooo
0?ooo`1V0?ooo`00o`3oool60?ooo`030?l0003oool0oooo0080oooo103o00050?ooo`030?l0003o
ool0oooo00/0oooo00@0o`000?ooo`3oool0o`00103oool00`3o0000oooo0?ooo`1U0?ooo`00o`3o
ool70?ooo`030?l0003oool0oooo00X0oooo00<0o`000?ooo`3oool02`3oool0103o0000oooo0?oo
o`3o00030?ooo`030?l0003oool0oooo06H0oooo003o0?ooo`L0oooo00<0o`000?ooo`3oool02P3o
ool00`3o0000oooo0?ooo`0;0?ooo`040?l0003oool0oooo0?l000<0oooo00<0o`000?ooo`3oool0
IP3oool00?l0oooo203oool00`3o0000oooo0?ooo`070?ooo`<0o`003@3oool0103o0000oooo0?oo
o`3o00020?ooo`030?l0003oool0oooo06L0oooo003o0?oooa@0oooo00<0o`000?ooo`3oool0303o
ool20?l006d0oooo003o0?oooi80oooo003o0?oooi80oooo003o0?oooi80oooo003o0?oooi80oooo
003o0?oooi80oooo003o0?oooi80oooo003o0?oooi80oooo003o0?oooi80oooo003o0?oooi80oooo
003o0?oooi80oooo003o0?oooi80oooo003o0?oooi80oooo003o0?oooi80oooo003o0?ooo`P0oooo
00<0o`000?ooo`3oool03@3oool00`3o0000oooo0?ooo`0=0?ooo`030?l0003oool0oooo06L0oooo
003o0?ooo`L0oooo00<0o`000?ooo`3oool03`3oool00`3o0000oooo0?ooo`0=0?ooo`030?l0003o
ool0oooo06H0oooo003o0?ooo`L0oooo00<0o`000?ooo`3oool0203oool40?l000<0oooo00<0o`00
0?ooo`3oool01P3oool40?l000<0oooo00<0o`000?ooo`3oool0IP3oool00<X0o`00?03oool00`3o
0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo00d0oooo00<0o`000?ooo`3oool00P3oool00`3o
0000oooo0?ooo`1V0?ooo`00bP3o000k0?ooo`030?l0003oool0oooo0080oooo103o00050?ooo`03
0?l0003oool0oooo00d0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`1U0?ooo`00
bP3o000l0?ooo`030?l0003oool0oooo00X0oooo00<0o`000?ooo`3oool03@3oool00`3o0000oooo
0?ooo`020?ooo`030?l0003oool0oooo06H0oooo003o0?ooo`L0oooo00<0o`000?ooo`3oool02P3o
ool00`3o0000oooo0?ooo`0=0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0IP3o
ool00?l0oooo203oool00`3o0000oooo0?ooo`070?ooo`<0o`003@3oool30?l000<0oooo00<0o`00
0?ooo`3oool0I`3oool00?l0oooo503oool00`3o0000oooo0?ooo`0=0?ooo`030?l0003oool0oooo
06/0oooo003o0?oooi80oooo003o0?oooi80oooo003o0?oooi80oooo003o0?oooi80oooo003o0?oo
oi80oooo003o0?oooi80oooo003o0?oooi80oooo003o0?oooi80oooo003o0?oooi80oooo003o0?oo
oah0oooo1000I01`0?ooo`00o`3ooolN0?ooo`03001T003oool0oooo0740oooo003o0?ooo`T0oooo
00<006@00?ooo`3oool04`3oool00`00I000oooo0?ooo`050?ooo`03001T003oool0oooo06P0oooo
003o0?ooo`P0oooo00<006@00?ooo`3oool05@3oool00`00I000oooo0?ooo`050?ooo`03001T003o
ool0oooo06L0oooo003o0?ooo`P0oooo00<006@00?ooo`3oool01`3oool00`00I000oooo0?ooo`0<
0?ooo`03001T003oool0oooo00@0oooo00<006@00?ooo`3oool0I`3oool00?l0oooo203oool00`00
I000oooo0?ooo`080?ooo`03001T003oool0oooo00P0oooo00@006@00?ooo`3oool006@01P3oool0
0`00I000oooo0?ooo`1W0?ooo`00o`3oool80?ooo`03001T003oool0oooo0080oooo0P00I0040?oo
o`03001T003oool0oooo00T0oooo0P00I0070?ooo`03001T003oool0oooo06L0oooo003o0?ooo`P0
oooo00D006@00?ooo`3oool0oooo001T00020?ooo`03001T003oool0oooo01H0oooo00<006@00?oo
o`3oool0I`3oool00<T006@0?@3oool00`00I000oooo0?ooo`020?ooo`04001T003oool0oooo001T
00`0oooo2@00I0040?ooo`03001T003oool0oooo06H0oooo003o0?ooo`P0oooo00D006@00?ooo`3o
ool0oooo001T00020?ooo`03001T003oool0oooo01H0oooo00<006@00?ooo`3oool0I`3oool00?l0
oooo203oool01@00I000oooo0?ooo`3oool006@00080oooo00<006@00?ooo`3oool05P3oool00`00
I000oooo0?ooo`1W0?ooo`00o`3oool80?ooo`05001T003oool0oooo0?ooo`00I0000P3oool00`00
I000oooo0?ooo`0F0?ooo`03001T003oool0oooo06L0oooo003o0?ooo`P0oooo00<006@00?ooo`3o
ool00P3oool2001T00l0oooo1000I0060?ooo`03001T003oool0oooo06L0oooo003o0?ooo`P0oooo
00<006@00?ooo`3oool05@3oool00`00I000oooo0?ooo`050?ooo`03001T003oool0oooo06L0oooo
003o0?ooo`T0oooo00<006@00?ooo`3oool0503oool00`00I000oooo0?ooo`040?ooo`03001T003o
ool0oooo06P0oooo003o0?ooob00oooo00<006@00?ooo`3oool0K`3oool00?l0oooo803oool00`00
I000oooo0?ooo`1_0?ooo`00o`3ooolN0?ooo`<006@0L@3oool00?l0oooo803oool00`00I000oooo
0?ooo`1_0?ooo`00o`3ooonB0?ooo`00o`3ooonB0?ooo`00o`3ooonB0?ooo`00o`3ooolN0?ooo`@0
06@0L03oool00?l0oooo7P3oool00`00I000oooo0?ooo`1a0?ooo`00o`3oool90?ooo`03001T003o
ool0oooo01<0oooo00<006@00?ooo`3oool01@3oool00`00I000oooo0?ooo`1X0?ooo`00o`3oool8
0?ooo`03001T003oool0oooo01D0oooo00<006@00?ooo`3oool01@3oool00`00I000oooo0?ooo`1W
0?ooo`00o`3oool80?ooo`03001T003oool0oooo00L0oooo00<006@00?ooo`3oool0303oool00`00
I000oooo0?ooo`040?ooo`03001T003oool0oooo06L0oooo003o0?ooo`P0oooo00<006@00?ooo`3o
ool0203oool00`00I000oooo0?ooo`080?ooo`04001T003oool0oooo001T00H0oooo00<006@00?oo
o`3oool0I`3oool00?l0oooo203oool00`00I000oooo0?ooo`020?ooo`8006@0103oool00`00I000
oooo0?ooo`090?ooo`8006@01`3oool00`00I000oooo0?ooo`1W0?ooo`00o`3oool80?ooo`05001T
003oool0oooo0?ooo`00I0000P3oool00`00I000oooo0?ooo`0F0?ooo`03001T003oool0oooo06L0
oooo003o0?ooo`L0oooo00<006@00?ooo`3oool00P3oool01000I000oooo0?ooo`00I00<0?ooo`T0
06@0103oool00`00I000oooo0?ooo`1V0?ooo`00b@00I00n0?ooo`05001T003oool0oooo0?ooo`00
I0000P3oool00`00I000oooo0?ooo`0F0?ooo`03001T003oool0oooo06L0oooo0039001T03h0oooo
00D006@00?ooo`3oool0oooo001T00020?ooo`03001T003oool0oooo01H0oooo00<006@00?ooo`3o
ool0I`3oool00?l0oooo203oool01@00I000oooo0?ooo`3oool006@00080oooo00<006@00?ooo`3o
ool05P3oool00`00I000oooo0?ooo`1W0?ooo`00o`3oool80?ooo`03001T003oool0oooo0080oooo
0P00I00@0?ooo`8006@01`3oool00`00I000oooo0?ooo`1W0?ooo`00o`3oool80?ooo`03001T003o
ool0oooo01<0oooo00@006@00?ooo`3oool006@01P3oool00`00I000oooo0?ooo`1W0?ooo`00o`3o
ool90?ooo`03001T003oool0oooo01D0oooo00<006@00?ooo`3oool00`3oool00`00I000oooo0?oo
o`1X0?ooo`00o`3ooolO0?ooo`8006@0L@3oool00?l0oooo8@3oool00`00I000oooo0?ooo`1^0?oo
o`00o`3ooolN0?ooo`04001T003oool0oooo001T0700oooo003o0?oooal0oooo0P00I01a0?ooo`00
o`3ooonB0?ooo`00o`3ooonB0?ooo`00o`3ooonB0?ooo`00o`3ooonB0?ooo`00o`3ooonB0?ooo`00
o`3ooonB0?ooo`00o`3ooonB0?ooo`00o`3ooonB0?ooo`00o`3ooonB0?ooo`00o`3oool<0?ooo`03
0?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool0303oool00`3o0000oooo0?ooo`1[0?ooo`00
o`3oool;0?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool0303oool00`3o0000oooo
0?ooo`1Z0?ooo`00o`3oool;0?ooo`040?l0003oool0oooo0?ooo`@0o`000`3oool00`3o0000oooo
0?ooo`060?ooo`80o`00103oool00`3o0000oooo0?ooo`1Z0?ooo`001@3o00030?ooo`D0o`000`3o
ool50?l000<0oooo1@3o00030?ooo`D0o`000`3oool50?l000<0oooo1@3o00030?ooo`D0o`000`3o
ool50?l000<0oooo1@3o00030?ooo`D0o`000`3oool50?l000<0oooo1@3o00030?ooo`D0o`000`3o
ool50?l000<0oooo1@3o00030?ooo`D0o`000`3oool50?l000<0oooo1@3o00030?ooo`D0o`000`3o
ool50?l000<0oooo1@3o00030?ooo`D0o`000P3oool50?l000<0oooo1@3o00030?ooo`80o`00@@3o
ool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00X0oooo00@0o`000?ooo`3oool0o`00
0`3oool00`3o0000oooo0?ooo`1Z0?ooo`00o`3oool:0?ooo`030?l0003oool0oooo00@0oooo00<0
o`000?ooo`3oool02P3oool0103o0000oooo0?ooo`3o00040?ooo`030?l0003oool0oooo06T0oooo
003o0?ooo`/0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0:0?ooo`040?l0003o
ool0oooo0?l000<0oooo00<0o`000?ooo`3oool0JP3oool00?l0oooo2`3oool00`3o0000oooo0?oo
o`030?ooo`030?l0003oool0oooo00X0oooo00@0o`000?ooo`3oool0o`000`3oool00`3o0000oooo
0?ooo`1Z0?ooo`00o`3oool<0?ooo`030?l0003oool0oooo00<0o`00303oool0103o0000oooo0?oo
o`3o00020?ooo`030?l0003oool0oooo06/0oooo003o0?oooa40oooo00<0o`000?ooo`3oool02`3o
ool20?l00740oooo003o0?oooi80oooo003o0?oooi80oooo003o0?oooi80oooo003o0?oooi80oooo
003o0?oooi80oooo003o0?oooi80oooo003o0?oooi80oooo003o0?oooi80oooo003o0?oooi80oooo
003o0?oooi80oooo003o0?oooi80oooo003o0?oooi80oooo003o0?oooi80oooo003o0?ooo``0oooo
00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0<0?ooo`030?l0003oool0oooo06/0oooo
003o0?ooo`/0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo06X0oooo00060?l000030?ooo`3o0000o`0000D0o`0000<0oooo0?l0003o00001@3o0000
0`3oool0o`000?l000050?l000030?ooo`3o0000o`0000D0o`0000<0oooo0?l0003o00001@3o0000
0`3oool0o`000?l000050?l000030?ooo`3o0000o`0000D0o`0000<0oooo0?l0003o00001@3o0000
0`3oool0o`000?l000050?l000030?ooo`3o0000o`0000D0o`0000<0oooo0?l0003o00001@3o0000
0`3oool0o`000?l000050?l000030?ooo`3o0000o`0000D0o`0000<0oooo0?l0003o00001@3o0000
0`3oool0o`000?l000050?l000030?ooo`3o0000o`0000D0o`0000<0oooo0?l0003o00001@3o0000
0`3oool0o`000?l000050?l000030?ooo`3o0000o`0000D0o`0000<0oooo0?l0003o00001@3o0000
0`3oool0o`000?l000050?l000030?ooo`3o0000o`0000`0o`0000<0oooo0?l0003o00001@3o0000
0`3oool0o`000?l000020?l00400oooo00@0o`000?ooo`3oool0oooo103o00030?ooo`030?l0003o
ool0oooo00D0oooo103o00030?ooo`030?l0003oool0oooo06X0oooo00060?l000030?ooo`3o0000
o`0000D0o`0000<0oooo0?l0003o00001@3o00000`3oool0o`000?l000050?l000030?ooo`3o0000
o`0000D0o`0000<0oooo0?l0003o00001@3o00000`3oool0o`000?l000050?l000030?ooo`3o0000
o`0000D0o`0000<0oooo0?l0003o00001@3o00000`3oool0o`000?l000050?l000030?ooo`3o0000
o`0000D0o`0000<0oooo0?l0003o00001@3o00000`3oool0o`000?l000050?l000030?ooo`3o0000
o`0000D0o`0000<0oooo0?l0003o00001@3o00000`3oool0o`000?l000050?l000030?ooo`3o0000
o`0000D0o`0000<0oooo0?l0003o00001@3o00000`3oool0o`000?l000050?l000030?ooo`3o0000
o`0000D0o`0000<0oooo0?l0003o00001@3o00000`3oool0o`000?l000050?l000030?ooo`3o0000
o`0000`0o`0000<0oooo0?l0003o00001@3o00000`3oool0o`000?l000020?l00400oooo00<0o`00
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`0<0?ooo`030?l0003oool0oooo0080oooo00<0o`00
0?ooo`3oool0JP3oool000H0o`0000<0oooo0?l0003o00001@3o00000`3oool0o`000?l000050?l0
00030?ooo`3o0000o`0000D0o`0000<0oooo0?l0003o00001@3o00000`3oool0o`000?l000050?l0
00030?ooo`3o0000o`0000D0o`0000<0oooo0?l0003o00001@3o00000`3oool0o`000?l000050?l0
00030?ooo`3o0000o`0000D0o`0000<0oooo0?l0003o00001@3o00000`3oool0o`000?l000050?l0
00030?ooo`3o0000o`0000D0o`0000<0oooo0?l0003o00001@3o00000`3oool0o`000?l000050?l0
00030?ooo`3o0000o`0000D0o`0000<0oooo0?l0003o00001@3o00000`3oool0o`000?l000050?l0
00030?ooo`3o0000o`0000D0o`0000<0oooo0?l0003o00001@3o00000`3oool0o`000?l000050?l0
00030?ooo`3o0000o`0000D0o`0000<0oooo0?l0003o0000303o00000`3oool0o`000?l000050?l0
00030?ooo`3o0000o`000080o`00?`3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo
00`0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`1Y0?ooo`00o`3oool;0?ooo`03
0?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0303oool00`3o0000oooo0?ooo`020?ooo`03
0?l0003oool0oooo06X0oooo003o0?ooo`/0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo
0?ooo`0<0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0JP3oool00?l0oooo303o
ool00`3o0000oooo0?ooo`030?l000`0oooo0`3o00030?ooo`030?l0003oool0oooo06/0oooo003o
0?oooa40oooo00<0o`000?ooo`3oool0303oool00`3o0000oooo0?ooo`1_0?ooo`00o`3ooonB0?oo
o`00o`3ooonB0?ooo`00o`3ooonB0?ooo`00o`3ooonB0?ooo`00o`3ooonB0?ooo`00o`3ooonB0?oo
o`00o`3ooonB0?ooo`00o`3ooonB0?ooo`00o`3ooonB0?ooo`00o`3ooolN0?ooo`@0003oL03oool0
0?l0oooo7P3oool00`000?l0oooo0?ooo`1a0?ooo`00o`3oool90?ooo`030000o`3oool0oooo01<0
oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`1X0?ooo`00o`3oool80?ooo`030000
o`3oool0oooo01D0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`1W0?ooo`00o`3o
ool80?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?oo
o`040?ooo`030000o`3oool0oooo06L0oooo003o0?ooo`P0oooo00<0003o0?ooo`3oool0203oool0
0`000?l0oooo0?ooo`080?ooo`040000o`3oool0oooo0000o`H0oooo00<0003o0?ooo`3oool0I`3o
ool00?l0oooo203oool010000?l0oooo0?ooo`3oool40000o`<0oooo00<0003o0?ooo`3oool02@3o
ool20000o`L0oooo00<0003o0?ooo`3oool0I`3oool00?l0oooo203oool01@000?l0oooo0?ooo`3o
ool0003o01/0oooo00<0003o0?ooo`3oool0I`3oool000D0003o0`3oool50000o`<0oooo1@000?l3
0?ooo`D0003o0`3oool50000o`<0oooo1@000?l30?ooo`D0003o0`3oool50000o`<0oooo1@000?l3
0?ooo`D0003o0`3oool50000o`<0oooo1@000?l30?ooo`D0003o0`3oool50000o`<0oooo1@000?l3
0?ooo`D0003o0`3oool50000o`<0oooo1@000?l30?ooo`D0003o0`3oool50000o`<0oooo1@000?l3
0?ooo`D0003o0`3oool50000o`80oooo1@000?l30?ooo`D0003o0`3oool20000ocd0oooo00<0003o
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0<0?ooo`T0003o103oool00`000?l0oooo0?ooo`1V
0?ooo`00o`3oool80?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool05`3oool00`00
0?l0oooo0?ooo`1W0?ooo`00o`3oool80?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3o
ool05P3oool00`000?l0oooo0?ooo`1W0?ooo`00o`3oool80?ooo`050000o`3oool0oooo0?ooo`00
0?l00P3oool00`000?l0oooo0?ooo`0F0?ooo`030000o`3oool0oooo06L0oooo003o0?ooo`P0oooo
00<0003o0?ooo`3oool00P3oool20000o`l0oooo10000?l60?ooo`030000o`3oool0oooo06L0oooo
003o0?ooo`P0oooo00<0003o0?ooo`3oool05@3oool00`000?l0oooo0?ooo`050?ooo`030000o`3o
ool0oooo06L0oooo003o0?ooo`T0oooo00<0003o0?ooo`3oool0503oool00`000?l0oooo0?ooo`04
0?ooo`030000o`3oool0oooo06P0oooo003o0?ooob00oooo00<0003o0?ooo`3oool0K`3oool00?l0
oooo803oool00`000?l0oooo0?ooo`1_0?ooo`00o`3ooolN0?ooo`<0003oL@3oool00?l0oooo803o
ool00`000?l0oooo0?ooo`1_0?ooo`00o`3ooonB0?ooo`00o`3ooonB0?ooo`00o`3ooonB0?ooo`00
o`3ooonB0?ooo`00o`3ooonB0?ooo`00o`3ooonB0?ooo`00o`3ooonB0?ooo`00o`3ooonB0?ooo`00
o`3oool<0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`1[0?ooo`00o`3oool;0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`1Z0?ooo`00o`3oool;0?ooo`030000003oool0oooo0080oooo0P000004
0?ooo`030000003oool0oooo00H0oooo0P0000040?ooo`030000003oool0oooo06X0oooo00050000
00<0oooo1@0000030?ooo`D000000`3oool5000000<0oooo1@0000030?ooo`D000000`3oool50000
00<0oooo1@0000030?ooo`D000000`3oool5000000<0oooo1@0000030?ooo`D000000`3oool50000
00<0oooo1@0000030?ooo`D000000`3oool5000000<0oooo1@0000030?ooo`D000000`3oool50000
00<0oooo1@0000030?ooo`D000000`3oool5000000<0oooo1@0000020?ooo`D000000`3oool50000
00<0oooo0P0000110?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`09
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0JP3oool00?l0oooo2P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`1Y0?ooo`00o`3oool;0?ooo`030000003oool0oooo0080oooo0P00000<
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0JP3oool00?l0oooo2`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool000000`3o
ool00`000000oooo0?ooo`1Z0?ooo`00o`3oool<0?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool02@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo06/0oooo
003o0?oooa00oooo0P00000=0?ooo`800000L@3oool00?l0ooooTP3oool00?l0ooooTP3oool00?l0
ooooTP3oool00?l0ooooTP3oool00?l0ooooTP3oool00?l0ooooTP3oool00001\
\>"],
  ImageRangeCache->{{{0, 400.062}, {246.875, 0}} -> {0.499234, -0.500056, \
0.00250344, 0.0445571}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(pic1 = 
      Show[Table[slika[i], {i, 10}], 
        PlotRange \[Rule] {{mindelta, maxdelta}, {\(-2.5\), 0.5}}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.333333 0.515028 0.206011 [
[0 .50253 -12 -9 ]
[0 .50253 12 0 ]
[.16667 .50253 -6 -9 ]
[.16667 .50253 6 0 ]
[.33333 .50253 -12 -9 ]
[.33333 .50253 12 0 ]
[.66667 .50253 -9 -9 ]
[.66667 .50253 9 0 ]
[.83333 .50253 -3 -9 ]
[.83333 .50253 3 0 ]
[1 .50253 -9 -9 ]
[1 .50253 9 0 ]
[.4875 0 -24 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -24 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -12 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -24 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .51503 m
0 .52128 L
s
[(-1.5)] 0 .50253 0 1 Mshowa
.16667 .51503 m
.16667 .52128 L
s
[(-1)] .16667 .50253 0 1 Mshowa
.33333 .51503 m
.33333 .52128 L
s
[(-0.5)] .33333 .50253 0 1 Mshowa
.66667 .51503 m
.66667 .52128 L
s
[(0.5)] .66667 .50253 0 1 Mshowa
.83333 .51503 m
.83333 .52128 L
s
[(1)] .83333 .50253 0 1 Mshowa
1 .51503 m
1 .52128 L
s
[(1.5)] 1 .50253 0 1 Mshowa
.125 Mabswid
.03333 .51503 m
.03333 .51878 L
s
.06667 .51503 m
.06667 .51878 L
s
.1 .51503 m
.1 .51878 L
s
.13333 .51503 m
.13333 .51878 L
s
.2 .51503 m
.2 .51878 L
s
.23333 .51503 m
.23333 .51878 L
s
.26667 .51503 m
.26667 .51878 L
s
.3 .51503 m
.3 .51878 L
s
.36667 .51503 m
.36667 .51878 L
s
.4 .51503 m
.4 .51878 L
s
.43333 .51503 m
.43333 .51878 L
s
.46667 .51503 m
.46667 .51878 L
s
.53333 .51503 m
.53333 .51878 L
s
.56667 .51503 m
.56667 .51878 L
s
.6 .51503 m
.6 .51878 L
s
.63333 .51503 m
.63333 .51878 L
s
.7 .51503 m
.7 .51878 L
s
.73333 .51503 m
.73333 .51878 L
s
.76667 .51503 m
.76667 .51878 L
s
.8 .51503 m
.8 .51878 L
s
.86667 .51503 m
.86667 .51878 L
s
.9 .51503 m
.9 .51878 L
s
.93333 .51503 m
.93333 .51878 L
s
.96667 .51503 m
.96667 .51878 L
s
.25 Mabswid
0 .51503 m
1 .51503 L
s
.5 0 m
.50625 0 L
s
[(-2.5)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1.5)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(-1)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(-0.5)] .4875 .41202 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(0.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.61111 .61803 m
.62583 .59075 L
.66752 .51344 L
.70762 .43909 L
.7503 .35996 L
.79139 .28378 L
.83505 .20283 L
.87712 .12483 L
.9176 .04978 L
s
.9176 .04978 m
.94444 0 L
s
0 0 1 r
.46548 .61803 m
.49953 .57595 L
.54183 .52366 L
.58254 .47334 L
.62583 .41984 L
.66752 .3683 L
.70762 .31873 L
.7503 .26598 L
.79139 .21519 L
.83505 .16122 L
.87712 .10922 L
.9176 .05919 L
.96065 .00597 L
s
.96065 .00597 m
.96548 0 L
s
.70118 .61803 m
.70762 .61007 L
.7503 .55732 L
.79139 .50654 L
.83505 .45257 L
.87712 .40057 L
.9176 .35053 L
.96065 .29732 L
1 .24868 L
s
.58333 .61803 m
.62583 .56551 L
.66752 .51397 L
.70762 .4644 L
.7503 .41165 L
.79139 .36086 L
.83505 .3069 L
.87712 .2549 L
.9176 .20486 L
.96065 .15164 L
1 .10301 L
s
1 0 0 r
.83333 .61803 m
.83505 .61697 L
.87712 .59097 L
.9176 .56596 L
.96065 .53935 L
1 .51503 L
s
.37799 .61803 m
.41848 .59301 L
.4598 .56747 L
.49953 .54292 L
.54183 .51678 L
.58254 .49162 L
.62583 .46486 L
.66752 .43909 L
.70762 .41431 L
.7503 .38793 L
.79139 .36254 L
.83505 .33556 L
.87712 .30956 L
.9176 .28454 L
.96065 .25793 L
1 .23361 L
s
.95534 .61803 m
.96065 .61475 L
1 .59043 L
s
.12009 .61803 m
.12636 .61416 L
.16632 .58946 L
.20885 .56318 L
.2498 .53787 L
.29331 .51098 L
.33524 .48507 L
.37557 .46014 L
.41848 .43362 L
.4598 .40808 L
.49953 .38353 L
.54183 .35738 L
.58254 .33222 L
.62583 .30547 L
.66752 .2797 L
.70762 .25492 L
.7503 .22854 L
.79139 .20315 L
.83505 .17617 L
.87712 .15017 L
.9176 .12515 L
.96065 .09854 L
1 .07422 L
s
.57656 .61803 m
.58254 .61434 L
.62583 .58759 L
.66752 .56182 L
.70762 .53703 L
.7503 .51066 L
.79139 .48526 L
.83505 .45828 L
.87712 .43228 L
.9176 .40726 L
.96065 .38065 L
1 .35633 L
s
.008 w
.5 .61803 m
.54183 .59218 L
.58254 .56702 L
.62583 .54027 L
.66752 .5145 L
.70762 .48972 L
.7503 .46334 L
.79139 .43795 L
.83505 .41096 L
.87712 .38496 L
.9176 .35994 L
.96065 .33334 L
1 .30902 L
s
.2643 .61803 m
.29331 .6001 L
.33524 .57419 L
.37557 .54926 L
.41848 .52274 L
.4598 .49721 L
.49953 .47265 L
.54183 .44651 L
.58254 .42135 L
.62583 .3946 L
.66752 .36883 L
.70762 .34404 L
.7503 .31767 L
.79139 .29227 L
.83505 .26529 L
.87712 .23929 L
.9176 .21427 L
.96065 .18766 L
1 .16335 L
s
.7357 .61803 m
.7503 .60901 L
.79139 .58362 L
.83505 .55663 L
.87712 .53063 L
.9176 .50562 L
.96065 .47901 L
1 .45469 L
s
0 .392 0 r
.5 Mabswid
0 .32755 m
.04057 .32755 L
.08481 .32755 L
.12636 .32755 L
.16632 .32755 L
.20885 .32755 L
.2498 .32755 L
.29331 .32755 L
.33524 .32755 L
.37557 .32755 L
.41848 .32755 L
.4598 .32755 L
.49953 .32755 L
.54183 .32755 L
.58254 .32755 L
.62583 .32755 L
.66752 .32755 L
.70762 .32755 L
.7503 .32755 L
.79139 .32755 L
.83505 .32755 L
.87712 .32755 L
.9176 .32755 L
.96065 .32755 L
1 .32755 L
s
0 .43962 m
.04057 .43962 L
.08481 .43962 L
.12636 .43962 L
.16632 .43962 L
.20885 .43962 L
.2498 .43962 L
.29331 .43962 L
.33524 .43962 L
.37557 .43962 L
.41848 .43962 L
.4598 .43962 L
.49953 .43962 L
.54183 .43962 L
.58254 .43962 L
.62583 .43962 L
.66752 .43962 L
.70762 .43962 L
.7503 .43962 L
.79139 .43962 L
.83505 .43962 L
.87712 .43962 L
.9176 .43962 L
.96065 .43962 L
1 .43962 L
s
0 .57537 m
.04057 .57537 L
.08481 .57537 L
.12636 .57537 L
.16632 .57537 L
.20885 .57537 L
.2498 .57537 L
.29331 .57537 L
.33524 .57537 L
.37557 .57537 L
.41848 .57537 L
.4598 .57537 L
.49953 .57537 L
.54183 .57537 L
.58254 .57537 L
.62583 .57537 L
.66752 .57537 L
.70762 .57537 L
.7503 .57537 L
.79139 .57537 L
.83505 .57537 L
.87712 .57537 L
.9176 .57537 L
.96065 .57537 L
1 .57537 L
s
.006 w
0 .51503 m
.00123 .51503 L
.00236 .51503 L
.00365 .51503 L
.00488 .51503 L
.00601 .51503 L
.00706 .51503 L
.00821 .51503 L
.00942 .51503 L
.01065 .51503 L
.01196 .51503 L
.0132 .51503 L
.01434 .51503 L
.01566 .51503 L
.01641 .51503 L
.01711 .51503 L
.01839 .51503 L
.01975 .51503 L
.02043 .51503 L
.02115 .51503 L
.02245 .51503 L
.02317 .51503 L
.02384 .51503 L
.02458 .51503 L
.02537 .51503 L
.02605 .51503 L
.02679 .51503 L
.02814 .51503 L
.02945 .51503 L
.03067 .51503 L
.03184 .51503 L
.03295 .51503 L
.03416 .51503 L
.03547 .51503 L
.03676 .51503 L
.03813 .51503 L
.03929 .51503 L
.04057 .51503 L
.04131 .51503 L
.042 .51503 L
.04275 .51503 L
.04355 .51503 L
.0449 .51503 L
.04566 .51503 L
.04637 .51503 L
.0477 .51503 L
.04892 .51503 L
.04959 .51503 L
.05032 .51503 L
.05165 .51503 L
Mistroke
.05245 .51503 L
.05321 .51503 L
.05389 .51503 L
.05462 .51503 L
.05543 .51503 L
.05627 .51503 L
.057 .51503 L
.05779 .51503 L
.05854 .51503 L
.05921 .51503 L
.06 .51503 L
.06074 .51503 L
.06205 .51503 L
.0628 .51503 L
.06349 .51503 L
.06471 .51503 L
.06603 .51503 L
.06727 .51503 L
.06841 .51503 L
.06967 .51503 L
.07105 .51503 L
.07175 .51503 L
.07249 .51503 L
.07383 .51503 L
.07457 .51503 L
.07525 .51503 L
.076 .51503 L
.07679 .51503 L
.07812 .51503 L
.07888 .51503 L
.07959 .51503 L
.0809 .51503 L
.08211 .51503 L
.08349 .51503 L
.08481 .51503 L
.086 .51503 L
.08729 .51503 L
.0885 .51503 L
.08962 .51503 L
.09085 .51503 L
.0922 .51503 L
.09289 .51503 L
.09361 .51503 L
.09493 .51503 L
.09565 .51503 L
.09632 .51503 L
.09705 .51503 L
.09783 .51503 L
.09913 .51503 L
.09987 .51503 L
Mistroke
.10056 .51503 L
.10185 .51503 L
.10303 .51503 L
.10439 .51503 L
.10569 .51503 L
.10691 .51503 L
.10801 .51503 L
.10928 .51503 L
.11048 .51503 L
.1116 .51503 L
.11262 .51503 L
.11375 .51503 L
.11493 .51503 L
.11613 .51503 L
.11742 .51503 L
.11864 .51503 L
.11974 .51503 L
.12104 .51503 L
.12178 .51503 L
.12245 .51503 L
.1237 .51503 L
.12502 .51503 L
.12622 .51503 L
.12753 .51503 L
.12889 .51503 L
.13016 .51503 L
.13135 .51503 L
.13244 .51503 L
.13369 .51503 L
.13487 .51503 L
.13616 .51503 L
.13752 .51503 L
.13868 .51503 L
.13996 .51503 L
.14134 .51503 L
.14211 .51503 L
.14281 .51503 L
.14418 .51503 L
.14548 .51503 L
.14669 .51503 L
.14779 .51503 L
.14906 .51503 L
.15025 .51503 L
.15136 .51503 L
.15237 .51503 L
.15349 .51503 L
.15467 .51503 L
.15586 .51503 L
.15714 .51503 L
.15835 .51503 L
Mistroke
.15945 .51503 L
.16074 .51503 L
.16146 .51503 L
.16214 .51503 L
.16337 .51503 L
.16468 .51503 L
.16594 .51503 L
.16732 .51503 L
.16863 .51503 L
.16984 .51503 L
.17103 .51503 L
.17212 .51503 L
.17337 .51503 L
.17456 .51503 L
.17585 .51503 L
.17721 .51503 L
.17838 .51503 L
.17966 .51503 L
.18104 .51503 L
.18181 .51503 L
.18251 .51503 L
.18388 .51503 L
.18518 .51503 L
.18628 .51503 L
.1875 .51503 L
.18877 .51503 L
.18996 .51503 L
.19107 .51503 L
.19209 .51503 L
.19321 .51503 L
.19438 .51503 L
.19558 .51503 L
.19686 .51503 L
.19807 .51503 L
.19916 .51503 L
.20045 .51503 L
.20118 .51503 L
.20185 .51503 L
.20309 .51503 L
.20439 .51503 L
.20566 .51503 L
.20705 .51503 L
.20835 .51503 L
.20957 .51503 L
.21077 .51503 L
.21186 .51503 L
.21311 .51503 L
.2143 .51503 L
.21559 .51503 L
.21696 .51503 L
Mistroke
.21813 .51503 L
.21941 .51503 L
.22079 .51503 L
.22157 .51503 L
.22227 .51503 L
.22364 .51503 L
.22494 .51503 L
.22604 .51503 L
.22726 .51503 L
.22853 .51503 L
.22973 .51503 L
.23084 .51503 L
.23186 .51503 L
.23297 .51503 L
.23415 .51503 L
.23535 .51503 L
.23663 .51503 L
.23784 .51503 L
.23893 .51503 L
.24023 .51503 L
.24095 .51503 L
.24163 .51503 L
.24286 .51503 L
.24416 .51503 L
.24544 .51503 L
.24683 .51503 L
.24814 .51503 L
.24935 .51503 L
.25044 .51503 L
.25165 .51503 L
.25291 .51503 L
.25409 .51503 L
.25539 .51503 L
.25676 .51503 L
.25793 .51503 L
.25922 .51503 L
.2606 .51503 L
.26137 .51503 L
.26208 .51503 L
.26345 .51503 L
.26475 .51503 L
.26586 .51503 L
.26708 .51503 L
.26835 .51503 L
.26954 .51503 L
.27066 .51503 L
.27168 .51503 L
.27286 .51503 L
.27397 .51503 L
.27518 .51503 L
Mistroke
.27646 .51503 L
.27767 .51503 L
.27876 .51503 L
.28005 .51503 L
.28078 .51503 L
.28145 .51503 L
.28268 .51503 L
.28399 .51503 L
.28527 .51503 L
.28599 .51503 L
.28666 .51503 L
.28789 .51503 L
.28919 .51503 L
.29036 .51503 L
.29145 .51503 L
.29265 .51503 L
.29394 .51503 L
.29524 .51503 L
.29597 .51503 L
.29665 .51503 L
.29803 .51503 L
.29881 .51503 L
.29951 .51503 L
.30077 .51503 L
.30213 .51503 L
.30342 .51503 L
.30461 .51503 L
.30572 .51503 L
.30691 .51503 L
.30804 .51503 L
.30907 .51503 L
.31027 .51503 L
.31158 .51503 L
.31282 .51503 L
.31396 .51503 L
.31526 .51503 L
.31648 .51503 L
.31758 .51503 L
.31876 .51503 L
.32005 .51503 L
.32142 .51503 L
.32259 .51503 L
.32386 .51503 L
.32524 .51503 L
.32651 .51503 L
.32718 .51503 L
.32791 .51503 L
.32867 .51503 L
.32939 .51503 L
.3307 .51503 L
Mistroke
.3319 .51503 L
.33329 .51503 L
.33461 .51503 L
.33578 .51503 L
.33704 .51503 L
.33822 .51503 L
.33929 .51503 L
.34055 .51503 L
.34192 .51503 L
.34321 .51503 L
.3444 .51503 L
.34567 .51503 L
.34703 .51503 L
.34831 .51503 L
.34949 .51503 L
.35086 .51503 L
.35164 .51503 L
.35236 .51503 L
.35368 .51503 L
.35434 .51503 L
.35508 .51503 L
.35579 .51503 L
.35654 .51503 L
.35788 .51503 L
.35863 .51503 L
.35932 .51503 L
.36009 .51503 L
.3609 .51503 L
.36161 .51503 L
.36238 .51503 L
.3631 .51503 L
.36377 .51503 L
.36503 .51503 L
.36637 .51503 L
.36764 .51503 L
.36902 .51503 L
.37033 .51503 L
.37154 .51503 L
.37274 .51503 L
.37383 .51503 L
.37509 .51503 L
.37627 .51503 L
.37756 .51503 L
.37893 .51503 L
.3801 .51503 L
.38138 .51503 L
.38276 .51503 L
.38353 .51503 L
.38424 .51503 L
.38561 .51503 L
Mistroke
.38691 .51503 L
.38801 .51503 L
.38923 .51503 L
.3905 .51503 L
.39169 .51503 L
.3928 .51503 L
.39382 .51503 L
.39494 .51503 L
.39612 .51503 L
.39732 .51503 L
.3986 .51503 L
.3998 .51503 L
.4009 .51503 L
.40219 .51503 L
.40292 .51503 L
.40359 .51503 L
.40482 .51503 L
.40613 .51503 L
.4074 .51503 L
.40879 .51503 L
.4101 .51503 L
.41132 .51503 L
.41252 .51503 L
.41361 .51503 L
.41487 .51503 L
.41605 .51503 L
.41735 .51503 L
.41872 .51503 L
.41989 .51503 L
.42117 .51503 L
.42256 .51503 L
.42333 .51503 L
.42404 .51503 L
.42541 .51503 L
.4267 .51503 L
.42781 .51503 L
.42903 .51503 L
.43031 .51503 L
.4315 .51503 L
.43261 .51503 L
.43363 .51503 L
.43481 .51503 L
.43593 .51503 L
.43713 .51503 L
.43841 .51503 L
.43962 .51503 L
.44071 .51503 L
.44201 .51503 L
.44273 .51503 L
.4434 .51503 L
Mistroke
.44464 .51503 L
.44594 .51503 L
.44722 .51503 L
.44794 .51503 L
.44861 .51503 L
.44984 .51503 L
.45114 .51503 L
.45231 .51503 L
.4534 .51503 L
.4546 .51503 L
.45589 .51503 L
.45718 .51503 L
.45792 .51503 L
.4586 .51503 L
.45998 .51503 L
.46075 .51503 L
.46145 .51503 L
.46271 .51503 L
.46408 .51503 L
.46537 .51503 L
.46656 .51503 L
.46766 .51503 L
.46886 .51503 L
.46998 .51503 L
.47101 .51503 L
.47221 .51503 L
.47352 .51503 L
.47476 .51503 L
.4759 .51503 L
.4772 .51503 L
.47842 .51503 L
.47952 .51503 L
.4807 .51503 L
.48199 .51503 L
.48336 .51503 L
.48453 .51503 L
.4858 .51503 L
.48718 .51503 L
.48845 .51503 L
.48911 .51503 L
.48984 .51503 L
.49061 .51503 L
.49132 .51503 L
.49264 .51503 L
.49384 .51503 L
.49516 .51503 L
.49655 .51503 L
.49772 .51503 L
.49897 .51503 L
.50015 .51503 L
Mistroke
.50122 .51503 L
.50248 .51503 L
.50385 .51503 L
.50514 .51503 L
.50633 .51503 L
.5076 .51503 L
.50896 .51503 L
.51024 .51503 L
.51142 .51503 L
.51279 .51503 L
.51357 .51503 L
.51429 .51503 L
.5156 .51503 L
.51627 .51503 L
.51701 .51503 L
.51772 .51503 L
.51847 .51503 L
.51981 .51503 L
.52055 .51503 L
.52125 .51503 L
.52201 .51503 L
.52283 .51503 L
.52354 .51503 L
.5243 .51503 L
.52503 .51503 L
.52569 .51503 L
.52696 .51503 L
.5283 .51503 L
.52957 .51503 L
.53095 .51503 L
.53225 .51503 L
.53347 .51503 L
.53467 .51503 L
.53575 .51503 L
.53701 .51503 L
.53819 .51503 L
.53948 .51503 L
.54085 .51503 L
.54202 .51503 L
.5433 .51503 L
.54468 .51503 L
.54545 .51503 L
.54616 .51503 L
.54753 .51503 L
.54882 .51503 L
.54993 .51503 L
.55114 .51503 L
.55241 .51503 L
.55361 .51503 L
.55472 .51503 L
Mistroke
.55574 .51503 L
.55685 .51503 L
.55803 .51503 L
.55923 .51503 L
.56051 .51503 L
.56172 .51503 L
.56281 .51503 L
.5641 .51503 L
.56483 .51503 L
.5655 .51503 L
.56674 .51503 L
.56804 .51503 L
.56932 .51503 L
.5707 .51503 L
.57201 .51503 L
.57323 .51503 L
.57443 .51503 L
.57552 .51503 L
.57678 .51503 L
.57796 .51503 L
.57926 .51503 L
.58063 .51503 L
.5818 .51503 L
.58308 .51503 L
.58446 .51503 L
.58524 .51503 L
.58594 .51503 L
.58731 .51503 L
.58861 .51503 L
.58971 .51503 L
.59093 .51503 L
.59221 .51503 L
.5934 .51503 L
.59451 .51503 L
.59553 .51503 L
.59671 .51503 L
.59783 .51503 L
.59903 .51503 L
.60031 .51503 L
.60152 .51503 L
.60261 .51503 L
.60391 .51503 L
.60463 .51503 L
.6053 .51503 L
.60654 .51503 L
.60784 .51503 L
.60912 .51503 L
.60984 .51503 L
.61051 .51503 L
.61174 .51503 L
Mistroke
.61304 .51503 L
.6142 .51503 L
.61529 .51503 L
.61649 .51503 L
.61778 .51503 L
.61908 .51503 L
.61981 .51503 L
.62049 .51503 L
.62187 .51503 L
.62264 .51503 L
.62335 .51503 L
.6246 .51503 L
.62597 .51503 L
.62726 .51503 L
.62845 .51503 L
.62955 .51503 L
.63075 .51503 L
.63187 .51503 L
.6329 .51503 L
.6341 .51503 L
.63541 .51503 L
.63665 .51503 L
.63779 .51503 L
.63909 .51503 L
.64031 .51503 L
.6414 .51503 L
.64259 .51503 L
.64388 .51503 L
.64525 .51503 L
.64641 .51503 L
.64769 .51503 L
.64907 .51503 L
.65034 .51503 L
.651 .51503 L
.65173 .51503 L
.65249 .51503 L
.65321 .51503 L
.65452 .51503 L
.65572 .51503 L
.65704 .51503 L
.65843 .51503 L
.6596 .51503 L
.66085 .51503 L
.66203 .51503 L
.6631 .51503 L
.66436 .51503 L
.66573 .51503 L
.66702 .51503 L
.66821 .51503 L
.66947 .51503 L
Mistroke
.67083 .51503 L
.67212 .51503 L
.67329 .51503 L
.67467 .51503 L
.67544 .51503 L
.67616 .51503 L
.67748 .51503 L
.67815 .51503 L
.67888 .51503 L
.67959 .51503 L
.68034 .51503 L
.68168 .51503 L
.68243 .51503 L
.68312 .51503 L
.68389 .51503 L
.6847 .51503 L
.68541 .51503 L
.68618 .51503 L
.6869 .51503 L
.68757 .51503 L
.68883 .51503 L
.69018 .51503 L
.69144 .51503 L
.69282 .51503 L
.69413 .51503 L
.69534 .51503 L
.69654 .51503 L
.69762 .51503 L
.69888 .51503 L
.70006 .51503 L
.70135 .51503 L
.70272 .51503 L
.70388 .51503 L
.70517 .51503 L
.70654 .51503 L
.70732 .51503 L
.70802 .51503 L
.70939 .51503 L
.71069 .51503 L
.71179 .51503 L
.71301 .51503 L
.71428 .51503 L
.71547 .51503 L
.71658 .51503 L
.7176 .51503 L
.71872 .51503 L
.71989 .51503 L
.72109 .51503 L
.72237 .51503 L
.72358 .51503 L
Mistroke
.72468 .51503 L
.72597 .51503 L
.72669 .51503 L
.72737 .51503 L
.7286 .51503 L
.72991 .51503 L
.73118 .51503 L
.73256 .51503 L
.73387 .51503 L
.73508 .51503 L
.73629 .51503 L
.73738 .51503 L
.73863 .51503 L
.73982 .51503 L
.74111 .51503 L
.74248 .51503 L
.74365 .51503 L
.74493 .51503 L
.74631 .51503 L
.74709 .51503 L
.74779 .51503 L
.74916 .51503 L
.75046 .51503 L
.75157 .51503 L
.75279 .51503 L
.75406 .51503 L
.75525 .51503 L
.75636 .51503 L
.75738 .51503 L
.7585 .51503 L
.75968 .51503 L
.76088 .51503 L
.76216 .51503 L
.76337 .51503 L
.76446 .51503 L
.76575 .51503 L
.76648 .51503 L
.76715 .51503 L
.76839 .51503 L
.76969 .51503 L
.77097 .51503 L
.77169 .51503 L
.77236 .51503 L
.77358 .51503 L
.77489 .51503 L
.77605 .51503 L
.77714 .51503 L
.77834 .51503 L
.77963 .51503 L
.78092 .51503 L
Mistroke
.78165 .51503 L
.78233 .51503 L
.78371 .51503 L
.78448 .51503 L
.78519 .51503 L
.78644 .51503 L
.78781 .51503 L
.7891 .51503 L
.79029 .51503 L
.79139 .51503 L
.79258 .51503 L
.79371 .51503 L
.79473 .51503 L
.79593 .51503 L
.79724 .51503 L
.79848 .51503 L
.79963 .51503 L
.80093 .51503 L
.80214 .51503 L
.80324 .51503 L
.80442 .51503 L
.80572 .51503 L
.80708 .51503 L
.80825 .51503 L
.80953 .51503 L
.8109 .51503 L
.81217 .51503 L
.81283 .51503 L
.81356 .51503 L
.81432 .51503 L
.81504 .51503 L
.81635 .51503 L
.81755 .51503 L
.81887 .51503 L
.82026 .51503 L
.82143 .51503 L
.82268 .51503 L
.82386 .51503 L
.82493 .51503 L
.82619 .51503 L
.82755 .51503 L
.82884 .51503 L
.83003 .51503 L
.8313 .51503 L
.83266 .51503 L
.83394 .51503 L
.83512 .51503 L
.83649 .51503 L
.83727 .51503 L
.83798 .51503 L
Mistroke
.8393 .51503 L
.84004 .51503 L
.84071 .51503 L
.84142 .51503 L
.84216 .51503 L
.8435 .51503 L
.84425 .51503 L
.84495 .51503 L
.84571 .51503 L
.84653 .51503 L
.84723 .51503 L
.848 .51503 L
.84872 .51503 L
.84939 .51503 L
.85066 .51503 L
.852 .51503 L
.85326 .51503 L
.85464 .51503 L
.85595 .51503 L
.85716 .51503 L
.85835 .51503 L
.85944 .51503 L
.86069 .51503 L
.86188 .51503 L
.86317 .51503 L
.86453 .51503 L
.8657 .51503 L
.86698 .51503 L
.86836 .51503 L
.86913 .51503 L
.86984 .51503 L
.87121 .51503 L
.8725 .51503 L
.8736 .51503 L
.87482 .51503 L
.87609 .51503 L
.87728 .51503 L
.87839 .51503 L
.87941 .51503 L
.88053 .51503 L
.8817 .51503 L
.8829 .51503 L
.88418 .51503 L
.88539 .51503 L
.88649 .51503 L
.88778 .51503 L
.8885 .51503 L
.88918 .51503 L
.89041 .51503 L
.89172 .51503 L
Mistroke
.89299 .51503 L
.89437 .51503 L
.89568 .51503 L
.89689 .51503 L
.89809 .51503 L
.89918 .51503 L
.90044 .51503 L
.90162 .51503 L
.90292 .51503 L
.90428 .51503 L
.90545 .51503 L
.90673 .51503 L
.90812 .51503 L
.90889 .51503 L
.90959 .51503 L
.91096 .51503 L
.91226 .51503 L
.91337 .51503 L
.91458 .51503 L
.91586 .51503 L
.91705 .51503 L
.91816 .51503 L
.91918 .51503 L
.9203 .51503 L
.92148 .51503 L
.92268 .51503 L
.92396 .51503 L
.92516 .51503 L
.92626 .51503 L
.92755 .51503 L
.92828 .51503 L
.92895 .51503 L
.93018 .51503 L
.93149 .51503 L
.93276 .51503 L
.93348 .51503 L
.93415 .51503 L
.93538 .51503 L
.93668 .51503 L
.93784 .51503 L
.93893 .51503 L
.94013 .51503 L
.94142 .51503 L
.94271 .51503 L
.94344 .51503 L
.94412 .51503 L
.9455 .51503 L
.94627 .51503 L
.94697 .51503 L
.94823 .51503 L
Mistroke
.9496 .51503 L
.95089 .51503 L
.95207 .51503 L
.95318 .51503 L
.95437 .51503 L
.95549 .51503 L
.95652 .51503 L
.95772 .51503 L
.95903 .51503 L
.96027 .51503 L
.96141 .51503 L
.96271 .51503 L
.96393 .51503 L
.96502 .51503 L
.96621 .51503 L
.9675 .51503 L
.96887 .51503 L
.97003 .51503 L
.97131 .51503 L
.97224 .51503 L
.9731 .51503 L
.97404 .51503 L
.97503 .51503 L
.9759 .51503 L
.97671 .51503 L
.9776 .51503 L
.97856 .51503 L
.97936 .51503 L
.98024 .51503 L
.98115 .51503 L
.982 .51503 L
.9828 .51503 L
.98353 .51503 L
.98437 .51503 L
.98516 .51503 L
.98602 .51503 L
.98696 .51503 L
.98795 .51503 L
.98887 .51503 L
.98973 .51503 L
.99051 .51503 L
.99142 .51503 L
.99228 .51503 L
.99321 .51503 L
.9942 .51503 L
.99513 .51503 L
.99598 .51503 L
.99697 .51503 L
.99805 .51503 L
.99907 .51503 L
Mistroke
1 .51503 L
Mfstroke
1 0 0 r
.5 Mabswid
[ .01 .01 ] 0 setdash
0 .51503 m
.04057 .5401 L
.08481 .56744 L
.12636 .59312 L
.16632 .61782 L
s
.16632 .61782 m
.16667 .61803 L
s
0 .23361 m
.04057 .25868 L
.08481 .28603 L
.12636 .31171 L
.16632 .3364 L
.20885 .36269 L
.2498 .38799 L
.29331 .41489 L
.33524 .4408 L
.37557 .46573 L
.41848 .49225 L
.4598 .51779 L
.49953 .54234 L
.54183 .56848 L
.58254 .59364 L
s
.58254 .59364 m
.62201 .61803 L
s
0 .59043 m
.04057 .61551 L
s
.04057 .61551 m
.04466 .61803 L
s
0 .07422 m
.04057 .09929 L
.08481 .12664 L
.12636 .15231 L
.16632 .17701 L
.20885 .2033 L
.2498 .2286 L
.29331 .2555 L
.33524 .28141 L
.37557 .30634 L
.41848 .33286 L
.4598 .35839 L
.49953 .38295 L
.54183 .40909 L
.58254 .43425 L
.62583 .461 L
.66752 .48677 L
.70762 .51156 L
.7503 .53793 L
.79139 .56332 L
.83505 .59031 L
.87712 .61631 L
s
.87712 .61631 m
.87991 .61803 L
s
0 .35633 m
.04057 .38141 L
.08481 .40875 L
.12636 .43443 L
.16632 .45912 L
.20885 .48541 L
.2498 .51072 L
.29331 .53761 L
.33524 .56352 L
.37557 .58845 L
.41848 .61497 L
s
.41848 .61497 m
.42344 .61803 L
s
.008 w
0 .30902 m
.04057 .33409 L
.08481 .36143 L
.12636 .38711 L
.16632 .41181 L
.20885 .43809 L
.2498 .4634 L
.29331 .49029 L
.33524 .51621 L
.37557 .54113 L
.41848 .56765 L
.4598 .59319 L
.49953 .61774 L
s
.49953 .61774 m
.5 .61803 L
s
0 .16335 m
.04057 .18842 L
.08481 .21576 L
.12636 .24144 L
.16632 .26614 L
.20885 .29242 L
.2498 .31773 L
.29331 .34462 L
.33524 .37053 L
.37557 .39546 L
.41848 .42198 L
.4598 .44752 L
.49953 .47207 L
.54183 .49822 L
.58254 .52338 L
.62583 .55013 L
.66752 .5759 L
.70762 .60068 L
s
.70762 .60068 m
.7357 .61803 L
s
0 .45469 m
.04057 .47976 L
.08481 .5071 L
.12636 .53278 L
.16632 .55748 L
.20885 .58377 L
.2498 .60907 L
s
.2498 .60907 m
.2643 .61803 L
s
0 0 1 r
.5 Mabswid
0 .10301 m
.04057 .15315 L
.08481 .20784 L
.12636 .25919 L
.16632 .30859 L
.20885 .36116 L
.2498 .41177 L
.29331 .46556 L
.33524 .51738 L
.37557 .56724 L
s
.37557 .56724 m
.41667 .61803 L
s
.03452 0 m
.04057 .00748 L
.08481 .06216 L
.12636 .11352 L
.16632 .16291 L
.20885 .21549 L
.2498 .2661 L
.29331 .31989 L
.33524 .37171 L
.37557 .42157 L
.41848 .47461 L
.4598 .52568 L
.49953 .57479 L
s
.49953 .57479 m
.53452 .61803 L
s
0 .24868 m
.04057 .29882 L
.08481 .35351 L
.12636 .40487 L
.16632 .45426 L
.20885 .50683 L
.2498 .55744 L
.29331 .61123 L
s
.29331 .61123 m
.29882 .61803 L
s
0 g
.05556 0 m
.08481 .05424 L
.12636 .13128 L
.16632 .20537 L
.20885 .28423 L
.2498 .36014 L
.29331 .44083 L
.33524 .51856 L
.37557 .59335 L
s
.37557 .59335 m
.38889 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00O03oool4000000<0oooo00<0
00000?ooo`3oool00P3oool3000009D0oooo001l0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0TP3oool001D0oooo00<0003o0?ooo`3oool00P3oool00`000000oooo0?ooo`1P0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool2000007@0oooo00<000000?oo
o`3oool00P3oool00`000?l0oooo0?ooo`0A0?ooo`005@3oool00`000?l0oooo0?ooo`030?ooo`03
0000003oool0oooo05P0oooo100000040?ooo`030000003oool0oooo00L0oooo0`0000060?ooo`03
0000003oool0oooo0780oooo00<000000?ooo`3oool00P3oool00`000?l0oooo0?ooo`0B0?ooo`00
5P3oool00`000?l0oooo0?ooo`030?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0780oooo00D000000?ooo`3oool0
oooo0000o`0E0?ooo`00O03oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`020?ooo`030000o`3oool0oooo01<0
oooo000H0?ooo`030000o`3oool0oooo0680oooo0P0000090?ooo`@000001@3oool00`000000oooo
0?ooo`1a0?ooo`050000003oool0oooo0?ooo`000?l05P3oool001T0oooo00D0003o0?ooo`3oool0
oooo0000001c0?ooo`030000003oool0oooo0700oooo00D000000?ooo`3oool0oooo0000o`0G0?oo
o`006P3oool010000?l0oooo0?ooo`00001c0?ooo`030000003oool0oooo0700oooo00@000000?oo
o`3oool0003o603oool001h0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`1_0?oo
o`050000003oool0oooo0?ooo`000?l0603oool001/0oooo00<0003o0?ooo`3oool0L`3oool00`00
0000oooo0?ooo`1_0?ooo`040000003oool0oooo0000oaT0oooo000L0?ooo`040000o`3oool0oooo
00000740oooo00<000000?ooo`3oool0KP3oool010000000oooo0?ooo`000?lJ0?ooo`007@3oool0
10000?l0oooo0?ooo`00001`0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`000?l06`3o
ool00200oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1]0?ooo`040000003oool0
oooo0000oa/0oooo000O0?ooo`030000o`3oool0000006l0oooo00<000000?ooo`3oool0K@3oool0
0`000000oooo0000o`0L0?ooo`007`3oool00`000?l0oooo0?ooo`1_0?ooo`030000003oool0oooo
06`0oooo00<000000?ooo`000?l07@3oool00200oooo00<0003o0?ooo`000000KP3oool00`000000
oooo0?ooo`1[0?ooo`030000003oool0003o01h0oooo000R0?ooo`030000003oool0oooo06`0oooo
00<000000?ooo`3oool0J`3oool00`000000oooo0000o`0N0?ooo`008P3oool00`000?l000000?oo
o`1/0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`000?l07`3oool002<0oooo00<0003o
0?ooo`3oool0J`3oool00`000000oooo0?ooo`1Z0?ooo`03000000000?l0oooo01l0oooo000T0?oo
o`030000o`3oool0oooo06X0oooo00<000000?ooo`3oool0J@3oool00`000000003o0?ooo`0P0?oo
o`00903oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo06T0oooo00<0003o0?ooo`3o
ool0803oool000`0oooo0P3o000G0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0
J03oool00`000000003o0?ooo`0G0?ooo`030?l0003oool0oooo00L0oooo000>0?ooo`030?l0003o
ool0oooo01@0oooo00<0003o0000003oool0J@3oool00`000000oooo0?ooo`1X0?ooo`030000o`3o
ool0oooo01D0oooo0P3o000:0?ooo`00403oool00`3o0000oooo0?ooo`0C0?ooo`030000o`3oool0
oooo06P0oooo00<000000?ooo`3oool0I`3oool00`000?l0oooo0?ooo`0D0?ooo`80o`00303oool0
0140oooo00<0o`000?ooo`3oool04`3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo
06H0oooo00<0003o0?ooo`3oool04`3oool20?l000h0oooo000B0?ooo`030?l0003oool0oooo0180
oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`1U0?ooo`030000o`000000oooo0180
oooo0P3o000@0?ooo`005@3oool00`3o0000oooo0?ooo`0@0?ooo`03000000000?l0oooo05d0oooo
100000050?ooo`030000003oool0oooo06@0oooo00<0003o0000003oool04@3oool20?l00180oooo
000F0?ooo`030?l0003oool0oooo00l0oooo00<000000000o`3oool0G@3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo06@0oooo00<0003o0000003oool0403oool00`3o0000oooo0?oo
o`0B0?ooo`00303oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo0100oooo00<0003o
0?ooo`3oool0G03oool00`000000oooo0?ooo`050?ooo`800000I03oool00`000?l000000?ooo`0?
0?ooo`80o`002`3oool00`000?l0oooo0?ooo`070?ooo`00303oool00`000?l0oooo0?ooo`0:0?oo
o`80o`003P3oool00`000000oooo0?ooo`1F0?ooo`@00000103oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0680oooo00<0003o0?ooo`0000003`3oool00`3o0000oooo0?ooo`0:0?oo
o`030000o`3oool0oooo00P0oooo000=0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3o
ool0303oool00`000000oooo0000o`1N0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0H@3oool00`000?l0oooo0000000>0?ooo`80o`00303oool00`000?l0oooo0?ooo`090?ooo`00
:`3oool00`000000oooo0000o`1J0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3o
ool0H03oool010000?l0oooo0?ooo`00000<0?ooo`80o`003@3oool00`000?l0oooo0?ooo`0:0?oo
o`003`3oool00`000?l0oooo0?ooo`0<0?ooo`80o`003P3oool00`000?l0oooo0?ooo`1H0?ooo`80
00001P3oool00`000000oooo0?ooo`1O0?ooo`040000o`3oool0oooo000000`0oooo00<0o`000?oo
o`3oool03@3oool00`000?l0oooo0?ooo`0:0?ooo`00403oool00`000?l0oooo0?ooo`0=0?ooo`03
0?l0003oool0oooo06h0oooo00<000000?ooo`3oool0G`3oool010000?l0oooo0?ooo`00000:0?oo
o`80o`003`3oool00`000?l0oooo0?ooo`0;0?ooo`004@3oool00`000?l0oooo0?ooo`0H0?ooo`04
0000003oool0oooo0000of40oooo00<000000?ooo`3oool0GP3oool010000?l0oooo0?ooo`00000:
0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool0303oool00280oooo0P3o00080?oo
o`050000003oool0oooo0?ooo`000?l0H03oool00`000000oooo0?ooo`1M0?ooo`040000o`3oool0
oooo000000T0oooo0P3o000@0?ooo`030000o`3oool0oooo00d0oooo000T0?ooo`030?l0003oool0
oooo00H0oooo00D000000?ooo`3oool0oooo0000o`1O0?ooo`030000003oool0oooo05`0oooo00D0
003o0?ooo`3oool0oooo000000080?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool0
3P3oool00180oooo00<0003o0?ooo`3oool04P3oool00`3o0000oooo0?ooo`1W0?ooo`030000003o
ool0oooo05/0oooo00D0003o0?ooo`3oool0oooo000000070?ooo`80o`004@3oool00`000?l0oooo
0?ooo`0?0?ooo`004`3oool00`000?l0oooo0?ooo`0B0?ooo`030?l0003oool0oooo00<0oooo00<0
00000?ooo`3oool00P3oool00`000?l0oooo0?ooo`1K0?ooo`030000003oool0oooo05/0oooo00D0
003o0?ooo`3oool0oooo000000050?ooo`80o`004`3oool00`000?l0oooo0?ooo`0?0?ooo`00503o
ool00`000?l0oooo0?ooo`0B0?ooo`030?l0003oool0oooo00<0oooo00D000000?ooo`3oool0oooo
0000o`1M0?ooo`030000003oool0oooo05X0oooo00D0003o0?ooo`3oool0oooo000000050?ooo`03
0?l0003oool0oooo0180oooo00<0003o0?ooo`3oool0403oool002/0oooo0P3o00020?ooo`030000
003oool0oooo0080oooo00<0003o0?ooo`3oool0FP3oool00`000000oooo0?ooo`1I0?ooo`030000
o`3oool0oooo0080oooo00@000000?ooo`3oool0oooo0P3o000D0?ooo`030000o`3oool0oooo0140
oooo000F0?ooo`030000o`3oool0oooo01@0oooo00@0o`000?ooo`3oool00000H03oool00`000000
oooo0?ooo`1H0?ooo`030000o`3oool0oooo0080oooo00D000000?ooo`3oool0oooo0?l0000E0?oo
o`030000o`3oool0oooo0180oooo000F0?ooo`030000o`3oool0oooo01@0oooo00<0o`000?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`1H0?ooo`030000003oool0oooo05P0oooo00<0003o0?ooo`3o
ool00P3oool010000000oooo0?l0003o000E0?ooo`030000o`3oool0oooo01<0oooo000<0?ooo`03
0?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool05P3oool00`3o000000000?ooo`040?ooo`03
0000o`3oool0oooo05L0oooo00<000000?ooo`3oool0E`3oool00`000?l0oooo0?ooo`020?ooo`03
0000003oool0o`0001H0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`070?ooo`00
303oool20?l002<0oooo00<000000?l0003oool0103oool00`000?l0oooo0?ooo`1F0?ooo`030000
003oool0oooo05H0oooo00<0003o0?ooo`3oool00`3oool20?l001L0oooo00<0003o0?ooo`3oool0
2@3oool20?l000T0oooo000<0?ooo`<0o`002P3oool00`000?l0oooo0?ooo`0F0?ooo`030000003o
ool0oooo05`0oooo00<000000?ooo`3oool0E@3oool00`000?l0oooo0?ooo`020?ooo`80o`00603o
ool00`000?l0oooo0?ooo`080?ooo`@0o`002@3oool000d0oooo103o00090?ooo`030000o`3oool0
oooo01L0oooo0P3o00030?ooo`030000o`3oool0oooo05D0oooo00<000000?ooo`3oool0E03oool0
0`000?l0oooo0?ooo`020?ooo`030?l0003oool0000001L0oooo00<0003o0?ooo`3oool01`3oool4
0?l000/0oooo000>0?ooo`@0o`002@3oool00`000?l0oooo0?ooo`0H0?ooo`050?l0003oool0oooo
0?ooo`000?l0EP3oool00`000000oooo0?ooo`1C0?ooo`040000o`3oool0oooo0?ooo`80o`0000<0
oooo0000003oool05P3oool00`000?l0oooo0?ooo`070?ooo`@0o`00303oool00100oooo0`3o000P
0?ooo`030000003oool0oooo00D0oooo00<0003o0?ooo`3oool0D`3oool00`000000oooo0?ooo`1C
0?ooo`040000o`3oool0oooo0?l000<0oooo00<000000?ooo`3oool0503oool00`000?l0oooo0?oo
o`060?ooo`@0o`003P3oool00140oooo0`3o00000`3oool0o`000?ooo`050?ooo`030000o`3oool0
oooo01D0oooo00<000000?ooo`3oool00P3oool20?l005H0oooo00<000000?ooo`3oool0DP3oool0
10000?l0oooo0?l0003o00030?ooo`030000003oool0oooo01D0oooo00<0003o0?ooo`3oool01@3o
ool40?l000l0oooo000B0?ooo`030?l0003oool0o`000080o`001P3oool00`000?l0oooo0?ooo`0E
0?ooo`030000003oool0oooo00<0oooo00<0o`000?ooo`000?l0D`3oool00`000000oooo0?ooo`1A
0?ooo`030000o`3o0000o`0000D0oooo00<000000?ooo`3oool0503oool00`000?l0oooo0?ooo`04
0?ooo`@0o`004@3oool001D0oooo0`3o00060?ooo`030000o`3oool0oooo01`0oooo00<0003o0?oo
o`3oool0D@3oool00`000000oooo0?ooo`1@0?ooo`030000o`3o0000oooo00D0oooo00<000000?oo
o`3oool0503oool00`000?l0oooo0?ooo`040?ooo`<0o`004`3oool001D0oooo0`3o00000`3oool0
o`000?ooo`0K0?ooo`030000003oool0oooo00D0oooo00<0003o0?l0003oool0D03oool00`000000
oooo0?ooo`1?0?ooo`80o`001`3oool00`000000oooo0?ooo`0C0?ooo`030000o`3oool0oooo00<0
oooo103o000D0?ooo`00603oool40?l000@0oooo00<0003o0?ooo`3oool04`3oool00`000000oooo
0?ooo`050?ooo`030000o`3oool0o`000500oooo00<000000?ooo`3oool0C@3oool20?l000P0oooo
00<000000?ooo`3oool0503oool010000?l0oooo0?ooo`3oool40?l001H0oooo000I0?ooo`@0o`00
0`3oool00`000?l0oooo0?ooo`0D0?ooo`030000003oool0oooo00P0oooo00<0o`000?ooo`3oool0
=`3oool4000000<0oooo00<000000?ooo`3oool00P3oool3000000H0oooo00<000000?ooo`3oool0
B`3oool20?l000030000o`3oool0oooo00L0oooo00<000000?ooo`3oool04`3oool010000?l0oooo
0?ooo`3oool40?l001L0oooo000K0?ooo`040?l0003oool0oooo0?l00080oooo00<0003o0?ooo`3o
ool04`3oool00`000000oooo0?ooo`060?ooo`040000o`3oool0oooo0?l003X0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo04X0oooo00@0o`000?oo
o`3oool0003o203oool00`000000oooo0?ooo`0C0?ooo`030000o`3oool0oooo00@0o`006@3oool0
01d0oooo103o000P0?ooo`040000o`3oool0oooo0?l003T0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`030?ooo`800000B@3oool20?l00080oooo00<0003o0?ooo`3oool01P3oool0
0`000000oooo0?ooo`0C0?ooo`030000o`3oool0oooo00@0o`006P3oool001h0oooo1@3o00000`00
0?l0oooo0?ooo`0C0?ooo`030000003oool0oooo00H0oooo00@0003o0?ooo`3oool0oooo0P3o000^
0?ooo`@00000103oool00`000000oooo0?ooo`070?ooo`<000001P3oool00`000000oooo0?ooo`17
0?ooo`050?l0003oool0oooo0?ooo`000?l02@3oool00`000000oooo0?ooo`0B0?ooo`030000o`3o
ool0o`0000<0o`00703oool00200oooo103o00000`000?l0oooo0?ooo`0B0?ooo`030000003oool0
oooo00`0oooo0P3o000d0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`150?ooo`80o`000`3oool00`000?l0oooo0?ooo`070?ooo`030000003oool0
oooo01<0oooo103o000N0?ooo`008P3oool30?l000030000o`3oool0oooo0180oooo00<000000?oo
o`3oool01P3oool00`000?l0oooo0?ooo`0f0?ooo`<000002@3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo04<0oooo0P3o00040?ooo`030000o`3oool0oooo00P0oooo00<000000?oo
o`3oool04P3oool40?l001l0oooo000S0?ooo`<0o`0000<0oooo0?l0003oool06`3oool00`000?l0
oooo0?ooo`040?ooo`80o`00<@3oool00`000000oooo0?ooo`070?ooo`@000001@3oool00`000000
oooo0?ooo`120?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0203oool00`000000
oooo0?ooo`0A0?ooo`@0o`008@3oool002@0oooo00<0o`000?ooo`000?l00`3o000K0?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0@@3oool00`000000oooo0?ooo`100?ooo`80o`00
1P3oool00`000?l0oooo0?ooo`080?ooo`030000003oool0oooo00l0oooo103o000S0?ooo`009`3o
ool010000?l0o`000?l0003o000@0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0
?`3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00P0oooo00<000000?ooo`3oool0
3P3oool40?l002D0oooo000<0?ooo`80o`006P3oool010000?l0o`000?ooo`3o000?0?ooo`030000
003oool0oooo00T0oooo00<0003o0?ooo`3oool01@3oool20?l00400oooo00<000000?ooo`3oool0
?@3oool20?l000L0oooo00<0003o0?ooo`3oool0203oool00`000000oooo0?ooo`0=0?ooo`@0o`00
00<0oooo0000o`3oool06P3oool00`3o0000oooo0?ooo`070?ooo`003P3oool00`3o0000oooo0?oo
o`0I0?ooo`@0o`003P3oool00`000000oooo0?ooo`090?ooo`030000o`3oool0oooo00H0oooo0P3o
000n0?ooo`030000003oool0oooo03`0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`090?ooo`030000003oool0oooo00`0oooo103o00000`3oool0003o0?ooo`0I0?ooo`80o`002P3o
ool002X0oooo00<0003o0?l0003o00000P3o000J0?ooo`030000o`3oool0oooo00P0oooo00<0o`00
0?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`80o`00203oool00`000?l0oooo0?ooo`09
0?ooo`030000003oool0oooo00/0oooo103o00020?ooo`030000o`3oool0oooo01L0oooo0P3o000<
0?ooo`00403oool20?l001P0oooo00@0003o0?ooo`3o0000o`000P3oool00`3o0000oooo0?ooo`0;
0?ooo`030000003oool0oooo01@0oooo00<0o`000?ooo`3oool0>@3oool00`000000oooo0?ooo`0h
0?ooo`80o`002P3oool00`000?l0oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo103o0003
0?ooo`030000o`3oool0oooo01H0oooo0P3o000>0?ooo`00303oool00`000?l0oooo0?ooo`030?oo
o`030?l0003oool0oooo01H0oooo00@0003o0?ooo`3oool0oooo103o000;0?ooo`030000003oool0
oooo00T0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0h0?ooo`030000003oool0
oooo03L0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`090?ooo`030000003oool0
oooo00T0oooo103o00040?ooo`030000o`3oool0oooo01@0oooo0P3o00060?ooo`030000o`3oool0
oooo00L0oooo000<0?ooo`030000o`3oool0oooo01`0oooo00<0003o0?ooo`3oool00P3oool50?l0
00X0oooo00<000000?ooo`3oool02@3oool00`000?l0oooo0?ooo`0:0?ooo`80o`00=`3oool00`00
0000oooo0?ooo`0e0?ooo`80o`002`3oool00`000?l0oooo0?ooo`0:0?ooo`030000003oool0oooo
00L0oooo103o00050?ooo`030000o`3oool0oooo01<0oooo0P3o00070?ooo`030000o`3oool0oooo
00P0oooo000=0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool06P3oool40?l000T0
oooo00<000000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo03@0
oooo00<000000?ooo`3oool0=03oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00X0
oooo00<000000?ooo`3oool01`3oool40?l000D0oooo00<0003o0?ooo`3oool04`3oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo00T0oooo000F0?ooo`80o`005@3oool00`000?l0oooo
0?ooo`040?ooo`<0o`00903oool00`3o0000oooo0?ooo`0c0?ooo`030000003oool0oooo0380oooo
0P3o000=0?ooo`030000o`3oool0oooo00T0oooo00<000000?ooo`3oool01P3oool40?l000H0oooo
00<0003o0?ooo`3oool04P3oool20?l000P0oooo00<0003o0?ooo`3oool02P3oool000l0oooo00<0
003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`0B0?ooo`030000o`3oool0oooo00@0oooo0`3o
00000`3oool0o`000?ooo`050?ooo`030000003oool0oooo00/0oooo00<0003o0?ooo`3oool0303o
ool20?l00380oooo00<000000?ooo`3oool0<03oool20?l000h0oooo00<0003o0?ooo`3oool02P3o
ool00`000000oooo0?ooo`050?ooo`<0o`001`3oool00`000?l0oooo0?ooo`0B0?ooo`030?l0003o
ool0oooo00P0oooo00<0003o0?ooo`3oool02P3oool00100oooo00<0003o0?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`0B0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o00000P3o0005
0?ooo`030000003oool0oooo00/0oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0_
0?ooo`030000003oool0oooo02h0oooo0P3o000?0?ooo`030000o`3oool0oooo00X0oooo00<00000
0?ooo`3oool0103oool40?l000L0oooo00<0003o0?ooo`3oool04P3oool00`3o0000oooo0?ooo`08
0?ooo`030000o`3oool0oooo00/0oooo000A0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?oo
o`3oool06`3oool30?l000D0oooo00<000000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0o0?oo
o`030000003oool0oooo02`0oooo0P3o000@0?ooo`030000o`3oool0oooo00/0oooo00<000000?oo
o`3oool00`3oool30?l000T0oooo00<0003o0?ooo`3oool0403oool20?l000X0oooo00<0003o0?oo
o`3oool0303oool001h0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`070?ooo`@0
o`008`3oool20?l002h0oooo00<000000?ooo`3oool0:P3oool20?l00140oooo00<0003o0?ooo`3o
ool02`3oool00`000000oooo0?ooo`020?ooo`@0o`002@3oool00`000?l0oooo0?ooo`0@0?ooo`03
0?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool03@3oool00180oooo00<0003o0?ooo`3oool0
2P3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo00L0oooo1P3o000@0?ooo`030000
o`3oool0oooo00l0oooo0P3o000/0?ooo`030000003oool0oooo02T0oooo00<0o`000?ooo`3oool0
4@3oool00`000?l0oooo0?ooo`0;0?ooo`040000003oool0oooo0?ooo`<0o`002P3oool00`000?l0
oooo0?ooo`0@0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool03P3oool001<0oooo
00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo00P0oooo
1@3o00000`3oool000000?ooo`0=0?ooo`030000o`3oool0oooo03`0oooo00<000000?ooo`3oool0
9`3oool20?l001<0oooo00<0003o0?ooo`3oool02`3oool00`000000oooo0?ooo`040?l000X0oooo
00<0003o0?ooo`3oool03`3oool20?l000/0oooo00<0003o0?ooo`3oool03`3oool001@0oooo00<0
003o0?ooo`3oool02`3oool20?l001`0oooo00@0o`000?ooo`3o000000003`3oool00`000?l0oooo
0?ooo`0@0?ooo`80o`00:@3oool00`000000oooo0?ooo`0V0?ooo`030?l0003oool0oooo0180oooo
00<0003o0?ooo`3oool02`3oool00`000000oooo0?ooo`030?l000/0oooo00<0003o0?ooo`3oool0
3`3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00l0oooo000T0?ooo`030?l0003o
ool0oooo00d0oooo00<0003o0?ooo`3oool02P3oool30?l000030000003oool0oooo0240oooo00<0
o`000?ooo`3oool09P3oool00`000000oooo0?ooo`0T0?ooo`80o`00503oool00`000?l0oooo0?oo
o`0<0?ooo`030000003o0000o`000080o`002`3oool00`000?l0oooo0?ooo`0>0?ooo`80o`003@3o
ool00`000?l0oooo0?ooo`0@0?ooo`005P3oool00`000?l0oooo0?ooo`0K0?ooo`030000o`3oool0
oooo00/0oooo0`3o000?0?ooo`030000o`3oool0oooo01@0oooo00<0o`000?ooo`3oool08`3oool0
0`000000oooo0?ooo`0R0?ooo`80o`005@3oool00`000?l0oooo0?ooo`0<0?ooo`@0o`003@3oool0
0`000?l0oooo0?ooo`0<0?ooo`80o`003P3oool00`000?l0oooo0?ooo`0A0?ooo`005P3oool00`00
0?l0oooo0?ooo`0>0?ooo`80o`00303oool00`000?l0oooo0?ooo`0:0?ooo`<0o`0000<000000?l0
003oool03@3oool00`000?l0oooo0?ooo`0D0?ooo`030?l0003oool0oooo0280oooo00<000000?oo
o`3oool08@3oool00`3o0000oooo0?ooo`0E0?ooo`030000o`3oool0oooo00/0oooo103o000=0?oo
o`030000o`3oool0oooo00/0oooo0P3o000?0?ooo`030000o`3oool0oooo0180oooo000F0?ooo`03
0000o`3oool0oooo0100oooo00<0o`000?ooo`3oool06@3oool00`000000o`000?l000020?l000`0
oooo00<0003o0?ooo`3oool0503oool00`3o0000oooo0?ooo`0H0?ooo`@000001@3oool00`000000
oooo0?ooo`0O0?ooo`80o`005`3oool00`000?l0oooo0?ooo`0:0?ooo`@0o`003P3oool00`000?l0
oooo0?ooo`0:0?ooo`80o`00403oool00`000?l0oooo0?ooo`0C0?ooo`00303oool00`3o0000oooo
0?ooo`080?ooo`030000o`3oool0oooo01d0oooo00<0003o0?ooo`3oool0303oool00`000000o`00
0?l000030?l002<0oooo00<0o`000?ooo`3oool0603oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo01h0oooo00<0o`000?ooo`3oool05P3oool00`000?l0oooo0?ooo`090?ooo`@0o`00
00<000000?ooo`3oool0303oool00`000?l0oooo0?ooo`090?ooo`80o`004@3oool00`000?l0oooo
0?ooo`0:0?ooo`030?l0003oool0oooo00L0oooo000<0?ooo`<0o`00703oool20?l000/0oooo00<0
003o0?ooo`3oool02`3oool00`000000oooo0?ooo`040?l002<0oooo00<0o`000?ooo`3oool05`3o
ool00`000000oooo0?ooo`040?ooo`8000007@3oool20?l001P0oooo00<0003o0?ooo`3oool0203o
ool40?l000030?ooo`000000oooo00d0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?oo
o`0A0?ooo`030000o`3oool0oooo00P0oooo0`3o00090?ooo`00303oool40?l000T0oooo00<0003o
0?ooo`3oool04@3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00l0oooo0`3o000:
0?ooo`030000o`3oool0oooo01H0oooo00<0o`000?ooo`3oool03P3oool4000000@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0J0?ooo`80o`006P3oool00`000?l0oooo0?ooo`06
0?ooo`@0o`000`3oool00`000000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00P0oooo0P3o000C
0?ooo`030000o`3oool0oooo00P0oooo103o00090?ooo`003P3oool00`3o0000oooo0?l000090?oo
o`030000o`3oool0oooo01<0oooo00<0o`000?ooo`3oool05@3oool010000000oooo0?ooo`3oool4
0?l000P0oooo00<0003o0?ooo`3oool06@3oool20?l001@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0I0?ooo`030?l0003oool0oooo01T0oooo00<0003o0?ooo`3oool01P3oool4
0?l000<0oooo00<000000?ooo`3oool0303oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0
oooo0180oooo00<0003o0?ooo`3oool01`3oool40?l000/0oooo000?0?ooo`@0o`00203oool00`00
0?l0oooo0?ooo`0C0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool02`3oool00`00
0000oooo0?ooo`020?ooo`@0o`00203oool00`000?l0oooo0?ooo`0J0?ooo`030?l0003oool0oooo
00l0oooo0`0000060?ooo`030000003oool0oooo01L0oooo0P3o000K0?ooo`030000o`3oool0oooo
00D0oooo103o00050?ooo`030000003oool0oooo00/0oooo00<0003o0?ooo`3oool01P3oool20?l0
01@0oooo00<0003o0?ooo`3oool01P3oool40?l000d0oooo000@0?ooo`@0o`007P3oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo00/0oooo00<000000?ooo`3oool00`3oool40?l003L0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0E0?ooo`80o`00703oool00`000?l0
oooo0?ooo`040?ooo`@0o`001P3oool00`000000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00D0
oooo0P3o000E0?ooo`030000o`3oool0oooo00D0oooo103o000?0?ooo`00303oool6001T00040?l0
0000I00006@00?l000H006@000<0003o001T0000I0005@00I0000`3o000006@0001T0005001T0003
0000o`00I00006@0018006@0103o0006001T00030000o`00I00006@001X006@00P3o002M001T00T0
oooo000D0?ooo`<0o`001P3oool00`000?l0oooo0?ooo`0E0?ooo`030?l0003oool0oooo01X0oooo
1@3o00050?ooo`030000o`3oool0oooo01/0oooo00<0o`000?ooo`3oool0503oool00`000000oooo
0?ooo`0B0?ooo`030?l0003oool0oooo01`0oooo00<0003o0?ooo`3oool00`3oool40?l000P0oooo
00<000000?ooo`3oool02P3oool00`000?l0oooo0?ooo`040?ooo`80o`005`3oool00`000?l0oooo
0?ooo`030?ooo`@0o`004P3oool001D0oooo0`3o00000`3oool0o`000?ooo`030?ooo`030000o`3o
ool0oooo01D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`090?ooo`030000003o
ool0oooo00L0oooo103o00050?ooo`030000o`3oool0oooo0340oooo00<000000?ooo`3oool0403o
ool20?l001l0oooo00<0003o0?ooo`3oool00P3oool40?l000T0oooo00<000000?ooo`3oool02P3o
ool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo01H0oooo00<0003o0?ooo`3oool00P3o
ool40?l001@0oooo000E0?ooo`H0o`007P3oool20?l000<0oooo00<0003o0?ooo`3oool02P3oool0
0`000000oooo0?ooo`080?ooo`030?l0003oool0o`0002@0oooo0P3o000B0?ooo`030000003oool0
oooo00l0oooo00<0o`000?ooo`3oool07P3oool010000?l0oooo0?ooo`3oool40?l000X0oooo00<0
00000?ooo`3oool02P3oool00`000?l0oooo0?ooo`020?ooo`80o`00603oool00`000?l0oooo0?oo
o`020?ooo`<0o`005P3oool001T0oooo0`3o00040?ooo`030000o`3oool0oooo01P0oooo00D0o`00
0?ooo`3oool0oooo0000o`0<0?ooo`030000003oool0oooo00P0oooo103o00030?ooo`030000o`3o
ool0oooo01h0oooo00<0o`000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030?l0003o
ool0oooo01h0oooo00@0003o0?ooo`3oool0oooo0`3o000<0?ooo`030000003oool0oooo00T0oooo
00@0003o0?ooo`3oool0oooo0P3o000J0?ooo`040000o`3oool0oooo0?ooo`<0o`005`3oool001X0
oooo0`3o0000103oool0o`000?ooo`000?lg0?ooo`@0o`000`3oool00`000?l0oooo0?ooo`0O0?oo
o`030?l0003oool0oooo00d0oooo00<000000?ooo`3oool0303oool20?l00200oooo00<0003o0?oo
o`3oool0103o000<0?ooo`030000003oool0oooo00T0oooo00D0003o0?ooo`3oool0oooo0?l0000K
0?ooo`030000o`3oool0oooo00@0o`00603oool001/0oooo00<0o`000?ooo`3o00000P3o00000`3o
ool0003o0?ooo`0J0?ooo`80o`000P3oool00`000?l0oooo0?ooo`0E0?ooo`<0o`0000D0oooo0?l0
003oool0oooo0000o`0Q0?ooo`030?l0003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool0
0`3o0000oooo0?ooo`0O0?ooo`030000o`3oool0o`0000<0o`003P3oool00`000000oooo0?ooo`08
0?ooo`030000o`3oool0oooo0080o`006`3oool00`000?l0oooo0?ooo`030?l001X0oooo000N0?oo
o`<0o`007P3oool20?l000030?ooo`000?l0oooo00T0oooo00<000000?ooo`3oool0303oool40?l0
02<0oooo00<0o`000?ooo`3oool02`3oool00`000000oooo0?ooo`090?ooo`80o`008@3oool00`00
0?l0oooo0?l000030?l000h0oooo00<000000?ooo`3oool02@3oool00`000?l0o`000?l0000L0?oo
o`030000o`3oool0oooo00<0o`006`3oool000`0oooo0P3o000A0?ooo`@0o`0000<0003o0?ooo`3o
ool0703oool00`000?l0oooo0?ooo`080?ooo`030000003oool0oooo00d0oooo1@3o00000`000?l0
oooo0?ooo`0Q0?ooo`030?l0003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`3o0000
oooo0?ooo`0Q0?ooo`@0o`00403oool00`000000oooo0?ooo`080?ooo`80o`007@3oool00`000?l0
oooo0?l000030?l00180oooo00<0o`000?ooo`3oool01`3oool000h0oooo00<0o`000?ooo`3oool0
3`3oool40?l000030000o`3oool0oooo01/0oooo00<0o`000000o`3oool02@3oool00`000000oooo
0?ooo`0>0?ooo`<0o`0000<0003o0?ooo`3oool08P3oool00`3o0000oooo0?ooo`070?ooo`030000
003oool0oooo00H0oooo0P3o000S0?ooo`@0o`00403oool00`000000oooo0?ooo`080?ooo`030?l0
003oool0oooo01`0oooo00<0003o0?l0003o00000P3o000B0?ooo`80o`002P3oool00100oooo00<0
o`000?ooo`3oool03`3oool30?l000030000o`3oool0oooo01`0oooo00<0o`000?ooo`3oool06P3o
ool20?l000030000o`3o0000oooo0280oooo00<0o`000?ooo`3oool01P3oool00`000000oooo0?oo
o`040?ooo`80o`008`3oool40?l00140oooo00<000000?ooo`3oool01`3oool20?l001l0oooo103o
000A0?ooo`80o`00303oool00140oooo00<0o`000?ooo`3oool0403oool0103o0000oooo0?ooo`3o
000L0?ooo`030000o`3oool0o`0000P0oooo00<000000?ooo`3oool04@3oool40?l002<0oooo0P3o
00050?ooo`030000003oool0oooo00<0oooo00<0o`000?ooo`3oool08P3oool30?l001<0oooo00<0
00000?ooo`3oool01P3oool00`3o0000003o0?ooo`0M0?ooo`@0o`004@3oool20?l000h0oooo000B
0?ooo`030?l0003oool0oooo0140oooo00@0003o0?l0003o0000o`006`3oool010000?l0oooo0?l0
003o00070?ooo`030000003oool0oooo0140oooo00@0o`000000o`3o0000o`00903oool00`3o0000
oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`80o`008`3oool40?l001<0oooo00<000000?oo
o`3oool01@3oool20?l000030000o`3oool0oooo01/0oooo103o000A0?ooo`80o`00403oool001D0
oooo00<0o`000?ooo`3oool03`3oool010000?l0o`000?l0003o000K0?ooo`040000o`3oool0oooo
0?l000H0oooo00<000000?ooo`3oool04`3oool00`000?l0o`000?l0000X0?ooo`040000003oool0
o`000?l002<0oooo103o000E0?ooo`030000003oool0oooo00<0oooo0P3o00020?ooo`030000o`3o
ool0oooo01T0oooo103o000A0?ooo`80o`004P3oool001H0oooo00<0o`000?ooo`3oool03`3oool0
10000?l0o`000?ooo`3o000O0?ooo`030?l0003oool0oooo00<0oooo00<000000?ooo`3oool04`3o
ool01@000?l0o`000?l0003oool0o`0002<0oooo00@0o`000?ooo`3o0000o`00903oool40?l00003
0000o`3oool0oooo0180oooo00<000000?ooo`3oool00`3oool01@3o0000oooo0?ooo`3oool0003o
01X0oooo103o00000`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo0180oooo000G0?ooo`03
0?l0003oool0oooo0100oooo103o000J0?ooo`050000o`3oool0oooo0?ooo`3o00006`3oool00`3o
0000oooo0?l000030?l00280oooo0P3o000S0?ooo`@0o`0000<0oooo0000o`3oool0503oool01000
0000oooo0?ooo`3oool20?l000<0oooo00<0003o0?ooo`3oool0603oool40?l000030000o`3oool0
oooo00h0oooo0P3o000E0?ooo`006@3oool20?l000l0oooo00<0003o0?l0003o00000P3o00000`3o
ool0o`000?ooo`0F0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0C0?ooo`030000o`3oool0oooo00@0o`007`3oool20?l000030?ooo`000000oooo
0240oooo103o00000`3oool0003o0?ooo`0D0?ooo`050000003oool0oooo0?ooo`3o0000103oool0
0`000?l0oooo0?ooo`0G0?ooo`@0o`000P3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0
oooo01D0oooo000K0?ooo`030?l0003oool0oooo00`0oooo00D0003o0?ooo`3o0000o`000?ooo`03
0?l001L0oooo00<0003o0?ooo`3oool00`3oool20?l000030?ooo`000000oooo01D0oooo00L0003o
0?ooo`3oool0oooo0?l0003oool0o`0001`0oooo0P3o00030?ooo`040000003oool0o`000?l001d0
oooo103o00020?ooo`030000o`3oool0oooo01@0oooo00@000000?ooo`3o0000o`00103oool00`00
0?l0oooo0?ooo`0F0?ooo`@0o`000`3oool00`000?l0oooo0?ooo`0<0?ooo`80o`00603oool002/0
oooo00<0003o0?ooo`3oool00P3oool30?l001h0oooo0P3o00000`000000oooo0?ooo`0D0?ooo`04
0000o`3oool0oooo0?ooo`@0o`006@3oool00`3o0000oooo0?ooo`030?ooo`040000003oool0oooo
0?ooo`80o`006P3oool30?l000<0oooo00<0003o0?ooo`3oool0503oool00`000000oooo0?l00005
0?ooo`030000o`3oool0oooo01H0oooo103o00030?ooo`030000o`3oool0oooo00/0oooo0P3o000J
0?ooo`007P3oool20?l00140oooo103o000F0?ooo`030000o`3oool0oooo0200oooo1@3o000F0?oo
o`80o`001P3oool00`000000oooo0?ooo`040?ooo`030?l0003oool0oooo01@0oooo103o00040?oo
o`030000o`3oool0oooo01@0oooo0P3o00060?ooo`030000o`3oool0oooo01@0oooo103o00040?oo
o`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool06P3oool00200oooo00<0o`000?ooo`3o
ool02P3oool00`000?l0oooo0?ooo`020?ooo`@0o`005P3oool00`000?l0oooo0?ooo`050?ooo`80
o`005P3oool00`000?l0oooo0?ooo`020?ooo`040?l0003oool0oooo0?l000P0oooo0P0000040?oo
o`040000003oool0oooo0?ooo`80o`000P0000060?ooo`030000003oool0oooo00D0oooo00<0o`00
0?ooo`3oool04@3oool40?l000D0oooo00<0003o0?ooo`3oool04`3oool20?l000L0oooo00<0003o
0?ooo`3oool0503oool40?l000@0oooo00<0003o0?ooo`3oool02P3oool20?l001d0oooo000]0?oo
o`80003o1@3oool30?l001H0oooo00<0003o0?ooo`3oool0103oool00`000000oooo0?l0000E0?oo
o`030000o`3oool0oooo00@0oooo103o00050?ooo`040000003oool0oooo000000H0oooo00<0o`00
0?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<0o`00
0?ooo`3oool03P3oool40?l000H0oooo00<0003o0?ooo`3oool04`3oool00`3o0000oooo00000006
0?ooo`030000o`3oool0oooo01<0oooo103o00050?ooo`030000o`3oool0oooo00X0oooo00<0o`00
0?ooo`3oool07@3oool00280oooo0P3o000;0?ooo`030000o`3oool0oooo00<0oooo0`3o00000`3o
ool0o`000?ooo`0J0?ooo`030000003oool0oooo01D0oooo00<0003o0?ooo`3oool0103oool50?l0
00<0oooo00@000000?ooo`3oool00000103oool20?l000D0oooo00<000000?ooo`3oool00`3oool2
000000T0oooo00<0o`000?ooo`3oool02`3oool40?l000H0oooo00<0003o0?ooo`3oool04P3oool2
0?l000030?ooo`000000oooo00D0oooo00<0003o0?ooo`3oool04`3oool30?l000L0oooo00<0003o
0?ooo`3oool0203oool20?l00200oooo000T0?ooo`030?l0003oool0oooo00l0oooo00<0o`000?oo
o`3o00000`3o000B0?ooo`030000o`3oool0oooo00D0oooo00<000000?ooo`3o00000P3o000K0?oo
o`@0o`000P3oool010000000oooo0?ooo`0000030?ooo`030?l0003oool0oooo0080oooo0`000006
0?ooo`030000003oool0oooo00T0oooo0P3o00090?ooo`@0o`00203oool00`000?l0oooo0?ooo`0A
0?ooo`050?l0003oool0oooo0?ooo`0000001@3oool00`000?l0oooo0?ooo`0B0?ooo`@0o`001`3o
ool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo0200oooo000W0?ooo`030?l0003oool0
oooo00l0oooo103o000B0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool06P3oool3
0?l000060?ooo`000000oooo0?ooo`000000oooo0P3o00050?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool02`3oool00`3o0000oooo0?ooo`040?ooo`@0o`002@3oool00`000?l0oooo
0?ooo`0@0?ooo`80o`000`3oool00`000000oooo0?ooo`030?ooo`030000o`3oool0oooo0140oooo
103o00080?ooo`030000o`3oool0oooo00L0oooo0P3o000S0?ooo`00:03oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3o00004P3oool00`000?l0oooo0?oo
o`040?ooo`030000003oool0oooo00<0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?oo
o`070?ooo`<0o`0000<000000?l0003oool00P3o00070?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool03@3oool20?l00080oooo0`3o000:0?ooo`030000o`3oool0oooo0100oooo00<0
o`000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000o`3oool0oooo00l0oooo103o
00090?ooo`030000o`3oool0oooo00H0oooo0P3o000U0?ooo`00:@3oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo00P0oooo1@3o000F0?ooo`030000003oool0oooo00@0oooo00<0o`00
0?ooo`3oool03`3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0o`000080o`002@3oool4
000000D0oooo00<000000?ooo`3oool03`3oool40?l000X0oooo00<0003o0?ooo`3oool03`3oool2
0?l000D0oooo00<000000?ooo`3oool00`3oool00`000?l0oooo0?ooo`0?0?ooo`@0o`002@3oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo02D0oooo000[0?ooo`80o`001@3oool00`00
0?l0oooo0?ooo`080?ooo`D0o`00403oool00`000?l0oooo0?ooo`030?ooo`030000003oool0oooo
00@0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`080?ooo`@0o`004@3oool00`00
0000oooo0?ooo`0>0?ooo`<0o`002`3oool00`000?l0oooo0?ooo`0>0?ooo`80o`001`3oool00`00
0000oooo0?ooo`020?ooo`030000o`3oool0oooo00h0oooo103o000;0?ooo`030000o`3oool0oooo
00@0oooo0P3o000X0?ooo`00;@3oool00`3o0000oooo0?ooo`0@0?ooo`040?l0003oool0oooo0?l0
00h0oooo00<0003o0?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030?l0003oool0oooo
01L0oooo00<0o`000?ooo`3oool0103o000?0?ooo`030000003oool0oooo00`0oooo103o0000103o
ool0o`000?l0003o00070?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool01P3oool0
0`000000oooo0?ooo`020?ooo`030000o`3oool0oooo00d0oooo103o000<0?ooo`030000o`3oool0
oooo00@0oooo00<0o`000?ooo`3oool0:03oool002d0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`0:0?ooo`@0o`003P3oool00`000?l0oooo0?ooo`0<0?ooo`80o`003P3oool00`00
0?l0oooo0?ooo`040?ooo`80o`00103oool50?l000d0oooo00<000000?ooo`3oool02`3oool40?l0
00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`0<0?ooo`80o`002@3oool01@00
0000oooo0?ooo`3oool0003o00l0oooo0`3o000=0?ooo`030000o`3oool0oooo00<0oooo0P3o000[
0?ooo`00303ooolT001T0080o`000P00I0000`000?l006@0001T000:001T00H0o`004P00I0020000
00T006@000<0o`00001T0000I0003000I0000`000?l006@0001T000;001T00@0o`00TP00I0090?oo
o`00<P3oool0103o0000oooo0?ooo`000?l>0?ooo`@0o`003@3oool00`000?l0oooo0?ooo`020?oo
o`030000003oool0oooo00T0oooo0P3o000<0?ooo`030000o`3oool0o`0000`0oooo00@0o`000?oo
o`3oool0o`002P3oool00`000000oooo0?ooo`080?ooo`@0o`002P3oool20?l000030?ooo`000?l0
oooo00`0oooo0P3o000:0?ooo`030000003oool0oooo0080oooo00<0003o0?ooo`3oool02P3oool4
0?l000l0oooo00@0003o0?ooo`3oool0oooo0P3o000^0?ooo`00AP3oool40?l000`0oooo00<0003o
0?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030?l0003oool0oooo00T0oooo0P3o000?
0?ooo`@0o`00203oool00`000000oooo0?ooo`070?ooo`<0o`003P3oool00`3o0000oooo0?ooo`0:
0?ooo`80o`00303oool01@000000oooo0?ooo`3oool0003o00`0oooo103o000?0?ooo`030000o`3o
ool0oooo0080o`00<03oool000`0oooo00<0o`000?ooo`3oool09@3oool20?l000030?ooo`000?l0
oooo00l0oooo103o000;0?ooo`030000o`3oool0oooo01P0oooo0P3o00020?ooo`030000o`3oool0
oooo00`0oooo1@3o00070?ooo`030000003oool0oooo00D0oooo103o000>0?ooo`040000o`3oool0
oooo0?l000P0oooo0P3o000=0?ooo`050000003oool0oooo0?ooo`000?l02`3oool40?l00100oooo
00@0003o0?ooo`3oool0o`00:03oool00`3o0000oooo0?ooo`070?ooo`00303oool30?l002L0oooo
00<0o`000?ooo`000?l0403oool40?l001h0oooo0P3o00030?ooo`80o`00103oool00`000?l0oooo
0?ooo`0?0?ooo`030?l0003oool0o`0000H0oooo00<000000?ooo`3oool00`3oool40?l000l0oooo
00<0003o0?ooo`3oool00P3oool20?l000@0oooo0P3o000?0?ooo`050000003oool0oooo0?ooo`00
0?l02P3oool40?l00100oooo00@0003o0?ooo`3o0000o`009`3oool30?l000T0oooo000<0?ooo`@0
o`00:@3oool00`000?l0oooo0?ooo`0?0?ooo`<0o`002P3oool01@000?l0oooo0?ooo`3oool00000
0100oooo00<0o`000?ooo`3o00001`3oool00`000?l0oooo0?ooo`0?0?ooo`@0o`00103oool01000
0000oooo0?ooo`3oool40?l00100oooo00<0003o0?ooo`3oool01@3oool0103o0000oooo0?l0003o
000@0?ooo`050000003oool0oooo0?ooo`000?l02@3oool40?l00140oooo00<0003o0?ooo`3o0000
:03oool40?l000T0oooo000>0?ooo`030?l0003oool0o`0002P0oooo0P3o000A0?ooo`@0o`002@3o
ool010000?l0oooo0?ooo`00000@0?ooo`80o`006`3oool40?l000040?ooo`3o0000oooo00000080
oooo103o000A0?ooo`030000o`3oool0oooo00H0oooo0P3o000A0?ooo`040000003oool0oooo0000
o`T0oooo0`3o000C0?ooo`80o`009`3oool40?l000/0oooo000?0?ooo`@0o`009`3oool00`000?l0
o`000?ooo`0@0?ooo`H0o`001`3oool010000?l0oooo0?ooo`00000>0?ooo`030?l0003oool0oooo
0080o`00203oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0o`000080o`0000<000000?l0
003o00000P3o000B0?ooo`030000o`3oool0oooo00D0oooo0P3o00020?ooo`030?l0003oool0oooo
00d0oooo00@000000?ooo`3oool0003o203oool40?l00180oooo0P3o000W0?ooo`@0o`003@3oool0
0100oooo103o00000`3oool0o`000?ooo`0T0?ooo`030000o`3oool0o`000140oooo1@3o000G0?oo
o`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`0B0?oo
o`D0o`004`3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00<0oooo00<0o`000?oo
o`3oool02`3oool010000000oooo0?ooo`000?l70?ooo`@0o`004`3oool00`3o0000003o0?ooo`0U
0?ooo`@0o`003`3oool00180oooo00<0o`000?ooo`3o00000P3o000U0?ooo`040000o`3oool0o`00
0?l00180oooo00<0o`000?ooo`3o00002@3oool00`000000oooo0?ooo`080?ooo`80o`002@3oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo0140oooo1@3o000B0?ooo`030000o`3oool0
oooo00@0oooo0P3o00080?ooo`80o`002P3oool010000000oooo0?ooo`000?l60?ooo`@0o`004P3o
ool20?l000030000o`3oool0oooo02<0oooo103o000A0?ooo`001`3oool4000000<0oooo00<00000
0?ooo`3oool00P3oool2000000<0o`008@3oool4000000<0oooo00<0o`000?ooo`3oool0403oool4
0?l000D0oooo00<0003o0?ooo`3oool00`0000040?ooo`030000003oool0o`000080oooo0`000007
0?ooo`030?l0003oool0oooo01D0oooo203o000@0?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0?ooo`3oool01`3oool2000000050?ooo`3o0000o`000?ooo`000000103oool3000000030?ooo`00
0?l0oooo00@0oooo103o000B0?ooo`80o`0000@0oooo0000o`3oool0oooo1000000O0?ooo`@0o`00
100000030?ooo`030000003oool0oooo0080oooo0`0000030?ooo`002@3oool00`000000oooo0?oo
o`0:0?ooo`@0o`008@3oool010000000oooo0?ooo`000?l30?ooo`030?l0003oool0oooo00l0oooo
103o00040?ooo`040000o`3oool0oooo00000080oooo00@000000?ooo`3oool0oooo0P3o00060?oo
o`030000003oool0oooo00D0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`0<0?oo
o`@0o`000P3oool00`000000oooo0?l000030?l000d0oooo00<0003o0?ooo`3oool00`3oool20?l0
00T0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0000o`050?ooo`@0o`004@3oool2
0?l000<0oooo00<0003o0?ooo`3oool00P3oool00`000000oooo0?ooo`0L0?ooo`@0o`00103oool0
0`000000oooo0?ooo`0:0?ooo`4000000@3oool10?ooo`002@3oool00`000000oooo0?ooo`0:0?oo
o`030000003o0000o`000080o`00803oool010000000oooo0?ooo`000?l40?ooo`030?l0003oool0
oooo0100oooo00D0o`000?ooo`3oool0oooo0?l000020?ooo`060000o`3oool000000000003oool0
00000P3oool00`3o0000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<0o`000?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`0:0?ooo`<0o`00103oool010000000oooo0?ooo`3oool40?l0
00/0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`090?ooo`040000003oool0oooo
000000<0oooo0P3o00030?ooo`040000003oool0003o000000<0oooo103o000B0?ooo`030?l0003o
ool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`000000oooo0?ooo`0J0?ooo`@0o`001P3o
ool00`000000oooo0?ooo`0:0?ooo`4000000@3oool10?ooo`0000<0oooo0000000000000P000004
0?ooo`030000003oool0oooo00L0oooo0`0000030?ooo`<0o`005`3oool4000000@0oooo00D00000
0?ooo`3oool0oooo0000o`040?ooo`030?l0003oool0oooo0100oooo1@3o000010000000oooo0?oo
o`0000020?ooo`030000003o0000o`0000H0oooo0`00000;0?ooo`030?l0003oool0oooo0080oooo
00<0003o0?ooo`3oool01`3oool40?l000D0oooo00<000000?ooo`3oool00P3oool50?l000P0oooo
00@0003o0?ooo`3oool0oooo0P3o000<0?ooo`040000003oool0oooo000000D0oooo00H0o`000?oo
o`00000000000000o`0000030?ooo`<0o`004P3oool20?l000@0oooo00<0003o0?ooo`3oool0103o
ool00`000000oooo0?ooo`0I0?ooo`@0o`001`3oool00`000000oooo0?ooo`070?ooo`<000000`3o
ool000T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`<0o`0000<0oooo
0?l0003oool06`3oool00`000000oooo0?ooo`080?ooo`80o`003`3oool70?l000050?ooo`000?l0
oooo0000003o0000203oool00`000000oooo0?ooo`0<0?ooo`030?l0003oool0oooo00T0oooo103o
00070?ooo`030000003oool0oooo00@0oooo103o00060?ooo`050000o`3oool0oooo0?ooo`3o0000
3P3oool010000000oooo0?ooo`0000070?ooo`030000003o0000003o0080oooo103o000B0?ooo`03
0?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool01@3oool00`000000oooo0?ooo`0G0?ooo`@0
o`002@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00070?ooo`<00000
2@3oool00`000000oooo0?ooo`050?ooo`030?l0003oool0o`0000<0o`00603oool3000000D0oooo
00<0003o0?ooo`3oool0103oool20?l00140oooo103o000010000000003o0000000000080?ooo`03
0000003oool0oooo00l0oooo0P3o00000`3oool0003o0?ooo`030?ooo`<0o`002@3oool00`000000
oooo0?ooo`060?ooo`030?l0003oool0o`0000@0oooo00<0003o0?ooo`3oool00P3o000?0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`000?l01@3o000B0?ooo`80o`001@3oool00`00
0?l0oooo0?ooo`040?ooo`<00000603oool40?l000P0oooo0`0000090?ooo`030000003oool0oooo
00<0oooo00090?ooo`030000003oool0oooo00L0oooo100000070?ooo`@0o`006@3oool00`000000
oooo0?ooo`040?ooo`030000o`3oool0oooo01P0oooo0`3o00000`000000003o000000080?ooo`@0
0000403oool0103o0000003o0?ooo`3oool40?l000X0oooo00<000000?ooo`3oool01`3oool50?l0
00040?ooo`000?l0o`000?l00180oooo0P0000070?ooo`03000000000?l0000000@0o`004@3oool2
0?l000L0oooo00<0003o0?ooo`3oool01P3oool00`000000oooo0?ooo`0D0?ooo`@0o`00303oool0
0`000000oooo0?ooo`070?ooo`@000000P3oool00200oooo00<0o`000?ooo`3o0000803oool00`00
0?l0oooo0?ooo`050?ooo`80o`00403oool50?l001l0oooo00@0003o0?l0003o0000o`00303oool0
0`000000oooo0?ooo`080?ooo`H0o`00703oool00`000000003o0?l000030?l000030?ooo`3o0000
oooo00l0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`0M0?ooo`<0o`007P3oool0
0240oooo103o000X0?ooo`030?l0003oool0oooo00/0oooo0P3o00020?ooo`<0o`0000<0003o0?oo
o`3oool06`3oool40?l000d0oooo00<000000?ooo`3oool02`3oool30?l001`0oooo00<000000?l0
003o00000P3o00030?ooo`030?l0003oool0oooo00/0oooo0P3o00080?ooo`030000o`3oool0oooo
01`0oooo103o000O0?ooo`008P3oool40?l001h0oooo00<0003o0?ooo`3oool04`3oool00`3o0000
oooo0?ooo`040?ooo`80o`0000<000000?l0003oool0603oool40?l000030?ooo`000?l0oooo00`0
oooo00<000000?ooo`3oool02@3oool20?l000030?ooo`3o0000o`000080o`006@3oool40?l000H0
oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo01/0
oooo103o000Q0?ooo`00303oool20?l001H006@000@0o`00001T0000I000o`007@00I0000`000?l0
06@0001T0007001T0080o`004P00I000103o000000000?l0003o000M001T00030000o`00I00006@0
01X006@01@3o000T001T0080o`00B`00I0090?ooo`00303oool00`000000oooo0?l000050?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool40?l000D0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00D0003o0?ooo`3o
ool0oooo000000060?ooo`80o`000`3oool20?l000<0oooo00<000000?ooo`3oool01P3oool00`3o
000000000?l000020?l000@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?oo
o`@0o`0000<000000?ooo`3oool00`3oool010000?l0o`000?l0000000080?ooo`030000003oool0
oooo00D0oooo00D000000?l0003o0000oooo0000o`040?ooo`030000003o0000o`000080o`00103o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo103o00080?ooo`030000003o
ool0oooo00<0oooo00D0o`000?ooo`3oool000000?l000060?ooo`050000003oool0oooo0?ooo`00
0?l0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool00`3oool40?l000P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`80
o`0000<000000?ooo`3oool01`3oool002L0oooo1@3o000X0?ooo`80o`00403oool010000?l0o`00
0?l0003o000@0?ooo`<0o`002`3oool00`3o0000oooo0?ooo`060?ooo`030000003oool0oooo00@0
oooo0P3o00020?ooo`030000o`3oool0oooo00H0oooo103o000?0?ooo`@0o`004P3oool20?l000/0
oooo00<0003o0?ooo`3oool06@3oool40?l001L0oooo0P3o000<0?ooo`00403oool20?l001L0oooo
103o000K0?ooo`030000o`3oool0oooo00P0oooo0`3o000@0?ooo`030000003oool0o`000080oooo
00<0o`000?ooo`3oool02P3oool40?l000X0oooo00D0003o0?ooo`3oool0oooo0?l000060?ooo`03
0000003oool0oooo00<0oooo00D0o`000?ooo`3oool0oooo0000o`0:0?ooo`D0o`00303oool40?l0
00030000003oool0oooo00h0oooo103o000:0?ooo`030000o`3oool0oooo01P0oooo103o000G0?oo
o`80o`003P3oool00180oooo00<0o`000?ooo`3oool05P3oool30?l001X0oooo00<0003o0?ooo`3o
ool01P3oool20?l000<0oooo00<0o`000?ooo`3oool03@3oool010000000003o0?ooo`3oool40?l0
00P0oooo103o000=0?ooo`050000o`3oool0oooo0?ooo`3o00001@3oool010000000oooo0?ooo`3o
ool20?l000<0oooo00<0003o0?ooo`3oool02`3oool40?l000T0oooo103o00000`3oool0003o0?oo
o`0?0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`0H0?ooo`<0o`005`3oool20?l00100oooo000E0?ooo`030?l0003oool0oooo01@0oooo0`3o0000
0`3oool0o`000?ooo`0G0?ooo`030000o`3oool0oooo00<0oooo0P3o00070?ooo`80o`003@3oool0
10000000oooo0?ooo`3oool40?l000D0oooo103o000?0?ooo`030000o`3oool0oooo0080oooo00<0
o`000?ooo`3oool00P3oool010000000oooo0?l0003o00040?ooo`030000o`3oool0oooo00h0oooo
0`3o00070?ooo`@0o`0000<0oooo0000o`0000003P3oool20?l000d0oooo00<0003o0?ooo`3oool0
5`3oool40?l001H0oooo0P3o000B0?ooo`005P3oool00`3o0000oooo0?ooo`0C0?ooo`80o`0000@0
oooo0?l0003o0000o`005`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00T0oooo
00<0o`000?ooo`3oool02P3oool00`000000oooo0000o`030?ooo`030?l0003oool0o`0000<0oooo
103o000A0?ooo`030000o`3oool0oooo00@0oooo00@0o`000?ooo`3o0000o`001P3oool00`000?l0
oooo0?ooo`0?0?ooo`@0o`000`3oool40?l00080oooo00<0003o0000003oool03@3oool00`3o0000
oooo0?ooo`080?ooo`80o`000P3oool00`000?l0oooo0?ooo`0F0?ooo`@0o`005`3oool00`3o0000
oooo0?ooo`0B0?ooo`005`3oool00`3o0000oooo0?ooo`0F0?ooo`<0o`006@3oool20?l000d0oooo
00<0o`000?ooo`3oool0303oool010000?l0oooo0?ooo`3oool70?l001/0oooo00<0o`000000003o
ool01@3oool00`000?l0oooo0?ooo`0A0?ooo`P0o`000`3oool00`000?l0oooo0000000<0?ooo`80
o`003@3oool00`3o0000003o0?ooo`0G0?ooo`@0o`005P3oool20?l001D0oooo000I0?ooo`030?l0
003oool0oooo01D0oooo103o000F0?ooo`030000o`3oool0oooo00l0oooo0P3o000:0?ooo`030000
003oool0003o0080oooo1@3o00000`3oool0o`000?ooo`0D0?ooo`040000o`3oool0oooo0?ooo`80
o`0000<0oooo0?l0003oool0103oool00`000?l0oooo0?ooo`0D0?ooo`D0o`000`3oool00`000?l0
oooo0000000;0?ooo`80o`00403oool00`000?l0o`000?ooo`0D0?ooo`@0o`005`3oool00`3o0000
oooo0?ooo`0E0?ooo`006P3oool00`3o0000oooo0?ooo`0E0?ooo`D0o`004P3oool20?l000030?oo
o`000?l0oooo0140oooo00<0o`000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`@0o`00
00@0oooo0?l0003o0000o`00503oool010000?l0oooo0?ooo`3o00030?ooo`060000003oool0o`00
0?l0003oool0003o5P3oool50?l000040?ooo`3o0000oooo0000o`80oooo00<000000?ooo`3oool0
1`3oool20?l00140oooo00@0003o0?ooo`3oool0o`004`3oool40?l001H0oooo0P3o000H0?ooo`00
6`3oool00`3o0000oooo0?ooo`0F0?ooo`@0o`003`3oool20?l000@0oooo00<0003o0?ooo`3oool0
6P3oool010000000oooo0?l000000?l20?l000@0oooo0`3o000D0?ooo`030000o`3o0000oooo00<0
oooo00@000000?ooo`3oool0oooo0P3o000D0?ooo`@0o`000`3oool40?l000030?ooo`000000oooo
00L0oooo0P3o000B0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool03P3oool40?l0
01H0oooo0P3o000J0?ooo`007P3oool20?l001H0oooo00@0o`000?ooo`3oool0o`00303oool00`3o
0000oooo0?ooo`0H0?ooo`80o`00203oool20?l000030000o`3oool0oooo00D0oooo103o000A0?oo
o`80o`001@3oool010000000oooo0?ooo`000?lE0?ooo`@0o`001@3oool40?l000030000003oool0
oooo00@0oooo0P3o000C0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool02P3oool3
0?l001L0oooo00<0o`000?ooo`3oool06P3oool00200oooo00<0o`000?ooo`3oool05@3oool40?l0
00P0oooo0P3o00080?ooo`030000o`3oool0oooo0180oooo0P3o00040?ooo`@0o`0000<0oooo0000
o`3oool01P3oool40?l000l0oooo00D0o`000?ooo`3oool0oooo0000o`030?ooo`030000003oool0
003o00@0oooo0P3o000>0?ooo`@0o`001`3oool01@000?l0oooo0?l000000000o`0000D0oooo00<0
o`000?ooo`3oool04P3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00L0oooo103o
000F0?ooo`80o`007@3oool003T0oooo103o00060?ooo`030?l0003oool0oooo00T0oooo00<0003o
0?ooo`3oool05P3oool30?l000030000003oool0oooo00X0oooo0`3o000<0?ooo`80o`001@3oool0
1P000?l0oooo0?ooo`000000oooo0000o`H0oooo00<0o`000?ooo`3oool02@3oool40?l000P0oooo
00@0003o0?ooo`3oool0oooo1`3o000D0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3o
ool0103oool40?l001L0oooo00<0o`000?ooo`3oool07@3oool00280oooo0P3o000G0?ooo`030?l0
003oool0o`0000<0oooo0P3o000=0?ooo`030000o`3oool0oooo01<0oooo103o00000`3oool00000
0?ooo`020?ooo`030000o`3oool0oooo00L0oooo0`3o00000`3oool0o`000?ooo`070?ooo`030?l0
003oool0oooo00H0oooo00@0003o0?ooo`000000003o2@3oool00`3o0000oooo0?ooo`060?ooo`<0
o`002@3oool01P000?l0oooo0?ooo`3oool000000?ooo`H0o`00503oool00`000?l0oooo0?ooo`0<
0?ooo`80o`0000<0oooo0?l0003o00000P3o000G0?ooo`80o`00803oool002@0oooo00<0o`000?oo
o`3oool05@3oool50?l002@0oooo103o00030?ooo`050000003oool0oooo0?ooo`000?l02@3oool0
0`3o0000oooo0?l000030?l000@0oooo0P3o000;0?ooo`030000o`3oool0oooo00T0oooo0P3o0004
0?ooo`@0o`002@3oool00`000?l0oooo0?ooo`020?ooo`030000003oool0oooo00H0o`004P3oool0
0`000?l0oooo0?ooo`0?0?ooo`@0o`005`3oool00`3o0000oooo0?ooo`0P0?ooo`00303ooola001T
00H0o`003`00I0000`000?l006@0001T000F001T00030?l00000I00006@000<006@000<0003o001T
0000I0002@00I0040?l000l006@000<0003o001T0000I0003000I0000`3o000006@0001T000J001T
00<0o`00F000I0090?ooo`009`3oool20?l001<0oooo0P3o00020?ooo`@0o`003P3oool00`000?l0
oooo0?ooo`0=0?ooo`@0o`001P3oool00`3o0000oooo0000000@0?ooo`040?l0003oool0o`000?l0
00`0oooo00<0003o0?ooo`000?l03P3oool30?l000`0oooo00<0003o0?ooo`3oool00P3oool00`00
0000o`000?ooo`060?ooo`<0o`0000<0oooo0?l0003oool02`3oool00`000?l0oooo0?ooo`0=0?oo
o`@0o`000`3oool20?l00180oooo0P3o000U0?ooo`00:@3oool00`3o0000oooo0?ooo`0?0?ooo`03
0?l0003oool0oooo00@0oooo0`3o000>0?ooo`030000o`3oool0oooo00X0oooo103o00090?ooo`03
0?l000000000oooo00<0oooo00<0003o0?ooo`3oool02@3oool50?l000X0oooo00D0003o0?ooo`3o
ool000000000o`0;0?ooo`D0o`002`3oool00`000?l0oooo0?ooo`020?ooo`80o`002@3oool00`3o
0000oooo0?l000020?l000X0oooo00<0003o0?ooo`3oool03@3oool30?l000L0oooo00<0o`000?oo
o`3oool03P3oool00`3o0000oooo0?ooo`0U0?ooo`00:`3oool00`3o0000oooo0?ooo`0;0?ooo`80
o`00203oool40?l001L0oooo103o000=0?ooo`050000003oool0oooo0?ooo`000?l02P3oool00`3o
0000oooo0?ooo`040?l000T0oooo00@0003o0?ooo`3oool000002P3oool40?l000<0oooo00<0o`00
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`020?ooo`030?l000000000oooo00`0oooo0`3o0009
0?ooo`030000o`3oool0oooo00/0oooo103o000G0?ooo`80o`00:03oool000`0oooo0P3o000N0?oo
o`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool02@3oool40?l000d0oooo00<0003o0?oo
o`3oool0103oool40?l000l0oooo00<000000?l0003oool00P3oool00`000?l0oooo0?ooo`050?oo
o`80o`001@3oool0103o0000oooo0?ooo`3o00060?ooo`050000o`3oool0oooo0?ooo`0000000P3o
ool00`000?l0oooo0?ooo`040?ooo`<0o`001`3oool00`3o0000oooo0?ooo`040?ooo`040000o`3o
ool0oooo0?ooo`80o`0000<000000?ooo`3oool03@3oool40?l000H0oooo00<0003o0?ooo`3oool0
2P3oool40?l000`0oooo0`3o00090?ooo`030?l0003oool0oooo01h0oooo00<0o`000?ooo`3oool0
1`3oool000h0oooo00<0o`000?ooo`3oool0703oool00`3o0000oooo0?ooo`060?ooo`80o`003P3o
ool40?l000`0oooo00@0003o0?ooo`3oool0oooo103o000A0?ooo`030000003oool0o`0000T0oooo
00<0o`000?ooo`3oool01`3oool40?l000<0oooo00<0003o0?ooo`3oool00P3oool010000000oooo
0?ooo`000?l40?ooo`@0o`002@3oool20?l000@0oooo00H0003o0?ooo`3o0000o`000?ooo`00000A
0?ooo`D0o`000`3oool00`000?l0oooo0?ooo`0:0?ooo`@0o`00403oool00`3o0000oooo0?ooo`04
0?ooo`80o`007`3oool20?l000X0oooo000`0?ooo`040?l0003oool0oooo0?ooo`80o`004P3oool4
0?l000/0oooo00<0003o0?ooo`3o00000`3o000C0?ooo`040000003oool0oooo0?ooo`80o`0000<0
003o0?ooo`3oool00P3o000:0?ooo`H0o`0000<0003o0?ooo`3oool00`3oool01P000000oooo0?oo
o`3oool0003o0?ooo`@0o`003@3oool20?l000040?ooo`000?l0oooo0?l000<0oooo00<000000?oo
o`3oool04@3oool40?l000030?ooo`000?l0oooo00X0oooo103o000D0?ooo`050?l0003oool0oooo
0?ooo`3o00007`3oool20?l000`0oooo000@0?ooo`80o`007`3oool30?l001D0oooo1@3o00090?oo
o`@0o`005P3oool00`000000oooo0?ooo`020?ooo`030?l000000?l0o`0000l0oooo103o00050?oo
o`030000003oool0oooo0080oooo103o000@0?ooo`030000o`3o0000o`0000<0oooo00<000000?oo
o`3oool0503oool40?l000X0oooo103o000F0?ooo`<0o`007P3oool20?l000h0oooo000B0?ooo`03
0?l0003oool0oooo01/0oooo0`3o000H0?ooo`@0o`001P3oool30?l00080003o6`3oool20?l00003
0?ooo`000?l0oooo00l0oooo00@0003o0?l0003o0000o`00103oool00`000000oooo0?ooo`030?l0
00030000o`3oool0oooo00l0oooo103o00030?ooo`030000003oool0oooo01D0oooo1@3o00060?oo
o`@0o`005`3oool30?l001d0oooo0P3o000@0?ooo`00;P3oool20?l000@0oooo0P3o000G0?ooo`@0
o`000`3oool40?l00080oooo00<0003o0?ooo`3oool05@3oool00`000000o`000?l000030?ooo`80
o`000`3oool2000000@0oooo00<000000?ooo`3oool00P3oool00`000000003o000000030?l00005
0?ooo`3o0000oooo0000003oool0103o00000`3oool0003o0?ooo`0=0?ooo`80o`0000L0003o0?oo
o`3oool0oooo0?l0003oool0000001P0oooo00<0003o0?ooo`3o00000`3o00030?ooo`@0o`00603o
ool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo01L0oooo0P3o000B0?ooo`005@3oool0
0`3o0000oooo0?ooo`0E0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool05@3oool8
0?l000@0oooo00<0003o0?ooo`3oool0503oool00`3o000000000?ooo`050?ooo`040000o`3o0000
o`0000000080oooo00<000000?ooo`3oool01P3oool01P000?l0oooo0?ooo`000000o`000?ooo`L0
o`00103oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0003o00H0oooo0P3o000F0?ooo`03
0000o`3oool0oooo0080oooo203o000G0?ooo`80o`001P3oool20?l001H0oooo00<0o`000?ooo`3o
ool04P3oool001H0oooo0P3o000C0?ooo`80o`008`3oool40?l000L0oooo00<0003o0?ooo`3oool0
4P3oool0103o0000oooo0?ooo`0000060?ooo`030000o`3oool0o`000080oooo00<000000?ooo`3o
ool01@3oool01@000?l0oooo0?ooo`3oool0000000<0oooo103o000B0?ooo`030?l0003oool0003o
00H0oooo00@000000?ooo`3oool0o`00503oool00`000?l0oooo0?ooo`040?ooo`D0o`005`3oool2
0?l000X0oooo0P3o000C0?ooo`030?l0003oool0oooo01<0oooo001l0?ooo`040000003oool0oooo
000000P0oooo0`00002E0?ooo`00O03oool010000000oooo0?ooo`0000080?ooo`030000003oool0
oooo09D0oooo001l0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool0U@3oool0
07d0oooo0P0000090?ooo`@00000U03oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.63536, -2.61445, \
0.0112783, 0.0182487}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(picboth = Show[GraphicsArray[{{pic1, pic2}}]]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2943 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00700719 0.47619 [
[ 0 0 0 0 ]
[ 1 .2943 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .2943 L
0 .2943 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00700719 0.477324 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.333333 0.515028 0.206011 [
[0 .50253 -12 -9 ]
[0 .50253 12 0 ]
[.16667 .50253 -6 -9 ]
[.16667 .50253 6 0 ]
[.33333 .50253 -12 -9 ]
[.33333 .50253 12 0 ]
[.66667 .50253 -9 -9 ]
[.66667 .50253 9 0 ]
[.83333 .50253 -3 -9 ]
[.83333 .50253 3 0 ]
[1 .50253 -9 -9 ]
[1 .50253 9 0 ]
[.4875 0 -24 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -24 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -12 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -24 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .51503 m
0 .52128 L
s
[(-1.5)] 0 .50253 0 1 Mshowa
.16667 .51503 m
.16667 .52128 L
s
[(-1)] .16667 .50253 0 1 Mshowa
.33333 .51503 m
.33333 .52128 L
s
[(-0.5)] .33333 .50253 0 1 Mshowa
.66667 .51503 m
.66667 .52128 L
s
[(0.5)] .66667 .50253 0 1 Mshowa
.83333 .51503 m
.83333 .52128 L
s
[(1)] .83333 .50253 0 1 Mshowa
1 .51503 m
1 .52128 L
s
[(1.5)] 1 .50253 0 1 Mshowa
.125 Mabswid
.03333 .51503 m
.03333 .51878 L
s
.06667 .51503 m
.06667 .51878 L
s
.1 .51503 m
.1 .51878 L
s
.13333 .51503 m
.13333 .51878 L
s
.2 .51503 m
.2 .51878 L
s
.23333 .51503 m
.23333 .51878 L
s
.26667 .51503 m
.26667 .51878 L
s
.3 .51503 m
.3 .51878 L
s
.36667 .51503 m
.36667 .51878 L
s
.4 .51503 m
.4 .51878 L
s
.43333 .51503 m
.43333 .51878 L
s
.46667 .51503 m
.46667 .51878 L
s
.53333 .51503 m
.53333 .51878 L
s
.56667 .51503 m
.56667 .51878 L
s
.6 .51503 m
.6 .51878 L
s
.63333 .51503 m
.63333 .51878 L
s
.7 .51503 m
.7 .51878 L
s
.73333 .51503 m
.73333 .51878 L
s
.76667 .51503 m
.76667 .51878 L
s
.8 .51503 m
.8 .51878 L
s
.86667 .51503 m
.86667 .51878 L
s
.9 .51503 m
.9 .51878 L
s
.93333 .51503 m
.93333 .51878 L
s
.96667 .51503 m
.96667 .51878 L
s
.25 Mabswid
0 .51503 m
1 .51503 L
s
.5 0 m
.50625 0 L
s
[(-2.5)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1.5)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(-1)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(-0.5)] .4875 .41202 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(0.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.61111 .61803 m
.62583 .59075 L
.66752 .51344 L
.70762 .43909 L
.7503 .35996 L
.79139 .28378 L
.83505 .20283 L
.87712 .12483 L
.9176 .04978 L
s
.9176 .04978 m
.94444 0 L
s
0 0 1 r
.46548 .61803 m
.49953 .57595 L
.54183 .52366 L
.58254 .47334 L
.62583 .41984 L
.66752 .3683 L
.70762 .31873 L
.7503 .26598 L
.79139 .21519 L
.83505 .16122 L
.87712 .10922 L
.9176 .05919 L
.96065 .00597 L
s
.96065 .00597 m
.96548 0 L
s
.70118 .61803 m
.70762 .61007 L
.7503 .55732 L
.79139 .50654 L
.83505 .45257 L
.87712 .40057 L
.9176 .35053 L
.96065 .29732 L
1 .24868 L
s
.58333 .61803 m
.62583 .56551 L
.66752 .51397 L
.70762 .4644 L
.7503 .41165 L
.79139 .36086 L
.83505 .3069 L
.87712 .2549 L
.9176 .20486 L
.96065 .15164 L
1 .10301 L
s
1 0 0 r
.83333 .61803 m
.83505 .61697 L
.87712 .59097 L
.9176 .56596 L
.96065 .53935 L
1 .51503 L
s
.37799 .61803 m
.41848 .59301 L
.4598 .56747 L
.49953 .54292 L
.54183 .51678 L
.58254 .49162 L
.62583 .46486 L
.66752 .43909 L
.70762 .41431 L
.7503 .38793 L
.79139 .36254 L
.83505 .33556 L
.87712 .30956 L
.9176 .28454 L
.96065 .25793 L
1 .23361 L
s
.95534 .61803 m
.96065 .61475 L
1 .59043 L
s
.12009 .61803 m
.12636 .61416 L
.16632 .58946 L
.20885 .56318 L
.2498 .53787 L
.29331 .51098 L
.33524 .48507 L
.37557 .46014 L
.41848 .43362 L
.4598 .40808 L
.49953 .38353 L
.54183 .35738 L
.58254 .33222 L
.62583 .30547 L
.66752 .2797 L
.70762 .25492 L
.7503 .22854 L
.79139 .20315 L
.83505 .17617 L
.87712 .15017 L
.9176 .12515 L
.96065 .09854 L
1 .07422 L
s
.57656 .61803 m
.58254 .61434 L
.62583 .58759 L
.66752 .56182 L
.70762 .53703 L
.7503 .51066 L
.79139 .48526 L
.83505 .45828 L
.87712 .43228 L
.9176 .40726 L
.96065 .38065 L
1 .35633 L
s
.008 w
.5 .61803 m
.54183 .59218 L
.58254 .56702 L
.62583 .54027 L
.66752 .5145 L
.70762 .48972 L
.7503 .46334 L
.79139 .43795 L
.83505 .41096 L
.87712 .38496 L
.9176 .35994 L
.96065 .33334 L
1 .30902 L
s
.2643 .61803 m
.29331 .6001 L
.33524 .57419 L
.37557 .54926 L
.41848 .52274 L
.4598 .49721 L
.49953 .47265 L
.54183 .44651 L
.58254 .42135 L
.62583 .3946 L
.66752 .36883 L
.70762 .34404 L
.7503 .31767 L
.79139 .29227 L
.83505 .26529 L
.87712 .23929 L
.9176 .21427 L
.96065 .18766 L
1 .16335 L
s
.7357 .61803 m
.7503 .60901 L
.79139 .58362 L
.83505 .55663 L
.87712 .53063 L
.9176 .50562 L
.96065 .47901 L
1 .45469 L
s
0 .392 0 r
.5 Mabswid
0 .32755 m
.04057 .32755 L
.08481 .32755 L
.12636 .32755 L
.16632 .32755 L
.20885 .32755 L
.2498 .32755 L
.29331 .32755 L
.33524 .32755 L
.37557 .32755 L
.41848 .32755 L
.4598 .32755 L
.49953 .32755 L
.54183 .32755 L
.58254 .32755 L
.62583 .32755 L
.66752 .32755 L
.70762 .32755 L
.7503 .32755 L
.79139 .32755 L
.83505 .32755 L
.87712 .32755 L
.9176 .32755 L
.96065 .32755 L
1 .32755 L
s
0 .43962 m
.04057 .43962 L
.08481 .43962 L
.12636 .43962 L
.16632 .43962 L
.20885 .43962 L
.2498 .43962 L
.29331 .43962 L
.33524 .43962 L
.37557 .43962 L
.41848 .43962 L
.4598 .43962 L
.49953 .43962 L
.54183 .43962 L
.58254 .43962 L
.62583 .43962 L
.66752 .43962 L
.70762 .43962 L
.7503 .43962 L
.79139 .43962 L
.83505 .43962 L
.87712 .43962 L
.9176 .43962 L
.96065 .43962 L
1 .43962 L
s
0 .57537 m
.04057 .57537 L
.08481 .57537 L
.12636 .57537 L
.16632 .57537 L
.20885 .57537 L
.2498 .57537 L
.29331 .57537 L
.33524 .57537 L
.37557 .57537 L
.41848 .57537 L
.4598 .57537 L
.49953 .57537 L
.54183 .57537 L
.58254 .57537 L
.62583 .57537 L
.66752 .57537 L
.70762 .57537 L
.7503 .57537 L
.79139 .57537 L
.83505 .57537 L
.87712 .57537 L
.9176 .57537 L
.96065 .57537 L
1 .57537 L
s
.006 w
0 .51503 m
.00123 .51503 L
.00236 .51503 L
.00365 .51503 L
.00488 .51503 L
.00601 .51503 L
.00706 .51503 L
.00821 .51503 L
.00942 .51503 L
.01065 .51503 L
.01196 .51503 L
.0132 .51503 L
.01434 .51503 L
.01566 .51503 L
.01641 .51503 L
.01711 .51503 L
.01839 .51503 L
.01975 .51503 L
.02043 .51503 L
.02115 .51503 L
.02245 .51503 L
.02317 .51503 L
.02384 .51503 L
.02458 .51503 L
.02537 .51503 L
.02605 .51503 L
.02679 .51503 L
.02814 .51503 L
.02945 .51503 L
.03067 .51503 L
.03184 .51503 L
.03295 .51503 L
.03416 .51503 L
.03547 .51503 L
.03676 .51503 L
.03813 .51503 L
.03929 .51503 L
.04057 .51503 L
.04131 .51503 L
.042 .51503 L
.04275 .51503 L
.04355 .51503 L
.0449 .51503 L
.04566 .51503 L
.04637 .51503 L
.0477 .51503 L
.04892 .51503 L
.04959 .51503 L
.05032 .51503 L
.05165 .51503 L
Mistroke
.05245 .51503 L
.05321 .51503 L
.05389 .51503 L
.05462 .51503 L
.05543 .51503 L
.05627 .51503 L
.057 .51503 L
.05779 .51503 L
.05854 .51503 L
.05921 .51503 L
.06 .51503 L
.06074 .51503 L
.06205 .51503 L
.0628 .51503 L
.06349 .51503 L
.06471 .51503 L
.06603 .51503 L
.06727 .51503 L
.06841 .51503 L
.06967 .51503 L
.07105 .51503 L
.07175 .51503 L
.07249 .51503 L
.07383 .51503 L
.07457 .51503 L
.07525 .51503 L
.076 .51503 L
.07679 .51503 L
.07812 .51503 L
.07888 .51503 L
.07959 .51503 L
.0809 .51503 L
.08211 .51503 L
.08349 .51503 L
.08481 .51503 L
.086 .51503 L
.08729 .51503 L
.0885 .51503 L
.08962 .51503 L
.09085 .51503 L
.0922 .51503 L
.09289 .51503 L
.09361 .51503 L
.09493 .51503 L
.09565 .51503 L
.09632 .51503 L
.09705 .51503 L
.09783 .51503 L
.09913 .51503 L
.09987 .51503 L
Mistroke
.10056 .51503 L
.10185 .51503 L
.10303 .51503 L
.10439 .51503 L
.10569 .51503 L
.10691 .51503 L
.10801 .51503 L
.10928 .51503 L
.11048 .51503 L
.1116 .51503 L
.11262 .51503 L
.11375 .51503 L
.11493 .51503 L
.11613 .51503 L
.11742 .51503 L
.11864 .51503 L
.11974 .51503 L
.12104 .51503 L
.12178 .51503 L
.12245 .51503 L
.1237 .51503 L
.12502 .51503 L
.12622 .51503 L
.12753 .51503 L
.12889 .51503 L
.13016 .51503 L
.13135 .51503 L
.13244 .51503 L
.13369 .51503 L
.13487 .51503 L
.13616 .51503 L
.13752 .51503 L
.13868 .51503 L
.13996 .51503 L
.14134 .51503 L
.14211 .51503 L
.14281 .51503 L
.14418 .51503 L
.14548 .51503 L
.14669 .51503 L
.14779 .51503 L
.14906 .51503 L
.15025 .51503 L
.15136 .51503 L
.15237 .51503 L
.15349 .51503 L
.15467 .51503 L
.15586 .51503 L
.15714 .51503 L
.15835 .51503 L
Mistroke
.15945 .51503 L
.16074 .51503 L
.16146 .51503 L
.16214 .51503 L
.16337 .51503 L
.16468 .51503 L
.16594 .51503 L
.16732 .51503 L
.16863 .51503 L
.16984 .51503 L
.17103 .51503 L
.17212 .51503 L
.17337 .51503 L
.17456 .51503 L
.17585 .51503 L
.17721 .51503 L
.17838 .51503 L
.17966 .51503 L
.18104 .51503 L
.18181 .51503 L
.18251 .51503 L
.18388 .51503 L
.18518 .51503 L
.18628 .51503 L
.1875 .51503 L
.18877 .51503 L
.18996 .51503 L
.19107 .51503 L
.19209 .51503 L
.19321 .51503 L
.19438 .51503 L
.19558 .51503 L
.19686 .51503 L
.19807 .51503 L
.19916 .51503 L
.20045 .51503 L
.20118 .51503 L
.20185 .51503 L
.20309 .51503 L
.20439 .51503 L
.20566 .51503 L
.20705 .51503 L
.20835 .51503 L
.20957 .51503 L
.21077 .51503 L
.21186 .51503 L
.21311 .51503 L
.2143 .51503 L
.21559 .51503 L
.21696 .51503 L
Mistroke
.21813 .51503 L
.21941 .51503 L
.22079 .51503 L
.22157 .51503 L
.22227 .51503 L
.22364 .51503 L
.22494 .51503 L
.22604 .51503 L
.22726 .51503 L
.22853 .51503 L
.22973 .51503 L
.23084 .51503 L
.23186 .51503 L
.23297 .51503 L
.23415 .51503 L
.23535 .51503 L
.23663 .51503 L
.23784 .51503 L
.23893 .51503 L
.24023 .51503 L
.24095 .51503 L
.24163 .51503 L
.24286 .51503 L
.24416 .51503 L
.24544 .51503 L
.24683 .51503 L
.24814 .51503 L
.24935 .51503 L
.25044 .51503 L
.25165 .51503 L
.25291 .51503 L
.25409 .51503 L
.25539 .51503 L
.25676 .51503 L
.25793 .51503 L
.25922 .51503 L
.2606 .51503 L
.26137 .51503 L
.26208 .51503 L
.26345 .51503 L
.26475 .51503 L
.26586 .51503 L
.26708 .51503 L
.26835 .51503 L
.26954 .51503 L
.27066 .51503 L
.27168 .51503 L
.27286 .51503 L
.27397 .51503 L
.27518 .51503 L
Mistroke
.27646 .51503 L
.27767 .51503 L
.27876 .51503 L
.28005 .51503 L
.28078 .51503 L
.28145 .51503 L
.28268 .51503 L
.28399 .51503 L
.28527 .51503 L
.28599 .51503 L
.28666 .51503 L
.28789 .51503 L
.28919 .51503 L
.29036 .51503 L
.29145 .51503 L
.29265 .51503 L
.29394 .51503 L
.29524 .51503 L
.29597 .51503 L
.29665 .51503 L
.29803 .51503 L
.29881 .51503 L
.29951 .51503 L
.30077 .51503 L
.30213 .51503 L
.30342 .51503 L
.30461 .51503 L
.30572 .51503 L
.30691 .51503 L
.30804 .51503 L
.30907 .51503 L
.31027 .51503 L
.31158 .51503 L
.31282 .51503 L
.31396 .51503 L
.31526 .51503 L
.31648 .51503 L
.31758 .51503 L
.31876 .51503 L
.32005 .51503 L
.32142 .51503 L
.32259 .51503 L
.32386 .51503 L
.32524 .51503 L
.32651 .51503 L
.32718 .51503 L
.32791 .51503 L
.32867 .51503 L
.32939 .51503 L
.3307 .51503 L
Mistroke
.3319 .51503 L
.33329 .51503 L
.33461 .51503 L
.33578 .51503 L
.33704 .51503 L
.33822 .51503 L
.33929 .51503 L
.34055 .51503 L
.34192 .51503 L
.34321 .51503 L
.3444 .51503 L
.34567 .51503 L
.34703 .51503 L
.34831 .51503 L
.34949 .51503 L
.35086 .51503 L
.35164 .51503 L
.35236 .51503 L
.35368 .51503 L
.35434 .51503 L
.35508 .51503 L
.35579 .51503 L
.35654 .51503 L
.35788 .51503 L
.35863 .51503 L
.35932 .51503 L
.36009 .51503 L
.3609 .51503 L
.36161 .51503 L
.36238 .51503 L
.3631 .51503 L
.36377 .51503 L
.36503 .51503 L
.36637 .51503 L
.36764 .51503 L
.36902 .51503 L
.37033 .51503 L
.37154 .51503 L
.37274 .51503 L
.37383 .51503 L
.37509 .51503 L
.37627 .51503 L
.37756 .51503 L
.37893 .51503 L
.3801 .51503 L
.38138 .51503 L
.38276 .51503 L
.38353 .51503 L
.38424 .51503 L
.38561 .51503 L
Mistroke
.38691 .51503 L
.38801 .51503 L
.38923 .51503 L
.3905 .51503 L
.39169 .51503 L
.3928 .51503 L
.39382 .51503 L
.39494 .51503 L
.39612 .51503 L
.39732 .51503 L
.3986 .51503 L
.3998 .51503 L
.4009 .51503 L
.40219 .51503 L
.40292 .51503 L
.40359 .51503 L
.40482 .51503 L
.40613 .51503 L
.4074 .51503 L
.40879 .51503 L
.4101 .51503 L
.41132 .51503 L
.41252 .51503 L
.41361 .51503 L
.41487 .51503 L
.41605 .51503 L
.41735 .51503 L
.41872 .51503 L
.41989 .51503 L
.42117 .51503 L
.42256 .51503 L
.42333 .51503 L
.42404 .51503 L
.42541 .51503 L
.4267 .51503 L
.42781 .51503 L
.42903 .51503 L
.43031 .51503 L
.4315 .51503 L
.43261 .51503 L
.43363 .51503 L
.43481 .51503 L
.43593 .51503 L
.43713 .51503 L
.43841 .51503 L
.43962 .51503 L
.44071 .51503 L
.44201 .51503 L
.44273 .51503 L
.4434 .51503 L
Mistroke
.44464 .51503 L
.44594 .51503 L
.44722 .51503 L
.44794 .51503 L
.44861 .51503 L
.44984 .51503 L
.45114 .51503 L
.45231 .51503 L
.4534 .51503 L
.4546 .51503 L
.45589 .51503 L
.45718 .51503 L
.45792 .51503 L
.4586 .51503 L
.45998 .51503 L
.46075 .51503 L
.46145 .51503 L
.46271 .51503 L
.46408 .51503 L
.46537 .51503 L
.46656 .51503 L
.46766 .51503 L
.46886 .51503 L
.46998 .51503 L
.47101 .51503 L
.47221 .51503 L
.47352 .51503 L
.47476 .51503 L
.4759 .51503 L
.4772 .51503 L
.47842 .51503 L
.47952 .51503 L
.4807 .51503 L
.48199 .51503 L
.48336 .51503 L
.48453 .51503 L
.4858 .51503 L
.48718 .51503 L
.48845 .51503 L
.48911 .51503 L
.48984 .51503 L
.49061 .51503 L
.49132 .51503 L
.49264 .51503 L
.49384 .51503 L
.49516 .51503 L
.49655 .51503 L
.49772 .51503 L
.49897 .51503 L
.50015 .51503 L
Mistroke
.50122 .51503 L
.50248 .51503 L
.50385 .51503 L
.50514 .51503 L
.50633 .51503 L
.5076 .51503 L
.50896 .51503 L
.51024 .51503 L
.51142 .51503 L
.51279 .51503 L
.51357 .51503 L
.51429 .51503 L
.5156 .51503 L
.51627 .51503 L
.51701 .51503 L
.51772 .51503 L
.51847 .51503 L
.51981 .51503 L
.52055 .51503 L
.52125 .51503 L
.52201 .51503 L
.52283 .51503 L
.52354 .51503 L
.5243 .51503 L
.52503 .51503 L
.52569 .51503 L
.52696 .51503 L
.5283 .51503 L
.52957 .51503 L
.53095 .51503 L
.53225 .51503 L
.53347 .51503 L
.53467 .51503 L
.53575 .51503 L
.53701 .51503 L
.53819 .51503 L
.53948 .51503 L
.54085 .51503 L
.54202 .51503 L
.5433 .51503 L
.54468 .51503 L
.54545 .51503 L
.54616 .51503 L
.54753 .51503 L
.54882 .51503 L
.54993 .51503 L
.55114 .51503 L
.55241 .51503 L
.55361 .51503 L
.55472 .51503 L
Mistroke
.55574 .51503 L
.55685 .51503 L
.55803 .51503 L
.55923 .51503 L
.56051 .51503 L
.56172 .51503 L
.56281 .51503 L
.5641 .51503 L
.56483 .51503 L
.5655 .51503 L
.56674 .51503 L
.56804 .51503 L
.56932 .51503 L
.5707 .51503 L
.57201 .51503 L
.57323 .51503 L
.57443 .51503 L
.57552 .51503 L
.57678 .51503 L
.57796 .51503 L
.57926 .51503 L
.58063 .51503 L
.5818 .51503 L
.58308 .51503 L
.58446 .51503 L
.58524 .51503 L
.58594 .51503 L
.58731 .51503 L
.58861 .51503 L
.58971 .51503 L
.59093 .51503 L
.59221 .51503 L
.5934 .51503 L
.59451 .51503 L
.59553 .51503 L
.59671 .51503 L
.59783 .51503 L
.59903 .51503 L
.60031 .51503 L
.60152 .51503 L
.60261 .51503 L
.60391 .51503 L
.60463 .51503 L
.6053 .51503 L
.60654 .51503 L
.60784 .51503 L
.60912 .51503 L
.60984 .51503 L
.61051 .51503 L
.61174 .51503 L
Mistroke
.61304 .51503 L
.6142 .51503 L
.61529 .51503 L
.61649 .51503 L
.61778 .51503 L
.61908 .51503 L
.61981 .51503 L
.62049 .51503 L
.62187 .51503 L
.62264 .51503 L
.62335 .51503 L
.6246 .51503 L
.62597 .51503 L
.62726 .51503 L
.62845 .51503 L
.62955 .51503 L
.63075 .51503 L
.63187 .51503 L
.6329 .51503 L
.6341 .51503 L
.63541 .51503 L
.63665 .51503 L
.63779 .51503 L
.63909 .51503 L
.64031 .51503 L
.6414 .51503 L
.64259 .51503 L
.64388 .51503 L
.64525 .51503 L
.64641 .51503 L
.64769 .51503 L
.64907 .51503 L
.65034 .51503 L
.651 .51503 L
.65173 .51503 L
.65249 .51503 L
.65321 .51503 L
.65452 .51503 L
.65572 .51503 L
.65704 .51503 L
.65843 .51503 L
.6596 .51503 L
.66085 .51503 L
.66203 .51503 L
.6631 .51503 L
.66436 .51503 L
.66573 .51503 L
.66702 .51503 L
.66821 .51503 L
.66947 .51503 L
Mistroke
.67083 .51503 L
.67212 .51503 L
.67329 .51503 L
.67467 .51503 L
.67544 .51503 L
.67616 .51503 L
.67748 .51503 L
.67815 .51503 L
.67888 .51503 L
.67959 .51503 L
.68034 .51503 L
.68168 .51503 L
.68243 .51503 L
.68312 .51503 L
.68389 .51503 L
.6847 .51503 L
.68541 .51503 L
.68618 .51503 L
.6869 .51503 L
.68757 .51503 L
.68883 .51503 L
.69018 .51503 L
.69144 .51503 L
.69282 .51503 L
.69413 .51503 L
.69534 .51503 L
.69654 .51503 L
.69762 .51503 L
.69888 .51503 L
.70006 .51503 L
.70135 .51503 L
.70272 .51503 L
.70388 .51503 L
.70517 .51503 L
.70654 .51503 L
.70732 .51503 L
.70802 .51503 L
.70939 .51503 L
.71069 .51503 L
.71179 .51503 L
.71301 .51503 L
.71428 .51503 L
.71547 .51503 L
.71658 .51503 L
.7176 .51503 L
.71872 .51503 L
.71989 .51503 L
.72109 .51503 L
.72237 .51503 L
.72358 .51503 L
Mistroke
.72468 .51503 L
.72597 .51503 L
.72669 .51503 L
.72737 .51503 L
.7286 .51503 L
.72991 .51503 L
.73118 .51503 L
.73256 .51503 L
.73387 .51503 L
.73508 .51503 L
.73629 .51503 L
.73738 .51503 L
.73863 .51503 L
.73982 .51503 L
.74111 .51503 L
.74248 .51503 L
.74365 .51503 L
.74493 .51503 L
.74631 .51503 L
.74709 .51503 L
.74779 .51503 L
.74916 .51503 L
.75046 .51503 L
.75157 .51503 L
.75279 .51503 L
.75406 .51503 L
.75525 .51503 L
.75636 .51503 L
.75738 .51503 L
.7585 .51503 L
.75968 .51503 L
.76088 .51503 L
.76216 .51503 L
.76337 .51503 L
.76446 .51503 L
.76575 .51503 L
.76648 .51503 L
.76715 .51503 L
.76839 .51503 L
.76969 .51503 L
.77097 .51503 L
.77169 .51503 L
.77236 .51503 L
.77358 .51503 L
.77489 .51503 L
.77605 .51503 L
.77714 .51503 L
.77834 .51503 L
.77963 .51503 L
.78092 .51503 L
Mistroke
.78165 .51503 L
.78233 .51503 L
.78371 .51503 L
.78448 .51503 L
.78519 .51503 L
.78644 .51503 L
.78781 .51503 L
.7891 .51503 L
.79029 .51503 L
.79139 .51503 L
.79258 .51503 L
.79371 .51503 L
.79473 .51503 L
.79593 .51503 L
.79724 .51503 L
.79848 .51503 L
.79963 .51503 L
.80093 .51503 L
.80214 .51503 L
.80324 .51503 L
.80442 .51503 L
.80572 .51503 L
.80708 .51503 L
.80825 .51503 L
.80953 .51503 L
.8109 .51503 L
.81217 .51503 L
.81283 .51503 L
.81356 .51503 L
.81432 .51503 L
.81504 .51503 L
.81635 .51503 L
.81755 .51503 L
.81887 .51503 L
.82026 .51503 L
.82143 .51503 L
.82268 .51503 L
.82386 .51503 L
.82493 .51503 L
.82619 .51503 L
.82755 .51503 L
.82884 .51503 L
.83003 .51503 L
.8313 .51503 L
.83266 .51503 L
.83394 .51503 L
.83512 .51503 L
.83649 .51503 L
.83727 .51503 L
.83798 .51503 L
Mistroke
.8393 .51503 L
.84004 .51503 L
.84071 .51503 L
.84142 .51503 L
.84216 .51503 L
.8435 .51503 L
.84425 .51503 L
.84495 .51503 L
.84571 .51503 L
.84653 .51503 L
.84723 .51503 L
.848 .51503 L
.84872 .51503 L
.84939 .51503 L
.85066 .51503 L
.852 .51503 L
.85326 .51503 L
.85464 .51503 L
.85595 .51503 L
.85716 .51503 L
.85835 .51503 L
.85944 .51503 L
.86069 .51503 L
.86188 .51503 L
.86317 .51503 L
.86453 .51503 L
.8657 .51503 L
.86698 .51503 L
.86836 .51503 L
.86913 .51503 L
.86984 .51503 L
.87121 .51503 L
.8725 .51503 L
.8736 .51503 L
.87482 .51503 L
.87609 .51503 L
.87728 .51503 L
.87839 .51503 L
.87941 .51503 L
.88053 .51503 L
.8817 .51503 L
.8829 .51503 L
.88418 .51503 L
.88539 .51503 L
.88649 .51503 L
.88778 .51503 L
.8885 .51503 L
.88918 .51503 L
.89041 .51503 L
.89172 .51503 L
Mistroke
.89299 .51503 L
.89437 .51503 L
.89568 .51503 L
.89689 .51503 L
.89809 .51503 L
.89918 .51503 L
.90044 .51503 L
.90162 .51503 L
.90292 .51503 L
.90428 .51503 L
.90545 .51503 L
.90673 .51503 L
.90812 .51503 L
.90889 .51503 L
.90959 .51503 L
.91096 .51503 L
.91226 .51503 L
.91337 .51503 L
.91458 .51503 L
.91586 .51503 L
.91705 .51503 L
.91816 .51503 L
.91918 .51503 L
.9203 .51503 L
.92148 .51503 L
.92268 .51503 L
.92396 .51503 L
.92516 .51503 L
.92626 .51503 L
.92755 .51503 L
.92828 .51503 L
.92895 .51503 L
.93018 .51503 L
.93149 .51503 L
.93276 .51503 L
.93348 .51503 L
.93415 .51503 L
.93538 .51503 L
.93668 .51503 L
.93784 .51503 L
.93893 .51503 L
.94013 .51503 L
.94142 .51503 L
.94271 .51503 L
.94344 .51503 L
.94412 .51503 L
.9455 .51503 L
.94627 .51503 L
.94697 .51503 L
.94823 .51503 L
Mistroke
.9496 .51503 L
.95089 .51503 L
.95207 .51503 L
.95318 .51503 L
.95437 .51503 L
.95549 .51503 L
.95652 .51503 L
.95772 .51503 L
.95903 .51503 L
.96027 .51503 L
.96141 .51503 L
.96271 .51503 L
.96393 .51503 L
.96502 .51503 L
.96621 .51503 L
.9675 .51503 L
.96887 .51503 L
.97003 .51503 L
.97131 .51503 L
.97224 .51503 L
.9731 .51503 L
.97404 .51503 L
.97503 .51503 L
.9759 .51503 L
.97671 .51503 L
.9776 .51503 L
.97856 .51503 L
.97936 .51503 L
.98024 .51503 L
.98115 .51503 L
.982 .51503 L
.9828 .51503 L
.98353 .51503 L
.98437 .51503 L
.98516 .51503 L
.98602 .51503 L
.98696 .51503 L
.98795 .51503 L
.98887 .51503 L
.98973 .51503 L
.99051 .51503 L
.99142 .51503 L
.99228 .51503 L
.99321 .51503 L
.9942 .51503 L
.99513 .51503 L
.99598 .51503 L
.99697 .51503 L
.99805 .51503 L
.99907 .51503 L
Mistroke
1 .51503 L
Mfstroke
1 0 0 r
.5 Mabswid
[ .01 .01 ] 0 setdash
0 .51503 m
.04057 .5401 L
.08481 .56744 L
.12636 .59312 L
.16632 .61782 L
s
.16632 .61782 m
.16667 .61803 L
s
0 .23361 m
.04057 .25868 L
.08481 .28603 L
.12636 .31171 L
.16632 .3364 L
.20885 .36269 L
.2498 .38799 L
.29331 .41489 L
.33524 .4408 L
.37557 .46573 L
.41848 .49225 L
.4598 .51779 L
.49953 .54234 L
.54183 .56848 L
.58254 .59364 L
s
.58254 .59364 m
.62201 .61803 L
s
0 .59043 m
.04057 .61551 L
s
.04057 .61551 m
.04466 .61803 L
s
0 .07422 m
.04057 .09929 L
.08481 .12664 L
.12636 .15231 L
.16632 .17701 L
.20885 .2033 L
.2498 .2286 L
.29331 .2555 L
.33524 .28141 L
.37557 .30634 L
.41848 .33286 L
.4598 .35839 L
.49953 .38295 L
.54183 .40909 L
.58254 .43425 L
.62583 .461 L
.66752 .48677 L
.70762 .51156 L
.7503 .53793 L
.79139 .56332 L
.83505 .59031 L
.87712 .61631 L
s
.87712 .61631 m
.87991 .61803 L
s
0 .35633 m
.04057 .38141 L
.08481 .40875 L
.12636 .43443 L
.16632 .45912 L
.20885 .48541 L
.2498 .51072 L
.29331 .53761 L
.33524 .56352 L
.37557 .58845 L
.41848 .61497 L
s
.41848 .61497 m
.42344 .61803 L
s
.008 w
0 .30902 m
.04057 .33409 L
.08481 .36143 L
.12636 .38711 L
.16632 .41181 L
.20885 .43809 L
.2498 .4634 L
.29331 .49029 L
.33524 .51621 L
.37557 .54113 L
.41848 .56765 L
.4598 .59319 L
.49953 .61774 L
s
.49953 .61774 m
.5 .61803 L
s
0 .16335 m
.04057 .18842 L
.08481 .21576 L
.12636 .24144 L
.16632 .26614 L
.20885 .29242 L
.2498 .31773 L
.29331 .34462 L
.33524 .37053 L
.37557 .39546 L
.41848 .42198 L
.4598 .44752 L
.49953 .47207 L
.54183 .49822 L
.58254 .52338 L
.62583 .55013 L
.66752 .5759 L
.70762 .60068 L
s
.70762 .60068 m
.7357 .61803 L
s
0 .45469 m
.04057 .47976 L
.08481 .5071 L
.12636 .53278 L
.16632 .55748 L
.20885 .58377 L
.2498 .60907 L
s
.2498 .60907 m
.2643 .61803 L
s
0 0 1 r
.5 Mabswid
0 .10301 m
.04057 .15315 L
.08481 .20784 L
.12636 .25919 L
.16632 .30859 L
.20885 .36116 L
.2498 .41177 L
.29331 .46556 L
.33524 .51738 L
.37557 .56724 L
s
.37557 .56724 m
.41667 .61803 L
s
.03452 0 m
.04057 .00748 L
.08481 .06216 L
.12636 .11352 L
.16632 .16291 L
.20885 .21549 L
.2498 .2661 L
.29331 .31989 L
.33524 .37171 L
.37557 .42157 L
.41848 .47461 L
.4598 .52568 L
.49953 .57479 L
s
.49953 .57479 m
.53452 .61803 L
s
0 .24868 m
.04057 .29882 L
.08481 .35351 L
.12636 .40487 L
.16632 .45426 L
.20885 .50683 L
.2498 .55744 L
.29331 .61123 L
s
.29331 .61123 m
.29882 .61803 L
s
0 g
.05556 0 m
.08481 .05424 L
.12636 .13128 L
.16632 .20537 L
.20885 .28423 L
.2498 .36014 L
.29331 .44083 L
.33524 .51856 L
.37557 .59335 L
s
.37557 .59335 m
.38889 .61803 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00700719 0.97619 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.5 1 0.0280925 0.0561849 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.004 w
[ ] 0 setdash
0 .08428 m
.5 .08428 L
s
gsave
.7 .08428 -83.0938 -9.03125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.0625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 11.250 moveto
(8) show
69.000 11.250 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
75.625 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
81.625 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
91.188 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
97.188 11.250 moveto
(<) show
1.000 setlinewidth
grestore
0 0 1 r
0 .14046 m
.5 .14046 L
s
gsave
.7 .14046 -86.1875 -14.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
63.000 17.250 moveto
(9) show
69.000 17.250 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(-) show
75.625 17.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(2) show
81.625 17.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(,) show
94.250 11.188 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(1) show
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
93.000 17.250 moveto
(\\200) show
95.062 17.250 moveto
(\\200) show
97.125 17.250 moveto
(\\200) show
99.188 17.250 moveto
(\\200) show
99.625 17.250 moveto
(\\200) show
94.250 23.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(2) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
103.375 17.250 moveto
(=) show
1.000 setlinewidth
grestore
1 0 0 r
0 .19665 m
.5 .19665 L
s
gsave
.7 .19665 -83.0938 -9.03125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.0625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
63.000 11.250 moveto
(8) show
69.000 11.250 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(-) show
75.625 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(1) show
81.625 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(,) show
91.188 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(0) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
97.188 11.250 moveto
(<) show
1.000 setlinewidth
grestore
.008 w
0 .25283 m
.5 .25283 L
s
gsave
.7 .25283 -83.0938 -9.03125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.0625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
63.000 11.250 moveto
(8) show
69.000 11.250 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(-) show
75.625 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(1) show
81.625 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(,) show
91.188 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
97.188 11.250 moveto
(<) show
1.000 setlinewidth
grestore
0 .392 0 r
.004 w
0 .30902 m
.5 .30902 L
s
gsave
.7 .30902 -82.875 -14.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.392 0.000 setrgbcolor
63.000 17.250 moveto
(9) show
69.000 17.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.392 0.000 setrgbcolor
(0) show
75.000 17.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.392 0.000 setrgbcolor
(,) show
87.625 11.188 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.392 0.000 setrgbcolor
(1) show
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.392 0.000 setrgbcolor
86.375 17.250 moveto
(\\200) show
88.438 17.250 moveto
(\\200) show
90.500 17.250 moveto
(\\200) show
92.562 17.250 moveto
(\\200) show
93.000 17.250 moveto
(\\200) show
87.625 23.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.392 0.000 setrgbcolor
(2) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.392 0.000 setrgbcolor
96.750 17.250 moveto
(=) show
1.000 setlinewidth
grestore
.006 w
0 .3652 m
.5 .3652 L
s
gsave
.7 .3652 -82.875 -14.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.392 0.000 setrgbcolor
63.000 17.250 moveto
(9) show
69.000 17.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.392 0.000 setrgbcolor
(0) show
75.000 17.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.392 0.000 setrgbcolor
(,) show
87.625 11.188 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.392 0.000 setrgbcolor
(3) show
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.392 0.000 setrgbcolor
86.375 17.250 moveto
(\\200) show
88.438 17.250 moveto
(\\200) show
90.500 17.250 moveto
(\\200) show
92.562 17.250 moveto
(\\200) show
93.000 17.250 moveto
(\\200) show
87.625 23.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.392 0.000 setrgbcolor
(2) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.392 0.000 setrgbcolor
96.750 17.250 moveto
(=) show
1.000 setlinewidth
grestore
1 0 0 r
.004 w
[ .01 .01 ] 0 setdash
0 .42139 m
.5 .42139 L
s
gsave
.7 .42139 -79.7812 -9.03125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.0625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
63.000 11.250 moveto
(8) show
69.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(1) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(,) show
84.562 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(0) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
90.562 11.250 moveto
(<) show
1.000 setlinewidth
grestore
.008 w
0 .47757 m
.5 .47757 L
s
gsave
.7 .47757 -79.7812 -9.03125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.0625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
63.000 11.250 moveto
(8) show
69.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(1) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(,) show
84.562 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
90.562 11.250 moveto
(<) show
1.000 setlinewidth
grestore
0 0 1 r
.004 w
0 .53376 m
.5 .53376 L
s
gsave
.7 .53376 -82.875 -14.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
63.000 17.250 moveto
(9) show
69.000 17.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(2) show
75.000 17.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(,) show
87.625 11.188 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(1) show
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
86.375 17.250 moveto
(\\200) show
88.438 17.250 moveto
(\\200) show
90.500 17.250 moveto
(\\200) show
92.562 17.250 moveto
(\\200) show
93.000 17.250 moveto
(\\200) show
87.625 23.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(2) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
96.750 17.250 moveto
(=) show
1.000 setlinewidth
grestore
0 g
0 .58994 m
.5 .58994 L
s
gsave
.7 .58994 -79.7812 -9.03125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.0625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 11.250 moveto
(8) show
69.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
75.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
84.562 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
90.562 11.250 moveto
(<) show
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{825, 242.75},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000<i0000lR000`400?l00000o`00003oo`3ooooo
0?ooool0oooo?03oool00?l0ooooo`3ooooo0?oooc`0oooo003o0?ooool0ooooo`3oooll0?ooo`00
o`3ooooo0?ooool0oooo?03oool00?l0ooooo`3ooooo0?oooc`0oooo003o0?ooool0ooooo`3oooll
0?ooo`00o`3ooooo0?ooool0oooo?03oool00?l0ooooo`3ooooo0?oooc`0oooo003o0?ooool0oooo
o`3oooll0?ooo`00o`3ooooo0?ooool0oooo?03oool00;/0oooo100000030?ooo`030000003oool0
oooo0080oooo0`00003o0?ooool0ooooL@3oool00;/0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`3o0?ooool0ooooKP3oool002`0oooo00<0003o0?ooo`3oool01@3oool00`000000
oooo0?ooo`250?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool3000009T0
oooo00<000000?ooo`3oool01@3oool00`000?l0oooo0?ooo`3o0?oool<0oooo000]0?ooo`030000
o`3oool0oooo00@0oooo00<000000?ooo`3oool0OP3oool4000000@0oooo00<000000?ooo`3oool0
1`3oool3000000H0oooo00<000000?ooo`3oool0V03oool00`000000oooo0?ooo`050?ooo`030000
o`3oool0oooo0?l0ooooa03oool002h0oooo00<0003o0?ooo`3oool0103oool00`000000oooo0?oo
o`260?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`2H0?ooo`030000003oool0oooo00@0oooo00<0003o0?ooo`3oool0o`3oooo50?ooo`00;`3oool0
0`000?l0oooo0?ooo`030?ooo`030000003oool0oooo08<0oooo00@000000?ooo`3oool00000203o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo09L0oooo00<000000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`3o0?ooolH0oooo002l0?ooo`8000002@3oool4000000D0oooo00<00000
0?ooo`3oool0U`3oool00`000000oooo0?ooo`030?ooo`030000o`3oool0oooo0?l0ooooa`3oool0
0=00oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`040?ooo`030000o`3oool0oooo
0?l0ooooa`3oool00340oooo00<0003o0?ooo`3oool00`3oool00`000000oooo0?ooo`2F0?ooo`03
0000003oool0oooo09H0oooo00<000000?ooo`3oool00`3oool00`000?l0oooo0?ooo`3o0?ooolP0
oooo000b0?ooo`030000o`3oool0oooo00<0oooo00<000000?ooo`3oool0U@3oool2000009H0oooo
00<000000?ooo`3oool00`3oool00`000?l0oooo0?ooo`3o0?ooolT0oooo000c0?ooo`030000o`3o
ool0oooo0080oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`2E0?ooo`030000003o
ool0oooo0080oooo00<0003o0?ooo`3oool0o`3oooo:0?ooo`00>@3oool00`000000oooo0?ooo`2D
0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool00P3oool00`000?l0oooo0?ooo`3o
0?oool/0oooo003@0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`3o0?oool/0oooo000e0?ooo`030000o`3oool0oooo09P0oooo00<000000?ooo`3o
ool0T`3oool00`000000oooo0?ooo`020?ooo`030000o`3oool0oooo0?l0ooooc03oool003H0oooo
00<0003o0?ooo`3oool00P3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo09<0oooo
00D000000?ooo`3oool0oooo0000o`3o0?oooll0oooo000f0?ooo`030000o`3oool0oooo0080oooo
00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`2B0?ooo`050000003oool0oooo0?ooo`00
0?l0o`3oooo@0?ooo`00=`3oool01@000?l0oooo0?ooo`3oool0000009@0oooo00<000000?ooo`3o
ool0TP3oool01@000000oooo0?ooo`3oool0003o0?l0ooood03oool003`0oooo00<000000?ooo`3o
ool0T@3oool200000980oooo00D000000?ooo`3oool0oooo0000o`3o0?ooom40oooo000j0?ooo`03
0000o`3oool0000009<0oooo00<000000?ooo`3oool0T@3oool010000000oooo0?ooo`000?oo0?oo
om80oooo000k0?ooo`030000o`3oool0oooo0980oooo00<000000?ooo`3oool0T03oool010000000
oooo0?ooo`000?oo0?ooom<0oooo000k0?ooo`030000o`3oool0oooo0980oooo00<000000?ooo`3o
ool0T03oool00`000000oooo0000o`3o0?ooom@0oooo000l0?ooo`030000o`3oool000000940oooo
00<000000?ooo`3oool0S`3oool010000000oooo0?ooo`000?oo0?ooom@0oooo000o0?ooo`030000
003oool0oooo08h0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0000o`3o0?ooomD0oooo
000o0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0000
o`3o0?ooomH0oooo000n0?ooo`030000o`3oool0000008l0oooo0P00002?0?ooo`03000000000?l0
oooo0?l0oooo@03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0M03oool003l0oooo00<0003o0?ooo`3oool0SP3oool00`000000oooo0?ooo`2=0?oo
o`03000000000?l0oooo0?l0oooo@03oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0L`3oool003l0oooo00<0003o0?ooo`3oool0SP3oool00`000000
oooo0?ooo`2=0?ooo`03000000000?l0oooo0?l0oooo@03oool00`000000oooo0?ooo`080?ooo`80
0000103oool00`000000oooo0?ooo`070?ooo`800000103oool00`000000oooo0?ooo`1c0?ooo`00
@03oool00`000?l000000?ooo`2=0?ooo`030000003oool0oooo08`0oooo00<000000000o`3oool0
C03ooonk000003T0oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`00000<0?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`3oool0L`3oool00200oooo00<0o`000?ooo`3o
ool07`3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo08`0oooo00<0003o0?ooo`3o
ool07P3oool00`3o0000oooo0?ooo`3o0?oooal0oooo00<000000?ooo`3oool00P3oool4000000D0
oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
0780oooo000Q0?ooo`80o`007`3oool00`000000003o0?ooo`2;0?ooo`030000003oool0oooo08/0
oooo00<0003o0?ooo`3oool07@3oool20?l00?l0oooo8`3oool00`000000oooo0?ooo`080?ooo`80
00003@3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo07<0oooo000S0?ooo`03
0?l0003oool0oooo01d0oooo00<000000000o`3oool0RP3oool00`000000oooo0?ooo`2:0?ooo`03
0000o`000000oooo01d0oooo00<0o`000?ooo`3oool0o`3ooolS0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo
07<0oooo00140?ooo`030000o`3oool0oooo08T0oooo0P00002:0?ooo`030000o`000000oooo01`0
oooo0P3o003o0?ooobL0oooo00<000000?ooo`3oool01P3oool010000000oooo0?ooo`00000<0?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool0M03oool002H0oooo00<0o`000?oo
o`3oool0703oool00`000?l0oooo0?ooo`280?ooo`030000003oool0oooo08T0oooo00<0003o0000
003oool06`3oool00`3o0000oooo0?ooo`3o0?oooc40oooo0P00000>0?ooo`800000NP3oool002L0
oooo0P3o000L0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0R03oool00`000?l0
00000?ooo`0J0?ooo`80o`00o`3oooo00?ooo`00:@3oool00`3o0000oooo0?ooo`0I0?ooo`030000
003oool0oooo08P0oooo00<000000?ooo`3oool0Q`3oool00`000?l000000?ooo`0I0?ooo`80o`00
o`3oooo20?ooo`00AP3oool00`000000003o0?ooo`270?ooo`030000003oool0oooo08H0oooo00<0
003o0?ooo`0000006@3oool00`3o0000oooo0?ooo`3o0?oool80oooo000/0?ooo`80o`00603oool0
0`000000oooo0000o`1n0?ooo`@000001@3oool00`000000oooo0?ooo`250?ooo`030000o`3oool0
000001P0oooo0P3o003o0?ooolD0oooo000^0?ooo`80o`00603oool00`000?l0oooo0?ooo`1l0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0Q03oool010000?l0oooo0?ooo`00000G
0?ooo`030?l0003oool0oooo0?l0ooooa@3oool00200oooo00<0003o0?ooo`3oool09P3oool00`00
0?l0oooo0?ooo`1l0?ooo`030000003oool0oooo00D0oooo0`0000240?ooo`030000o`3oool00000
01H0oooo0P3o000>0?ooo`030000o`3oool0oooo0?l0oooo]`3oool00240oooo00<0003o0?ooo`3o
ool03P3oool00`3o0000oooo0?ooo`0C0?ooo`030000003oool0oooo07H0oooo100000040?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0P`3oool010000?l0oooo0?ooo`00000D0?oo
o`80o`003`3oool00`000?l0oooo0?ooo`3o0?oookP0oooo000R0?ooo`030000o`3oool0oooo00h0
oooo0P3o000D0?ooo`030000003oool0003o07h0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`220?ooo`040000o`3oool0oooo000001@0oooo00<0o`000?ooo`3oool03P3oool00`00
0?l0oooo0?ooo`3o0?oooc`0oooo10000?mi0?ooo`008`3oool00`000?l0oooo0?ooo`0?0?ooo`03
0?l0003oool0oooo0140oooo00@000000?ooo`3oool0003oNP3oool010000000oooo0?ooo`000005
0?ooo`030000003oool0oooo0840oooo00D0003o0?ooo`3oool0oooo0000000B0?ooo`80o`004@3o
ool00`000?l0oooo0?ooo`3o0?oooc`0oooo00<0003o0?ooo`3oool0NP3oool004X0oooo00@00000
0?ooo`3oool0003oNP3oool2000000H0oooo00<000000?ooo`3oool0P03oool01@000?l0oooo0?oo
o`3oool000000140oooo0P3o000B0?ooo`030000o`3oool0oooo0?l0oooo8@3oool00`000?l0oooo
0?ooo`0J0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0L@3oool003P0oooo00<0
o`000?ooo`3oool04`3oool00`000?l0oooo0?ooo`1o0?ooo`030000003oool0oooo0800oooo00D0
003o0?ooo`3oool0oooo0000000@0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool0
o`3ooolQ0?ooo`030000o`3oool0oooo01`0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo
0?ooo`1`0?ooo`009@3oool00`000?l0oooo0?ooo`0A0?ooo`80o`00U@3oool00`000000oooo0?oo
o`1o0?ooo`050000o`3oool0oooo0?ooo`0000003`3oool20?l001<0oooo00<0003o0?ooo`3oool0
o`3ooolR0?ooo`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3oool03@3oool00`000?l0oooo
0?ooo`040?ooo`030000o`3oool0oooo0700oooo000V0?ooo`030000o`3oool0oooo0180oooo00<0
o`000?ooo`3oool03@3oool00`000000oooo0?ooo`220?ooo`800000O`3oool00`000?l0oooo0?oo
o`020?ooo`030000003oool0oooo00/0oooo0P3o000D0?ooo`030000o`3oool0oooo0?l0oooo8`3o
ool00`000?l0oooo0?ooo`0>0?ooo`030000o`3oool0oooo00T0oooo00@0003o0?ooo`3oool0003o
1P3oool00`000?l0oooo0?ooo`1`0?ooo`009`3oool00`000?l0oooo0?ooo`0R0?ooo`050000003o
ool0oooo0?ooo`000?l0O`3oool00`000000oooo0?ooo`1m0?ooo`030000o`3oool0oooo0080oooo
00<000000?ooo`3oool02`3oool00`3o0000oooo0?ooo`0C0?ooo`030000o`3oool0oooo0?l0oooo
903oool00`000?l0oooo0?ooo`070?ooo`@0003o0`3oool00`000?l0oooo0?ooo`0:0?ooo`80003o
1`3oool00`000?l0oooo0?ooo`1`0?ooo`00?P3oool20?l000`0oooo00<000000?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`1l0?ooo`030000003oool0oooo07`0oooo00<0003o0?ooo`3oool00P3o
ool00`000000oooo0?ooo`0:0?ooo`80o`005P3oool00`000?l0oooo0?ooo`3o0?ooob@0oooo00<0
003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0J0?ooo`030000o`3oool0oooo0700oooo0010
0?ooo`80o`002`3oool01@000000oooo0?ooo`3oool0003o07h0oooo00<000000?ooo`3oool0O03o
ool00`000?l0oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<0o`000?ooo`3oool05@3o
ool00`000?l0oooo0?ooo`0c0?oook/0003o=@3oool00`000?l0oooo0?ooo`020?ooo`@0003o0`3o
ool00`000?l0oooo0?ooo`0=0?ooo`P0003o1@3oool00`000?l0oooo0?ooo`1_0?ooo`00:@3oool0
0`000?l0oooo0?ooo`0V0?ooo`030000o`3oool0oooo07/0oooo00<000000?ooo`3oool0N`3oool0
0`000?l0oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo0P3o000G0?ooo`030000o`3oool0
oooo0?l0oooo9P3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo01P0oooo00<0003o
0?ooo`3oool0L03oool002X0oooo00<0003o0?ooo`3oool05`3oool00`3o0000oooo0?ooo`290?oo
o`030000003oool0oooo07X0oooo00<0003o0?ooo`3oool00`3oool00`000000oooo0?ooo`070?oo
o`030?l0003oool0oooo01H0oooo00<0003o0?ooo`3oool0o`3ooolW0?ooo`030000o`3oool0oooo
00X0oooo00<0003o0?ooo`3oool05`3oool00`000?l0oooo0?ooo`1`0?ooo`00:P3oool00`000?l0
oooo0?ooo`0H0?ooo`80o`003@3oool00`000?l0oooo0?ooo`1i0?ooo`030000003oool0oooo07T0
oooo00<0003o0?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`80o`00603oool00`000?l0
oooo0?ooo`3o0?ooobP0oooo00<0003o0?ooo`3oool01`3oool010000?l0oooo0?ooo`000?lI0?oo
o`030000o`3oool0oooo0700oooo000[0?ooo`030000o`3oool0oooo01T0oooo00<0o`000?ooo`3o
ool01@3oool00`000000oooo0?ooo`030?ooo`030000o`3oool0oooo07P0oooo00<000000?ooo`3o
ool0N@3oool00`000?l0oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo0P3o000I0?ooo`03
0000o`3oool0oooo0?l0oooo:@3oool00`000?l0oooo0?ooo`080?ooo`80003o403oool40000o`H0
oooo00<0003o0?ooo`3oool0L03oool004l0oooo00<000000?ooo`3oool00`3oool00`000?l0oooo
0?ooo`1h0?ooo`800000N@3oool00`000?l0oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo
00<0o`000?ooo`3oool06@3oool00`000?l0oooo0?ooo`3o0?ooobT0oooo00<0003o0?ooo`3oool0
703oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0700oooo001:0?ooo`030?l0003o
ool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000?l0oooo0?ooo`1g0?ooo`030000003o
ool0oooo07L0oooo00<0003o0?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`80o`006`3o
ool00`000?l0oooo0?ooo`3o0?ooob/0oooo00<0003o0?ooo`3oool06`3oool00`000?l0oooo0?oo
o`040?ooo`030000o`3oool0oooo0740oooo000^0?ooo`030000o`3oool0oooo01X0oooo0P3o0003
0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0MP3oool00`000?l0oooo0?ooo`04
0?ooo`030000003oool0oooo0080oooo00<0o`000?ooo`3oool06P3oool00`000?l0oooo0?ooo`3o
0?ooodX0oooo00<0003o0?ooo`3oool0N03oool002l0oooo00<0003o0?ooo`3oool06`3oool00`3o
0000oooo0?ooo`200?ooo`030000003oool0oooo07D0oooo00<0003o0?ooo`3oool0103oool01000
0000oooo0?ooo`3oool20?l001`0oooo00<0003o0?ooo`3oool0o`3ooom;0?ooo`030000o`3oool0
oooo07P0oooo000`0?ooo`030000o`3oool0oooo02H0oooo00<0003o0?ooo`3oool0M03oool00`00
0000oooo0?ooo`1e0?ooo`030000o`3oool0oooo00@0oooo00@000000?ooo`3o0000o`007@3oool0
0`000?l0oooo0?ooo`3o0?ooodX0oooo0`000?mj0?ooo`00803oool00`3o0000oooo0?ooo`0]0?oo
o`030?l0003oool0000000L0oooo00<0003o0?ooo`3oool0L`3oool00`000000oooo0?ooo`1d0?oo
o`030000o`3oool0oooo00@0oooo00<000000?ooo`3o00007`3oool00`000?l0oooo0?ooo`0=0?oo
o`030?l0003oool0oooo0?l0oooo?03oool00`000?l0oooo0?ooo`1h0?ooo`00803oool20?l002l0
oooo0P3o00000`000000oooo0?ooo`050?ooo`030000o`3oool0oooo0780oooo00<000000?ooo`3o
ool0L`3oool00`000?l0oooo0?ooo`050?ooo`80o`007`3oool00`000?l0oooo0?ooo`0=0?ooo`80
o`00o`3oooni0?ooo`00803oool40?l000h0oooo00<0003o0?ooo`3oool07P3oool00`000000oooo
0?ooo`1j0?ooo`800000L`3oool00`000?l0oooo0?ooo`040?ooo`80o`00803oool00`000?l0oooo
0?ooo`0<0?ooo`@0o`00o`3oooni0?ooo`008P3oool30?l000h0oooo00<0003o0?ooo`3oool07P3o
ool00`000000oooo0?l0001i0?ooo`030000003oool0oooo0740oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0000000O0?ooo`030000o`3oool0oooo00`0oooo0`3o003o0?oook/0oooo000S
0?ooo`040?l0003oool0oooo0?l000`0oooo00<0003o0?ooo`3oool08@3oool20?l000@0oooo00<0
003o0?ooo`3oool0L03oool00`000000oooo0?ooo`1`0?ooo`030000o`3oool0oooo00<0oooo0P3o
00000`3oool000000?ooo`0N0?ooo`030000o`3oool0oooo00/0oooo103o003o0?oook`0oooo000U
0?ooo`<0o`00303oool00`000?l0oooo0?ooo`0R0?ooo`030?l0003oool0oooo0080oooo00<0003o
0?ooo`3oool0K`3oool00`000000oooo0?ooo`1`0?ooo`040000o`3oool0oooo0?ooo`80o`000`3o
ool00`000000oooo0?ooo`0M0?ooo`030000o`3oool0oooo00T0oooo103o003o0?oookh0oooo000V
0?ooo`@0o`00:`3oool00`000000oooo0?ooo`060?ooo`030000o`3oool0oooo06l0oooo00<00000
0?ooo`3oool0K`3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<000000?ooo`3oool07@3o
ool00`000?l0oooo0?ooo`090?ooo`@0o`00o`3ooono0?ooo`00:03oool30?l002/0oooo00<00000
0?ooo`3oool00`3oool0103o0000oooo0?ooo`000?m`0?ooo`030000003oool0oooo06h0oooo00<0
003o0?ooo`3oool00P3o00040?ooo`030000003oool0oooo01d0oooo00<0003o0?ooo`3oool0203o
ool40?l00?l0oooo`@3oool002T0oooo00@0o`000?ooo`3oool0o`002@3oool00`000?l0oooo0?oo
o`0M0?ooo`030000003oool0oooo00@0oooo0P3o001a0?ooo`030000003oool0oooo06d0oooo00@0
003o0?ooo`3o0000o`001P3oool00`000000oooo0?ooo`0L0?ooo`030000o`3oool0oooo00P0oooo
0`3o003o0?ooobd0oooo00<0o`000?ooo`3oool0303oool00`3o0000oooo0?ooo`0=0?ooo`030?l0
003oool0oooo07@0oooo000[0?ooo`D0o`001`3oool20000oah0oooo00<000000?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`1^0?ooo`800000K@3oool00`000?l0o`000?l000070?ooo`030000003o
ool0oooo01d0oooo00<0003o0?ooo`3oool01P3oool40?l00?l0oooo;@3oool00`3o0000oooo0?oo
o`0>0?ooo`030?l0003oool0oooo00d0oooo00<0o`000?ooo`3oool0L`3oool002`0oooo1@3o0008
0?ooo`030000o`3oool0oooo02D0oooo00<0003o0?ooo`3oool0K03oool00`000000oooo0?ooo`1[
0?ooo`030000o`3o0000oooo00P0oooo00<000000?ooo`3oool0703oool00`000?l0oooo0?ooo`06
0?ooo`<0o`00o`3oool_0?ooo`030?l0003oool0oooo00L0oooo103o00030?ooo`030?l0003oool0
oooo00L0oooo0P3o00040?ooo`030?l0003oool0oooo07<0oooo000^0?ooo`80o`00<P3oool20000
of`0oooo00<000000?ooo`3oool0JP3oool20?l000T0oooo00<000000?ooo`3oool0703oool00`00
0?l0oooo0?ooo`050?ooo`@0o`00>`3ooonk0?l003T0oooo00<0o`000?ooo`3oool02@3oool00`3o
0000oooo0?ooo`0;0?ooo`040?l0003oool0oooo0?l000<0oooo00<0o`000?ooo`3oool0L`3oool0
02h0oooo0P3o00020?ooo`030?l0003oool0oooo02@0oooo00<000000?ooo`3oool01`3oool00`3o
0000003o0?ooo`1Z0?ooo`030000003oool0oooo06P0oooo0P3o00000`000?l0oooo0?ooo`080?oo
o`030000003oool0oooo01/0oooo00<0003o0?ooo`3oool0103oool40?l00?l0oooo<@3oool00`3o
0000oooo0?ooo`020?ooo`@0o`00103oool00`3o0000oooo0?ooo`0;0?ooo`040?l0003oool0oooo
0?l000@0oooo00<0o`000?ooo`3oool0LP3oool00340oooo1@3o00050?ooo`030000o`3oool0oooo
01/0oooo00<000000?ooo`3oool02@3oool00`3o0000oooo0?ooo`1X0?ooo`030000003oool0oooo
06H0oooo0P3o00000`3oool0003o0?ooo`090?ooo`030000003oool0oooo01/0oooo00<0003o0?oo
o`3oool0103oool30?l00?l0oooo=03oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo
00/0oooo00@0o`000?ooo`3oool0o`000`3oool00`3o0000oooo0?ooo`1c0?ooo`00<P3oool50?l0
00D0oooo00<0003o0?ooo`3oool06`3oool00`000000oooo0?ooo`0;0?ooo`80o`00D@3oool40000
00<0oooo00<000000?ooo`3oool00P3oool3000000H0oooo00<000000?ooo`3oool0I03oool20?l0
0080oooo00<0003o0?ooo`3oool02@3oool00`000000oooo0?ooo`0K0?ooo`030000o`3oool0oooo
0080oooo103o003o0?ooocD0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`0;0?oo
o`040?l0003oool0oooo0?l000<0oooo00<0o`000?ooo`3oool0L`3oool003D0oooo00@0o`000?oo
o`3oool0o`000`3oool00`000?l0oooo0?ooo`0K0?ooo`030000003oool0oooo00T0oooo00D0003o
0?ooo`3oool0oooo0?l0001B0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`1S0?ooo`050?l0003oool0oooo0?ooo`000?l02`3oool00`000000oooo
0?ooo`0K0?ooo`040000o`3oool0oooo0?ooo`@0o`00o`3ooolh0?ooo`030?l0003oool0oooo00H0
oooo0`3o000=0?ooo`040?l0003oool0oooo0?l00080oooo00<0o`000?ooo`3oool0M03oool003L0
oooo0`3o00030?ooo`030000o`3oool0oooo02L0oooo00D0003o0?ooo`3oool0oooo0?l0001A0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool300000640oooo0P3o00030?oo
o`030000o`3oool0oooo00T0oooo00<000000?ooo`3oool06`3oool010000?l0oooo0?ooo`3oool3
0?l00?l0ooooA@3oool00`3o0000oooo0?ooo`0<0?ooo`80o`00NP3oool003P0oooo103o000[0?oo
o`030000o`3oool0oooo04/0oooo100000040?ooo`030000003oool0oooo00L0oooo0`0000060?oo
o`030000003oool0oooo0600oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`090?oo
o`030000003oool0oooo01X0oooo00<0003o0?ooo`3oool0103o003o0?ooom40oooo000j0?ooo`<0
o`007`3oool00`000000oooo0?ooo`090?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3o
ool0C03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0GP3oool20?l000D0oooo00<0003o0?ooo`3oool02@3oool00`000000oooo0?ooo`0J0?ooo`03
0000o`3oool0o`0000<0o`00o`3ooooC0?ooo`00>`3oool01@3o0000oooo0?ooo`3o0000003o01d0
oooo00<000000?ooo`3oool03`3oool20?l004X0oooo0`0000090?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0G@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00X0
oooo00<000000?ooo`3oool06P3oool010000?l0o`000?l0003o003o0?ooomD0oooo000m0?ooo`<0
o`0000<0003o0?ooo`3oool06P3oool00`000000oooo0?ooo`0A0?ooo`030?l0003oool0oooo04T0
oooo00<000000?ooo`3oool01`3oool4000000D0oooo00<000000?ooo`3oool0F`3oool20?l000H0
oooo00<0003o0?ooo`3oool02P3oool00`000000oooo0?ooo`0J0?ooo`@0o`00o`3ooooF0?ooo`00
?P3oool30?l000030000o`3oool0oooo01X0oooo00<000000?ooo`3oool02@3oool00`000?l0oooo
0?ooo`1S0?ooo`030000003oool0oooo05T0oooo0P3o00070?ooo`030000o`3oool0oooo00/0oooo
00<000000?ooo`3oool06@3oool30?l00?l0oooof03oool00400oooo0`3o000X0?ooo`80003o1`3o
ool00`3o0000oooo0?ooo`1I0?ooo`030000003oool0oooo05P0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`0;0?ooo`030000003oool0oooo01P0oooo103o003o0?ooomT0oooo0011
0?ooo`040?l0003oool0oooo0?l002P0oooo00<0003o0?ooo`3oool01@3oool20?l005T0oooo00<0
00000?ooo`3oool0EP3oool20?l000T0oooo00<0003o0?ooo`3oool02`3oool00`000000oooo0?oo
o`0F0?ooo`@0o`00o`3ooooK0?ooo`00@`3oool00`3o0000003o0?l0000I0?ooo`030000003oool0
oooo01D0oooo00<0o`000?ooo`3oool0EP3oool2000005H0oooo00<0o`000?ooo`3oool0203oool0
0`000?l0oooo0?ooo`0;0?ooo`030000003oool0oooo01H0oooo103o003o0?ooom`0oooo00140?oo
o`040?l000000?l0o`000?l001L0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1C
0?ooo`80o`002P3oool00`000?l0oooo0?ooo`0;0?ooo`030000003oool0oooo01D0oooo103o0000
0`000?l0oooo0?ooo`3o0?ooom/0oooo000P0?ooo`030?l0003oool0oooo0280oooo00H0003o0?l0
003o0000o`000?ooo`3o000E0?ooo`030000003oool0oooo00`0oooo00<0003o0?ooo`3oool0203o
ool20?l005@0oooo00<000000?ooo`3oool0DP3oool00`3o0000oooo0?ooo`090?ooo`030000o`3o
ool0oooo00`0oooo00<000000?ooo`3oool0503oool30?l000030?ooo`000?l0oooo02<0oooo00<0
o`000?ooo`3oool0o`3ooong0?ooo`008@3oool20?l002<0oooo00<0003o0?l0003oool00`3o000D
0?ooo`030000003oool0oooo00d0oooo00<0003o0?ooo`3oool02@3oool20?l00580oooo00<00000
0?ooo`3oool0D03oool20?l000`0oooo00<0003o0?ooo`3oool02`3oool00`000000oooo0?ooo`0C
0?ooo`@0o`0000<0oooo0000o`3oool08P3oool20?l00?l0oooo^P3oool002<0oooo00<0o`000?oo
o`3oool0903oool40?l001<0oooo00<000000?ooo`3oool0303oool00`000?l0oooo0?ooo`1M0?oo
o`030000003oool0oooo04l0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?oo
o`030000003oool0oooo0180oooo0`3o00030?ooo`030000o`3oool0oooo0200oooo00<0o`000?oo
o`3oool0o`3ooonj0?ooo`00B03oool010000?l0oooo0?ooo`3oool30?l00280oooo00<0003o0?oo
o`3oool0303oool00`3o0000oooo0?ooo`1=0?ooo`030000003oool0oooo04d0oooo0P3o000=0?oo
o`030000o`3oool0oooo00`0oooo00<000000?ooo`3oool04@3oool40?l000<0oooo00<0003o0?oo
o`3oool07`3oool20?l00?l0oooo9`3oool00`3o0000oooo0?ooo`0<0?ooo`030?l0003oool0oooo
00d0oooo00<0o`000?ooo`3oool0M03oool002H0oooo00<0o`000?ooo`3oool0803oool00`000?l0
oooo0?ooo`020?l00080oooo00<0o`000?ooo`3oool0;P3oool20?l004d0oooo00<000000?ooo`3o
ool0C03oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00d0oooo00<000000?ooo`3o
ool03`3oool40?l000@0oooo00<0003o0?ooo`3oool07`3oool00`3o0000oooo0?ooo`3o0?ooobH0
oooo00<0o`000?ooo`3oool03P3oool00`3o0000oooo0?ooo`0=0?ooo`030?l0003oool0oooo07<0
oooo000P0?ooo`030000o`3oool0oooo00@0oooo0P3o000P0?ooo`030000o`3oool0oooo00<0oooo
0`3o000A0?ooo`030000003oool0oooo01d0oooo00<0o`000?ooo`3oool0BP3oool2000004/0oooo
0P3o000>0?ooo`030000o`3oool0oooo00d0oooo00<000000?ooo`3oool03`3oool30?l000D0oooo
00<0003o0?ooo`3oool07P3oool20?l000H0oooo00<0003o0?ooo`3oool0o`3ooolP0?ooo`030?l0
003oool0oooo00L0oooo103o00030?ooo`030?l0003oool0oooo00H0oooo103o00030?ooo`030?l0
003oool0oooo07<0oooo000Q0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool07P3o
ool00`000?l0oooo0?ooo`030?ooo`@0o`003`3oool00`000000oooo0?ooo`0=0?ooo`030000o`3o
ool0oooo05X0oooo00<000000?ooo`3oool0B@3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3o
ool0oooo00d0oooo00<000000?ooo`3oool03@3oool40?l000H0oooo00<0003o0?ooo`3oool0703o
ool20?l000L0oooo00<0003o0?ooo`3oool0;03ooonk0?l003T0oooo00<0o`000?ooo`3oool02@3o
ool00`3o0000oooo0?ooo`0=0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0L`3o
ool00280oooo00<0003o0?ooo`3oool0;@3oool30?l000l0oooo00<000000?ooo`3oool03@3oool0
0`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo04L0oooo00<000000?ooo`3oool0A`3oool2
0?l00100oooo00<0003o0?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`@0o`001`3oool0
0`000?l0oooo0?ooo`0L0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0;@3ooonk
0?l003P0oooo00<0o`000?ooo`3oool00P3oool40?l000@0oooo00<0o`000?ooo`3oool03@3oool0
0`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0780oooo000S0?ooo`030000o`3oool0oooo
00H0oooo0P3o000U0?ooo`040?l0003oool0oooo0?l000d0oooo00<000000?ooo`3oool03P3oool0
0`000?l0oooo0?ooo`0?0?ooo`80o`00A`3oool00`000000oooo0?ooo`160?ooo`030?l0003oool0
oooo00l0oooo00<0003o0?ooo`3oool03P3oool00`000000oooo0?ooo`0;0?ooo`<0o`00203oool0
0`000?l0oooo0?ooo`0K0?ooo`80o`002@3oool00`000?l0oooo0?ooo`3o0?ooob80oooo00<0o`00
0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0=0?ooo`030?l0003oool0oooo0080oooo00<0o`00
0?ooo`3oool0L`3oool002h0oooo0P3o000L0?ooo`80003o1`3oool30?l00340oooo00<0o`000?oo
o`3oool0A03oool00`000000oooo0?ooo`140?ooo`80o`004@3oool00`000?l0oooo0?ooo`0>0?oo
o`030000003oool0oooo00X0oooo103o00080?ooo`030000o`3oool0oooo01/0oooo00<0o`000?oo
o`3oool0203oool00`000?l0oooo0?ooo`3o0?ooob<0oooo00<0o`000?ooo`3oool02@3oool00`3o
0000oooo0?ooo`0=0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0L`3oool004h0
oooo00<0003o0?ooo`3oool01@3oool40?l007H0oooo00<000000?ooo`3oool0@P3oool20?l001<0
oooo00<0003o0?ooo`3oool03@3oool00`000000oooo0?ooo`090?ooo`@0o`002@3oool00`000?l0
oooo0?ooo`0J0?ooo`80o`002P3oool00`000?l0oooo0?ooo`3o0?ooobD0oooo00<0o`000?ooo`3o
ool01P3oool30?l000d0oooo0`3o00030?ooo`030?l0003oool0oooo07@0oooo000U0?ooo`030000
o`3oool0oooo00X0oooo00<0o`000?ooo`3oool06@3oool00`000?l0oooo0?ooo`070?ooo`<0o`00
00<0oooo0?l0003oool0203oool00`000000oooo0?ooo`0?0?ooo`030000o`3oool0oooo0140oooo
00<0o`000?ooo`3oool0@@3oool00`000000oooo0?ooo`100?ooo`80o`00503oool00`000?l0oooo
0?ooo`0>0?ooo`030000003oool0oooo00P0oooo0`3o000:0?ooo`030000o`3oool0oooo01T0oooo
0P3o000;0?ooo`030000o`3oool0oooo0?l0oooo<@3oool00`3o0000oooo0?ooo`0=0?ooo`030?l0
003oool0oooo07P0oooo000V0?ooo`030000o`3oool0oooo00X0oooo0P3o000J0?ooo`030000o`3o
ool0oooo00L0oooo00<0o`000?ooo`3o00000P3o00090?ooo`030000003oool0oooo00h0oooo00<0
003o0?ooo`3oool04P3oool20?l00440oooo0P0000100?ooo`030?l0003oool0oooo01<0oooo00<0
003o0?ooo`3oool03P3oool00`000000oooo0?ooo`070?ooo`@0o`002`3oool00`000?l0oooo0?oo
o`0H0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0o`3ooonl0?ooo`009P3oool0
0`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo02@0oooo103o00070?ooo`030000003oool0
oooo00l0oooo00<0003o0?ooo`3oool04`3oool00`3o0000oooo0?ooo`0n0?ooo`030000003oool0
oooo03d0oooo0P3o000E0?ooo`030000o`3oool0oooo00l0oooo00<000000?ooo`3oool01@3oool4
0?l000`0oooo00<0003o0?ooo`3oool05`3oool20?l000d0oooo00<0003o0?ooo`3oool0o`3ooonm
0?ooo`009`3oool00`000?l0oooo0?ooo`0W0?ooo`030000o`3oool0oooo00X0oooo0`3o00070?oo
o`030000003oool0oooo00l0oooo00<0003o0?ooo`3oool05@3oool00`3o0000oooo0?ooo`0k0?oo
o`030000003oool0oooo03/0oooo0P3o000F0?ooo`030000o`3oool0oooo00l0oooo00<000000?oo
o`3oool01@3oool40?l000`0oooo00<0003o0?ooo`3oool05P3oool20?l000h0oooo00<0003o0?oo
o`3oool0o`3ooonn0?ooo`00>03oool00`3o0000oooo0?ooo`0G0?ooo`030000o`3oool0oooo00X0
oooo00@0o`000?ooo`3oool0o`00<03oool20?l003/0oooo00<000000?ooo`3oool0>@3oool20?l0
01L0oooo00<0003o0?ooo`3oool0403oool00`000000oooo0?ooo`030?ooo`@0o`003@3oool00`00
0?l0oooo0?ooo`0F0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0o`3ooono0?oo
o`00:@3oool00`000?l0oooo0?ooo`0=0?ooo`80o`005`3oool00`000?l0oooo0?ooo`0<0?ooo`<0
o`00603oool00`000?l0oooo0?ooo`0F0?ooo`030?l0003oool0oooo03P0oooo00<000000?ooo`3o
ool0>03oool00`3o0000oooo0?ooo`0G0?ooo`030000o`3oool0oooo00l0oooo00<000000?ooo`3o
ool00`3oool30?l000h0oooo00<0003o0?ooo`3oool05@3oool20?l000l0oooo00<0003o0?ooo`3o
ool0o`3oooo00?ooo`00:P3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo01D0oooo
00<0003o0?ooo`3oool0303oool40?l000<0oooo00<000000?ooo`3oool04@3oool00`000?l0oooo
0?ooo`1@0?ooo`030000003oool0oooo03H0oooo0P3o000I0?ooo`030000o`3oool0oooo0100oooo
00@000000?ooo`3oool0oooo103o000>0?ooo`030000o`3oool0oooo01@0oooo0P3o000A0?ooo`03
0000o`3oool0oooo0?l0oooo`03oool002X0oooo00<0003o0?ooo`3oool0=`3oool30?l000<0oooo
00<000000?ooo`3oool0403oool00`000?l0oooo0?ooo`0H0?ooo`030?l0003oool0oooo03D0oooo
00<000000?ooo`3oool0=03oool20?l001X0oooo00<0003o0?ooo`3oool0403oool00`000000oooo
0?ooo`040?l00100oooo00<0003o0?ooo`3oool04`3oool00`3o0000oooo0?ooo`0@0?ooo`030000
o`3oool0oooo0?l0oooo`@3oool002/0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?oo
o`0T0?ooo`060?l0003oool0oooo0?l0003oool000004`3oool00`000?l0oooo0?ooo`0H0?ooo`80
o`00=@3oool2000003@0oooo00<0o`000?ooo`3oool06@3oool00`000?l0oooo0?ooo`0@0?ooo`03
0000003oool0oooo00@0o`00403oool00`000?l0oooo0?ooo`0B0?ooo`80o`004P3oool00`000?l0
oooo0?ooo`3o0?oood80oooo1000I01l0?ooo`00?`3oool20?l001@0oooo00<0003o0?ooo`3oool0
3`3oool40?l000030000003oool0oooo02d0oooo00<0o`000?ooo`3oool0<P3oool00`000000oooo
0?ooo`0a0?ooo`80o`006`3oool00`000?l0oooo0?ooo`0A0?ooo`030000003o0000o`000080o`00
4@3oool00`000?l0oooo0?ooo`0B0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool0
o`3ooom30?ooo`03001T003oool0oooo07d0oooo00110?ooo`030?l0003oool0oooo0180oooo00<0
003o0?ooo`3oool03`3oool40?l006@0oooo00<000000?ooo`3oool0;`3oool20?l001`0oooo00<0
003o0?ooo`3oool04@3oool010000000o`000?l0003o000B0?ooo`030000o`3oool0oooo0140oooo
0P3o000D0?ooo`030000o`3oool0oooo0?l0oooo;@3oool00`00I000oooo0?ooo`0D0?ooo`03001T
003oool0oooo00D0oooo00<006@00?ooo`3oool0M03oool002h0oooo00<0003o0?ooo`3oool04`3o
ool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo0100oooo0`3o000C0?ooo`030000o`3o
ool0oooo01/0oooo00<0o`000?ooo`3oool0;`3oool00`000000oooo0?ooo`0^0?ooo`030?l0003o
ool0oooo01`0oooo00<0003o0?ooo`3oool0403oool40?l00180oooo00<0003o0?ooo`3oool04@3o
ool00`3o0000oooo0?ooo`0C0?ooo`030000o`3oool0oooo0?l0oooo;@3oool00`00I000oooo0?oo
o`0F0?ooo`03001T003oool0oooo00D0oooo00<006@00?ooo`3oool0L`3oool002l0oooo00<0003o
0?ooo`3oool04`3oool20?l00140oooo00<0003o0?ooo`3oool0403oool0103o0000oooo0000003o
000B0?ooo`030000o`3oool0oooo01/0oooo0P3o000_0?ooo`030000003oool0oooo02`0oooo0P3o
000N0?ooo`030000o`3oool0oooo0100oooo0`3o000C0?ooo`030000o`3oool0oooo0100oooo0P3o
000E0?ooo`030000o`3oool0oooo0?l0oooo;P3oool00`00I000oooo0?ooo`070?ooo`03001T003o
ool0oooo00d0oooo00<006@00?ooo`3oool0103oool00`00I000oooo0?ooo`1c0?ooo`00;`3oool0
0`000?l0oooo0?ooo`0E0?ooo`030?l0003oool0oooo02<0oooo00<000000?l0003o00000P3o000@
0?ooo`030000o`3oool0oooo01`0oooo00<0o`000?ooo`3oool0;03oool00`000000oooo0?ooo`0Z
0?ooo`80o`007`3oool00`000?l0oooo0?ooo`0?0?ooo`@0o`00503oool00`000?l0oooo0?ooo`0>
0?ooo`80o`005P3oool00`000?l0oooo0?ooo`3o0?ooobl0oooo00<006@00?ooo`3oool0203oool0
0`00I000oooo0?ooo`090?ooo`04001T003oool0oooo001T00H0oooo00<006@00?ooo`3oool0L`3o
ool00300oooo00<0003o0?ooo`3oool09`3oool00`000?l0oooo0?ooo`0A0?ooo`030000003o0000
o`000080o`00403oool00`000?l0oooo0?ooo`0N0?ooo`030?l0003oool0oooo0200oooo10000005
0?ooo`030000003oool0oooo02T0oooo00<0o`000?ooo`3oool07P3oool00`000?l0oooo0?ooo`0>
0?ooo`@0o`0000<000000?ooo`3oool04P3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0
oooo01D0oooo00<0003o0?ooo`3oool0o`3oool`0?ooo`03001T003oool0oooo0080oooo0P00I004
0?ooo`03001T003oool0oooo00X0oooo0P00I0070?ooo`03001T003oool0oooo07<0oooo000P0?oo
o`030?l0003oool0oooo02L0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0A0?oo
o`040000003oool0oooo0?l00080oooo00<0o`000?ooo`3oool0;@3oool20?l002<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0W0?ooo`80o`00803oool00`000?l0oooo0?ooo`0>
0?ooo`@0o`0000<0oooo0000003oool04P3oool00`000?l0oooo0?ooo`0=0?ooo`80o`005`3oool0
0`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo0?l0oooo803oool01@00I000oooo0?ooo`3o
ool006@00080oooo00<006@00?ooo`3oool05`3oool00`00I000oooo0?ooo`1c0?ooo`00803oool2
0?l00100oooo00<0003o0?ooo`3oool05P3oool20?l000h0oooo00<0003o0?ooo`3oool05@3oool3
0?l000l0oooo00<0003o0?ooo`3oool07P3oool20?l00240oooo00<000000?ooo`3oool0103oool3
000002H0oooo00<0o`000?ooo`3oool07`3oool00`000?l0oooo0?ooo`0=0?ooo`@0o`000P3oool0
0`000000oooo0?ooo`0A0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool05`3oool0
0`000?l0oooo0?ooo`0<0?ooo`<0o`00;@3ooonk001T03P0oooo00<006@00?ooo`3oool00P3oool0
1000I000oooo0?ooo`00I00<0?ooo`H006@000<0oooo001T0000I0001@3oool00`00I000oooo0?oo
o`1b0?ooo`00803oool40?l000l0oooo00<0003o0?ooo`3oool05`3oool00`3o0000oooo0?ooo`0<
0?ooo`030000o`3oool0oooo01D0oooo103o000>0?ooo`030000o`3oool0oooo03P0oooo10000004
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0903oool20?l00280oooo00<0003o
0?ooo`3oool0303oool30?l000@0oooo00<000000?ooo`3oool0403oool00`000?l0oooo0?ooo`0<
0?ooo`80o`006@3oool00`000?l0oooo0?ooo`0<0?ooo`@0o`00o`3ooolR0?ooo`05001T003oool0
oooo0?ooo`00I0000P3oool00`00I000oooo0?ooo`0G0?ooo`03001T003oool0oooo07<0oooo000R
0?ooo`<0o`0000<0oooo0?l0003oool02`3oool00`000?l0oooo0?ooo`0j0?ooo`030000003oool0
oooo00<0oooo0`3o000=0?ooo`030000o`3oool0oooo0240oooo00<0o`000?ooo`3oool0703oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo02<0oooo00<0o`000?ooo`3oool08@3oool0
0`000?l0oooo0?ooo`0;0?ooo`@0o`00103oool00`000000oooo0?ooo`0@0?ooo`030000o`3oool0
oooo00/0oooo0P3o000J0?ooo`030000o`3oool0oooo00/0oooo103o003o0?ooob@0oooo00D006@0
0?ooo`3oool0oooo001T00020?ooo`03001T003oool0oooo01L0oooo00<006@00?ooo`3oool0L`3o
ool002<0oooo00<0o`000?ooo`3o00000P3o000<0?ooo`030000o`3oool0oooo01T0oooo00<0o`00
0?ooo`3oool07@3oool00`000000oooo0?ooo`040?ooo`040?l0003oool0oooo0?l000`0oooo00<0
003o0?ooo`3oool08@3oool20?l001X0oooo0`0000060?ooo`030000003oool0oooo0240oooo0P3o
000S0?ooo`030000o`3oool0oooo00/0oooo0`3o00060?ooo`030000003oool0oooo0100oooo00<0
003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0I0?ooo`030000o`3oool0oooo00X0oooo103o
003o0?ooobH0oooo00D006@00?ooo`3oool0oooo001T00020?ooo`03001T003oool0oooo01L0oooo
00<006@00?ooo`3oool0L`3oool002H0oooo103o000W0?ooo`80o`002`3oool00`000?l0oooo0?oo
o`0@0?ooo`030000003oool0oooo00D0oooo0`3o000a0?ooo`030?l0003oool0oooo01T0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0P0?ooo`030?l0003oool0oooo0280oooo00<0
003o0?ooo`3oool02P3oool40?l000H0oooo00<000000?ooo`3oool0403oool00`000?l0oooo0?oo
o`090?ooo`80o`006`3oool00`000?l0oooo0?ooo`090?ooo`D0o`00o`3ooolW0?ooo`03001T003o
ool0oooo0080oooo0P00I00@0?ooo`@006@01P3oool00`00I000oooo0?ooo`1c0?ooo`00:03oool3
0?l002P0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`0?0?ooo`030000003oool0
oooo00H0oooo103o001B0?ooo`030000003oool0oooo01h0oooo0P3o000T0?ooo`030000o`3oool0
oooo00T0oooo103o00080?ooo`030000003oool0oooo00l0oooo00<0003o0?ooo`3oool0203oool2
0?l001`0oooo00<0003o0?ooo`3oool02@3oool40?l00?l0oooo:@3oool00`00I000oooo0?ooo`0F
0?ooo`03001T003oool0oooo00D0oooo00<006@00?ooo`3oool0L`3oool00200oooo2@00I000103o
000006@0001T003o0009001T00030000o`00I00006@001d006@000<0o`00001T0000I0001P00I000
0`000?l006@0001T000@001T000300000000I00006@000L006@00`3o000:001T00030000o`00I000
06@002@006@000<0o`00001T0000I000cP00I03o0?ooob<0oooo00<006@00?ooo`3oool05@3oool0
0`00I000oooo0?ooo`040?ooo`03001T003oool0oooo07@0oooo000[0?ooo`D0o`001`3oool00`00
0?l0oooo0?ooo`0M0?ooo`80o`001`3oool00`000?l0oooo0?ooo`0J0?ooo`040?l0003oool0oooo
0?l000T0oooo00<0003o0?ooo`3oool0903oool20?l001d0oooo0P00000L0?ooo`80o`009P3oool0
0`000?l0oooo0?ooo`070?ooo`@0o`002P3oool00`000000oooo0?ooo`0>0?ooo`030000o`3oool0
oooo00L0oooo0P3o000N0?ooo`030000o`3oool0oooo00H0oooo103o003o0?ooodH0oooo00<006@0
0?ooo`3oool0N`3oool002`0oooo1@3o00070?ooo`030000o`3oool0oooo01h0oooo00<0o`000?oo
o`3oool08`3oool50?l000H0oooo00<0003o0?ooo`3oool09P3oool00`3o0000oooo0?ooo`0J0?oo
o`030000003oool0oooo01X0oooo00<0o`000?ooo`3oool09@3oool00`000?l0oooo0?ooo`060?oo
o`@0o`002`3oool00`000000oooo0?ooo`0>0?ooo`030000o`3oool0oooo00H0oooo0P3o000O0?oo
o`030000o`3oool0oooo00H0oooo103o003o0?ooodL0oooo00<006@00?ooo`3oool0N`3oool002h0
oooo0P3o00090?ooo`030000o`3oool0oooo02L0oooo00<0003o0?ooo`3oool03@3oool00`000000
oooo0?ooo`0:0?ooo`D0o`001P3oool00`000?l0oooo0?ooo`120?ooo`030000003oool0oooo01P0
oooo0P3o000W0?ooo`030000o`3oool0oooo00H0oooo0`3o000=0?ooo`030000003oool0oooo00h0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`0N0?ooo`030000o`3oool0oooo00D0
oooo103o003o0?ooodL0oooo0`00I01m0?ooo`00;P3oool20?l00080oooo00<0o`000?ooo`3oool0
9`3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00d0oooo00<000000?ooo`3oool0
303oool0103o0000oooo0?ooo`3o000_0?ooo`80o`00603oool00`000000oooo0?ooo`0G0?ooo`03
0?l0003oool0oooo02H0oooo00<0003o0?ooo`3oool01@3oool40?l000d0oooo00<000000?ooo`3o
ool03P3oool00`000?l0oooo0?ooo`040?ooo`80o`00803oool00`000?l0oooo0?ooo`050?ooo`<0
o`00o`3ooom;0?ooo`03001T003oool0oooo07/0oooo000a0?ooo`<0o`001`3oool00`000?l0oooo
0?ooo`0O0?ooo`80o`001@3oool00`000?l0oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo
0`3o00060?ooo`030000o`3oool0oooo02L0oooo0P3o000F0?ooo`030000003oool0oooo01D0oooo
0P3o000X0?ooo`030000o`3oool0oooo00@0oooo103o000?0?ooo`030000003oool0oooo00d0oooo
00<0003o0?ooo`3oool00`3oool20?l00240oooo00<0003o0?ooo`3oool0103oool40?l00?l0oooo
bP3oool00380oooo103o00060?ooo`030000o`3oool0oooo0200oooo00<0o`000?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo103o00050?ooo`030000o`3o
ool0oooo03h0oooo00<000000?ooo`3oool0503oool00`3o0000oooo0?ooo`0X0?ooo`030000o`3o
ool0oooo00<0oooo0`3o000@0?ooo`030000003oool0oooo00d0oooo00<0003o0?ooo`3oool00P3o
ool20?l002<0oooo00<0003o0?ooo`3oool00`3oool30?l00?l0ooooC03oool4001T07`0oooo000d
0?ooo`<0o`0000<0oooo0?l0003oool00P3oool00`000?l0oooo0?ooo`180?ooo`@0o`00103oool0
0`000?l0oooo0?ooo`0Z0?ooo`030?l0003oool0oooo0140oooo00<000000?ooo`3oool04P3oool2
0?l002X0oooo00<0003o0?ooo`3oool00P3oool40?l00140oooo00<000000?ooo`3oool0303oool0
0`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0280oooo00<0003o0?ooo`3oool00P3oool4
0?l00?l0ooooC@3oool00`00I000oooo0?ooo`1m0?ooo`00=@3oool00`3o0000oooo0?l000020?l0
00<0oooo00<0003o0?ooo`3oool08P3oool00`3o0000oooo0?ooo`0T0?ooo`040?l0003oool0oooo
0?l000<0oooo00<0003o0?ooo`3oool0:P3oool20?l00140oooo0P00000A0?ooo`80o`00:`3oool0
0`000?l0oooo0?ooo`020?ooo`<0o`004P3oool00`000000oooo0?ooo`0<0?ooo`040000o`3oool0
oooo0?ooo`80o`00903oool00`000?l0oooo0?ooo`020?ooo`<0o`00o`3oooli0?ooo`03001T003o
ool0oooo01@0oooo00<006@00?ooo`3oool01@3oool00`00I000oooo0?ooo`1d0?ooo`00>03oool4
0?l002L0oooo0P3o00020?ooo`030000o`3oool0oooo00d0oooo00<000000?ooo`3oool04@3oool3
0?l00340oooo00<0o`000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030?l0003oool0
oooo02X0oooo00@0003o0?ooo`3oool0oooo103o000C0?ooo`030000003oool0oooo00`0oooo00@0
003o0?ooo`3o0000o`009@3oool010000?l0oooo0?ooo`3oool40?l00?l0oooo>@3oool00`00I000
oooo0?ooo`0F0?ooo`03001T003oool0oooo00D0oooo00<006@00?ooo`3oool0L`3oool00200oooo
00<0o`000?ooo`3oool05`3oool30?l002P0oooo00@0o`000?ooo`3oool0003o3P3oool00`000000
oooo0?ooo`0B0?ooo`@0o`00@03oool00`000000oooo0?ooo`0=0?ooo`80o`00;03oool00`000?l0
oooo0?ooo`040?l001@0oooo00<000000?ooo`3oool0303oool00`000?l0o`000?l0000V0?ooo`04
0000o`3oool0oooo0?ooo`<0o`00603oool00`3o0000oooo0?ooo`3o0?ooob00oooo00<006@00?oo
o`3oool01`3oool00`00I000oooo0?ooo`0=0?ooo`03001T003oool0oooo00@0oooo00<006@00?oo
o`3oool0L`3oool00240oooo0P3o000H0?ooo`050?l0003oool0oooo0?l000000?l0:@3oool00`00
0?l0oooo0?ooo`0<0?ooo`030000003oool0oooo01<0oooo0`3o00000`3oool0003o0?ooo`0^0?oo
o`030?l0003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`3o0000oooo0?ooo`0[0?oo
o`030000o`3oool0oooo00@0o`005@3oool00`000000oooo0?ooo`0;0?ooo`80o`00:03oool00`00
0?l0oooo0?l000030?l001L0oooo0P3o003o0?ooob<0oooo00<006@00?ooo`3oool0203oool00`00
I000oooo0?ooo`090?ooo`04001T003oool0oooo001T00H0oooo00<006@00?ooo`3oool0L`3oool0
02<0oooo00<0o`000?ooo`3oool05`3oool30?l000030000o`3oool0oooo02D0oooo0P3o000>0?oo
o`030000003oool0oooo01@0oooo00D0o`000?ooo`3oool0o`000000o`0_0?ooo`80o`002`3oool0
0`000000oooo0?ooo`0:0?ooo`80o`00;P3oool00`000?l0o`000?l000020?l001H0oooo00<00000
0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0W0?ooo`030000o`3o0000o`000080o`00603oool0
0`3o0000oooo0?ooo`3o0?ooob<0oooo00<006@00?ooo`3oool00P3oool2001T00@0oooo00<006@0
0?ooo`3oool02P3oool2001T00L0oooo00<006@00?ooo`3oool0L`3oool003h0oooo0`3o00000`00
0?l0oooo0?ooo`0V0?ooo`80o`009@3oool20?l000030000o`3oool0oooo02l0oooo00<0o`000?oo
o`3oool0203oool00`000000oooo0?ooo`080?ooo`80o`00;`3oool010000?l0o`000?l0003o000G
0?ooo`030000003oool0oooo00X0oooo0P3o000Y0?ooo`030000o`3o0000o`000080o`005`3oool2
0?l00?l0oooo9P3oool01@00I000oooo0?ooo`3oool006@00080oooo00<006@00?ooo`3oool05`3o
ool00`00I000oooo0?ooo`1c0?ooo`009P3oool00`3o0000oooo0?ooo`0G0?ooo`<0o`00:03oool0
0`000?l0oooo0?ooo`0T0?ooo`80o`0000<0003o0?l0003oool0>@3oool00`000000oooo0?ooo`07
0?ooo`030?l0003oool0oooo02h0oooo103o000H0?ooo`030000003oool0oooo00T0oooo00<0o`00
0000o`3oool0:03oool40?l001P0oooo00<0o`000?ooo`3oool0o`3ooolU0?ooo`03001T003oool0
oooo0080oooo00@006@00?ooo`3oool006@0303oool6001T00030?ooo`00I00006@000D0oooo00<0
06@00?ooo`3oool0LP3oool002L0oooo0P3o000H0?ooo`040?l0003oool0oooo0?l002L0oooo00<0
003o0?ooo`3o00002`3oool00`000000oooo0?ooo`0G0?ooo`<0o`0000<0oooo0?l0003oool0;P3o
ool00`3o0000oooo0?ooo`050?ooo`8000001P3oool20?l00300oooo0`3o000I0?ooo`030000003o
ool0oooo00P0oooo0P3o00000`3oool0003o0?ooo`0V0?ooo`@0o`00603oool20?l003@0oooo^`00
I00i0?ooo`05001T003oool0oooo0?ooo`00I0000P3oool00`00I000oooo0?ooo`0G0?ooo`03001T
003oool0oooo07<0oooo000Y0?ooo`030?l0003oool0oooo01L0oooo00<0o`000000o`3o00009`3o
ool010000?l0oooo0?l0003o000:0?ooo`030000003oool0oooo01L0oooo00<0o`000?ooo`000?l0
0P3o000_0?ooo`80o`001@3oool00`000000oooo0?ooo`030?ooo`80o`00<03oool40?l001X0oooo
00<000000?ooo`3oool01`3oool0103o0000oooo0?ooo`000?lV0?ooo`D0o`005`3oool20?l003H0
oooo^`00I00i0?ooo`05001T003oool0oooo0?ooo`00I0000P3oool00`00I000oooo0?ooo`0G0?oo
o`03001T003oool0oooo07<0oooo00140?ooo`040?l000000?l0o`000?l002H0oooo00@0003o0?oo
o`3oool0o`002@3oool00`000000oooo0?ooo`0J0?ooo`040000o`3o0000o`000?l002l0oooo00<0
o`000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030?l0003oool0oooo02h0oooo103o
000K0?ooo`030000003oool0oooo00H0oooo0P3o00020?ooo`030000o`3oool0oooo02@0oooo103o
000H0?ooo`030?l0003oool0oooo0?l0oooo:`3oool01@00I000oooo0?ooo`3oool006@00080oooo
00<006@00?ooo`3oool05`3oool00`00I000oooo0?ooo`1c0?ooo`00;03oool20?l001L0oooo00@0
003o0?l0003o0000o`00<`3oool00`000000oooo0?ooo`0I0?ooo`030000o`3oool0o`000080o`00
<@3oool00`3o0000oooo000000020?ooo`80o`00<03oool30?l000030000o`3oool0oooo01X0oooo
00<000000?ooo`3oool0103oool20?l000<0oooo00<0003o0?ooo`3oool08`3oool40?l000030000
o`3oool0oooo01D0oooo0P3o003o0?ooobh0oooo00<006@00?ooo`3oool00P3oool2001T01X0oooo
00<006@00?ooo`3oool0L`3oool002h0oooo0P3o000F0?ooo`050000o`3o0000oooo0?ooo`3o0000
:@3oool00`3o0000oooo0?ooo`0R0?ooo`030000o`3oool0o`000080oooo00<0o`000?ooo`3oool0
;P3oool0103o000000000?l0003o000`0?ooo`@0o`0000<0003o0?ooo`3oool06P3oool00`000000
oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool08@3oool40?l00003
0?ooo`000?l0oooo01H0oooo00<0o`000?ooo`3oool0o`3oool^0?ooo`03001T003oool0oooo01D0
oooo0P00I0070?ooo`03001T003oool0oooo07<0oooo000_0?ooo`030?l0003oool0oooo01L0oooo
1@3o000R0?ooo`030000o`3oool0oooo0080oooo0P3o000V0?ooo`<0o`00<03oool20?l002l0oooo
103o00000`3oool0003o0?ooo`0L0?ooo`030000003oool0oooo0080oooo0P3o00050?ooo`030000
o`3oool0oooo0240oooo103o00020?ooo`030000o`3oool0oooo01<0oooo0P3o003o0?oooc80oooo
00<006@00?ooo`3oool04`3oool01000I000oooo0?ooo`00I0050?ooo`03001T003oool0oooo07@0
oooo000b0?ooo`030?l0003oool0oooo01D0oooo1@3o000R0?ooo`030000o`3oool0oooo00<0oooo
00<0o`000?ooo`3oool00`3oool00`000000oooo0?ooo`0N0?ooo`@0o`00;03oool20?l000030000
003oool0oooo02d0oooo0`3o00020?ooo`030000o`3oool0oooo01/0oooo00<000000?ooo`3oool0
0P3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo0200oooo103o00030?ooo`030000
o`3oool0oooo0180oooo0P3o003o0?ooodd0oooo00<006@00?ooo`3oool0NP3oool003<0oooo0P3o
000C0?ooo`040000o`3oool0oooo0?ooo`80o`000P3oool00`3o0000oooo0?ooo`0O0?ooo`030000
o`3oool0oooo00T0oooo00<000000?ooo`3oool06P3oool00`000?l0oooo0?ooo`020?ooo`<0o`00
:@3oool20?l00080oooo00D000000?ooo`3oool0oooo0?l0000Y0?ooo`@0o`000`3oool00`000?l0
oooo0?ooo`0J0?ooo`040000003oool0oooo0?ooo`80o`001P3oool00`000?l0oooo0?ooo`0O0?oo
o`@0o`00103oool00`000?l0oooo0?ooo`0B0?ooo`030?l0003oool0oooo0?l0ooooB`3oool2001T
07d0oooo000e0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool00`3oool30?l002P0
oooo0P3o00020?ooo`030000003oool0oooo01/0oooo00<0003o0?ooo`3oool00P3oool0103o0000
oooo0?ooo`3o000U0?ooo`80o`00103oool2000000<0oooo0P3o000U0?ooo`@0o`00103oool00`00
0?l0oooo0?ooo`0K0?ooo`040000003oool0oooo0?l000L0oooo00<0003o0?ooo`3oool07`3oool3
0?l000D0oooo00<0003o0?ooo`3oool04@3oool20?l00?l0ooooD03oool00`00I000oooo0?ooo`1j
0?ooo`00BP3oool00`000?l0oooo0?ooo`030?ooo`@0o`00:03oool20?l000030?ooo`000000oooo
01`0oooo00<0003o0?ooo`3oool00`3oool30?l002<0oooo00<0o`000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030?l0003oool0oooo0240oooo0`3o00050?ooo`030000o`3oool0oooo
01/0oooo00@000000?ooo`3o0000o`00203oool00`000?l0oooo0?ooo`0M0?ooo`@0o`001P3oool0
0`000?l0oooo0?ooo`0?0?ooo`80o`00o`3ooom?0?ooo`04001T003oool0oooo001T07`0oooo000h
0?ooo`030?l0003oool0oooo01L0oooo0`3o000O0?ooo`030000o`3oool0oooo02`0oooo1@3o000O
0?ooo`80o`001`3oool00`000000oooo0?ooo`0V0?ooo`@0o`001@3oool00`000?l0oooo0?ooo`0L
0?ooo`030000003o0000oooo00P0oooo00<0003o0?ooo`3oool0703oool40?l000L0oooo00<0003o
0?ooo`3oool03`3oool00`3o0000oooo0?ooo`3o0?oooe00oooo0P00I01m0?ooo`00>@3oool20?l0
01P0oooo00@0o`000?ooo`3oool0o`007P3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0
oooo02<0oooo0`3o00000`3oool0o`000?ooo`0I0?ooo`80o`002@3oool00`000000oooo0?ooo`07
0?ooo`030?l0003oool0oooo01X0oooo103o00070?ooo`030000o`3oool0oooo01/0oooo0P3o0009
0?ooo`030000o`3oool0oooo01`0oooo0`3o00080?ooo`030000o`3oool0oooo00h0oooo0P3o003o
0?ooom80oooo000k0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool01@3oool30?l0
01d0oooo00<0003o0?ooo`3oool02@3oool00`000000o`000?ooo`0K0?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3o00000P3o000G0?ooo`80o`002`3oool00`000000oooo0?ooo`080?oo
o`80o`006@3oool30?l000P0oooo00<0003o0?ooo`3oool06`3oool00`3o000000000?ooo`080?oo
o`030000o`3oool0oooo01/0oooo103o00080?ooo`030000o`3oool0oooo00d0oooo0P3o003o0?oo
om@0oooo001>0?ooo`030000o`3oool0oooo00D0oooo103o000L0?ooo`030000o`3oool0oooo00P0
oooo00<000000?ooo`3o0000703oool00`000?l0oooo0?ooo`070?ooo`@0o`003P3oool2000000@0
oooo00<0o`000?ooo`3oool00P3oool3000000H0oooo00<000000?ooo`3oool02P3oool00`3o0000
oooo0?ooo`0D0?ooo`@0o`00203oool00`000?l0oooo0?ooo`0J0?ooo`80o`0000<000000?ooo`3o
ool0203oool00`000?l0oooo0?ooo`0I0?ooo`@0o`002@3oool00`000?l0oooo0?ooo`0=0?ooo`03
0?l0003oool0oooo0?l0ooooe03oool003h0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo
0?ooo`070?ooo`<0o`009`3oool00`000000oooo0?ooo`0L0?ooo`030000o`3oool0oooo00P0oooo
0`3o000<0?ooo`050000003oool0oooo0000003oool00P3o00080?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool03@3oool00`3o0000oooo0?ooo`0?0?ooo`@0o`002@3oool00`000?l0
oooo0?ooo`0J0?ooo`040?l0003oool0oooo000000T0oooo00<0003o0?ooo`3oool06@3oool30?l0
00X0oooo00<0003o0?ooo`3oool0303oool20?l00?l0ooooe`3oool003l0oooo0P3o000>0?ooo`03
0000o`3oool0oooo00L0oooo00@0o`000?ooo`3oool0o`009@3oool01@000000oooo0?ooo`3oool0
o`0001/0oooo00<0003o0?ooo`3oool0203oool0103o0000oooo0?ooo`3o000:0?ooo`030000003o
ool0oooo0080o`002P3oool00`000000oooo0?ooo`030?ooo`<000003P3oool20?l000h0oooo0`3o
000:0?ooo`030000o`3oool0oooo01T0oooo0P3o00020?ooo`030000003oool0oooo00L0oooo00<0
003o0?ooo`3oool0603oool40?l000/0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?oo
o`3o0?ooomL0oooo00110?ooo`030?l0003oool0oooo01L0oooo0`3o000K0?ooo`030000o`3oool0
oooo00/0oooo0P3o000V0?ooo`<0o`000`3oool400000080oooo00@000000?ooo`3o00000000203o
ool3000000H0oooo00<000000?ooo`3oool0403oool00`3o0000oooo0?ooo`090?ooo`@0o`002`3o
ool00`000?l0oooo0?ooo`0H0?ooo`050?l0003oool0oooo0?ooo`0000002@3oool00`000?l0oooo
0?ooo`0G0?ooo`@0o`00303oool00`000?l0oooo0?ooo`0:0?ooo`80o`00o`3ooooJ0?ooo`00A03o
ool00`3o0000oooo0?ooo`0E0?ooo`@0o`006P3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo02@0oooo103o00070?ooo`80o`0000<0oooo0000003oool01`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo01X0oooo103o000<0?ooo`030000o`3oool0oooo01L0oooo0P3o
00040?ooo`030000003oool0oooo00H0oooo00<0003o0?ooo`3oool05`3oool40?l000`0oooo00<0
003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`3o0?ooodL0oooo00<0o`000?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`0=0?ooo`030?l0003oool0oooo07L0oooo00150?ooo`80o`002P3oool0
0`000?l0oooo0?ooo`0:0?ooo`<0o`0000<0oooo0?l0003oool05`3oool00`000?l0oooo0?ooo`0V
0?ooo`030000o`3oool0oooo00/0oooo0`3o00040?ooo`80o`0000@000000?ooo`3oool00000203o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01<0oooo00<0o`000?ooo`3oool00`3o
ool30?l000d0oooo00<0003o0?ooo`3oool05P3oool20?l000D0oooo00<000000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`0F0?ooo`@0o`003@3oool00`000?l0oooo0?ooo`090?ooo`80o`00o`3o
oom90?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool03@3oool00`3o0000oooo0?oo
o`1f0?ooo`00A`3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00X0oooo00<0o`00
0?ooo`3o00000P3o000P0?ooo`030000003oool0oooo00D0oooo00<0o`000?ooo`3oool05P3oool0
0`000?l0oooo0?ooo`0;0?ooo`060?l0003oool0oooo0?l0003oool0o`000`3oool2000000T0oooo
100000050?ooo`030000003oool0oooo01@0oooo0P3o00000`3oool0o`000?l000020?l000d0oooo
00<0003o0?ooo`3oool05@3oool20?l000L0oooo00<000000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`0E0?ooo`<0o`003P3oool00`000?l0oooo0?ooo`080?ooo`80o`00o`3ooom;0?ooo`040?l0
003oool0oooo0?ooo`@0o`000`3oool00`3o0000oooo0?ooo`070?ooo`80o`00103oool00`3o0000
oooo0?ooo`1f0?ooo`00D`3oool00`000?l0oooo0?ooo`0<0?ooo`@0o`007`3oool00`000000oooo
0?ooo`050?ooo`80o`005`3oool00`000?l0oooo0?ooo`0<0?ooo`<0o`00603oool00`000000oooo
0?ooo`0F0?ooo`<0o`003P3oool00`000?l0oooo0?ooo`0E0?ooo`030?l0003oool0oooo00H0oooo
00<000000?ooo`3oool01P3oool00`000?l0oooo0?ooo`0D0?ooo`@0o`003P3oool00`000?l0oooo
0?ooo`080?ooo`030?l0003oool0oooo0?l0ooooB`3oool00`3o0000oooo0?ooo`030?ooo`030?l0
003oool0oooo00/0oooo00@0o`000?ooo`3oool0o`000`3oool00`3o0000oooo0?ooo`1f0?ooo`00
BP3oool00`3o0000oooo0?ooo`0G0?ooo`<0o`005P3oool00`000?l0oooo0?ooo`050?ooo`030000
003oool0oooo00L0oooo00<0o`000?ooo`3oool08P3oool60?l001H0oooo00<000000?ooo`3oool0
503oool40?l000h0oooo00<0003o0?ooo`3oool0503oool20?l000T0oooo00<000000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`0C0?ooo`@0o`00403oool00`000?l0oooo0?ooo`060?ooo`80o`00
EP3oool50?l000<0oooo103o00030?ooo`D0o`000P3oool50?l000<0oooo1@3o00020?ooo`D0o`00
0`3oool50?l00080oooo1@3o00030?ooo`@0o`000`3oool50?l000<0oooo103o00030?ooo`D0o`00
0`3oool40?l000<0oooo1@3o00020?ooo`D0o`000`3oool50?l00080oooo1@3o00030?ooo`@0o`00
0`3oool50?l000<0oooo103o00030?ooo`D0o`000`3oool40?l000<0oooo1@3o00020?ooo`D0o`00
0`3oool50?l00080oooo00<0o`000?ooo`3oool0>@3oool00`3o0000oooo0?ooo`040?ooo`030?l0
003oool0oooo00/0oooo00@0o`000?ooo`3oool0o`00103oool00`3o0000oooo0?ooo`1e0?ooo`00
B`3oool20?l001P0oooo00@0o`000?ooo`3oool0o`005@3oool00`000?l0oooo0?ooo`050?ooo`03
0000003oool0oooo00T0oooo00<0o`000?ooo`3oool07P3oool00`3o0000oooo0?ooo`020?ooo`<0
o`005@3oool2000001<0oooo103o00030?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3o
ool04P3oool20?l000X0oooo00<000000?ooo`3oool01@3oool00`000?l0oooo0?ooo`0C0?ooo`@0
o`00403oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo0?l0ooooCP3oool00`3o0000
oooo0?ooo`030?ooo`030?l0003oool0oooo00/0oooo00@0o`000?ooo`3oool0o`000`3oool00`3o
0000oooo0?ooo`1f0?ooo`00C@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00l0
oooo103o000C0?ooo`030000o`3oool0oooo0180oooo0P3o000C0?ooo`030000o`3oool0oooo00H0
oooo0P3o00060?ooo`040?l0003oool0oooo0?l001<0oooo00<000000?ooo`3oool04@3oool40?l0
00D0oooo0P3o00090?ooo`030000o`3oool0oooo0140oooo0P3o000<0?ooo`030000003oool0oooo
00@0oooo00<0003o0?ooo`3oool04P3oool40?l00140oooo00<0003o0?ooo`3oool01@3oool20?l0
0?l0ooooD@3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00/0oooo00@0o`000?oo
o`3oool0o`000`3oool00`3o0000oooo0?ooo`1f0?ooo`00EP3oool00`000?l0oooo0?ooo`0?0?oo
o`@0o`004`3oool00`000?l0oooo0?ooo`0C0?ooo`030?l0003oool0oooo0140oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`080?ooo`D0o`00403oool00`000000oooo0?ooo`0?0?oo
o`@0o`002@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo0140oooo00<0o`000?oo
o`3oool02`3oool00`000000oooo0?ooo`040?ooo`030000o`3oool0oooo0180oooo0`3o000B0?oo
o`030000o`3oool0oooo00@0oooo0P3o003o0?oooe@0oooo00<0o`000?ooo`3oool00`3o000=0?oo
o`040?l0003oool0oooo0?l00080oooo00<0o`000?ooo`3oool0M`3oool00200oooo<000I0000`3o
000006@0001T0004001T00030000o`00I00006@0010006@00`3o000J001T000300000000I00006@0
01l006@000<0003o001T0000I0004000I0050?l00<0006@0o`3oool[0?ooo`030?l0003oool0oooo
00`0oooo0P3o001m0?ooo`00D@3oool20?l000D0oooo00<0003o0?ooo`3oool0403oool0103o0000
oooo0?ooo`3o000I0?ooo`030000003oool0oooo00d0oooo00<0o`000?ooo`3oool03`3oool01000
0?l0oooo0?ooo`3o000A0?ooo`040?l0003oool0oooo0?l000d0oooo00<000000?ooo`3oool0303o
ool40?l000l0oooo0P3o00000`3oool0003o0?ooo`0@0?ooo`80o`003`3oool00`000000oooo0?oo
o`040?ooo`030000o`3oool0oooo0100oooo0`3o000C0?ooo`030000o`3oool0oooo00<0oooo0P3o
003o0?ooonX0oooo001C0?ooo`030?l0003oool0oooo01L0oooo0`3o000B0?ooo`030000o`3oool0
oooo00<0oooo00<000000?ooo`3oool03P3oool20?l00100oooo0P3o000D0?ooo`<0o`00303oool0
0`000000oooo0?ooo`0;0?ooo`<0o`004`3oool20?l00100oooo00<0o`000?ooo`3oool03P3oool0
0`000000oooo0?ooo`040?ooo`030000o`3oool0oooo00l0oooo103o000D0?ooo`040000o`3oool0
oooo0?ooo`80o`00o`3oooo/0?ooo`00KP3oool40?l00140oooo00<0003o0?ooo`3oool00`3oool0
0`000000oooo0?ooo`0?0?ooo`030?l0003oool0oooo00`0oooo00<0o`000?ooo`3oool0503oool5
0?l000X0oooo00<000000?ooo`3oool02@3oool40?l001@0oooo00<0003o0?ooo`3oool03@3oool2
0?l00140oooo00<000000?ooo`3oool00`3oool00`000?l0oooo0?ooo`0>0?ooo`@0o`005@3oool0
1@000?l0oooo0?ooo`3oool0o`000?l0ooookP3oool00200oooo00<0o`000?ooo`3oool0<`3oool2
0?l00080oooo00<0003o0?ooo`3oool04`3oool30?l000030?ooo`3o0000oooo00h0oooo00<0003o
0?ooo`3oool08@3oool20?l000<0oooo00<0003o0?ooo`3oool0503oool30?l000T0oooo0P000008
0?ooo`@0o`005@3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00L0oooo0P3o000B
0?ooo`030000003oool0oooo00<0oooo00<0003o0?ooo`3oool03P3oool40?l001D0oooo00<0003o
0?ooo`3oool00P3o000e0?ooo`030?l0003oool0oooo0?l0oooo]`3oool00200oooo0P3o000f0?oo
o`80o`0000<0oooo0000o`3oool0503oool00`3o0000oooo0?l000020?l002P0oooo00<0o`000?oo
o`3oool01P3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo01@0oooo00@0o`000?oo
o`3oool0o`001`3oool00`000000oooo0?ooo`060?ooo`<0o`005P3oool00`000?l0oooo0?ooo`04
0?ooo`80o`001P3oool00`3o0000oooo0?ooo`0B0?ooo`030000003oool0oooo0080oooo00<0003o
0?ooo`3oool03@3oool40?l001H0oooo00@0003o0?ooo`3o0000o`00=@3oool30?l00?l0oooo^@3o
ool00200oooo103o000h0?ooo`030000o`3oool0oooo01D0oooo103o000C0?ooo`030000003oool0
oooo0140oooo0P3o00040?ooo`80o`00203oool00`000?l0oooo0?ooo`0E0?ooo`<0o`001P3oool0
0`000000oooo0?ooo`040?ooo`@0o`005P3oool00`000?l0oooo0?ooo`070?ooo`040?l0003oool0
oooo0?ooo`80o`00503oool00`000000oooo0?ooo`030?ooo`030000o`3oool0oooo00`0oooo0`3o
000G0?ooo`030000o`3oool0o`0003H0oooo103o003o0?oookT0oooo000R0?ooo`<0o`00=`3oool0
0`3o0000oooo0?ooo`0G0?ooo`<0o`003@3oool00`000?l0oooo0?ooo`020?ooo`030000003oool0
oooo01<0oooo00@0o`000?ooo`3oool0o`008`3oool40?l000@0oooo00<000000?ooo`3oool00P3o
ool40?l001L0oooo00<0003o0?ooo`3oool02P3oool20?l001H0oooo00<000000?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`0;0?ooo`@0o`005`3oool00`000?l0o`000?l0000e0?ooo`@0o`00o`3o
oonk0?ooo`008`3oool0103o0000oooo0?ooo`3o000f0?ooo`80o`00603oool0103o0000oooo0?oo
o`3o000;0?ooo`030000o`3oool0oooo00<0oooo00<000000?ooo`3oool04`3oool30?l002D0oooo
0`3o00030?ooo`040000003oool0oooo0?ooo`<0o`00603oool00`000?l0oooo0?ooo`0:0?ooo`03
0?l0003oool0o`0001D0oooo00<000000?ooo`3oool00P3oool00`000?l0oooo0?ooo`0;0?ooo`<0
o`006@3oool00`3o0000oooo0?ooo`0c0?ooo`@0o`00o`3ooonm0?ooo`009@3oool50?l003@0oooo
00<0003o0?l0003oool0603oool30?l000/0oooo00<0003o0?ooo`3oool00P3oool00`000000oooo
0?ooo`0B0?ooo`030?l0003oool0oooo0080o`002`3oool00`000?l0oooo0?ooo`0G0?ooo`070?l0
003oool0oooo0?l0003oool000000?ooo`040?l001T0oooo00<0003o0?ooo`3oool0203oool20?l0
00<0oooo0P3o000C0?ooo`050000003oool0oooo0?ooo`000?l0303oool40?l001P0oooo0P3o000d
0?ooo`D0o`00o`3ooonn0?ooo`009P3oool50?l003@0oooo00<0003o0?ooo`3oool0603oool40?l0
00X0oooo00<0003o0?ooo`3oool0503oool20?l000D0oooo0P3o000:0?ooo`030000o`3oool0oooo
01P0oooo1`3o000J0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01@3oool00`3o
0000oooo0?ooo`0?0?ooo`050000003oool0oooo0?ooo`000?l02`3oool40?l001P0oooo0P3o0000
0`000?l0oooo0?ooo`0b0?ooo`@0o`00o`3oooo00?ooo`00:@3oool0103o0000oooo0?ooo`3o000b
0?ooo`040000o`3oool0oooo0?l001T0oooo0`3o000O0?ooo`030?l0003oool0oooo0140oooo00<0
003o0?ooo`3oool06@3oool40?l001/0oooo00<0003o0?ooo`3oool01`3oool20?l001X0oooo00D0
00000?ooo`3oool0oooo0000o`0:0?ooo`<0o`006@3oool00`3o0000oooo0000o`0c0?ooo`@0o`00
o`3oooo20?ooo`00:`3oool30?l00380oooo00<0003o0?ooo`3oool00P3o000H0?ooo`040?l0003o
ool0oooo0?l000T0oooo00D0003o0?ooo`3oool0oooo0000000=0?ooo`80o`00303oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo01L0oooo1P3o00000`3oool0o`000?ooo`0F0?ooo`03
0000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool02`3oool20?l000`0oooo00D000000?ooo`3o
ool0oooo0000o`090?ooo`@0o`00603oool20?l000030?ooo`000?l0oooo0340oooo103o003o0?oo
ol@0oooo000/0?ooo`@0o`00=@3oool00`3o0000oooo0?ooo`0G0?ooo`<0o`002@3oool01@000?l0
oooo0?ooo`3oool0000000X0oooo0P3o000?0?ooo`80o`007`3oool30?l000040?ooo`000000o`00
0?ooo`<0o`005@3oool00`000?l0oooo0?ooo`060?ooo`80o`00403oool20?l000X0oooo00@00000
0?ooo`3oool0003o203oool40?l001T0oooo00@0o`000?ooo`3oool0003o<P3oool40?l00?l0oooo
<P3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00d0oooo00<0o`000?ooo`3oool0
M`3oool002h0oooo0`3o000b0?ooo`030000o`3oool0oooo01X0oooo103o00080?ooo`040000o`3o
ool0oooo000000T0oooo00<0o`000?ooo`3oool04@3oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo0180oooo103o00020?ooo`040000003oool0oooo0?ooo`@0o`004`3oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo01/0oooo00@000000?ooo`3oool0003o203oool30?l0
01T0oooo0P3o00030?ooo`030000o`3oool0oooo02h0oooo103o003o0?oooc<0oooo00<0o`000?oo
o`3oool0203oool00`3o0000oooo0?ooo`0=0?ooo`030?l0003oool0oooo07H0oooo000K0?ooo`@0
00000`3oool00`000000oooo0?ooo`020?ooo`<00000103oool20?l00080oooo00<0o`000?ooo`3o
ool09`3oool4000000@0oooo00@0003o0?ooo`3oool0oooo0P3o000H0?ooo`<0o`00203oool00`00
0?l0oooo0?ooo`03000000@0oooo0P3o00030?ooo`<000005`3oool00`000?l0oooo0?ooo`0?0?oo
o`@0o`00103oool00`000000oooo0?ooo`030?ooo`<0o`004@3oool00`000?l0oooo0?ooo`040?oo
o`80o`004@3oool2000000@0oooo00<0o`000?ooo`3oool00P3oool300000080oooo00<0003o0?oo
o`3oool0103oool40?l001P0oooo0P3o00040?ooo`030000o`3oool0oooo00<0oooo1000000W0?oo
o`<0o`001`3oool4000000<0oooo00<000000?ooo`3oool00P3oool300000?l0oooo7`3oool0103o
0000oooo0?ooo`3oool40?l000<0oooo00<0o`000?ooo`3oool01P3oool40?l000<0oooo00<0o`00
0?ooo`3oool0MP3oool001d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`040?oo
o`<0o`00:P3oool00`000000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0o`000?oo
o`3oool05P3oool01@3o0000oooo0?ooo`3oool0o`0000P0oooo00@000000?ooo`3oool000000P3o
ool00`3o0000oooo0?ooo`060?ooo`030000003oool0oooo00h0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`0=0?ooo`@0o`001@3oool00`000000oooo0?ooo`040?ooo`040?l0003o
ool0oooo0?l000h0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`0@0?ooo`040000
003oool0oooo000000@0oooo00<0o`000?ooo`3oool00P3oool010000000oooo000000000?l50?oo
o`@0o`006@3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00H0oooo00<000000?oo
o`3oool0903oool40?l000X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0T0?oo
o`D0o`000P3oool50?l00080oooo1P3o00000`3oool0o`000?l000040?l00080oooo1P3o00000`3o
ool0o`000?l000040?l00080oooo1P3o00000`3oool0o`000?l000040?l00080oooo1@3o00020?oo
o`H0o`000P3oool50?l00080oooo1P3o00020?ooo`D0o`000P3oool60?l000030?ooo`3o0000o`00
00@0o`000P3oool60?l000030?ooo`3o0000o`0000@0o`000P3oool50?l00080oooo1P3o00020?oo
o`D0o`000P3oool60?l00080oooo1@3o00020?ooo`H0o`0000<0oooo0?l0003o0000103o00020?oo
o`H0o`0000<0oooo0?l0003o0000?03oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo
00d0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`1f0?ooo`007@3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo103o000X0?ooo`030000003oool0oooo00@0
oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`0G0?ooo`D0o`001P3oool010000000
oooo0?ooo`0000020?l000T0oooo00<000000?ooo`3oool03`3oool20?l000D0oooo00<0003o0?oo
o`3oool02P3oool40?l000L0oooo00<000000?ooo`3oool01P3oool30?l000`0oooo00<0003o0?oo
o`3oool00`3oool20?l001<0oooo00@000000?ooo`3oool000001@3oool01`3o0000oooo0?ooo`3o
ool000000?ooo`000?l01@3oool30?l001T0oooo0P3o00050?ooo`030000o`3oool0oooo00L0oooo
00<000000?ooo`3oool08`3oool30?l000`0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0T0?ooo`D0o`000P3oool50?l00080oooo1P3o00000`3oool0o`000?l000040?l00080oooo
1P3o00000`3oool0o`000?l000040?l00080oooo1P3o00000`3oool0o`000?l000040?l00080oooo
1@3o00020?ooo`H0o`000P3oool50?l00080oooo1P3o00020?ooo`D0o`000P3oool60?l000030?oo
o`3o0000o`0000@0o`000P3oool60?l000030?ooo`3o0000o`0000@0o`000P3oool50?l00080oooo
1P3o00020?ooo`D0o`000P3oool60?l00080oooo1@3o00020?ooo`H0o`0000<0oooo0?l0003o0000
103o00020?ooo`H0o`0000<0oooo0?l0003o0000>`3oool00`3o0000oooo0?ooo`040?ooo`030?l0
003oool0oooo00d0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`1e0?ooo`005@3o
ool4000000@0oooo00<000000?ooo`3oool01`3oool3000000X0oooo0`3o000O0?ooo`@00000103o
ool00`000000oooo0?ooo`0=0?ooo`030?l0003oool0oooo01@0oooo1P3o0003000000040?ooo`00
0?l0000000000080o`00203oool3000001@0oooo00<0o`000?ooo`3oool03P3oool30?l000T0oooo
00<000000?ooo`3oool01`3oool40?l000X0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo
0?ooo`0C0?ooo`040000003oool0oooo000000P0oooo0P0000000`000?l0oooo0?ooo`020?ooo`@0
o`006@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00P0oooo00<000000?ooo`3o
ool08@3oool40?l000d0oooo00<000000?ooo`3oool01`3oool300000?l0oooo7`3oool00`3o0000
oooo0?ooo`030?ooo`030?l0003oool0oooo00d0oooo00<0o`000?ooo`3oool00P3oool00`3o0000
oooo0?ooo`1f0?ooo`007@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00/0oooo
00@0o`000?ooo`3oool0o`009@3oool00`000000oooo0?ooo`0>0?ooo`80o`00603oool0103o0000
oooo0?ooo`3o00030?ooo`040000o`3o00000000000000P0oooo00<000000?ooo`3oool08`3oool4
0?l000X0oooo0P00000:0?ooo`<0o`00203oool010000?l0oooo0?ooo`3oool20?l001H0oooo00@0
00000?ooo`3oool00000203oool00`3o0000003o0?ooo`030?ooo`<0o`006@3oool20?l000H0oooo
00<0003o0?ooo`3oool02@3oool00`000000oooo0?ooo`0P0?ooo`<0o`003`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo0?l0oooo7`3oool00`3o0000oooo0?ooo`030?ooo`030?l0
003oool0oooo00d0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`1f0?ooo`006`3o
ool3000000T0oooo00<000000?ooo`3oool03@3oool30?l00280oooo0`0000080?ooo`030000o`3o
ool0oooo00L0oooo00<0o`000?ooo`3oool05`3oool30?l000040?ooo`3o0000003o0?ooo`800000
203oool00`000000oooo0?ooo`0G0?ooo`80o`000P3oool00`000?l0oooo0?ooo`040?ooo`<0o`00
303oool00`000000oooo0?ooo`0:0?ooo`040?l0003oool0oooo0?l000D0oooo00D0003o0?ooo`3o
ool0oooo0?l0000H0?ooo`040000003oool0oooo000000L0oooo0P0000020?l000030?ooo`3o0000
o`000080o`006@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00L0oooo0`00000P
0?ooo`@0o`003P3oool3000000T0oooo00<000000?ooo`3oool0o`3ooolP0?ooo`030?l0003oool0
oooo00<0o`003@3oool30?l000<0oooo00<0o`000?ooo`3oool0M`3oool001d0oooo00<000000?oo
o`3oool01`3oool4000000d0oooo103o000R0?ooo`030000003oool0oooo00L0oooo00<0003o0?oo
o`3oool08@3oool40?l000040?ooo`000?l00000000000P0oooo1000000H0?ooo`80o`0000<0oooo
0000o`3oool00P3oool40?l000d0oooo00<000000?ooo`3oool0303oool30?l000<0oooo00<0003o
0?ooo`3oool00P3o000J0?ooo`800000203oool00`000000003o000000040?l001T0oooo0P3o0008
0?ooo`030000o`3oool0oooo00X0oooo00<000000?ooo`3oool07@3oool30?l00180oooo00<00000
0?ooo`3oool01`3oool400000?l0oooo903oool00`3o0000oooo0?ooo`0=0?ooo`030?l0003oool0
oooo07/0oooo000j0?ooo`<0o`0000<0oooo0?l0003oool0:03oool00`000?l0oooo0?ooo`090?oo
o`030?l0003oool0oooo01D0oooo00<0o`000?ooo`3o00000P3o000Z0?ooo`030000o`3oool0o`00
00<0o`003`3oool00`000000oooo0?ooo`0=0?ooo`@0o`0000@0003o0?ooo`3oool0o`009@3oool0
0`000000003o0?ooo`040?l001P0oooo0P3o00090?ooo`030000o`3oool0oooo02T0oooo103o003o
0?ooom<0oooo000k0?ooo`030?l0003oool0o`000080o`00:@3oool00`000?l0oooo0?ooo`090?oo
o`80o`004`3oool20?l000<0oooo00D0o`000?ooo`3oool0o`000000o`0X0?ooo`030000o`3o0000
o`000140oooo00<000000?ooo`3oool03`3oool50?l002H0oooo00<0003o0?l0003o00000P3o0003
0?ooo`030?l0003oool0oooo01<0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`0Y
0?ooo`<0o`00o`3ooooE0?ooo`00?P3oool40?l003D0oooo00<0o`000?ooo`3oool03P3oool20?l0
00L0oooo0`3o00000`000?l000000?ooo`0S0?ooo`D0o`004@3oool00`000000oooo0?ooo`0@0?oo
o`D0o`00903oool010000000o`000?l0003o00060?ooo`80o`004@3oool20?l000X0oooo00<0003o
0?ooo`3oool0:03oool40?l00?l0ooooeP3oool00400oooo0`3o000X0?ooo`030000o`3oool0oooo
01T0oooo00<0o`000?ooo`3oool0203oool20?l000030000o`000000oooo0240oooo103o00020?oo
o`030000o`3o0000oooo00l0oooo00<000000?ooo`3oool03`3oool0103o0000oooo0?ooo`3oool4
0?l00240oooo103o00090?ooo`030?l0003oool0oooo00d0oooo00<0o`000?ooo`3oool02@3oool0
0`000?l0oooo0?ooo`0X0?ooo`<0o`00o`3ooooH0?ooo`00803oool00`3o000006@0001T000N001T
00040?l00000I00006@00?l002L006@000<0003o001T0000I0002`00I0000`3o000006@0001T000G
001T00030?l000000?l0000002P006@000<0003o001T0000I0009P00I0030?l0030006@000<0o`00
001T0000I000H`00I03o0?oookT0oooo000P0?ooo`03001T003o0000o`00020006@00`3o000W001T
00030000o`00I00006@000/006@00P3o000H001T00040?l00000000006@00?l002L006@000<0003o
001T003o00009P00I000103o000006@0001T003o000_001T0080o`00H`00I03o0?oookT0oooo000P
0?ooo`040000003oool0oooo0?l00200oooo103o000C0?ooo`030000003oool0oooo0100oooo00<0
003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo0100oooo0P00
00050?l001L0oooo103o000:0?ooo`040000o`3oool0o`000?l000/0oooo00<000000?ooo`3oool0
2P3oool20?l000030?ooo`000?l0oooo00T0oooo0`3o000H0?ooo`@0o`000P00000B0?ooo`030?l0
003oool0oooo0080oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0@0?ooo`030000
003oool0oooo0180oooo103o000O0?ooo`040?l0003oool0oooo00000?l0oooo^@3oool004H0oooo
0`3o000g0?ooo`80o`005P3oool00`000?l0o`000?l000020?l001D0oooo0`3o000@0?ooo`030?l0
003oool0oooo00P0oooo00<000000?ooo`3oool0203oool20?l00080oooo00<0003o0?ooo`3oool0
2P3oool40?l001D0oooo0`3o00000`000?l000000?ooo`0F0?ooo`80o`003P3oool00`000?l0oooo
0?ooo`0T0?ooo`@0o`007`3oool20?l00?l0oooo?@3oool40000og`0oooo000V0?ooo`030?l0003o
ool0oooo01h0oooo00@0o`000?ooo`3oool0o`00<`3oool20?l000030?ooo`3o0000o`0001H0oooo
00<0003o0?ooo`3o00000P3oool00`3o0000oooo0?ooo`0?0?ooo`@0o`00703oool00`000000oooo
0?ooo`070?ooo`050?l0003oool0oooo0?ooo`000?l03P3oool40?l00180oooo103o00000`3oool0
003o0000000E0?ooo`<0o`003`3oool00`000?l0oooo0?ooo`0S0?ooo`<0o`00803oool00`3o0000
oooo0?ooo`3o0?ooocd0oooo00<0003o0?ooo`3oool0O@3oool002L0oooo0P3o000P0?ooo`D0o`00
8P3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0
4P3oool00`000000003o0?ooo`020?ooo`<0o`003P3oool40?l00140oooo00<0003o0?ooo`3oool0
0P3oool00`3o0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo0P3o00030?ooo`030000
o`3oool0oooo00l0oooo00@0o`000?ooo`3oool0o`003P3oool40?l00080oooo00<0003o0000003o
ool0503oool0103o0000oooo0?ooo`3oool20?l000`0oooo00<0003o0?ooo`3oool08P3oool40?l0
01l0oooo0P3o003o0?ooobX0oooo00<0003o0?ooo`3oool0503oool00`000?l0oooo0?ooo`050?oo
o`030000o`3oool0oooo07@0oooo000Y0?ooo`030?l0003oool0oooo01h0oooo1@3o000R0?ooo`03
0000o`3oool0oooo00L0oooo0P3o000L0?ooo`03000000000?l0oooo0080oooo103o000;0?ooo`<0
o`00503oool00`000?l0oooo0?ooo`020?ooo`80o`001@3oool00`000000oooo0?ooo`030?ooo`80
o`00103oool00`000?l0oooo0?ooo`0B0?ooo`<0o`00303oool30?l000<0oooo00<0003o0?ooo`00
00004`3oool20?l000H0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`0R0?ooo`<0
o`007`3oool20?l00?l0oooo:`3oool00`000?l0oooo0?ooo`0F0?ooo`030000o`3oool0oooo00D0
oooo00<0003o0?ooo`3oool0L`3oool004`0oooo0P3o00020?ooo`030?l0003oool0oooo01h0oooo
00<0003o0?ooo`3oool01@3oool20?l000/0oooo00<0o`000?ooo`3oool0403oool00`000000oooo
0?ooo`040?ooo`<0o`00203oool40?l001D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo
0?ooo`020?ooo`8000000`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo01<0oooo
103o00080?ooo`@0o`000`3oool00`000?l0oooo0000000B0?ooo`80o`004P3oool00`000?l0oooo
0?ooo`0Q0?ooo`@0o`007`3oool00`3o0000oooo0?ooo`3o0?ooob/0oooo00<0003o0?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0
L`3oool002`0oooo0P3o000N0?ooo`80o`0000@0oooo0?l0003o0000o`00803oool00`000?l0oooo
0?ooo`030?ooo`030?l0003oool0oooo00`0oooo0P3o000A0?ooo`030000003oool0003o00@0oooo
00@0o`000?ooo`3oool0o`00103oool40?l001P0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo000000020?ooo`80o`001P3oool00`000?l0oooo0?ooo`0F0?ooo`<0o`001@3oool40?l000@0
oooo00@0003o0?ooo`3oool000004@3oool00`3o0000oooo0?ooo`0;0?ooo`80o`00103oool00`00
0?l0oooo0?ooo`0P0?ooo`@0o`007`3oool20?l00?l0oooo;P3oool00`000?l0oooo0?ooo`080?oo
o`030000o`3oool0oooo00T0oooo00@0003o0?ooo`3oool0003o1P3oool00`000?l0oooo0?ooo`1c
0?ooo`00;P3oool20?l00200oooo103o000R0?ooo`80o`004@3oool00`3o0000oooo0?ooo`0A0?oo
o`030000o`3oool0oooo00<0oooo0`3o00020?ooo`<0o`00903oool0103o000000000?l0003o0007
0?ooo`030000o`3oool0oooo01P0oooo00@0o`000?ooo`3oool0o`000P3oool30?l000D0oooo00@0
003o0?ooo`3oool00000403oool20?l00100oooo00D0o`000?ooo`3oool0oooo0000o`0Q0?ooo`<0
o`00803oool00`3o0000oooo0?ooo`3o0?ooobh0oooo00@0003o0?ooo`3oool0oooo10000?l30?oo
o`030000o`3oool0oooo00X0oooo0P000?l70?ooo`030000o`3oool0oooo07<0oooo001B0?ooo`<0
o`007`3oool00`000?l0o`000?ooo`0V0?ooo`030000o`3oool0oooo00<0oooo1`3o000M0?ooo`03
0000o`3oool0oooo00H0oooo0P3o00070?ooo`030000o`3oool0oooo01/0oooo1P3o00060?ooo`03
0000o`3oool000000100oooo00<0o`000?ooo`3oool04@3oool00`3o0000oooo0000o`0P0?ooo`@0
o`007`3oool20?l00?l0oooo<@3oool01@000?l0oooo0?ooo`3oool0003o01`0oooo00<0003o0?oo
o`3oool0L`3oool00380oooo00<0o`000?ooo`3oool07P3oool0103o0000oooo0?ooo`3o000L0?oo
o`80o`0000<0003o0?ooo`3oool0503oool00`3o0000oooo0?ooo`0<0?ooo`040000003oool0oooo
0000o`D0oooo1@3o000O0?ooo`030000o`3oool0oooo00<0oooo0P3o00000`000000oooo0?ooo`05
0?ooo`030000o`3oool0oooo01`0oooo1P3o00050?ooo`040000o`3oool0oooo000000h0oooo0P3o
000E0?ooo`030000o`3oool0o`0001d0oooo103o000O0?ooo`80o`00?P3oool50000o`<0oooo1000
0?l30?ooo`D0003o0P3oool50000o`<0oooo1@000?l20?ooo`D0003o0`3oool50000o`80oooo1@00
0?l30?ooo`@0003o0`3oool50000o`<0oooo10000?l30?ooo`D0003o0`3oool40000o`<0oooo1@00
0?l20?ooo`D0003o0`3oool50000o`80oooo1@000?l30?ooo`@0003o0`3oool50000o`<0oooo1000
0?l30?ooo`D0003o0`3oool40000o`<0oooo1@000?l20?ooo`D0003o0`3oool50000o`80oooo00<0
003o0?ooo`3oool0=P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00`0oooo1P00
0?l00`3oool0003o0000o`050?ooo`030000o`3oool0oooo0780oooo000c0?ooo`80o`00803oool3
0?l001X0oooo00D0o`000?ooo`3oool0oooo0000o`0F0?ooo`80o`003@3oool00`000000oooo0?oo
o`040?ooo`<0o`0000D0oooo0?l0003oool0oooo0?l0000M0?ooo`030000o`3oool0oooo0080oooo
00@0o`000?ooo`3oool000000`3oool0103o0000oooo0?ooo`000?lN0?ooo`<0o`000P3oool0103o
0000oooo0?ooo`3o00020?ooo`040000o`3oool0oooo000000h0oooo00<0o`000?ooo`3oool0503o
ool010000?l0oooo0?ooo`3oool20?l001X0oooo0`3o000P0?ooo`030?l0003oool0oooo0?l0oooo
<`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo01P0oooo00<0003o0?ooo`3oool0
L`3oool003D0oooo00<0o`000?ooo`3oool07P3oool40?l001H0oooo0P3o00050?ooo`030000o`3o
ool0oooo01D0oooo00<0o`000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`@0o`00103o
ool30?l001d0oooo00@0003o0?ooo`3o0000o`000`3oool00`000000oooo0?ooo`020?ooo`80o`00
00<0003o0?ooo`3oool06P3oool40?l000D0oooo0`3o00001@000?l0oooo0?ooo`3oool0000000`0
oooo0P3o000G0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool05@3oool40?l001l0
oooo0P3o003o0?ooocH0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0G0?ooo`03
0000o`3oool0oooo07<0oooo001H0?ooo`<0o`004`3oool20?l002d0oooo00H000000?ooo`3oool0
o`000000o`3o00070?ooo`@0o`00703oool00`3o0000oooo0?ooo`030?ooo`030000003oool0oooo
00<0oooo00<0003o0?l0003oool06@3oool40?l000P0oooo103o00000`3oool000000?ooo`0:0?oo
o`80o`00603oool00`000?l0oooo0?ooo`0J0?ooo`@0o`007`3oool20?l00?l0oooo>03oool01@00
0?l0oooo0?ooo`3oool0003o0080oooo00<0003o0?ooo`3oool05`3oool00`000?l0oooo0?ooo`1c
0?ooo`00>03oool00`3o0000oooo0?ooo`0N0?ooo`040?l0003oool0oooo0?l00100oooo00<0o`00
0?ooo`3oool08P3oool20?l000X0oooo103o00000`000?l0oooo0?ooo`070?ooo`<0o`0000<0oooo
0?l0003oool05P3oool20?l000H0oooo0P0000030?ooo`030000o`3oool0oooo01T0oooo0`3o000:
0?ooo`030000o`3oool0o`000080o`0000<000000?ooo`3oool0203oool00`3o0000oooo0?ooo`0G
0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool03P3oool40?l00200oooo00<0o`00
0?ooo`3oool0o`3ooolh0?ooo`030000o`3oool0oooo0080oooo0P000?l@0?ooo`@0003o1P3oool0
0`000?l0oooo0?ooo`1c0?ooo`00>@3oool20?l00200oooo0`3o000=0?ooo`80o`00303oool00`00
0?l0oooo0?ooo`0H0?ooo`80o`001P3oool40?l000<0oooo00<0003o0?ooo`3oool01`3oool00`3o
0000oooo0?l000020?l001@0oooo0P3o00040?ooo`050000o`3oool0oooo0?ooo`0000000`3oool0
0`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0180oooo103o000;0?ooo`070000o`3oool0
oooo0?l000000000oooo0?l000070?ooo`80o`006@3oool00`000?l0oooo0?ooo`0:0?ooo`80o`00
3@3oool40?l001l0oooo0P3o003o0?oooc/0oooo00<0003o0?ooo`3oool05P3oool00`000?l0oooo
0?ooo`050?ooo`030000o`3oool0oooo07<0oooo000k0?ooo`030?l0003oool0oooo01h0oooo103o
000:0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool07P3oool40?l000030000003o
ool0oooo00h0oooo103o000A0?ooo`030?l0003oool0oooo00D0oooo00@0003o0?ooo`3oool00000
0P3oool00`000?l0oooo0?ooo`050?ooo`80o`00403oool40?l000`0oooo00<0003o0?ooo`3oool0
0P3oool010000000o`000?l0003o00050?ooo`030?l0003oool0oooo01P0oooo00<0003o0?ooo`3o
ool03@3oool00`3o0000oooo0?ooo`080?ooo`@0o`007`3oool20?l00?l0oooo?P3oool00`000?l0
oooo0?ooo`0E0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0M03oool005h0oooo
0`3o00070?ooo`80o`00403oool00`000?l0oooo0?ooo`0K0?ooo`D0o`000P3oool00`000000oooo
0?ooo`020?ooo`030000o`3oool0oooo00/0oooo0`3o000>0?ooo`80o`00203oool01P000?l0oooo
0?ooo`000000oooo0000o`X0oooo00<0o`000?ooo`3oool0303oool30?l000d0oooo00<0003o0?oo
o`3oool00P3oool00`000000oooo0?ooo`040?l000030?ooo`3o0000o`0001X0oooo00<0003o0?oo
o`3oool05`3oool40?l00200oooo00<0o`000?ooo`3oool0o`3ooomF0?ooo`030000o`3oool0oooo
07/0oooo000n0?ooo`80o`007`3oool0103o0000oooo0?ooo`3o00030?ooo`80o`004`3oool00`00
0?l0oooo0?ooo`0J0?ooo`<0o`001@3oool00`000000oooo0?ooo`020?ooo`030000o`3oool0oooo
00/0oooo00@0o`000?ooo`3oool0o`002`3oool00`3o0000oooo0?ooo`090?ooo`050000o`3oool0
00000?ooo`000?l03@3oool00`3o0000oooo0?ooo`070?ooo`@0o`003@3oool00`000?l0oooo0?oo
o`020?ooo`030000003oool0oooo00<0oooo0`3o000L0?ooo`030000o`3oool0oooo0140oooo00@0
o`000?ooo`3oool0oooo103o000P0?ooo`80o`00o`3ooomI0?ooo`030000o`3oool0oooo07/0oooo
00100?ooo`80o`007`3oool50?l00300oooo103o00000`3oool0o`000?ooo`030?ooo`030000003o
ool0oooo00<0oooo00<0003o0?ooo`3oool0303oool30?l000P0oooo0P3o000>0?ooo`0300000000
0?l0oooo00h0oooo0P3o00060?ooo`<0o`003P3oool00`000?l0oooo0?ooo`030?ooo`030000003o
ool0oooo00<0oooo0P3o00030?ooo`030?l0003oool0oooo01H0oooo00<0003o0?ooo`3oool04`3o
ool60?l00200oooo00<0o`000?ooo`3oool0o`3ooomG0?ooo`<0003oO@3oool00200oooo@P00I005
0?l001H006@000<0003o001T0000I0009`00I0000`000?l006@0001T000<001T00@0o`005P00I000
0`000?l006@0001T000@001T00030?l00000I00006@002<006@01@3o000^001T00030?l00000I000
06@0048006@0o`3ooolk0?ooo`030000o`3oool0oooo07/0oooo00140?ooo`030?l0003oool0oooo
01X0oooo0P3o00020?ooo`040?l0003oool0oooo0?l001D0oooo00<0003o0?ooo`3oool04P3oool4
0?l000L0oooo00<0o`000?ooo`3oool05`3oool30?l000030?ooo`3o0000o`000140oooo00<0003o
000000000?l04`3oool40?l00100oooo00<0003o0?ooo`3oool00`3oool00`000000oooo0?ooo`02
0?l000D0oooo1P3o000C0?ooo`030000o`3oool0oooo01<0oooo103o000Q0?ooo`030?l0003oool0
oooo0?l0oooofP3oool004D0oooo0P3o000I0?ooo`030?l0003oool0oooo00@0oooo103o000C0?oo
o`030000o`3oool0oooo0100oooo103o000:0?ooo`80o`0000<0oooo0000003oool05@3oool40?l0
0140oooo00@0003o0?ooo`000000003o4P3oool40?l00100oooo00<0003o0?ooo`3oool00`3oool0
10000000oooo0?ooo`3o000;0?ooo`040?l0003oool0oooo0?l00100oooo00<0003o0?ooo`3oool0
4P3oool40?l000D0oooo0P3o000J0?ooo`80o`00o`3ooooM0?ooo`00A`3oool00`3o0000oooo0?oo
o`0D0?ooo`80o`00203oool40?l001<0oooo00<0003o0?ooo`3oool03P3oool30?l000h0oooo00<0
o`000?ooo`0000001@3oool00`000?l0oooo0?ooo`0<0?ooo`80o`0000@0oooo0?l0003o0000o`00
403oool01@000?l0oooo0000003oool0003o00l0oooo103o00000`3oool0o`000?l0000>0?ooo`03
0000o`3oool0oooo00@0oooo00<000000?l0003o00003P3oool30?l000h0oooo00<0003o0?ooo`3o
ool04P3oool40?l000P0oooo0P3o000F0?ooo`80o`00o`3ooooO0?ooo`00G03oool20?l000`0oooo
0`3o000Q0?ooo`@0o`004@3oool00`000000oooo0?ooo`040?ooo`030000o`3oool0oooo00T0oooo
0P3o00040?ooo`@0o`003@3oool010000?l0oooo0?ooo`00000@0?ooo`<0o`001@3oool00`3o0000
oooo0?ooo`0:0?ooo`030000o`3oool0oooo00@0oooo0P3o000A0?ooo`@0o`00303oool00`000?l0
oooo0?ooo`0@0?ooo`@0o`008@3oool00`3o0000oooo0?ooo`3o0?oooml0oooo001:0?ooo`030?l0
003oool0oooo00h0oooo00<0o`000?ooo`3oool03@3oool0103o0000oooo0?ooo`3o000M0?ooo`@0
o`00503oool00`000000o`000?ooo`030?ooo`030000o`3oool0oooo00L0oooo0P3o00080?ooo`<0
o`002`3oool01@000?l0oooo0?ooo`3oool0000000h0oooo103o000B0?ooo`030000o`3oool0oooo
00@0oooo00<0o`000000003oool04`3oool30?l000X0oooo00<0003o0?ooo`3oool0403oool30?l0
0100oooo00<0o`000?ooo`3oool03P3oool20?l00?l0oooohP3oool00200oooo0P3o000Y0?ooo`80
o`00303oool20?l00180oooo0`3o000B0?ooo`030000o`3oool0oooo00H0oooo0`3o000H0?ooo`80
o`000`3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00T0oooo00@0o`000?ooo`3o
0000o`00203oool00`000?l0oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000?l02@3oool3
0?l000/0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`80o`0000<00000
0?ooo`3oool0503oool00`3o0000oooo0?l000080?ooo`030000o`3oool0oooo00l0oooo103o000B
0?ooo`80o`003@3oool00`3o0000oooo0?ooo`0X0?ooo`030?l0003oool0oooo0?l0oooo]`3oool0
0280oooo0P3o000Y0?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool04`3oool40?l0
0140oooo00<0003o0?ooo`3oool00`3oool40?l001L0oooo00<000000?ooo`3oool02P3oool20?l0
00h0oooo1@3o00040?ooo`030000o`3oool0oooo00<0oooo00<000000?ooo`3oool00P3oool20000
o`D0oooo103o000=0?ooo`030?l0003oool0oooo00@0oooo00@0003o0?ooo`3oool0oooo0P3o0000
0`3oool000000?ooo`0G0?ooo`<0o`001P3oool00`000?l0oooo0?ooo`0>0?ooo`@0o`005P3oool0
0`3o0000oooo0?ooo`080?ooo`80o`00:@3oool20?l00?l0oooo^P3oool005H0oooo0P3o000H0?oo
o`<0o`004@3oool00`000?l0oooo0?ooo`040?l001X0oooo00<000000?ooo`3oool00P3oool0103o
0000oooo0?ooo`000?l20?ooo`030?l0003oool0oooo00h0oooo1P3o00030?ooo`030000o`3oool0
oooo00<0oooo0P0000050?ooo`030000o`3oool0oooo00@0o`00403oool20?l000<0oooo00D0003o
0?ooo`3oool0oooo0?l000030?ooo`030000003oool0oooo01L0oooo1@3o00020?ooo`030000o`3o
ool0oooo00h0oooo103o000P0?ooo`80o`00:@3oool20?l00?l0oooo:@3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0M`3oool002H0oooo00<0o`00
0?ooo`3oool09`3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo01T0oooo00@0o`00
0?ooo`3oool0o`004@3oool30?l001`0oooo00<000000?ooo`3oool00`3oool20?l000030?ooo`00
0?l0o`0001D0oooo00D0o`000?ooo`3oool0o`000000o`060?ooo`030000003oool0oooo00H0oooo
0`3o000D0?ooo`030?l0003oool0003o0080oooo0P3o00030?ooo`030000003oool0oooo01X0oooo
103o00000`000?l0oooo0?ooo`0=0?ooo`@0o`00703oool00`3o0000oooo0?ooo`020?ooo`030?l0
003oool0oooo02L0oooo0P3o003o0?ooobX0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo07H0oooo000W0?ooo`80o`00:03oool40?l001h0oooo1@3o
000<0?ooo`@0o`007P3oool00`000000oooo0?ooo`040?ooo`030?l000000?l0oooo01L0oooo0`3o
00060?ooo`030000003oool0oooo00@0oooo103o000F0?ooo`040000o`3oool0o`000?l000D0oooo
00<000000?ooo`3oool06`3oool50?l000d0oooo0`3o000O0?ooo`@0o`00:@3oool00`3o0000oooo
0?ooo`3o0?ooobX0oooo00<000000?ooo`3oool00P3oool2000000@0oooo00<000000?ooo`3oool0
1`3oool2000000@0oooo00<000000?ooo`3oool0MP3oool002T0oooo00<0o`000?ooo`3oool09@3o
ool30?l00200oooo1@3o00090?ooo`@0o`0000<0003o0?ooo`3oool08P3oool20?l00080oooo00<0
003o0?ooo`3oool05@3oool00`000?l0o`000?l000020?l000@0oooo00<000000?ooo`3oool00P3o
ool40?l000030000o`3oool0oooo01@0oooo00@0003o0?ooo`3o0000oooo0P3o00030?ooo`030000
003oool0oooo01h0oooo00@0003o0?l0003o0000o`002P3oool40?l00200oooo0`3o000X0?ooo`80
o`00=@3oool5000000<0oooo100000030?ooo`D000000P3oool5000000<0oooo1@0000020?ooo`D0
00000`3oool500000080oooo1@0000030?ooo`@000000`3oool5000000<0oooo100000030?ooo`D0
00000`3oool4000000<0oooo1@0000020?ooo`D000000`3oool500000080oooo1@0000030?ooo`@0
00000`3oool5000000<0oooo100000030?ooo`D000000`3oool4000000<0oooo1@0000020?ooo`D0
00000`3oool500000080oooo00<000000?ooo`3oool0>P3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0
oooo07H0oooo001@0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool07P3oool30?l0
00L0oooo0`3o00020?ooo`030000o`3oool0oooo0200oooo0P3o00050?ooo`030?l0003oool0oooo
01<0oooo00@0003o0?ooo`3oool0oooo0`3o00030?ooo`040000003oool0oooo0?ooo`<0o`000`3o
ool00`000?l0oooo0?ooo`0B0?ooo`030000o`3o0000o`0000@0oooo00@0o`000?ooo`3oool00000
7`3oool010000?l0oooo0?ooo`3o00020?ooo`030?l0003oool0oooo00D0oooo0`3o000Q0?ooo`03
0?l0003oool0oooo02L0oooo0P3o003o0?ooobh0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0:0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0M@3oool002`0
oooo0P3o000P0?ooo`80o`001`3oool20?l001l0oooo103o00030?ooo`@0o`00103oool00`000?l0
oooo0?ooo`0N0?ooo`030000003oool0oooo00H0oooo0P3o00090?ooo`800000103oool01@000000
oooo0?ooo`3oool0003o00<0000000P0oooo0?l0003oool0oooo0?l0003oool000000?ooo`@0o`00
103oool00`000?l0oooo0?ooo`0A0?ooo`80o`00203oool00`000000oooo0?ooo`0M0?ooo`030000
o`3oool0oooo00<0oooo0`3o00040?ooo`@0o`00803oool20?l000H0oooo0P3o000P0?ooo`80o`00
o`3ooola0?ooo`030000003oool0oooo0080oooo0P00000=0?ooo`040000003oool0oooo000000<0
oooo00<000000?ooo`3oool0MP3oool002h0oooo0P3o000M0?ooo`030?l0003oool0oooo00T0oooo
00<0o`000?ooo`3oool07P3oool70?l000L0oooo00<0003o0?ooo`3oool06`3oool20?l000030000
003oool0oooo00L0oooo00<0003o0?l0003o00001P3oool010000000oooo0?ooo`0000060?ooo`03
0000o`3oool0oooo0080oooo00<000000?ooo`3oool01`3o00070?ooo`030000o`3oool0oooo00l0
oooo00<0o`000000o`3oool0203oool00`000000o`000?l0000M0?ooo`030000o`3oool0oooo00@0
oooo203o000P0?ooo`80o`002P3oool20?l001d0oooo00<0o`000?ooo`3oool0o`3ooola0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`0000030?oo
o`030000003oool0oooo07H0oooo000`0?ooo`030?l0003oool0oooo01P0oooo0P3o000^0?ooo`@0
o`002P3oool00`000?l0oooo0?ooo`0I0?ooo`050?l0003oool0oooo0?ooo`0000002@3oool00`00
0?l0oooo0?l000050?ooo`040000003oool0oooo000000D0oooo00<0003o0?ooo`3oool00`3oool0
10000000oooo0?ooo`3oool40?l000030000003oool0oooo01H0oooo0P3o00000`000?l0oooo0?oo
o`070?ooo`050000003oool0oooo0?ooo`3o00006`3oool00`000?l0oooo0?ooo`070?ooo`@0o`00
803oool20?l000h0oooo0P3o000I0?ooo`80o`00o`3ooole0?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
07L0oooo002k0?ooo`040000003oool0oooo000000P0oooo0`00003o0?ooon40oooo0P00000>0?oo
o`800000O@3oool00;/0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`3o0?oo
ool0ooooL@3oool00;/0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`3o0?oo
ool0ooooL@3oool00;`0oooo0P0000090?ooo`@00000o`3ooooo0?ooog00oooo003o0?ooool0oooo
o`3oooll0?ooo`00o`3ooooo0?ooool0oooo?03oool00?l0ooooo`3ooooo0?oooc`0oooo003o0?oo
ool0ooooo`3oooll0?ooo`00o`3ooooo0?ooool0oooo?03oool00?l0ooooo`3ooooo0?oooc`0oooo
003o0?ooool0ooooo`3oooll0?ooo`00o`3ooooo0?ooool0oooo?03oool00001\
\>"],
  ImageRangeCache->{{{0, 824}, {241.75, 0}} -> {-0.0532714, -0.0147151, \
0.00255649, 0.00255649}, {{20.8125, 393.312}, {235.938, 5.75}} -> {-1.78007, \
-2.66971, 0.00853494, 0.0138098}, {{430.625, 803.125}, {235.938, 5.75}} -> \
{-0.656263, -0.77782, 0.00268492, 0.0477873}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  GraphicsArray  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
},
FrontEndVersion->"5.1 for X",
ScreenRectangle->{{0, 1600}, {0, 1200}},
WindowSize->{971, 1110},
WindowMargins->{{Automatic, 44}, {Automatic, 27}},
Visible->True,
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"PaperSize"->{597.562, 842.375},
"PaperOrientation"->"Portrait",
"PostScriptOutputFile":>FrontEnd`FileName[{$RootDirectory, "home", "rok"}, \
"SW_TQD.ps", CharacterEncoding -> "iso8859-1"],
"Magnification"->1},
ShowSelection->True,
InputAliases->{"intt"->RowBox[ {"\[Integral]", 
        RowBox[ {"\[SelectionPlaceholder]", 
          RowBox[ {"\[DifferentialD]", "\[Placeholder]"}]}]}], 
    "dintt"->RowBox[ {
        SubsuperscriptBox[ 
        "\[Integral]", "\[SelectionPlaceholder]", "\[Placeholder]"], 
        RowBox[ {"\[Placeholder]", 
          RowBox[ {"\[DifferentialD]", "\[Placeholder]"}]}]}], 
    "sumt"->RowBox[ {
        UnderoverscriptBox[ "\[Sum]", 
          RowBox[ {"\[SelectionPlaceholder]", "=", "\[Placeholder]"}], 
          "\[Placeholder]"], "\[Placeholder]"}], "prodt"->RowBox[ {
        UnderoverscriptBox[ "\[Product]", 
          RowBox[ {"\[SelectionPlaceholder]", "=", "\[Placeholder]"}], 
          "\[Placeholder]"], "\[Placeholder]"}], "dt"->RowBox[ {
        SubscriptBox[ "\[PartialD]", "\[Placeholder]"], " ", 
        "\[SelectionPlaceholder]"}], "notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {"\"\[Placeholder]\"", "\[Rule]", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
Magnification->1,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Title"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Color"->RGBColor[0.269993, 0.308507, 0.6]},
    CellLabelMargins->{{12, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    CellLabelMargins->{{24, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->12],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellLabelMargins->{{8, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->8],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    CellLabelMargins->{{2, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->5,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{27, Inherited}, {10, 30}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    LineSpacing->{1, 11},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{27, 10}, {10, 30}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {12, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{27, Inherited}, {20, 2}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{27, 10}, {20, 2}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{27, Inherited}, {8, 2}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->16],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {20, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 8}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellFrame->{{0, 0}, {0, 1}},
    CellMargins->{{27, Inherited}, {8, 34}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->4,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    LineSpacing->{1, 2},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->20,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{2, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{60, Inherited}, {8, 12}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{60, Inherited}, {2, 10}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{60, 10}, {7, 7}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    Hyphenation->True,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{60, 10}, {6, 6}},
    DefaultNewInlineCellStyle->"None",
    LineSpacing->{1, 3},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    TextJustification->0.5,
    Hyphenation->True,
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names. Some attributes for these styles are actually set in FormatType Styles \
(in the last section of this stylesheet). \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{66, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Mathematica",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}},
    FontSize->11],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InputOnly"],
    CellMargins->{{66, 10}, {7, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Mathematica",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["InputOnly", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["InputOnly", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}},
    FontSize->11],
  
  Cell[StyleData["InputOnly", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{66, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Output"],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}},
    FontSize->11],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{66, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    AutoStyleOptions->{"UnmatchedBracketStyle"->None},
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->RGBColor[0.6, 0.100008, 0.100008]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}},
    FontSize->11],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->7,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{66, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}},
    FontSize->11],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageMargins->{{38, Inherited}, {Inherited, 0}},
    Magnification->0.6],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    Magnification->0.8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    LanguageCategory->None,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0.269993, 0.308507, 0.6]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FrameLabel"],
    LanguageCategory->None,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["FrameLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["FrameLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["FrameLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Section"],
  
  Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.\
\>", "Text"],
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["BF"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["IT"],
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["TB"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TBI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MR"],
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MO"],
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MB"],
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MBO"],
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SR"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SB"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SBO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{60, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{60, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->False,
    LanguageCategory->"Formula",
    ScriptLevel->1,
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["Program", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{2, 0}, {6, 6}},
    FontSize->9]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Outline Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline1"],
    CellMargins->{{60, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 50},
    ParagraphIndent->-38,
    CounterIncrements->"Outline1",
    FontSize->18,
    FontWeight->"Bold",
    CounterBoxOptions->{
    CounterFunction:>Utilities`Notation`Private`CapitalRomanNumeral}],
  
  Cell[StyleData["Outline1", "Printout"],
    CounterBoxOptions->{
    CounterFunction:>Utilities`Notation`Private`CapitalRomanNumeral}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline2"],
    CellMargins->{{90, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 60},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontSize->15,
    FontWeight->"Bold",
    CounterBoxOptions->{CounterFunction:>(Part[ 
        CharacterRange[ "A", "Z"], #]&)}],
  
  Cell[StyleData["Outline2", "Printout"],
    CounterBoxOptions->{CounterFunction:>(Part[ 
        CharacterRange[ "A", "Z"], #]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline3"],
    CellMargins->{{120, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-21,
    CounterIncrements->"Outline3",
    FontSize->12,
    CounterBoxOptions->{CounterFunction:>Identity}],
  
  Cell[StyleData["Outline3", "Printout"],
    CounterBoxOptions->{CounterFunction:>Identity}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline4"],
    CellMargins->{{150, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 80},
    ParagraphIndent->-18,
    CounterIncrements->"Outline4",
    FontSize->10,
    CounterBoxOptions->{CounterFunction:>(Part[ 
        CharacterRange[ "a", "z"], #]&)}],
  
  Cell[StyleData["Outline4", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Hyperlink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["MainBookLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["AddOnsLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["RefGuideLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLinkText"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLinkText", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["RefGuideLinkText", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["RefGuideLinkText", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["GettingStartedLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DemosLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "Demos", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["DemosLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TourLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "Tour", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["TourLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["OtherInformationLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MasterIndexLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MasterIndex", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MasterIndexLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    DefaultNewInlineCellStyle->"None",
    LanguageCategory->"NaturalLanguage",
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    DefaultNewInlineCellStyle->"None",
    LanguageCategory->"NaturalLanguage",
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, Placeholder]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Placeholder->True,
    StyleMenuListing->None,
    FontSlant->"Italic",
    FontColor->RGBColor[0.890623, 0.864698, 0.384756],
    TagBoxOptions->{Editable->False,
    Selectable->False,
    StripWrapperBoxes->False}],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PrimaryPlaceholder"],
    StyleMenuListing->None,
    DrawHighlighted->True,
    FontSlant->"Italic",
    Background->RGBColor[0.912505, 0.891798, 0.507774],
    TagBoxOptions->{Editable->False,
    Selectable->False,
    StripWrapperBoxes->False}],
  
  Cell[StyleData["PrimaryPlaceholder", "Presentation"]],
  
  Cell[StyleData["PrimaryPlaceholder", "Condensed"]],
  
  Cell[StyleData["PrimaryPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options. This is particularly true of Input and Output.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    Hyphenation->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    InputAutoReplacements->{},
    AllowInlineCells->False,
    Hyphenation->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{0.6, 1},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    LanguageCategory->"Formula",
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Automatic Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are used to affect the display \
of certain types of objects in typeset expressions.  For example, \
\"UnmatchedBracket\" style defines how unmatched bracket, curly bracket, and \
parenthesis characters are displayed (typically by coloring them to make them \
stand out).\
\>", "Text"],
  
  Cell[StyleData["UnmatchedBracket"],
    StyleMenuListing->None,
    FontColor->RGBColor[0.760006, 0.330007, 0.8]],
  
  Cell[StyleData["Completions"],
    StyleMenuListing->None,
    FontFamily->"Courier"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles from HelpBrowser", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MathCaption"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{66, 12}, {2, 24}},
    PageBreakBelow->False,
    CellFrameMargins->{{8, 8}, {8, 2}},
    CellFrameColor->GrayLevel[0.700008],
    CellFrameLabelMargins->4,
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None,
    FontColor->GrayLevel[0.2]],
  
  Cell[StyleData["MathCaption", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["MathCaption", "Printout"],
    CellMargins->{{39, 0}, {0, 14}},
    Hyphenation->True,
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectName"],
    ShowCellBracket->True,
    CellMargins->{{66, 4}, {8, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Mathematica",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ObjectName", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Usage"],
    ShowCellBracket->True,
    CellMargins->{{66, 4}, {8, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Mathematica",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["Usage", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Usage", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Notes"],
    ShowCellBracket->True,
    CellMargins->{{66, 4}, {8, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Mathematica",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["Notes", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Notes", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineOutput"],
    ShowCellBracket->True,
    CellMargins->{{66, 4}, {8, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Mathematica",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["InlineOutput", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["InlineOutput", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Emphasis Boxes and Pictures", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Box"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["Box", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Box", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DoubleBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnSpacings->2,
    RowAlignments->Top}],
  
  Cell[StyleData["DoubleBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["DoubleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["1ColumnBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["1ColumnBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["1ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    SingleLetterItalics->False,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->{0.31, 0.67}}],
  
  Cell[StyleData["2ColumnBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["2ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->0.46}],
  
  Cell[StyleData["2ColumnEvenBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["2ColumnEvenBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnSmallBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.35,
    ColumnAlignments->{Right, Left}}],
  
  Cell[StyleData["2ColumnSmallBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["2ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->0.32}],
  
  Cell[StyleData["3ColumnBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["3ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnSmallBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.24,
    ColumnAlignments->{Right, Center, Left}}],
  
  Cell[StyleData["3ColumnSmallBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["3ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["4ColumnBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    SingleLetterItalics->False,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->{0.13, 0.35, 0.13, 0.35}}],
  
  Cell[StyleData["4ColumnBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["4ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["5ColumnBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->0.202}],
  
  Cell[StyleData["5ColumnBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["5ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["6ColumnBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->{0.12, 0.22, 0.12, 0.12, 0.22, 0.12}}],
  
  Cell[StyleData["6ColumnBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["6ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FramedBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["FramedBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["FramedBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.4, 0.6},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["DefinitionBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox3Col"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.35, 0.2, 0.45},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox3Col", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["DefinitionBox3Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox4Col"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.15, 0.35, 0.15, 0.35},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox4Col", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["DefinitionBox4Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox5Col"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->0.2,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox5Col", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["DefinitionBox5Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox6Col"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.13, 0.24, 0.13, 0.13, 0.24, 0.13},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox6Col", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["DefinitionBox6Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["TopBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{27, 12}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakAbove->False,
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["MiddleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 2}},
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BottomBox"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{27, 12}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakAbove->False,
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["BottomBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["BottomBox", "Printout"],
    CellMargins->{{2, 0}, {0, -5}},
    FontSize->10,
    Background->GrayLevel[1],
    GridBoxOptions->{RowMinHeight->2.2}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{27, 12}, {-2, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopSpanBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["TopSpanBox", "Printout"],
    CellMargins->{{2, 0}, {-2, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{27, 12}, {0, 0}},
    CellHorizontalScrolling->True,
    PageBreakAbove->False,
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleSpanBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["MiddleSpanBox", "Printout"],
    CellMargins->{{2, 0}, {-5, 0}},
    FontSize->10,
    Background->GrayLevel[1],
    GridBoxOptions->{RowMinHeight->1.8}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Picture"],
    CellMargins->{{27, Inherited}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Picture", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Picture", "Printout"],
    CellMargins->{{2, Inherited}, {4, 4}},
    Magnification->0.65]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OpenCloseItemizedPicture"],
    CellMargins->{{88, 4}, {4, 4}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["OpenCloseItemizedPicture", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["OpenCloseItemizedPicture", "Printout"],
    CellMargins->{{76, 2}, {0, 0}},
    CellElementSpacings->{"CellMinHeight"->1,
    "ClosedCellHeight"->0},
    CellOpen->False]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedPicture"],
    CellMargins->{{88, 4}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedPicture", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ItemizedPicture", "Printout"],
    CellMargins->{{77, 2}, {4, -4}},
    Magnification->0.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ListGraphic"],
    CellMargins->{{88, 4}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ListGraphic", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ListGraphic", "Printout"],
    CellMargins->{{77, 2}, {4, -4}},
    Magnification->0.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ListNoteBox"],
    CellFrame->0.5,
    CellMargins->{{88, 12}, {8, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["ListNoteBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ListNoteBox", "Printout"],
    CellMargins->{{77, 4}, {6, 2}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureGroup"],
    CellMargins->{{41, 4}, {0, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureGroup", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["PictureGroup", "Printout"],
    CellMargins->{{76, 2}, {0, 0}},
    CellElementSpacings->{"CellMinHeight"->1,
    "ClosedCellHeight"->0},
    CellOpen->False]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Sound"],
    ShowCellBracket->True,
    CellMargins->{{27, Inherited}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Sound", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Sound", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Tables", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnTable"],
    CellMargins->{{35, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.34, 0.64},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnTable", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["2ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenTable"],
    CellMargins->{{35, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->0.49,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnEvenTable", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["2ColumnEvenTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnTable"],
    CellMargins->{{35, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.28, 0.28, 0.43},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["3ColumnTable", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["3ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9]
  }, Closed]]
  }, Closed]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation \
package. These styles serve to make visible otherwise invisible \
tagboxes.\
\>", "Text",
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"]
  }, Closed]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 195, 5, 68, "Text"],

Cell[CellGroupData[{
Cell[1974, 60, 51, 1, 27, "Input"],
Cell[2028, 63, 92, 1, 23, "Print"],
Cell[2123, 66, 81, 1, 23, "Print"],
Cell[2207, 69, 104, 2, 27, "Output"]
}, Open  ]],
Cell[2326, 74, 117, 2, 43, "Input"],
Cell[2446, 78, 178, 3, 59, "Input"],
Cell[2627, 83, 55, 1, 27, "Input"],
Cell[2685, 86, 10392, 249, 568, "Input"],
Cell[13080, 337, 185, 3, 43, "Input"],
Cell[13268, 342, 38, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[13331, 346, 626, 10, 123, "Input"],
Cell[13960, 358, 483, 7, 44, "Output"],
Cell[14446, 367, 483, 7, 44, "Output"],
Cell[14932, 376, 483, 7, 44, "Output"],
Cell[15418, 385, 360, 6, 29, "Output"],
Cell[15781, 393, 360, 6, 29, "Output"],
Cell[16144, 401, 564, 8, 29, "Output"],
Cell[16711, 411, 2704, 41, 137, "Output"]
}, Open  ]],
Cell[19430, 455, 96, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[19551, 462, 258, 6, 92, "Input"],
Cell[19812, 470, 3244, 44, 226, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23093, 519, 463, 9, 123, "Input"],
Cell[23559, 530, 1984, 28, 118, "Output"],
Cell[25546, 560, 1272, 17, 94, "Output"],
Cell[26821, 579, 1090, 17, 68, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27948, 601, 812, 16, 203, "Input"],
Cell[28763, 619, 224, 3, 29, "Output"],
Cell[28990, 624, 6127, 100, 292, "Output"],
Cell[35120, 726, 2280, 43, 280, "Output"],
Cell[37403, 771, 155, 2, 44, "Output"],
Cell[37561, 775, 36, 1, 27, "Output"]
}, Open  ]],
Cell[37612, 779, 1116, 19, 251, "Input"],
Cell[38731, 800, 204, 4, 59, "Input"],
Cell[38938, 806, 764, 13, 155, "Input"],

Cell[CellGroupData[{
Cell[39727, 823, 45, 1, 27, "Input"],
Cell[39775, 826, 307, 9, 29, "Print"],
Cell[40085, 837, 73, 1, 40, "Print"],
Cell[40161, 840, 39, 1, 23, "Print"],
Cell[40203, 843, 16196, 412, 186, 3449, 250, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[56436, 1260, 47, 1, 27, "Input"],
Cell[56486, 1263, 444, 11, 79, "Print"],
Cell[56933, 1276, 118, 2, 40, "Print"],
Cell[57054, 1280, 80, 1, 23, "Print"],
Cell[57137, 1283, 20311, 563, 186, 5003, 369, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[77485, 1851, 46, 1, 27, "Input"],
Cell[77534, 1854, 814, 19, 195, "Print"],
Cell[78351, 1875, 646, 11, 101, "Print"],
Cell[79000, 1888, 162, 3, 23, "Print"],
Cell[79165, 1893, 22055, 629, 186, 5942, 426, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[101257, 2527, 64, 1, 27, "Input"],
Cell[101324, 2530, 444, 11, 79, "Print"],
Cell[101771, 2543, 130, 2, 40, "Print"],
Cell[101904, 2547, 87, 1, 23, "Print"],
Cell[101994, 2550, 18246, 492, 186, 4271, 315, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[120277, 3047, 88, 2, 43, "Input"],
Cell[120368, 3051, 1001, 20, 303, "Print"],
Cell[121372, 3073, 273, 4, 77, "Print"],
Cell[121648, 3079, 215, 4, 23, "Print"],
Cell[121866, 3085, 17020, 607, 186, 6666, 475, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[138923, 3697, 70, 1, 27, "Input"],
Cell[138996, 3700, 288, 9, 24, "Print"],
Cell[139287, 3711, 36, 1, 23, "Print"],
Cell[139326, 3714, 38, 1, 23, "Print"],
Cell[139367, 3717, 27833, 1282, 186, 17616, 1151, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[167237, 5004, 69, 1, 27, "Input"],
Cell[167309, 5007, 792, 18, 195, "Print"],
Cell[168104, 5027, 646, 11, 101, "Print"],
Cell[168753, 5040, 162, 3, 23, "Print"],
Cell[168918, 5045, 23990, 654, 186, 5961, 427, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[192945, 5704, 87, 1, 27, "Input"],
Cell[193035, 5707, 424, 11, 79, "Print"],
Cell[193462, 5720, 130, 2, 40, "Print"],
Cell[193595, 5724, 87, 1, 23, "Print"],
Cell[193685, 5727, 22037, 539, 186, 4304, 316, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[215759, 6271, 70, 1, 27, "Input"],
Cell[215832, 6274, 424, 11, 79, "Print"],
Cell[216259, 6287, 118, 2, 40, "Print"],
Cell[216380, 6291, 80, 1, 23, "Print"],
Cell[216463, 6294, 20691, 568, 186, 5027, 370, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[237191, 6867, 72, 1, 27, "Input"],
Cell[237266, 6870, 307, 9, 29, "Print"],
Cell[237576, 6881, 59, 1, 40, "Print"],
Cell[237638, 6884, 39, 1, 23, "Print"],
Cell[237680, 6887, 16336, 414, 186, 3476, 251, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[254053, 7306, 129, 3, 27, "Input"],
Cell[254185, 7311, 40642, 1124, 257, 22992, 902, "GraphicsData", \
"PostScript", "Graphics"],
Cell[294830, 8437, 130, 3, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[294997, 8445, 145, 3, 27, "Input"],
Cell[295145, 8450, 72769, 2225, 186, 23936, 1618, "GraphicsData", \
"PostScript", "Graphics"],
Cell[367917, 10677, 130, 3, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[368084, 10685, 78, 1, 27, "Input"],
Cell[368165, 10688, 125926, 3512, 251, 47193, 2536, "GraphicsData", \
"PostScript", "Graphics"],
Cell[494094, 14202, 135, 3, 27, "Output"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

